<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:pharm="urn:ihe:pharm:medication"
                xmlns:sdtc="urn:hl7-org:sdtc"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title=" Schematron file for  - ASIC "
                              schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="hl7"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="cda"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:ihe:pharm:medication" prefix="pharm"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:sdtc" prefix="sdtc"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M8"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">ASIC</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M9"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009</xsl:attribute>
            <xsl:attribute name="name">Anwendungsfall ASIC</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M10"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009-closed</xsl:attribute>
            <xsl:attribute name="name">Anwendungsfall ASIC</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M11"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.201-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA Section</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M73"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.301-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA Act</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M74"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.302-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA Encounter</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M75"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.303-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA Observation</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M76"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.304-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA ObservationMedia</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M77"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.305-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA Organizer</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M78"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.306-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA Procedure</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M79"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.307-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA RegionOfInterest</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M80"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.308-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA SubstanceAdministration</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M81"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.10.12.309-2005-09-07T000000</xsl:attribute>
            <xsl:attribute name="name">CDA Supply</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M82"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300</xsl:attribute>
            <xsl:attribute name="name">Template Messwertkategorie</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M83"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551</xsl:attribute>
            <xsl:attribute name="name">Dok3 Niere</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M84"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636</xsl:attribute>
            <xsl:attribute name="name">Leber Pankreas</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M85"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058</xsl:attribute>
            <xsl:attribute name="name">Messwert: Leber Pankreas</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M86"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412</xsl:attribute>
            <xsl:attribute name="name">Messwert: Leber Pankreas</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M87"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001</xsl:attribute>
            <xsl:attribute name="name">Messwerte: Pankreas Leber</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M88"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851</xsl:attribute>
            <xsl:attribute name="name">Messwerte: Pankreas Leber</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M89"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523</xsl:attribute>
            <xsl:attribute name="name">Niere (Werte aus Gesamt-ValueSet)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M90"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341</xsl:attribute>
            <xsl:attribute name="name">Niere (Werte aus Gesamt-ValueSet)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M91"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307</xsl:attribute>
            <xsl:attribute name="name">Dok1 Moegliche Messwerte</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M92"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745</xsl:attribute>
            <xsl:attribute name="name">Dok1 Messwerte</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M93"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014</xsl:attribute>
            <xsl:attribute name="name">Dok2 Messwerte</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M94"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139</xsl:attribute>
            <xsl:attribute name="name">Dok2 Messwertauswahl</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M95"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101</xsl:attribute>
            <xsl:attribute name="name">Dok3 Messwerte</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M96"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941</xsl:attribute>
            <xsl:attribute name="name">Dok3 Pankreas Leber</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M97"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525</xsl:attribute>
            <xsl:attribute name="name">Messwert: ASAT</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M98"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648</xsl:attribute>
            <xsl:attribute name="name">Messwert: ALAT</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M99"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837</xsl:attribute>
            <xsl:attribute name="name">Messwert: Alkalische Phosphatase</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M100"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956</xsl:attribute>
            <xsl:attribute name="name">Messwert: Gamma Glutamyl</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M101"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952</xsl:attribute>
            <xsl:attribute name="name">Dok3 kleines Blutbild</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M102"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135</xsl:attribute>
            <xsl:attribute name="name">Dok3 Sepsis</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M103"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241</xsl:attribute>
            <xsl:attribute name="name">Dok3 Sonstiges</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M104"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439</xsl:attribute>
            <xsl:attribute name="name">Dok3 unbekannt</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M105"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811</xsl:attribute>
            <xsl:attribute name="name">Dok3 kleines Blutbild ?</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M106"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423</xsl:attribute>
            <xsl:attribute name="name">Dok4 Messwerte</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M107"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627</xsl:attribute>
            <xsl:attribute name="name">Dok4 Messwerte</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M108"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335</xsl:attribute>
            <xsl:attribute name="name">Dok4 Messwert Organizer</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M109"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053</xsl:attribute>
            <xsl:attribute name="name">ASIC Messwerte</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M110"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226</xsl:attribute>
            <xsl:attribute name="name">ASIC Beatmungsparameter</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M111"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614</xsl:attribute>
            <xsl:attribute name="name">ASIC Blutgasanalyse</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M112"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657</xsl:attribute>
            <xsl:attribute name="name">ASIC Sauerstoffsättigung</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M113"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427</xsl:attribute>
            <xsl:attribute name="name">CDA Section t</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M114"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904</xsl:attribute>
            <xsl:attribute name="name">ASIC weitere Vitaldaten</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M115"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443</xsl:attribute>
            <xsl:attribute name="name">ASIC Einschlusskriterien</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M116"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612</xsl:attribute>
            <xsl:attribute name="name">ASIC Ausschlusskriterien</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M117"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717</xsl:attribute>
            <xsl:attribute name="name">ASIC radiologische Befunde</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M118"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801</xsl:attribute>
            <xsl:attribute name="name">ASIC Lungenoedem</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M119"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919</xsl:attribute>
            <xsl:attribute name="name">ASIC adjunktiv/supportive Maßnahmen</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M120"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137</xsl:attribute>
            <xsl:attribute name="name">ASIC ECMO</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M121"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214</xsl:attribute>
            <xsl:attribute name="name">ASIC Medikamente</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M122"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326</xsl:attribute>
            <xsl:attribute name="name">ASIC Patienten-Bewegungsdaten</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M123"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413</xsl:attribute>
            <xsl:attribute name="name">ASIC Outcome Parameter</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M124"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351</xsl:attribute>
            <xsl:attribute name="name">CDA Observation t</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M125"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139</xsl:attribute>
            <xsl:attribute name="name">ASIC Horowitz Quotient</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M126"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233</xsl:attribute>
            <xsl:attribute name="name">ASIC adjunktiv supportive Maßnahmen</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M127"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422</xsl:attribute>
            <xsl:attribute name="name">Template Messwerte: Adipositas</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M128"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721</xsl:attribute>
            <xsl:attribute name="name">Messwert: Harnstoff</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M129"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812</xsl:attribute>
            <xsl:attribute name="name">Messwert: Kreatinin</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M130"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl"> Schematron file for  - ASIC </svrl:text>

   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*" mode="M8"/>
   </xsl:template>

   <!--PATTERN ASIC-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC</svrl:text>

	  <!--RULE -->
   <xsl:template match="/" priority="1000" mode="M9">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Instance is expected to have the following element: descendant-or-self::hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M9"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*" mode="M9"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009Anwendungsfall ASIC-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Anwendungsfall ASIC</svrl:text>

	  <!--RULE d19e5365-false-d12451096e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]"
                 priority="1052"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCCLIN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCCLIN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von classCode MUSS 'DOCCLIN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.1']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.1']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.1'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.1']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.1']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.1'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:recordTarget[hl7:patientRole]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:recordTarget[hl7:patientRole]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:recordTarget[hl7:patientRole] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:author[hl7:assignedAuthor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:author[hl7:assignedAuthor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:author[hl7:assignedAuthor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime[not(@nullFlavor)]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime[not(@nullFlavor)]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:effectiveTime[not(@nullFlavor)] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime[not(@nullFlavor)]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime[not(@nullFlavor)]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:effectiveTime[not(@nullFlavor)] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:custodian[hl7:assignedCustodian]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:custodian[hl7:assignedCustodian]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:custodian[hl7:assignedCustodian] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:custodian[hl7:assignedCustodian]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:custodian[hl7:assignedCustodian]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:custodian[hl7:assignedCustodian] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[@contextConductionInd][hl7:structuredBody]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[@contextConductionInd][hl7:structuredBody]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[@contextConductionInd][hl7:structuredBody] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[@contextConductionInd][hl7:structuredBody]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[@contextConductionInd][hl7:structuredBody]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[@contextConductionInd][hl7:structuredBody] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d19e5371-false-d12451350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040']"
                 priority="1051"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.1.3')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.1.3')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von root MUSS '2.16.840.1.113883.1.3' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@extension) = ('POCD_HD000040')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@extension) = ('POCD_HD000040')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von extension MUSS 'POCD_HD000040' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@extension"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@extension) or string-length(@extension)&gt;0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@extension) or string-length(@extension)&gt;0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @extension MUSS vom Datentyp 'st' sein  - '<xsl:text/>
                  <xsl:value-of select="@extension"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d19e5378-false-d12451373e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.1']"
                 priority="1050"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von root MUSS '2.16.840.1.113883.10.12.1' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d19e5383-false-d12451388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:id"
                 priority="1049"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d19e5386-false-d12451400e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1048"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d19e5391-false-d12451417e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:title"
                 priority="1047"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e27-false-d12451429e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]"
                 priority="1046"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('RCT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('RCT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Der Wert von typeCode MUSS 'RCT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:patientRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:patientRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:patientRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:patientRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:patientRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:patientRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e33-false-d12451454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole"
                 priority="1045"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PAT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PAT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Der Wert von classCode MUSS 'PAT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:patient) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:patient) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:patient kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e37-false-d12451479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:id"
                 priority="1044"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e39-false-d12451490e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:patient"
                 priority="1043"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:name) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:name) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:name ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:name) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:name) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:name kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e45-false-d12451539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:patient/hl7:id"
                 priority="1042"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e47-false-d12451550e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:patient/hl7:name"
                 priority="1041"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.1-EN: entity name shall not be null and have elements or text</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.2-EN: entity name shall not have both elements and text (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.3-EN: entity name that is not null shall not be empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-3-EN: empty name particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="substring(normalize-space(.),1,1)='&#34;'">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-EN: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-EN: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-EN: enxp elements SHALL have distinct values in @qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*[tokenize(@qualifier,'\s')='LS'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(*[tokenize(@qualifier,'\s')='LS'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PN: Person names SHALL NOT contain a name part qualified with 'LS' (Legal status for organizations)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PN" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e54-false-d12451588e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:patient/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1040"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451418e60-false-d12451610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:patient/hl7:birthTime"
                 priority="1039"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e31-false-d12451633e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]"
                 priority="1038"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e37-false-d12451689e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1037"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e42-false-d12451711e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:time"
                 priority="1036"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e44-false-d12451733e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1035"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e48-false-d12451782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:id"
                 priority="1034"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e50-false-d12451794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1033"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e55-false-d12451811e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:addr"
                 priority="1032"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451611e57-false-d12451822e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:telecom"
                 priority="1031"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1030"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1029"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1028"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1027"
                 mode="M10">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1026"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12451846e116-false-d12452119e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:effectiveTime[not(@nullFlavor)]"
                 priority="1025"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{14,14}')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or matches(@value, '^[0-9]{14,14}')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS.DATETIME.MIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS.DATETIME.MIN: null or date precision of time stamp shall be at least YYYYMMDDhhmmss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-1.2.276.0.76.10.90006-2012-12-12T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAeffectiveTime): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-1.2.276.0.76.10.90006-2012-12-12T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAeffectiveTime): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS.DATETIME.MIN, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452120e34-false-d12452134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:setId"
                 priority="1024"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.34-2018-05-02T150922.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAsetIdversionNumber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452120e36-false-d12452145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:versionNumber"
                 priority="1023"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value &gt; 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value &gt; 0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II.POS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT.POS: null or value &gt; 0</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.34-2018-05-02T150922.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAsetIdversionNumber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.34-2018-05-02T150922.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAsetIdversionNumber): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452146e27-false-d12452160e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]"
                 priority="1022"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('CST') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('CST') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Der Wert von typeCode MUSS 'CST' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedCustodian[hl7:representedCustodianOrganization]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedCustodian[hl7:representedCustodianOrganization]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:assignedCustodian[hl7:representedCustodianOrganization] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedCustodian[hl7:representedCustodianOrganization]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedCustodian[hl7:representedCustodianOrganization]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:assignedCustodian[hl7:representedCustodianOrganization] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452146e31-false-d12452181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]"
                 priority="1021"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedCustodianOrganization) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedCustodianOrganization) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:representedCustodianOrganization ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedCustodianOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedCustodianOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:representedCustodianOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452146e35-false-d12452202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]/hl7:representedCustodianOrganization"
                 priority="1020"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id[not(@nullFlavor)]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:id[not(@nullFlavor)]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:id[not(@nullFlavor)] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:name) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:name) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:name kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:telecom) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:telecom) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:telecom kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:addr) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:addr) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Element hl7:addr kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452146e41-false-d12452245e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]/hl7:representedCustodianOrganization/hl7:id[not(@nullFlavor)]"
                 priority="1019"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452146e43-false-d12452256e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]/hl7:representedCustodianOrganization/hl7:name"
                 priority="1018"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.1-EN: entity name shall not be null and have elements or text</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.2-EN: entity name shall not have both elements and text (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.3-EN: entity name that is not null shall not be empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-3-EN: empty name particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="substring(normalize-space(.),1,1)='&#34;'">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-EN: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-EN: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-EN: enxp elements SHALL have distinct values in @qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:family)=0 and count(hl7:given)=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ON</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ON: no parts may be person name type particles</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ON</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ON: organization names SHALL be element content</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ON' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ON' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ON" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452146e45-false-d12452267e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]/hl7:representedCustodianOrganization/hl7:telecom"
                 priority="1017"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d12452146e48-false-d12452278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]/hl7:representedCustodianOrganization/hl7:addr"
                 priority="1016"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d19e5404-false-d12452378e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]"
                 priority="1015"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE d19e5410-false-d12452586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]"
                 priority="1014"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCBODY') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCBODY') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von classCode MUSS 'DOCBODY' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Element hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]"
                 priority="1013"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1012"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1011"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1010"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1009"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1008"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1007"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1006"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1005"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1004"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1003"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1002"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1001"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1000"
                 mode="M10">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@contextConductionInd"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@contextConductionInd">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribut @contextConductionInd MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M10"/>
   <xsl:template match="@*|node()" priority="-2" mode="M10">
      <xsl:apply-templates select="*" mode="M10"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009-closedAnwendungsfall ASIC-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Anwendungsfall ASIC</svrl:text>

	  <!--RULE d19e5365-true-d12453740e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/*[not(self::hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.1'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:title | self::hl7:recordTarget[hl7:patientRole] | self::hl7:author[hl7:assignedAuthor] | self::hl7:effectiveTime[not(@nullFlavor)] | self::hl7:setId | self::hl7:versionNumber | self::hl7:custodian[hl7:assignedCustodian] | self::hl7:component[@contextConductionInd][hl7:structuredBody])]"
                 priority="7896"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5365-true-d12453740e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:typeId[@root = '2.16.840.1.113883.1.3'][@extension = 'POCD_HD000040'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.1'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:title | hl7:recordTarget[hl7:patientRole] | hl7:author[hl7:assignedAuthor] | hl7:effectiveTime[not(@nullFlavor)] | hl7:setId | hl7:versionNumber | hl7:custodian[hl7:assignedCustodian] | hl7:component[@contextConductionInd][hl7:structuredBody] (rule-reference: d19e5365-true-d12453740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12453773e16-true-d12453785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/*[not(self::hl7:patientRole)]"
                 priority="7895"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband)/d12453773e16-true-d12453785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:patientRole (rule-reference: d12453773e16-true-d12453785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12453773e22-true-d12453805e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/*[not(self::hl7:id | self::hl7:patient)]"
                 priority="7894"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband)/d12453773e22-true-d12453805e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:patient (rule-reference: d12453773e22-true-d12453805e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12453773e28-true-d12453846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:patient/*[not(self::hl7:id | self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7893"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband)/d12453773e28-true-d12453846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12453773e28-true-d12453846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12453773e36-true-d12453871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:recordTarget[hl7:patientRole]/hl7:patientRole/hl7:patient/hl7:name/*[not(self::hl7:given | self::hl7:family)]"
                 priority="7892"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.18-2018-04-24T104832.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProband)/d12453773e36-true-d12453871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:given | hl7:family (rule-reference: d12453773e36-true-d12453871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12453899e16-true-d12453951e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7891"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor)/d12453899e16-true-d12453951e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12453899e16-true-d12453951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12453899e29-true-d12454025e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:representedOrganization)]"
                 priority="7890"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor)/d12453899e29-true-d12454025e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:representedOrganization (rule-reference: d12453899e29-true-d12454025e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12453899e45-true-d12454089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7889"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor)/d12453899e45-true-d12454089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12453899e45-true-d12454089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12454052e12-true-d12454157e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7888"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor)/d12454052e12-true-d12454157e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12454052e12-true-d12454157e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12454052e35-true-d12454216e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7887"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.19-2018-04-24T105442.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAutor)/d12454052e35-true-d12454216e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12454052e35-true-d12454216e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12454265e13-true-d12454277e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/*[not(self::hl7:assignedCustodian[hl7:representedCustodianOrganization])]"
                 priority="7886"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian)/d12454265e13-true-d12454277e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedCustodian[hl7:representedCustodianOrganization] (rule-reference: d12454265e13-true-d12454277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12454265e17-true-d12454292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]/*[not(self::hl7:representedCustodianOrganization)]"
                 priority="7885"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian)/d12454265e17-true-d12454292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:representedCustodianOrganization (rule-reference: d12454265e17-true-d12454292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12454265e21-true-d12454322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:custodian[hl7:assignedCustodian]/hl7:assignedCustodian[hl7:representedCustodianOrganization]/hl7:representedCustodianOrganization/*[not(self::hl7:id[not(@nullFlavor)] | self::hl7:name | self::hl7:telecom | self::hl7:addr)]"
                 priority="7884"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.104-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAcustodian)/d12454265e21-true-d12454322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id[not(@nullFlavor)] | hl7:name | hl7:telecom | hl7:addr (rule-reference: d12454265e21-true-d12454322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5404-true-d12454625e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/*[not(self::hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]])]"
                 priority="7883"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5404-true-d12454625e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]] (rule-reference: d19e5404-true-d12454625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5410-true-d12455059e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/*[not(self::hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]])]"
                 priority="7882"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5410-true-d12455059e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] (rule-reference: d19e5410-true-d12455059e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5416-true-d12455090e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61'] | self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7881"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5416-true-d12455090e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61'] | hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5416-true-d12455090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455064e12-true-d12455155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="7880"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455064e12-true-d12455155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12455064e12-true-d12455155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5423-true-d12455225e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7879"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5423-true-d12455225e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5423-true-d12455225e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455204e8-true-d12455290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="7878"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455204e8-true-d12455290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12455204e8-true-d12455290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5430-true-d12455380e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7877"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5430-true-d12455380e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5430-true-d12455380e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455342e8-true-d12455483e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]])]"
                 priority="7876"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455342e8-true-d12455483e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] (rule-reference: d12455342e8-true-d12455483e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455342e44-true-d12455557e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7875"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455342e44-true-d12455557e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12455342e44-true-d12455557e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455536e14-true-d12455628e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="7874"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455536e14-true-d12455628e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12455536e14-true-d12455628e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455342e54-true-d12455704e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7873"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455342e54-true-d12455704e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12455342e54-true-d12455704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455683e14-true-d12455769e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="7872"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455683e14-true-d12455769e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12455683e14-true-d12455769e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5438-true-d12455859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7871"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5438-true-d12455859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5438-true-d12455859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455821e8-true-d12455962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]])]"
                 priority="7870"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455821e8-true-d12455962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] (rule-reference: d12455821e8-true-d12455962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455821e44-true-d12456036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7869"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455821e44-true-d12456036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12455821e44-true-d12456036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456015e14-true-d12456095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode | self::hl7:value)]"
                 priority="7868"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456015e14-true-d12456095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode | hl7:value (rule-reference: d12456015e14-true-d12456095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12455821e54-true-d12456165e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7867"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12455821e54-true-d12456165e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12455821e54-true-d12456165e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456144e14-true-d12456230e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="7866"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456144e14-true-d12456230e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12456144e14-true-d12456230e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5445-true-d12456303e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7865"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5445-true-d12456303e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5445-true-d12456303e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456282e8-true-d12456368e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="7864"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456282e8-true-d12456368e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12456282e8-true-d12456368e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5452-true-d12456441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7863"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5452-true-d12456441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5452-true-d12456441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456420e8-true-d12456506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="7862"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456420e8-true-d12456506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12456420e8-true-d12456506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5459-true-d12456579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7861"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5459-true-d12456579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5459-true-d12456579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456558e8-true-d12456644e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="7860"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456558e8-true-d12456644e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12456558e8-true-d12456644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5466-true-d12456717e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7859"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5466-true-d12456717e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5466-true-d12456717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456696e8-true-d12456782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="7858"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456696e8-true-d12456782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12456696e8-true-d12456782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5473-true-d12456989e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7857"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5473-true-d12456989e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5473-true-d12456989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456834e8-true-d12457242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:code | self::hl7:title | self::hl7:text | self::hl7:effectiveTime | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | self::hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]])]"
                 priority="7856"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456834e8-true-d12457242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:code | hl7:title | hl7:text | hl7:effectiveTime | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] | hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]] (rule-reference: d12456834e8-true-d12457242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456834e41-true-d12457330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7855"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456834e41-true-d12457330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d12456834e41-true-d12457330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457304e1-true-d12457433e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]])]"
                 priority="7854"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457304e1-true-d12457433e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] (rule-reference: d12457304e1-true-d12457433e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457304e37-true-d12457507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7853"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457304e37-true-d12457507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12457304e37-true-d12457507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457486e14-true-d12457578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="7852"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457486e14-true-d12457578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12457486e14-true-d12457578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457304e47-true-d12457654e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7851"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457304e47-true-d12457654e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12457304e47-true-d12457654e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457633e14-true-d12457719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="7850"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457633e14-true-d12457719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12457633e14-true-d12457719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456834e43-true-d12457809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7849"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456834e43-true-d12457809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d12456834e43-true-d12457809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457783e1-true-d12457912e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]])]"
                 priority="7848"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457783e1-true-d12457912e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] (rule-reference: d12457783e1-true-d12457912e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457783e37-true-d12457986e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7847"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457783e37-true-d12457986e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12457783e37-true-d12457986e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457965e14-true-d12458045e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode | self::hl7:value)]"
                 priority="7846"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457965e14-true-d12458045e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode | hl7:value (rule-reference: d12457965e14-true-d12458045e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12457783e47-true-d12458115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7845"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12457783e47-true-d12458115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12457783e47-true-d12458115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12458094e14-true-d12458180e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="7844"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12458094e14-true-d12458180e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12458094e14-true-d12458180e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456834e46-true-d12458270e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7843"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456834e46-true-d12458270e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d12456834e46-true-d12458270e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12458244e1-true-d12458373e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]])]"
                 priority="7842"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12458244e1-true-d12458373e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] (rule-reference: d12458244e1-true-d12458373e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12458244e37-true-d12458447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7841"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12458244e37-true-d12458447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12458244e37-true-d12458447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12458426e14-true-d12458506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode | self::hl7:value)]"
                 priority="7840"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12458426e14-true-d12458506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode | hl7:value (rule-reference: d12458426e14-true-d12458506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12458244e47-true-d12458576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="7839"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12458244e47-true-d12458576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12458244e47-true-d12458576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12458555e14-true-d12458641e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="7838"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12458555e14-true-d12458641e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12458555e14-true-d12458641e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456834e48-true-d12459734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="7837"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456834e48-true-d12459734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d12456834e48-true-d12459734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12459039e1-true-d12460819e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="7836"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12459039e1-true-d12460819e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12459039e1-true-d12460819e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12459039e32-true-d12465933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/*[not(self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="7835"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12459039e32-true-d12465933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12459039e32-true-d12465933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e28-true-d12467387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7834"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e28-true-d12467387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12465933e28-true-d12467387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e89-true-d12467467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7833"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e89-true-d12467467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12465933e89-true-d12467467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467444e9-true-d12467511e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7832"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467444e9-true-d12467511e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12467444e9-true-d12467511e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467444e29-true-d12467560e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7831"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467444e29-true-d12467560e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12467444e29-true-d12467560e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e93-true-d12467596e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7830"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e93-true-d12467596e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12465933e93-true-d12467596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467584e2-true-d12467616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7829"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467584e2-true-d12467616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12467584e2-true-d12467616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467584e8-true-d12467657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7828"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467584e8-true-d12467657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12467584e8-true-d12467657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e97-true-d12467750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7827"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e97-true-d12467750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12465933e97-true-d12467750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467686e9-true-d12467810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7826"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467686e9-true-d12467810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12467686e9-true-d12467810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e102-true-d12467932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7825"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e102-true-d12467932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12465933e102-true-d12467932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467859e10-true-d12468024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7824"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467859e10-true-d12468024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12467859e10-true-d12468024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467859e30-true-d12468063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7823"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467859e30-true-d12468063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12467859e30-true-d12468063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467859e34-true-d12468102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7822"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467859e34-true-d12468102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12467859e34-true-d12468102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12467859e39-true-d12468163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7821"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12467859e39-true-d12468163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12467859e39-true-d12468163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468126e12-true-d12468231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7820"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468126e12-true-d12468231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12468126e12-true-d12468231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468126e35-true-d12468290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7819"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468126e35-true-d12468290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12468126e35-true-d12468290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e106-true-d12468387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7818"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e106-true-d12468387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12465933e106-true-d12468387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468321e7-true-d12468462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7817"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468321e7-true-d12468462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12468321e7-true-d12468462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468392e9-true-d12468501e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7816"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468392e9-true-d12468501e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12468392e9-true-d12468501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468392e10-true-d12468549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7815"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468392e10-true-d12468549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12468392e10-true-d12468549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468512e12-true-d12468617e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7814"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468512e12-true-d12468617e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12468512e12-true-d12468617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468512e35-true-d12468676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7813"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468512e35-true-d12468676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12468512e35-true-d12468676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468321e11-true-d12468753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7812"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468321e11-true-d12468753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12468321e11-true-d12468753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468707e16-true-d12468794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7811"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468707e16-true-d12468794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12468707e16-true-d12468794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e110-true-d12468866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7810"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e110-true-d12468866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12465933e110-true-d12468866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468805e15-true-d12468942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7809"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468805e15-true-d12468942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12468805e15-true-d12468942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468805e35-true-d12468997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7808"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468805e35-true-d12468997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12468805e35-true-d12468997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468805e39-true-d12469054e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7807"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468805e39-true-d12469054e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12468805e39-true-d12469054e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12468805e42-true-d12469108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7806"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12468805e42-true-d12469108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12468805e42-true-d12469108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e115-true-d12474215e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="7805"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e115-true-d12474215e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12465933e115-true-d12474215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e16-true-d12475680e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7804"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e16-true-d12475680e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12474230e16-true-d12475680e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e77-true-d12475760e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7803"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e77-true-d12475760e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12474230e77-true-d12475760e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12475737e9-true-d12475804e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7802"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12475737e9-true-d12475804e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12475737e9-true-d12475804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12475737e29-true-d12475853e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7801"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12475737e29-true-d12475853e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12475737e29-true-d12475853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e81-true-d12475889e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7800"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e81-true-d12475889e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12474230e81-true-d12475889e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12475877e2-true-d12475909e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7799"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12475877e2-true-d12475909e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12475877e2-true-d12475909e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12475877e8-true-d12475950e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7798"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12475877e8-true-d12475950e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12475877e8-true-d12475950e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e85-true-d12476043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7797"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e85-true-d12476043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12474230e85-true-d12476043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12475979e9-true-d12476103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7796"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12475979e9-true-d12476103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12475979e9-true-d12476103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e90-true-d12476225e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7795"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e90-true-d12476225e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12474230e90-true-d12476225e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476152e10-true-d12476317e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7794"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476152e10-true-d12476317e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12476152e10-true-d12476317e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476152e30-true-d12476356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7793"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476152e30-true-d12476356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12476152e30-true-d12476356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476152e34-true-d12476395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7792"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476152e34-true-d12476395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12476152e34-true-d12476395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476152e39-true-d12476456e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7791"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476152e39-true-d12476456e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12476152e39-true-d12476456e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476419e12-true-d12476524e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7790"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476419e12-true-d12476524e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12476419e12-true-d12476524e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476419e35-true-d12476583e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7789"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476419e35-true-d12476583e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12476419e35-true-d12476583e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e94-true-d12476680e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7788"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e94-true-d12476680e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12474230e94-true-d12476680e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476614e7-true-d12476755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7787"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476614e7-true-d12476755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12476614e7-true-d12476755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476685e9-true-d12476794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7786"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476685e9-true-d12476794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12476685e9-true-d12476794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476685e10-true-d12476842e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7785"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476685e10-true-d12476842e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12476685e10-true-d12476842e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476805e12-true-d12476910e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7784"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476805e12-true-d12476910e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12476805e12-true-d12476910e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476805e35-true-d12476969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7783"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476805e35-true-d12476969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12476805e35-true-d12476969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12476614e11-true-d12477046e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7782"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12476614e11-true-d12477046e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12476614e11-true-d12477046e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477000e16-true-d12477087e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7781"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12477000e16-true-d12477087e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12477000e16-true-d12477087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e98-true-d12477159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7780"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e98-true-d12477159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12474230e98-true-d12477159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477098e15-true-d12477235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7779"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12477098e15-true-d12477235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12477098e15-true-d12477235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477098e35-true-d12477290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7778"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12477098e35-true-d12477290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12477098e35-true-d12477290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477098e39-true-d12477347e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7777"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12477098e39-true-d12477347e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12477098e39-true-d12477347e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477098e42-true-d12477401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7776"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12477098e42-true-d12477401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12477098e42-true-d12477401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e126-true-d12477470e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7775"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e126-true-d12477470e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12474230e126-true-d12477470e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477480e13-true-d12477504e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7774"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12477480e13-true-d12477504e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12477480e13-true-d12477504e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477525e13-true-d12477549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7773"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12477525e13-true-d12477549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12477525e13-true-d12477549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477570e13-true-d12477594e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7772"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12477570e13-true-d12477594e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12477570e13-true-d12477594e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477615e13-true-d12477649e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7771"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12477615e13-true-d12477649e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12477615e13-true-d12477649e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12474230e130-true-d12477693e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7770"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12474230e130-true-d12477693e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12474230e130-true-d12477693e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477681e2-true-d12477720e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7769"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12477681e2-true-d12477720e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12477681e2-true-d12477720e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e16-true-d12479184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7768"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e16-true-d12479184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12477741e16-true-d12479184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e65-true-d12479258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7767"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e65-true-d12479258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12477741e65-true-d12479258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479235e9-true-d12479302e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7766"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479235e9-true-d12479302e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12479235e9-true-d12479302e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479235e29-true-d12479351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7765"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479235e29-true-d12479351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12479235e29-true-d12479351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e69-true-d12479387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7764"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e69-true-d12479387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12477741e69-true-d12479387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479375e2-true-d12479407e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7763"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479375e2-true-d12479407e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12479375e2-true-d12479407e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479375e8-true-d12479448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7762"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479375e8-true-d12479448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12479375e8-true-d12479448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e73-true-d12479541e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7761"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e73-true-d12479541e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12477741e73-true-d12479541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479477e9-true-d12479601e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7760"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479477e9-true-d12479601e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12479477e9-true-d12479601e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e78-true-d12479723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7759"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e78-true-d12479723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12477741e78-true-d12479723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479650e10-true-d12479815e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7758"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479650e10-true-d12479815e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12479650e10-true-d12479815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479650e30-true-d12479854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7757"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479650e30-true-d12479854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12479650e30-true-d12479854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479650e34-true-d12479893e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7756"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479650e34-true-d12479893e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12479650e34-true-d12479893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479650e39-true-d12479954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7755"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479650e39-true-d12479954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12479650e39-true-d12479954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479917e12-true-d12480022e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7754"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479917e12-true-d12480022e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12479917e12-true-d12480022e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12479917e35-true-d12480081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7753"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12479917e35-true-d12480081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12479917e35-true-d12480081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e82-true-d12480178e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7752"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e82-true-d12480178e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12477741e82-true-d12480178e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480112e7-true-d12480253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7751"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480112e7-true-d12480253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12480112e7-true-d12480253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480183e9-true-d12480292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7750"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480183e9-true-d12480292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12480183e9-true-d12480292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480183e10-true-d12480340e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7749"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480183e10-true-d12480340e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12480183e10-true-d12480340e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480303e12-true-d12480408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7748"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480303e12-true-d12480408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12480303e12-true-d12480408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480303e35-true-d12480467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7747"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480303e35-true-d12480467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12480303e35-true-d12480467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480112e11-true-d12480544e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7746"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480112e11-true-d12480544e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12480112e11-true-d12480544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480498e16-true-d12480585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7745"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480498e16-true-d12480585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12480498e16-true-d12480585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e86-true-d12480657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7744"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e86-true-d12480657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12477741e86-true-d12480657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480596e15-true-d12480733e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7743"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480596e15-true-d12480733e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12480596e15-true-d12480733e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480596e35-true-d12480788e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7742"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480596e35-true-d12480788e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12480596e35-true-d12480788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480596e39-true-d12480845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7741"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480596e39-true-d12480845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12480596e39-true-d12480845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480596e42-true-d12480899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7740"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12480596e42-true-d12480899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12480596e42-true-d12480899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e114-true-d12480968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7739"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e114-true-d12480968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12477741e114-true-d12480968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12480978e13-true-d12481002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7738"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12480978e13-true-d12481002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12480978e13-true-d12481002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481023e13-true-d12481047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7737"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12481023e13-true-d12481047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12481023e13-true-d12481047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481068e13-true-d12481092e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7736"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12481068e13-true-d12481092e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12481068e13-true-d12481092e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481113e13-true-d12481147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7735"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12481113e13-true-d12481147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12481113e13-true-d12481147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12477741e118-true-d12481191e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7734"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12477741e118-true-d12481191e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12477741e118-true-d12481191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481179e2-true-d12481218e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7733"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12481179e2-true-d12481218e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12481179e2-true-d12481218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e16-true-d12482742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="7732"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e16-true-d12482742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12481239e16-true-d12482742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e100-true-d12482861e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7731"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e100-true-d12482861e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12481239e100-true-d12482861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12482838e9-true-d12482905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7730"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12482838e9-true-d12482905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12482838e9-true-d12482905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12482838e29-true-d12482954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7729"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12482838e29-true-d12482954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12482838e29-true-d12482954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e104-true-d12482990e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7728"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e104-true-d12482990e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12481239e104-true-d12482990e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12482978e2-true-d12483010e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7727"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12482978e2-true-d12483010e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12482978e2-true-d12483010e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12482978e8-true-d12483051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7726"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12482978e8-true-d12483051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12482978e8-true-d12483051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e108-true-d12483144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7725"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e108-true-d12483144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12481239e108-true-d12483144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483080e9-true-d12483204e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7724"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483080e9-true-d12483204e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12483080e9-true-d12483204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e113-true-d12483326e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7723"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e113-true-d12483326e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12481239e113-true-d12483326e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483253e10-true-d12483418e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7722"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483253e10-true-d12483418e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12483253e10-true-d12483418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483253e30-true-d12483457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7721"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483253e30-true-d12483457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12483253e30-true-d12483457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483253e34-true-d12483496e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7720"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483253e34-true-d12483496e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12483253e34-true-d12483496e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483253e39-true-d12483557e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7719"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483253e39-true-d12483557e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12483253e39-true-d12483557e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483520e12-true-d12483625e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7718"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483520e12-true-d12483625e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12483520e12-true-d12483625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483520e35-true-d12483684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7717"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483520e35-true-d12483684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12483520e35-true-d12483684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e117-true-d12483781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7716"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e117-true-d12483781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12481239e117-true-d12483781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483715e7-true-d12483856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7715"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483715e7-true-d12483856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12483715e7-true-d12483856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483786e9-true-d12483895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7714"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483786e9-true-d12483895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12483786e9-true-d12483895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483786e10-true-d12483943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7713"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483786e10-true-d12483943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12483786e10-true-d12483943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483906e12-true-d12484011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7712"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483906e12-true-d12484011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12483906e12-true-d12484011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483906e35-true-d12484070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7711"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483906e35-true-d12484070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12483906e35-true-d12484070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12483715e11-true-d12484147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7710"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12483715e11-true-d12484147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12483715e11-true-d12484147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484101e16-true-d12484188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7709"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12484101e16-true-d12484188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12484101e16-true-d12484188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e121-true-d12484260e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7708"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e121-true-d12484260e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12481239e121-true-d12484260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484199e15-true-d12484336e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7707"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12484199e15-true-d12484336e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12484199e15-true-d12484336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484199e35-true-d12484391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7706"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12484199e35-true-d12484391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12484199e35-true-d12484391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484199e39-true-d12484448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7705"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12484199e39-true-d12484448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12484199e39-true-d12484448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484199e42-true-d12484502e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7704"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12484199e42-true-d12484502e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12484199e42-true-d12484502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e149-true-d12484571e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7703"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e149-true-d12484571e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12481239e149-true-d12484571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484581e13-true-d12484605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7702"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12484581e13-true-d12484605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12484581e13-true-d12484605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484626e13-true-d12484650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7701"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12484626e13-true-d12484650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12484626e13-true-d12484650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484671e13-true-d12484695e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7700"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12484671e13-true-d12484695e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12484671e13-true-d12484695e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484716e13-true-d12484750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7699"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12484716e13-true-d12484750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12484716e13-true-d12484750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e153-true-d12484794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7698"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e153-true-d12484794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12481239e153-true-d12484794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484782e2-true-d12484821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7697"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12484782e2-true-d12484821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12484782e2-true-d12484821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e158-true-d12484852e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="7696"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e158-true-d12484852e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12481239e158-true-d12484852e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12481239e162-true-d12484890e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="7695"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12481239e162-true-d12484890e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12481239e162-true-d12484890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e16-true-d12486335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7694"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e16-true-d12486335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12484919e16-true-d12486335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e43-true-d12486388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7693"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e43-true-d12486388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12484919e43-true-d12486388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486365e9-true-d12486432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7692"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486365e9-true-d12486432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12486365e9-true-d12486432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486365e29-true-d12486481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7691"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486365e29-true-d12486481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12486365e29-true-d12486481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e47-true-d12486517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7690"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e47-true-d12486517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12484919e47-true-d12486517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486505e2-true-d12486537e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7689"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486505e2-true-d12486537e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12486505e2-true-d12486537e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486505e8-true-d12486578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7688"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486505e8-true-d12486578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12486505e8-true-d12486578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e52-true-d12486671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7687"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e52-true-d12486671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12484919e52-true-d12486671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486607e9-true-d12486731e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7686"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486607e9-true-d12486731e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12486607e9-true-d12486731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e56-true-d12486853e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7685"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e56-true-d12486853e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12484919e56-true-d12486853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486780e10-true-d12486945e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7684"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486780e10-true-d12486945e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12486780e10-true-d12486945e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486780e30-true-d12486984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7683"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486780e30-true-d12486984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12486780e30-true-d12486984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486780e34-true-d12487023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7682"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486780e34-true-d12487023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12486780e34-true-d12487023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12486780e39-true-d12487084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7681"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12486780e39-true-d12487084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12486780e39-true-d12487084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487047e12-true-d12487152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7680"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487047e12-true-d12487152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12487047e12-true-d12487152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487047e35-true-d12487211e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7679"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487047e35-true-d12487211e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12487047e35-true-d12487211e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e60-true-d12487308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7678"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e60-true-d12487308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12484919e60-true-d12487308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487242e7-true-d12487383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7677"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487242e7-true-d12487383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12487242e7-true-d12487383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487313e9-true-d12487422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7676"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487313e9-true-d12487422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12487313e9-true-d12487422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487313e10-true-d12487470e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7675"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487313e10-true-d12487470e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12487313e10-true-d12487470e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487433e12-true-d12487538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7674"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487433e12-true-d12487538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12487433e12-true-d12487538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487433e35-true-d12487597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7673"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487433e35-true-d12487597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12487433e35-true-d12487597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487242e11-true-d12487674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7672"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487242e11-true-d12487674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12487242e11-true-d12487674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487628e16-true-d12487715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7671"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487628e16-true-d12487715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12487628e16-true-d12487715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e65-true-d12487787e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7670"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e65-true-d12487787e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12484919e65-true-d12487787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487726e15-true-d12487863e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7669"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487726e15-true-d12487863e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12487726e15-true-d12487863e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487726e35-true-d12487918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7668"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487726e35-true-d12487918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12487726e35-true-d12487918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487726e39-true-d12487975e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7667"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487726e39-true-d12487975e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12487726e39-true-d12487975e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12487726e42-true-d12488029e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7666"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12487726e42-true-d12488029e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12487726e42-true-d12488029e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e92-true-d12488098e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7665"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e92-true-d12488098e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12484919e92-true-d12488098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488108e13-true-d12488132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7664"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12488108e13-true-d12488132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12488108e13-true-d12488132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488153e13-true-d12488177e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7663"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12488153e13-true-d12488177e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12488153e13-true-d12488177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488198e13-true-d12488222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7662"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12488198e13-true-d12488222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12488198e13-true-d12488222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488243e13-true-d12488277e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7661"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12488243e13-true-d12488277e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12488243e13-true-d12488277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12484919e97-true-d12488321e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7660"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12484919e97-true-d12488321e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12484919e97-true-d12488321e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488309e2-true-d12488348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7659"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12488309e2-true-d12488348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12488309e2-true-d12488348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e16-true-d12489792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="7658"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e16-true-d12489792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12488369e16-true-d12489792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e53-true-d12489851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7657"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e53-true-d12489851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12488369e53-true-d12489851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12489828e9-true-d12489895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7656"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12489828e9-true-d12489895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12489828e9-true-d12489895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12489828e29-true-d12489944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7655"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12489828e29-true-d12489944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12489828e29-true-d12489944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e58-true-d12489980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7654"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e58-true-d12489980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12488369e58-true-d12489980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12489968e2-true-d12490000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7653"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12489968e2-true-d12490000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12489968e2-true-d12490000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12489968e8-true-d12490041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7652"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12489968e8-true-d12490041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12489968e8-true-d12490041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e62-true-d12490134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7651"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e62-true-d12490134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12488369e62-true-d12490134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490070e9-true-d12490194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7650"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490070e9-true-d12490194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12490070e9-true-d12490194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e66-true-d12490316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7649"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e66-true-d12490316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12488369e66-true-d12490316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490243e10-true-d12490408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7648"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490243e10-true-d12490408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12490243e10-true-d12490408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490243e30-true-d12490447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7647"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490243e30-true-d12490447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12490243e30-true-d12490447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490243e34-true-d12490486e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7646"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490243e34-true-d12490486e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12490243e34-true-d12490486e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490243e39-true-d12490547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7645"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490243e39-true-d12490547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12490243e39-true-d12490547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490510e12-true-d12490615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7644"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490510e12-true-d12490615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12490510e12-true-d12490615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490510e35-true-d12490674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7643"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490510e35-true-d12490674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12490510e35-true-d12490674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e71-true-d12490771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7642"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e71-true-d12490771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12488369e71-true-d12490771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490705e7-true-d12490846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7641"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490705e7-true-d12490846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12490705e7-true-d12490846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490776e9-true-d12490885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7640"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490776e9-true-d12490885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12490776e9-true-d12490885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490776e10-true-d12490933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7639"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490776e10-true-d12490933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12490776e10-true-d12490933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490896e12-true-d12491001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7638"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490896e12-true-d12491001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12490896e12-true-d12491001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490896e35-true-d12491060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7637"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490896e35-true-d12491060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12490896e35-true-d12491060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12490705e11-true-d12491137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7636"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12490705e11-true-d12491137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12490705e11-true-d12491137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491091e16-true-d12491178e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7635"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12491091e16-true-d12491178e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12491091e16-true-d12491178e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e75-true-d12491250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7634"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e75-true-d12491250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12488369e75-true-d12491250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491189e15-true-d12491326e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7633"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12491189e15-true-d12491326e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12491189e15-true-d12491326e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491189e35-true-d12491381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7632"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12491189e35-true-d12491381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12491189e35-true-d12491381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491189e39-true-d12491438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7631"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12491189e39-true-d12491438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12491189e39-true-d12491438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491189e42-true-d12491492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7630"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12491189e42-true-d12491492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12491189e42-true-d12491492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e81-true-d12491552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7629"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e81-true-d12491552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12488369e81-true-d12491552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491562e13-true-d12491586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7628"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12491562e13-true-d12491586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12491562e13-true-d12491586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491607e13-true-d12491631e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7627"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12491607e13-true-d12491631e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12491607e13-true-d12491631e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491652e13-true-d12491676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7626"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12491652e13-true-d12491676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12491652e13-true-d12491676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491697e13-true-d12491731e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7625"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12491697e13-true-d12491731e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12491697e13-true-d12491731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12488369e86-true-d12491775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7624"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12488369e86-true-d12491775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12488369e86-true-d12491775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491763e2-true-d12491802e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7623"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12491763e2-true-d12491802e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12491763e2-true-d12491802e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e16-true-d12493303e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7622"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e16-true-d12493303e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12491832e16-true-d12493303e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e87-true-d12493401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7621"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e87-true-d12493401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12491832e87-true-d12493401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493378e9-true-d12493445e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7620"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493378e9-true-d12493445e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12493378e9-true-d12493445e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493378e29-true-d12493494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7619"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493378e29-true-d12493494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12493378e29-true-d12493494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e92-true-d12493530e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7618"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e92-true-d12493530e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12491832e92-true-d12493530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493518e2-true-d12493550e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7617"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493518e2-true-d12493550e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12493518e2-true-d12493550e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493518e8-true-d12493591e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7616"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493518e8-true-d12493591e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12493518e8-true-d12493591e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e96-true-d12493684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7615"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e96-true-d12493684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12491832e96-true-d12493684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493620e9-true-d12493744e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7614"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493620e9-true-d12493744e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12493620e9-true-d12493744e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e100-true-d12493866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7613"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e100-true-d12493866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12491832e100-true-d12493866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493793e10-true-d12493958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7612"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493793e10-true-d12493958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12493793e10-true-d12493958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493793e30-true-d12493997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7611"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493793e30-true-d12493997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12493793e30-true-d12493997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493793e34-true-d12494036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7610"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493793e34-true-d12494036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12493793e34-true-d12494036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12493793e39-true-d12494097e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7609"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12493793e39-true-d12494097e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12493793e39-true-d12494097e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494060e12-true-d12494165e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7608"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494060e12-true-d12494165e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12494060e12-true-d12494165e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494060e35-true-d12494224e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7607"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494060e35-true-d12494224e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12494060e35-true-d12494224e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e105-true-d12494321e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7606"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e105-true-d12494321e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12491832e105-true-d12494321e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494255e7-true-d12494396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7605"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494255e7-true-d12494396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12494255e7-true-d12494396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494326e9-true-d12494435e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7604"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494326e9-true-d12494435e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12494326e9-true-d12494435e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494326e10-true-d12494483e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7603"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494326e10-true-d12494483e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12494326e10-true-d12494483e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494446e12-true-d12494551e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7602"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494446e12-true-d12494551e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12494446e12-true-d12494551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494446e35-true-d12494610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7601"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494446e35-true-d12494610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12494446e35-true-d12494610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494255e11-true-d12494687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7600"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494255e11-true-d12494687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12494255e11-true-d12494687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494641e16-true-d12494728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7599"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494641e16-true-d12494728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12494641e16-true-d12494728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e109-true-d12494800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7598"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e109-true-d12494800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12491832e109-true-d12494800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494739e15-true-d12494876e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7597"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494739e15-true-d12494876e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12494739e15-true-d12494876e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494739e35-true-d12494931e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7596"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494739e35-true-d12494931e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12494739e35-true-d12494931e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494739e39-true-d12494988e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7595"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494739e39-true-d12494988e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12494739e39-true-d12494988e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12494739e42-true-d12495042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7594"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12494739e42-true-d12495042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12494739e42-true-d12495042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e137-true-d12495111e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7593"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e137-true-d12495111e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12491832e137-true-d12495111e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495121e13-true-d12495145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7592"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12495121e13-true-d12495145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12495121e13-true-d12495145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495166e13-true-d12495190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7591"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12495166e13-true-d12495190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12495166e13-true-d12495190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495211e13-true-d12495235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7590"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12495211e13-true-d12495235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12495211e13-true-d12495235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495256e13-true-d12495290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7589"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12495256e13-true-d12495290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12495256e13-true-d12495290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12491832e141-true-d12495334e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7588"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12491832e141-true-d12495334e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12491832e141-true-d12495334e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495322e2-true-d12495361e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7587"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12495322e2-true-d12495361e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12495322e2-true-d12495361e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e16-true-d12496798e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7586"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e16-true-d12496798e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12495382e16-true-d12496798e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e43-true-d12496851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7585"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e43-true-d12496851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12495382e43-true-d12496851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12496828e9-true-d12496895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7584"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12496828e9-true-d12496895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12496828e9-true-d12496895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12496828e29-true-d12496944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7583"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12496828e29-true-d12496944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12496828e29-true-d12496944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e47-true-d12496980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7582"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e47-true-d12496980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12495382e47-true-d12496980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12496968e2-true-d12497000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7581"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12496968e2-true-d12497000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12496968e2-true-d12497000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12496968e8-true-d12497041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7580"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12496968e8-true-d12497041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12496968e8-true-d12497041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e52-true-d12497134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7579"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e52-true-d12497134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12495382e52-true-d12497134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497070e9-true-d12497194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7578"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497070e9-true-d12497194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12497070e9-true-d12497194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e56-true-d12497316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7577"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e56-true-d12497316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12495382e56-true-d12497316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497243e10-true-d12497408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7576"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497243e10-true-d12497408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12497243e10-true-d12497408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497243e30-true-d12497447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7575"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497243e30-true-d12497447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12497243e30-true-d12497447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497243e34-true-d12497486e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7574"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497243e34-true-d12497486e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12497243e34-true-d12497486e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497243e39-true-d12497547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7573"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497243e39-true-d12497547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12497243e39-true-d12497547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497510e12-true-d12497615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7572"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497510e12-true-d12497615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12497510e12-true-d12497615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497510e35-true-d12497674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7571"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497510e35-true-d12497674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12497510e35-true-d12497674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e60-true-d12497771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7570"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e60-true-d12497771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12495382e60-true-d12497771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497705e7-true-d12497846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7569"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497705e7-true-d12497846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12497705e7-true-d12497846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497776e9-true-d12497885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7568"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497776e9-true-d12497885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12497776e9-true-d12497885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497776e10-true-d12497933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7567"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497776e10-true-d12497933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12497776e10-true-d12497933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497896e12-true-d12498001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7566"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497896e12-true-d12498001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12497896e12-true-d12498001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497896e35-true-d12498060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7565"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497896e35-true-d12498060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12497896e35-true-d12498060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12497705e11-true-d12498137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7564"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12497705e11-true-d12498137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12497705e11-true-d12498137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498091e16-true-d12498178e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7563"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12498091e16-true-d12498178e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12498091e16-true-d12498178e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e65-true-d12498250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7562"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e65-true-d12498250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12495382e65-true-d12498250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498189e15-true-d12498326e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7561"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12498189e15-true-d12498326e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12498189e15-true-d12498326e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498189e35-true-d12498381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7560"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12498189e35-true-d12498381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12498189e35-true-d12498381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498189e39-true-d12498438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7559"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12498189e39-true-d12498438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12498189e39-true-d12498438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498189e42-true-d12498492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7558"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12498189e42-true-d12498492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12498189e42-true-d12498492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e92-true-d12498561e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7557"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e92-true-d12498561e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12495382e92-true-d12498561e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498571e13-true-d12498595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7556"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12498571e13-true-d12498595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12498571e13-true-d12498595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498616e13-true-d12498640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7555"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12498616e13-true-d12498640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12498616e13-true-d12498640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498661e13-true-d12498685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7554"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12498661e13-true-d12498685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12498661e13-true-d12498685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498706e13-true-d12498740e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7553"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12498706e13-true-d12498740e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12498706e13-true-d12498740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12495382e97-true-d12498784e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7552"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12495382e97-true-d12498784e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12495382e97-true-d12498784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498772e2-true-d12498811e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7551"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12498772e2-true-d12498811e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12498772e2-true-d12498811e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e16-true-d12500371e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7550"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e16-true-d12500371e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12498832e16-true-d12500371e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e95-true-d12500487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7549"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e95-true-d12500487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12498832e95-true-d12500487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500464e9-true-d12500531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7548"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500464e9-true-d12500531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12500464e9-true-d12500531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500464e29-true-d12500580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7547"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500464e29-true-d12500580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12500464e29-true-d12500580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e99-true-d12500616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7546"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e99-true-d12500616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12498832e99-true-d12500616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500604e2-true-d12500636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7545"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500604e2-true-d12500636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12500604e2-true-d12500636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500604e8-true-d12500677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7544"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500604e8-true-d12500677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12500604e8-true-d12500677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e103-true-d12500754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="7543"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e103-true-d12500754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12498832e103-true-d12500754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500706e5-true-d12500810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="7542"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500706e5-true-d12500810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12500706e5-true-d12500810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500820e13-true-d12500837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="7541"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12500820e13-true-d12500837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12500820e13-true-d12500837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500852e13-true-d12500880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="7540"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12500852e13-true-d12500880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12500852e13-true-d12500880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500706e24-true-d12500941e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7539"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500706e24-true-d12500941e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12500706e24-true-d12500941e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500904e12-true-d12501009e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7538"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500904e12-true-d12501009e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12500904e12-true-d12501009e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12500904e35-true-d12501068e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7537"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12500904e35-true-d12501068e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12500904e35-true-d12501068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e111-true-d12501163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7536"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e111-true-d12501163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12498832e111-true-d12501163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501099e9-true-d12501223e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7535"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501099e9-true-d12501223e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12501099e9-true-d12501223e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e115-true-d12501345e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7534"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e115-true-d12501345e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12498832e115-true-d12501345e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501272e10-true-d12501437e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7533"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501272e10-true-d12501437e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12501272e10-true-d12501437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501272e30-true-d12501476e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7532"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501272e30-true-d12501476e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12501272e30-true-d12501476e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501272e34-true-d12501515e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7531"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501272e34-true-d12501515e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12501272e34-true-d12501515e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501272e39-true-d12501576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7530"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501272e39-true-d12501576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12501272e39-true-d12501576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501539e12-true-d12501644e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7529"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501539e12-true-d12501644e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12501539e12-true-d12501644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501539e35-true-d12501703e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7528"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501539e35-true-d12501703e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12501539e35-true-d12501703e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e119-true-d12501800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7527"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e119-true-d12501800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12498832e119-true-d12501800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501734e7-true-d12501875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7526"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501734e7-true-d12501875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12501734e7-true-d12501875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501805e9-true-d12501914e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7525"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501805e9-true-d12501914e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12501805e9-true-d12501914e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501805e10-true-d12501962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7524"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501805e10-true-d12501962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12501805e10-true-d12501962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501925e12-true-d12502030e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7523"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501925e12-true-d12502030e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12501925e12-true-d12502030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501925e35-true-d12502089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7522"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501925e35-true-d12502089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12501925e35-true-d12502089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12501734e11-true-d12502166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7521"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12501734e11-true-d12502166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12501734e11-true-d12502166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502120e16-true-d12502207e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7520"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12502120e16-true-d12502207e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12502120e16-true-d12502207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e124-true-d12502279e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7519"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e124-true-d12502279e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12498832e124-true-d12502279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502218e15-true-d12502355e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7518"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12502218e15-true-d12502355e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12502218e15-true-d12502355e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502218e35-true-d12502410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7517"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12502218e35-true-d12502410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12502218e35-true-d12502410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502218e39-true-d12502467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7516"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12502218e39-true-d12502467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12502218e39-true-d12502467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502218e42-true-d12502521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7515"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12502218e42-true-d12502521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12502218e42-true-d12502521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e151-true-d12502590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7514"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e151-true-d12502590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12498832e151-true-d12502590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502600e13-true-d12502624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7513"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12502600e13-true-d12502624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12502600e13-true-d12502624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502645e13-true-d12502669e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7512"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12502645e13-true-d12502669e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12502645e13-true-d12502669e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502690e13-true-d12502714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7511"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12502690e13-true-d12502714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12502690e13-true-d12502714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502735e13-true-d12502769e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7510"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12502735e13-true-d12502769e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12502735e13-true-d12502769e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12498832e156-true-d12502813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7509"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12498832e156-true-d12502813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12498832e156-true-d12502813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502801e2-true-d12502840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7508"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12502801e2-true-d12502840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12502801e2-true-d12502840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e16-true-d12504367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7507"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e16-true-d12504367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12502861e16-true-d12504367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e71-true-d12504459e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7506"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e71-true-d12504459e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12502861e71-true-d12504459e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504436e9-true-d12504503e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7505"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504436e9-true-d12504503e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12504436e9-true-d12504503e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504436e29-true-d12504552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7504"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504436e29-true-d12504552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12504436e29-true-d12504552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e76-true-d12504588e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7503"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e76-true-d12504588e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12502861e76-true-d12504588e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504576e2-true-d12504608e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7502"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504576e2-true-d12504608e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12504576e2-true-d12504608e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504576e8-true-d12504649e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7501"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504576e8-true-d12504649e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12504576e8-true-d12504649e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e80-true-d12504726e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="7500"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e80-true-d12504726e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12502861e80-true-d12504726e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504678e5-true-d12504782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="7499"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504678e5-true-d12504782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12504678e5-true-d12504782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504792e13-true-d12504809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="7498"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12504792e13-true-d12504809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12504792e13-true-d12504809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504824e13-true-d12504852e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="7497"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12504824e13-true-d12504852e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12504824e13-true-d12504852e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504678e24-true-d12504913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7496"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504678e24-true-d12504913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12504678e24-true-d12504913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504876e12-true-d12504981e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7495"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504876e12-true-d12504981e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12504876e12-true-d12504981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12504876e35-true-d12505040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7494"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12504876e35-true-d12505040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12504876e35-true-d12505040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e87-true-d12505135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7493"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e87-true-d12505135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12502861e87-true-d12505135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505071e9-true-d12505195e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7492"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505071e9-true-d12505195e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12505071e9-true-d12505195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e92-true-d12505317e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7491"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e92-true-d12505317e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12502861e92-true-d12505317e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505244e10-true-d12505409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7490"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505244e10-true-d12505409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12505244e10-true-d12505409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505244e30-true-d12505448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7489"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505244e30-true-d12505448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12505244e30-true-d12505448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505244e34-true-d12505487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7488"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505244e34-true-d12505487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12505244e34-true-d12505487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505244e39-true-d12505548e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7487"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505244e39-true-d12505548e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12505244e39-true-d12505548e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505511e12-true-d12505616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7486"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505511e12-true-d12505616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12505511e12-true-d12505616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505511e35-true-d12505675e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7485"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505511e35-true-d12505675e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12505511e35-true-d12505675e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e96-true-d12505772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7484"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e96-true-d12505772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12502861e96-true-d12505772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505706e7-true-d12505847e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7483"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505706e7-true-d12505847e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12505706e7-true-d12505847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505777e9-true-d12505886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7482"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505777e9-true-d12505886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12505777e9-true-d12505886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505777e10-true-d12505934e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7481"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505777e10-true-d12505934e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12505777e10-true-d12505934e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505897e12-true-d12506002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7480"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505897e12-true-d12506002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12505897e12-true-d12506002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505897e35-true-d12506061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7479"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505897e35-true-d12506061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12505897e35-true-d12506061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12505706e11-true-d12506138e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7478"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12505706e11-true-d12506138e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12505706e11-true-d12506138e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506092e16-true-d12506179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7477"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12506092e16-true-d12506179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12506092e16-true-d12506179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e100-true-d12506251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7476"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e100-true-d12506251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12502861e100-true-d12506251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506190e15-true-d12506327e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7475"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12506190e15-true-d12506327e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12506190e15-true-d12506327e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506190e35-true-d12506382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7474"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12506190e35-true-d12506382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12506190e35-true-d12506382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506190e39-true-d12506439e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7473"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12506190e39-true-d12506439e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12506190e39-true-d12506439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506190e42-true-d12506493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7472"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12506190e42-true-d12506493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12506190e42-true-d12506493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e128-true-d12506562e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7471"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e128-true-d12506562e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12502861e128-true-d12506562e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506572e13-true-d12506596e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7470"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12506572e13-true-d12506596e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12506572e13-true-d12506596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506617e13-true-d12506641e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7469"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12506617e13-true-d12506641e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12506617e13-true-d12506641e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506662e13-true-d12506686e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7468"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12506662e13-true-d12506686e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12506662e13-true-d12506686e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506707e13-true-d12506741e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7467"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12506707e13-true-d12506741e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12506707e13-true-d12506741e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12502861e132-true-d12506785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7466"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12502861e132-true-d12506785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12502861e132-true-d12506785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506773e2-true-d12506812e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7465"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12506773e2-true-d12506812e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12506773e2-true-d12506812e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e138-true-d12506870e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7464"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e138-true-d12506870e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12465933e138-true-d12506870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506880e13-true-d12506904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7463"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12506880e13-true-d12506904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12506880e13-true-d12506904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506925e13-true-d12506949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7462"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12506925e13-true-d12506949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12506925e13-true-d12506949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12506970e13-true-d12506994e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7461"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12506970e13-true-d12506994e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12506970e13-true-d12506994e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507015e13-true-d12507049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7460"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12507015e13-true-d12507049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12507015e13-true-d12507049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12465933e142-true-d12507093e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7459"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12465933e142-true-d12507093e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12465933e142-true-d12507093e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507081e2-true-d12507120e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7458"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12507081e2-true-d12507120e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12507081e2-true-d12507120e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e16-true-d12508584e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7457"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e16-true-d12508584e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12507141e16-true-d12508584e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e65-true-d12508658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7456"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e65-true-d12508658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12507141e65-true-d12508658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12508635e9-true-d12508702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7455"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12508635e9-true-d12508702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12508635e9-true-d12508702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12508635e29-true-d12508751e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7454"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12508635e29-true-d12508751e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12508635e29-true-d12508751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e69-true-d12508787e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7453"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e69-true-d12508787e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12507141e69-true-d12508787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12508775e2-true-d12508807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7452"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12508775e2-true-d12508807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12508775e2-true-d12508807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12508775e8-true-d12508848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7451"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12508775e8-true-d12508848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12508775e8-true-d12508848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e73-true-d12508941e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7450"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e73-true-d12508941e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12507141e73-true-d12508941e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12508877e9-true-d12509001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7449"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12508877e9-true-d12509001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12508877e9-true-d12509001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e78-true-d12509123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7448"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e78-true-d12509123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12507141e78-true-d12509123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509050e10-true-d12509215e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7447"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509050e10-true-d12509215e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12509050e10-true-d12509215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509050e30-true-d12509254e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7446"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509050e30-true-d12509254e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12509050e30-true-d12509254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509050e34-true-d12509293e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7445"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509050e34-true-d12509293e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12509050e34-true-d12509293e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509050e39-true-d12509354e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7444"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509050e39-true-d12509354e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12509050e39-true-d12509354e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509317e12-true-d12509422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7443"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509317e12-true-d12509422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12509317e12-true-d12509422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509317e35-true-d12509481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7442"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509317e35-true-d12509481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12509317e35-true-d12509481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e82-true-d12509578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7441"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e82-true-d12509578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12507141e82-true-d12509578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509512e7-true-d12509653e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7440"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509512e7-true-d12509653e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12509512e7-true-d12509653e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509583e9-true-d12509692e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7439"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509583e9-true-d12509692e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12509583e9-true-d12509692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509583e10-true-d12509740e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7438"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509583e10-true-d12509740e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12509583e10-true-d12509740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509703e12-true-d12509808e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7437"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509703e12-true-d12509808e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12509703e12-true-d12509808e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509703e35-true-d12509867e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7436"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509703e35-true-d12509867e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12509703e35-true-d12509867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509512e11-true-d12509944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7435"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509512e11-true-d12509944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12509512e11-true-d12509944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509898e16-true-d12509985e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7434"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509898e16-true-d12509985e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12509898e16-true-d12509985e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e86-true-d12510057e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7433"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e86-true-d12510057e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12507141e86-true-d12510057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509996e15-true-d12510133e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7432"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509996e15-true-d12510133e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12509996e15-true-d12510133e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509996e35-true-d12510188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7431"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509996e35-true-d12510188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12509996e35-true-d12510188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509996e39-true-d12510245e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7430"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509996e39-true-d12510245e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12509996e39-true-d12510245e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12509996e42-true-d12510299e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7429"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12509996e42-true-d12510299e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12509996e42-true-d12510299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e91-true-d12515406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="7428"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e91-true-d12515406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12507141e91-true-d12515406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e16-true-d12516871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7427"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e16-true-d12516871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12515421e16-true-d12516871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e77-true-d12516951e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7426"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e77-true-d12516951e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12515421e77-true-d12516951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12516928e9-true-d12516995e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7425"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12516928e9-true-d12516995e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12516928e9-true-d12516995e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12516928e29-true-d12517044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7424"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12516928e29-true-d12517044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12516928e29-true-d12517044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e81-true-d12517080e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7423"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e81-true-d12517080e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12515421e81-true-d12517080e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517068e2-true-d12517100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7422"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517068e2-true-d12517100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12517068e2-true-d12517100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517068e8-true-d12517141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7421"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517068e8-true-d12517141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12517068e8-true-d12517141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e85-true-d12517234e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7420"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e85-true-d12517234e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12515421e85-true-d12517234e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517170e9-true-d12517294e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7419"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517170e9-true-d12517294e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12517170e9-true-d12517294e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e90-true-d12517416e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7418"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e90-true-d12517416e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12515421e90-true-d12517416e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517343e10-true-d12517508e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7417"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517343e10-true-d12517508e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12517343e10-true-d12517508e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517343e30-true-d12517547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7416"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517343e30-true-d12517547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12517343e30-true-d12517547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517343e34-true-d12517586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7415"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517343e34-true-d12517586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12517343e34-true-d12517586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517343e39-true-d12517647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7414"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517343e39-true-d12517647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12517343e39-true-d12517647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517610e12-true-d12517715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7413"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517610e12-true-d12517715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12517610e12-true-d12517715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517610e35-true-d12517774e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7412"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517610e35-true-d12517774e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12517610e35-true-d12517774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e94-true-d12517871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7411"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e94-true-d12517871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12515421e94-true-d12517871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517805e7-true-d12517946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7410"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517805e7-true-d12517946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12517805e7-true-d12517946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517876e9-true-d12517985e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7409"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517876e9-true-d12517985e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12517876e9-true-d12517985e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517876e10-true-d12518033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7408"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517876e10-true-d12518033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12517876e10-true-d12518033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517996e12-true-d12518101e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7407"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517996e12-true-d12518101e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12517996e12-true-d12518101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517996e35-true-d12518160e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7406"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517996e35-true-d12518160e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12517996e35-true-d12518160e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12517805e11-true-d12518237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7405"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12517805e11-true-d12518237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12517805e11-true-d12518237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518191e16-true-d12518278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7404"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12518191e16-true-d12518278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12518191e16-true-d12518278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e98-true-d12518350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7403"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e98-true-d12518350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12515421e98-true-d12518350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518289e15-true-d12518426e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7402"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12518289e15-true-d12518426e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12518289e15-true-d12518426e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518289e35-true-d12518481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7401"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12518289e35-true-d12518481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12518289e35-true-d12518481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518289e39-true-d12518538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7400"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12518289e39-true-d12518538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12518289e39-true-d12518538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518289e42-true-d12518592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7399"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12518289e42-true-d12518592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12518289e42-true-d12518592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e126-true-d12518661e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7398"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e126-true-d12518661e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12515421e126-true-d12518661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518671e13-true-d12518695e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7397"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12518671e13-true-d12518695e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12518671e13-true-d12518695e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518716e13-true-d12518740e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7396"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12518716e13-true-d12518740e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12518716e13-true-d12518740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518761e13-true-d12518785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7395"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12518761e13-true-d12518785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12518761e13-true-d12518785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518806e13-true-d12518840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7394"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12518806e13-true-d12518840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12518806e13-true-d12518840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12515421e130-true-d12518884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7393"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12515421e130-true-d12518884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12515421e130-true-d12518884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518872e2-true-d12518911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7392"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12518872e2-true-d12518911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12518872e2-true-d12518911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e16-true-d12520375e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7391"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e16-true-d12520375e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12518932e16-true-d12520375e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e65-true-d12520449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7390"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e65-true-d12520449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12518932e65-true-d12520449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520426e9-true-d12520493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7389"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520426e9-true-d12520493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12520426e9-true-d12520493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520426e29-true-d12520542e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7388"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520426e29-true-d12520542e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12520426e29-true-d12520542e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e69-true-d12520578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7387"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e69-true-d12520578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12518932e69-true-d12520578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520566e2-true-d12520598e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7386"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520566e2-true-d12520598e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12520566e2-true-d12520598e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520566e8-true-d12520639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7385"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520566e8-true-d12520639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12520566e8-true-d12520639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e73-true-d12520732e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7384"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e73-true-d12520732e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12518932e73-true-d12520732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520668e9-true-d12520792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7383"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520668e9-true-d12520792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12520668e9-true-d12520792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e78-true-d12520914e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7382"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e78-true-d12520914e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12518932e78-true-d12520914e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520841e10-true-d12521006e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7381"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520841e10-true-d12521006e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12520841e10-true-d12521006e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520841e30-true-d12521045e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7380"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520841e30-true-d12521045e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12520841e30-true-d12521045e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520841e34-true-d12521084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7379"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520841e34-true-d12521084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12520841e34-true-d12521084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12520841e39-true-d12521145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7378"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12520841e39-true-d12521145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12520841e39-true-d12521145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521108e12-true-d12521213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7377"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521108e12-true-d12521213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12521108e12-true-d12521213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521108e35-true-d12521272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7376"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521108e35-true-d12521272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12521108e35-true-d12521272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e82-true-d12521369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7375"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e82-true-d12521369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12518932e82-true-d12521369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521303e7-true-d12521444e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7374"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521303e7-true-d12521444e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12521303e7-true-d12521444e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521374e9-true-d12521483e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7373"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521374e9-true-d12521483e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12521374e9-true-d12521483e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521374e10-true-d12521531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7372"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521374e10-true-d12521531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12521374e10-true-d12521531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521494e12-true-d12521599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7371"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521494e12-true-d12521599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12521494e12-true-d12521599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521494e35-true-d12521658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7370"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521494e35-true-d12521658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12521494e35-true-d12521658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521303e11-true-d12521735e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7369"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521303e11-true-d12521735e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12521303e11-true-d12521735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521689e16-true-d12521776e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7368"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521689e16-true-d12521776e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12521689e16-true-d12521776e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e86-true-d12521848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7367"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e86-true-d12521848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12518932e86-true-d12521848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521787e15-true-d12521924e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7366"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521787e15-true-d12521924e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12521787e15-true-d12521924e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521787e35-true-d12521979e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7365"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521787e35-true-d12521979e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12521787e35-true-d12521979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521787e39-true-d12522036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7364"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521787e39-true-d12522036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12521787e39-true-d12522036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12521787e42-true-d12522090e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7363"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12521787e42-true-d12522090e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12521787e42-true-d12522090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e114-true-d12522159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7362"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e114-true-d12522159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12518932e114-true-d12522159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522169e13-true-d12522193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7361"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12522169e13-true-d12522193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12522169e13-true-d12522193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522214e13-true-d12522238e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7360"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12522214e13-true-d12522238e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12522214e13-true-d12522238e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522259e13-true-d12522283e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7359"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12522259e13-true-d12522283e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12522259e13-true-d12522283e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522304e13-true-d12522338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7358"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12522304e13-true-d12522338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12522304e13-true-d12522338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12518932e118-true-d12522382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7357"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12518932e118-true-d12522382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12518932e118-true-d12522382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522370e2-true-d12522409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7356"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12522370e2-true-d12522409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12522370e2-true-d12522409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e16-true-d12523933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="7355"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e16-true-d12523933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12522430e16-true-d12523933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e100-true-d12524052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7354"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e100-true-d12524052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12522430e100-true-d12524052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524029e9-true-d12524096e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7353"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524029e9-true-d12524096e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12524029e9-true-d12524096e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524029e29-true-d12524145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7352"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524029e29-true-d12524145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12524029e29-true-d12524145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e104-true-d12524181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7351"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e104-true-d12524181e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12522430e104-true-d12524181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524169e2-true-d12524201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7350"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524169e2-true-d12524201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12524169e2-true-d12524201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524169e8-true-d12524242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7349"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524169e8-true-d12524242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12524169e8-true-d12524242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e108-true-d12524335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7348"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e108-true-d12524335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12522430e108-true-d12524335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524271e9-true-d12524395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7347"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524271e9-true-d12524395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12524271e9-true-d12524395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e113-true-d12524517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7346"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e113-true-d12524517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12522430e113-true-d12524517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524444e10-true-d12524609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7345"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524444e10-true-d12524609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12524444e10-true-d12524609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524444e30-true-d12524648e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7344"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524444e30-true-d12524648e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12524444e30-true-d12524648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524444e34-true-d12524687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7343"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524444e34-true-d12524687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12524444e34-true-d12524687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524444e39-true-d12524748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7342"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524444e39-true-d12524748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12524444e39-true-d12524748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524711e12-true-d12524816e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7341"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524711e12-true-d12524816e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12524711e12-true-d12524816e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524711e35-true-d12524875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7340"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524711e35-true-d12524875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12524711e35-true-d12524875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e117-true-d12524972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7339"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e117-true-d12524972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12522430e117-true-d12524972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524906e7-true-d12525047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7338"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524906e7-true-d12525047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12524906e7-true-d12525047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524977e9-true-d12525086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7337"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524977e9-true-d12525086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12524977e9-true-d12525086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524977e10-true-d12525134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7336"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524977e10-true-d12525134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12524977e10-true-d12525134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525097e12-true-d12525202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7335"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525097e12-true-d12525202e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12525097e12-true-d12525202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525097e35-true-d12525261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7334"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525097e35-true-d12525261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12525097e35-true-d12525261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12524906e11-true-d12525338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7333"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12524906e11-true-d12525338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12524906e11-true-d12525338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525292e16-true-d12525379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7332"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525292e16-true-d12525379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12525292e16-true-d12525379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e121-true-d12525451e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7331"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e121-true-d12525451e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12522430e121-true-d12525451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525390e15-true-d12525527e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7330"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525390e15-true-d12525527e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12525390e15-true-d12525527e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525390e35-true-d12525582e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7329"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525390e35-true-d12525582e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12525390e35-true-d12525582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525390e39-true-d12525639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7328"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525390e39-true-d12525639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12525390e39-true-d12525639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525390e42-true-d12525693e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7327"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525390e42-true-d12525693e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12525390e42-true-d12525693e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e149-true-d12525762e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7326"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e149-true-d12525762e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12522430e149-true-d12525762e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525772e13-true-d12525796e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7325"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12525772e13-true-d12525796e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12525772e13-true-d12525796e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525817e13-true-d12525841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7324"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12525817e13-true-d12525841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12525817e13-true-d12525841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525862e13-true-d12525886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7323"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12525862e13-true-d12525886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12525862e13-true-d12525886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525907e13-true-d12525941e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7322"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12525907e13-true-d12525941e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12525907e13-true-d12525941e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e153-true-d12525985e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7321"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e153-true-d12525985e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12522430e153-true-d12525985e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12525973e2-true-d12526012e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7320"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12525973e2-true-d12526012e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12525973e2-true-d12526012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e158-true-d12526043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="7319"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e158-true-d12526043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12522430e158-true-d12526043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12522430e162-true-d12526081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="7318"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12522430e162-true-d12526081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12522430e162-true-d12526081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e16-true-d12527526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7317"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e16-true-d12527526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12526110e16-true-d12527526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e43-true-d12527579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7316"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e43-true-d12527579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12526110e43-true-d12527579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527556e9-true-d12527623e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7315"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527556e9-true-d12527623e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12527556e9-true-d12527623e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527556e29-true-d12527672e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7314"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527556e29-true-d12527672e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12527556e29-true-d12527672e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e47-true-d12527708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7313"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e47-true-d12527708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12526110e47-true-d12527708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527696e2-true-d12527728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7312"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527696e2-true-d12527728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12527696e2-true-d12527728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527696e8-true-d12527769e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7311"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527696e8-true-d12527769e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12527696e8-true-d12527769e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e52-true-d12527862e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7310"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e52-true-d12527862e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12526110e52-true-d12527862e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527798e9-true-d12527922e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7309"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527798e9-true-d12527922e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12527798e9-true-d12527922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e56-true-d12528044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7308"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e56-true-d12528044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12526110e56-true-d12528044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527971e10-true-d12528136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7307"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527971e10-true-d12528136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12527971e10-true-d12528136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527971e30-true-d12528175e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7306"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527971e30-true-d12528175e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12527971e30-true-d12528175e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527971e34-true-d12528214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7305"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527971e34-true-d12528214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12527971e34-true-d12528214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12527971e39-true-d12528275e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7304"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12527971e39-true-d12528275e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12527971e39-true-d12528275e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528238e12-true-d12528343e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7303"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528238e12-true-d12528343e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12528238e12-true-d12528343e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528238e35-true-d12528402e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7302"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528238e35-true-d12528402e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12528238e35-true-d12528402e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e60-true-d12528499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7301"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e60-true-d12528499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12526110e60-true-d12528499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528433e7-true-d12528574e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7300"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528433e7-true-d12528574e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12528433e7-true-d12528574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528504e9-true-d12528613e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7299"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528504e9-true-d12528613e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12528504e9-true-d12528613e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528504e10-true-d12528661e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7298"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528504e10-true-d12528661e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12528504e10-true-d12528661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528624e12-true-d12528729e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7297"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528624e12-true-d12528729e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12528624e12-true-d12528729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528624e35-true-d12528788e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7296"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528624e35-true-d12528788e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12528624e35-true-d12528788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528433e11-true-d12528865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7295"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528433e11-true-d12528865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12528433e11-true-d12528865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528819e16-true-d12528906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7294"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528819e16-true-d12528906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12528819e16-true-d12528906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e65-true-d12528978e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7293"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e65-true-d12528978e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12526110e65-true-d12528978e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528917e15-true-d12529054e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7292"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528917e15-true-d12529054e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12528917e15-true-d12529054e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528917e35-true-d12529109e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7291"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528917e35-true-d12529109e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12528917e35-true-d12529109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528917e39-true-d12529166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7290"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528917e39-true-d12529166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12528917e39-true-d12529166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12528917e42-true-d12529220e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7289"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12528917e42-true-d12529220e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12528917e42-true-d12529220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e92-true-d12529289e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7288"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e92-true-d12529289e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12526110e92-true-d12529289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529299e13-true-d12529323e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7287"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12529299e13-true-d12529323e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12529299e13-true-d12529323e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529344e13-true-d12529368e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7286"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12529344e13-true-d12529368e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12529344e13-true-d12529368e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529389e13-true-d12529413e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7285"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12529389e13-true-d12529413e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12529389e13-true-d12529413e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529434e13-true-d12529468e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7284"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12529434e13-true-d12529468e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12529434e13-true-d12529468e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12526110e97-true-d12529512e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7283"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12526110e97-true-d12529512e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12526110e97-true-d12529512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529500e2-true-d12529539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7282"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12529500e2-true-d12529539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12529500e2-true-d12529539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e16-true-d12530983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="7281"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e16-true-d12530983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12529560e16-true-d12530983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e53-true-d12531042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7280"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e53-true-d12531042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12529560e53-true-d12531042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531019e9-true-d12531086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7279"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531019e9-true-d12531086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12531019e9-true-d12531086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531019e29-true-d12531135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7278"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531019e29-true-d12531135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12531019e29-true-d12531135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e58-true-d12531171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7277"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e58-true-d12531171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12529560e58-true-d12531171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531159e2-true-d12531191e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7276"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531159e2-true-d12531191e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12531159e2-true-d12531191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531159e8-true-d12531232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7275"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531159e8-true-d12531232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12531159e8-true-d12531232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e62-true-d12531325e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7274"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e62-true-d12531325e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12529560e62-true-d12531325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531261e9-true-d12531385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7273"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531261e9-true-d12531385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12531261e9-true-d12531385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e66-true-d12531507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7272"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e66-true-d12531507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12529560e66-true-d12531507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531434e10-true-d12531599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7271"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531434e10-true-d12531599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12531434e10-true-d12531599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531434e30-true-d12531638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7270"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531434e30-true-d12531638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12531434e30-true-d12531638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531434e34-true-d12531677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7269"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531434e34-true-d12531677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12531434e34-true-d12531677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531434e39-true-d12531738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7268"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531434e39-true-d12531738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12531434e39-true-d12531738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531701e12-true-d12531806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7267"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531701e12-true-d12531806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12531701e12-true-d12531806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531701e35-true-d12531865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7266"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531701e35-true-d12531865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12531701e35-true-d12531865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e71-true-d12531962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7265"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e71-true-d12531962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12529560e71-true-d12531962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531896e7-true-d12532037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7264"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531896e7-true-d12532037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12531896e7-true-d12532037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531967e9-true-d12532076e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7263"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531967e9-true-d12532076e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12531967e9-true-d12532076e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531967e10-true-d12532124e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7262"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531967e10-true-d12532124e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12531967e10-true-d12532124e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532087e12-true-d12532192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7261"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532087e12-true-d12532192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12532087e12-true-d12532192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532087e35-true-d12532251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7260"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532087e35-true-d12532251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12532087e35-true-d12532251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12531896e11-true-d12532328e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7259"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12531896e11-true-d12532328e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12531896e11-true-d12532328e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532282e16-true-d12532369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7258"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532282e16-true-d12532369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12532282e16-true-d12532369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e75-true-d12532441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7257"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e75-true-d12532441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12529560e75-true-d12532441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532380e15-true-d12532517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7256"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532380e15-true-d12532517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12532380e15-true-d12532517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532380e35-true-d12532572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7255"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532380e35-true-d12532572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12532380e35-true-d12532572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532380e39-true-d12532629e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7254"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532380e39-true-d12532629e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12532380e39-true-d12532629e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532380e42-true-d12532683e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7253"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532380e42-true-d12532683e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12532380e42-true-d12532683e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e81-true-d12532743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7252"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e81-true-d12532743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12529560e81-true-d12532743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532753e13-true-d12532777e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7251"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12532753e13-true-d12532777e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12532753e13-true-d12532777e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532798e13-true-d12532822e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7250"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12532798e13-true-d12532822e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12532798e13-true-d12532822e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532843e13-true-d12532867e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7249"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12532843e13-true-d12532867e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12532843e13-true-d12532867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532888e13-true-d12532922e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7248"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12532888e13-true-d12532922e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12532888e13-true-d12532922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12529560e86-true-d12532966e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7247"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12529560e86-true-d12532966e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12529560e86-true-d12532966e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12532954e2-true-d12532993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7246"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12532954e2-true-d12532993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12532954e2-true-d12532993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e16-true-d12534494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7245"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e16-true-d12534494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12533023e16-true-d12534494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e87-true-d12534592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7244"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e87-true-d12534592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12533023e87-true-d12534592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534569e9-true-d12534636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7243"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534569e9-true-d12534636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12534569e9-true-d12534636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534569e29-true-d12534685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7242"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534569e29-true-d12534685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12534569e29-true-d12534685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e92-true-d12534721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7241"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e92-true-d12534721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12533023e92-true-d12534721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534709e2-true-d12534741e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7240"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534709e2-true-d12534741e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12534709e2-true-d12534741e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534709e8-true-d12534782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7239"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534709e8-true-d12534782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12534709e8-true-d12534782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e96-true-d12534875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7238"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e96-true-d12534875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12533023e96-true-d12534875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534811e9-true-d12534935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7237"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534811e9-true-d12534935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12534811e9-true-d12534935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e100-true-d12535057e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7236"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e100-true-d12535057e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12533023e100-true-d12535057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534984e10-true-d12535149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7235"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534984e10-true-d12535149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12534984e10-true-d12535149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534984e30-true-d12535188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7234"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534984e30-true-d12535188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12534984e30-true-d12535188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534984e34-true-d12535227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7233"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534984e34-true-d12535227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12534984e34-true-d12535227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12534984e39-true-d12535288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7232"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12534984e39-true-d12535288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12534984e39-true-d12535288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535251e12-true-d12535356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7231"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535251e12-true-d12535356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12535251e12-true-d12535356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535251e35-true-d12535415e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7230"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535251e35-true-d12535415e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12535251e35-true-d12535415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e105-true-d12535512e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7229"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e105-true-d12535512e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12533023e105-true-d12535512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535446e7-true-d12535587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7228"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535446e7-true-d12535587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12535446e7-true-d12535587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535517e9-true-d12535626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7227"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535517e9-true-d12535626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12535517e9-true-d12535626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535517e10-true-d12535674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7226"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535517e10-true-d12535674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12535517e10-true-d12535674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535637e12-true-d12535742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7225"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535637e12-true-d12535742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12535637e12-true-d12535742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535637e35-true-d12535801e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7224"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535637e35-true-d12535801e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12535637e35-true-d12535801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535446e11-true-d12535878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7223"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535446e11-true-d12535878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12535446e11-true-d12535878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535832e16-true-d12535919e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7222"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535832e16-true-d12535919e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12535832e16-true-d12535919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e109-true-d12535991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7221"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e109-true-d12535991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12533023e109-true-d12535991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535930e15-true-d12536067e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7220"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535930e15-true-d12536067e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12535930e15-true-d12536067e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535930e35-true-d12536122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7219"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535930e35-true-d12536122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12535930e35-true-d12536122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535930e39-true-d12536179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7218"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535930e39-true-d12536179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12535930e39-true-d12536179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12535930e42-true-d12536233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7217"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12535930e42-true-d12536233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12535930e42-true-d12536233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e137-true-d12536302e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7216"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e137-true-d12536302e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12533023e137-true-d12536302e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536312e13-true-d12536336e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7215"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12536312e13-true-d12536336e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12536312e13-true-d12536336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536357e13-true-d12536381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7214"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12536357e13-true-d12536381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12536357e13-true-d12536381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536402e13-true-d12536426e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7213"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12536402e13-true-d12536426e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12536402e13-true-d12536426e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536447e13-true-d12536481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7212"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12536447e13-true-d12536481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12536447e13-true-d12536481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12533023e141-true-d12536525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7211"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12533023e141-true-d12536525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12533023e141-true-d12536525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536513e2-true-d12536552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7210"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12536513e2-true-d12536552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12536513e2-true-d12536552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e16-true-d12537989e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7209"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e16-true-d12537989e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12536573e16-true-d12537989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e43-true-d12538042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7208"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e43-true-d12538042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12536573e43-true-d12538042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538019e9-true-d12538086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7207"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538019e9-true-d12538086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12538019e9-true-d12538086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538019e29-true-d12538135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7206"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538019e29-true-d12538135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12538019e29-true-d12538135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e47-true-d12538171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7205"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e47-true-d12538171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12536573e47-true-d12538171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538159e2-true-d12538191e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7204"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538159e2-true-d12538191e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12538159e2-true-d12538191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538159e8-true-d12538232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7203"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538159e8-true-d12538232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12538159e8-true-d12538232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e52-true-d12538325e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7202"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e52-true-d12538325e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12536573e52-true-d12538325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538261e9-true-d12538385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7201"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538261e9-true-d12538385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12538261e9-true-d12538385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e56-true-d12538507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7200"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e56-true-d12538507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12536573e56-true-d12538507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538434e10-true-d12538599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7199"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538434e10-true-d12538599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12538434e10-true-d12538599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538434e30-true-d12538638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7198"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538434e30-true-d12538638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12538434e30-true-d12538638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538434e34-true-d12538677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7197"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538434e34-true-d12538677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12538434e34-true-d12538677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538434e39-true-d12538738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7196"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538434e39-true-d12538738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12538434e39-true-d12538738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538701e12-true-d12538806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7195"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538701e12-true-d12538806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12538701e12-true-d12538806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538701e35-true-d12538865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7194"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538701e35-true-d12538865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12538701e35-true-d12538865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e60-true-d12538962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7193"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e60-true-d12538962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12536573e60-true-d12538962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538896e7-true-d12539037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7192"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538896e7-true-d12539037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12538896e7-true-d12539037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538967e9-true-d12539076e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7191"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538967e9-true-d12539076e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12538967e9-true-d12539076e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538967e10-true-d12539124e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7190"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538967e10-true-d12539124e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12538967e10-true-d12539124e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539087e12-true-d12539192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7189"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539087e12-true-d12539192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12539087e12-true-d12539192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539087e35-true-d12539251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7188"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539087e35-true-d12539251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12539087e35-true-d12539251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12538896e11-true-d12539328e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7187"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12538896e11-true-d12539328e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12538896e11-true-d12539328e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539282e16-true-d12539369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7186"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539282e16-true-d12539369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12539282e16-true-d12539369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e65-true-d12539441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7185"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e65-true-d12539441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12536573e65-true-d12539441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539380e15-true-d12539517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7184"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539380e15-true-d12539517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12539380e15-true-d12539517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539380e35-true-d12539572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7183"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539380e35-true-d12539572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12539380e35-true-d12539572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539380e39-true-d12539629e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7182"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539380e39-true-d12539629e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12539380e39-true-d12539629e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539380e42-true-d12539683e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7181"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539380e42-true-d12539683e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12539380e42-true-d12539683e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e92-true-d12539752e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7180"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e92-true-d12539752e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12536573e92-true-d12539752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539762e13-true-d12539786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7179"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12539762e13-true-d12539786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12539762e13-true-d12539786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539807e13-true-d12539831e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7178"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12539807e13-true-d12539831e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12539807e13-true-d12539831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539852e13-true-d12539876e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7177"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12539852e13-true-d12539876e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12539852e13-true-d12539876e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539897e13-true-d12539931e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7176"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12539897e13-true-d12539931e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12539897e13-true-d12539931e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12536573e97-true-d12539975e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7175"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12536573e97-true-d12539975e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12536573e97-true-d12539975e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12539963e2-true-d12540002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7174"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12539963e2-true-d12540002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12539963e2-true-d12540002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e16-true-d12541562e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7173"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e16-true-d12541562e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12540023e16-true-d12541562e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e95-true-d12541678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7172"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e95-true-d12541678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12540023e95-true-d12541678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12541655e9-true-d12541722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7171"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12541655e9-true-d12541722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12541655e9-true-d12541722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12541655e29-true-d12541771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7170"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12541655e29-true-d12541771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12541655e29-true-d12541771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e99-true-d12541807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7169"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e99-true-d12541807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12540023e99-true-d12541807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12541795e2-true-d12541827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7168"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12541795e2-true-d12541827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12541795e2-true-d12541827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12541795e8-true-d12541868e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7167"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12541795e8-true-d12541868e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12541795e8-true-d12541868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e103-true-d12541945e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="7166"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e103-true-d12541945e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12540023e103-true-d12541945e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12541897e5-true-d12542001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="7165"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12541897e5-true-d12542001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12541897e5-true-d12542001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542011e13-true-d12542028e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="7164"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12542011e13-true-d12542028e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12542011e13-true-d12542028e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542043e13-true-d12542071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="7163"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12542043e13-true-d12542071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12542043e13-true-d12542071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12541897e24-true-d12542132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7162"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12541897e24-true-d12542132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12541897e24-true-d12542132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542095e12-true-d12542200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7161"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542095e12-true-d12542200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12542095e12-true-d12542200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542095e35-true-d12542259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7160"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542095e35-true-d12542259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12542095e35-true-d12542259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e111-true-d12542354e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7159"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e111-true-d12542354e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12540023e111-true-d12542354e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542290e9-true-d12542414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7158"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542290e9-true-d12542414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12542290e9-true-d12542414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e115-true-d12542536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7157"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e115-true-d12542536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12540023e115-true-d12542536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542463e10-true-d12542628e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7156"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542463e10-true-d12542628e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12542463e10-true-d12542628e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542463e30-true-d12542667e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7155"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542463e30-true-d12542667e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12542463e30-true-d12542667e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542463e34-true-d12542706e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7154"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542463e34-true-d12542706e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12542463e34-true-d12542706e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542463e39-true-d12542767e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7153"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542463e39-true-d12542767e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12542463e39-true-d12542767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542730e12-true-d12542835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7152"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542730e12-true-d12542835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12542730e12-true-d12542835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542730e35-true-d12542894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7151"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542730e35-true-d12542894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12542730e35-true-d12542894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e119-true-d12542991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7150"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e119-true-d12542991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12540023e119-true-d12542991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542925e7-true-d12543066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7149"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542925e7-true-d12543066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12542925e7-true-d12543066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542996e9-true-d12543105e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7148"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542996e9-true-d12543105e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12542996e9-true-d12543105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542996e10-true-d12543153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7147"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542996e10-true-d12543153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12542996e10-true-d12543153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543116e12-true-d12543221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7146"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543116e12-true-d12543221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12543116e12-true-d12543221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543116e35-true-d12543280e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7145"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543116e35-true-d12543280e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12543116e35-true-d12543280e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12542925e11-true-d12543357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7144"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12542925e11-true-d12543357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12542925e11-true-d12543357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543311e16-true-d12543398e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7143"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543311e16-true-d12543398e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12543311e16-true-d12543398e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e124-true-d12543470e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7142"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e124-true-d12543470e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12540023e124-true-d12543470e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543409e15-true-d12543546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7141"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543409e15-true-d12543546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12543409e15-true-d12543546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543409e35-true-d12543601e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7140"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543409e35-true-d12543601e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12543409e35-true-d12543601e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543409e39-true-d12543658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7139"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543409e39-true-d12543658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12543409e39-true-d12543658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543409e42-true-d12543712e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7138"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543409e42-true-d12543712e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12543409e42-true-d12543712e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e151-true-d12543781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7137"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e151-true-d12543781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12540023e151-true-d12543781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543791e13-true-d12543815e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7136"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12543791e13-true-d12543815e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12543791e13-true-d12543815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543836e13-true-d12543860e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7135"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12543836e13-true-d12543860e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12543836e13-true-d12543860e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543881e13-true-d12543905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7134"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12543881e13-true-d12543905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12543881e13-true-d12543905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543926e13-true-d12543960e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7133"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12543926e13-true-d12543960e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12543926e13-true-d12543960e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12540023e156-true-d12544004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7132"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12540023e156-true-d12544004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12540023e156-true-d12544004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12543992e2-true-d12544031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7131"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12543992e2-true-d12544031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12543992e2-true-d12544031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e16-true-d12545558e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7130"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e16-true-d12545558e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12544052e16-true-d12545558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e71-true-d12545650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7129"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e71-true-d12545650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12544052e71-true-d12545650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12545627e9-true-d12545694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7128"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12545627e9-true-d12545694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12545627e9-true-d12545694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12545627e29-true-d12545743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7127"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12545627e29-true-d12545743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12545627e29-true-d12545743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e76-true-d12545779e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7126"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e76-true-d12545779e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12544052e76-true-d12545779e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12545767e2-true-d12545799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7125"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12545767e2-true-d12545799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12545767e2-true-d12545799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12545767e8-true-d12545840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7124"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12545767e8-true-d12545840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12545767e8-true-d12545840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e80-true-d12545917e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="7123"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e80-true-d12545917e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12544052e80-true-d12545917e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12545869e5-true-d12545973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="7122"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12545869e5-true-d12545973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12545869e5-true-d12545973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12545983e13-true-d12546000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="7121"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12545983e13-true-d12546000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12545983e13-true-d12546000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546015e13-true-d12546043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="7120"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12546015e13-true-d12546043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12546015e13-true-d12546043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12545869e24-true-d12546104e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7119"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12545869e24-true-d12546104e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12545869e24-true-d12546104e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546067e12-true-d12546172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7118"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546067e12-true-d12546172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12546067e12-true-d12546172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546067e35-true-d12546231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7117"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546067e35-true-d12546231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12546067e35-true-d12546231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e87-true-d12546326e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7116"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e87-true-d12546326e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12544052e87-true-d12546326e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546262e9-true-d12546386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7115"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546262e9-true-d12546386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12546262e9-true-d12546386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e92-true-d12546508e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7114"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e92-true-d12546508e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12544052e92-true-d12546508e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546435e10-true-d12546600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7113"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546435e10-true-d12546600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12546435e10-true-d12546600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546435e30-true-d12546639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7112"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546435e30-true-d12546639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12546435e30-true-d12546639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546435e34-true-d12546678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7111"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546435e34-true-d12546678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12546435e34-true-d12546678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546435e39-true-d12546739e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7110"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546435e39-true-d12546739e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12546435e39-true-d12546739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546702e12-true-d12546807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7109"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546702e12-true-d12546807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12546702e12-true-d12546807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546702e35-true-d12546866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7108"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546702e35-true-d12546866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12546702e35-true-d12546866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e96-true-d12546963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7107"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e96-true-d12546963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12544052e96-true-d12546963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546897e7-true-d12547038e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7106"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546897e7-true-d12547038e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12546897e7-true-d12547038e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546968e9-true-d12547077e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7105"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546968e9-true-d12547077e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12546968e9-true-d12547077e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546968e10-true-d12547125e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7104"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546968e10-true-d12547125e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12546968e10-true-d12547125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547088e12-true-d12547193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7103"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547088e12-true-d12547193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12547088e12-true-d12547193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547088e35-true-d12547252e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7102"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547088e35-true-d12547252e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12547088e35-true-d12547252e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12546897e11-true-d12547329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7101"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12546897e11-true-d12547329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12546897e11-true-d12547329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547283e16-true-d12547370e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7100"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547283e16-true-d12547370e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12547283e16-true-d12547370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e100-true-d12547442e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7099"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e100-true-d12547442e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12544052e100-true-d12547442e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547381e15-true-d12547518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7098"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547381e15-true-d12547518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12547381e15-true-d12547518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547381e35-true-d12547573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7097"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547381e35-true-d12547573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12547381e35-true-d12547573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547381e39-true-d12547630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7096"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547381e39-true-d12547630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12547381e39-true-d12547630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547381e42-true-d12547684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7095"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547381e42-true-d12547684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12547381e42-true-d12547684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e128-true-d12547753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7094"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e128-true-d12547753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12544052e128-true-d12547753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547763e13-true-d12547787e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7093"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12547763e13-true-d12547787e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12547763e13-true-d12547787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547808e13-true-d12547832e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7092"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12547808e13-true-d12547832e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12547808e13-true-d12547832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547853e13-true-d12547877e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7091"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12547853e13-true-d12547877e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12547853e13-true-d12547877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547898e13-true-d12547932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7090"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12547898e13-true-d12547932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12547898e13-true-d12547932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12544052e132-true-d12547976e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7089"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12544052e132-true-d12547976e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12544052e132-true-d12547976e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12547964e2-true-d12548003e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7088"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12547964e2-true-d12548003e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12547964e2-true-d12548003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e114-true-d12548061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7087"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e114-true-d12548061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12507141e114-true-d12548061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548071e13-true-d12548095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7086"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12548071e13-true-d12548095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12548071e13-true-d12548095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548116e13-true-d12548140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7085"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12548116e13-true-d12548140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12548116e13-true-d12548140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548161e13-true-d12548185e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7084"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12548161e13-true-d12548185e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12548161e13-true-d12548185e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548206e13-true-d12548240e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7083"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12548206e13-true-d12548240e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12548206e13-true-d12548240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12507141e118-true-d12548284e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7082"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12507141e118-true-d12548284e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12507141e118-true-d12548284e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548272e2-true-d12548311e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7081"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12548272e2-true-d12548311e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12548272e2-true-d12548311e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e16-true-d12549835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="7080"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e16-true-d12549835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12548332e16-true-d12549835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e100-true-d12549954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7079"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e100-true-d12549954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12548332e100-true-d12549954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12549931e9-true-d12549998e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7078"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12549931e9-true-d12549998e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12549931e9-true-d12549998e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12549931e29-true-d12550047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7077"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12549931e29-true-d12550047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12549931e29-true-d12550047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e104-true-d12550083e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7076"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e104-true-d12550083e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12548332e104-true-d12550083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550071e2-true-d12550103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7075"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550071e2-true-d12550103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12550071e2-true-d12550103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550071e8-true-d12550144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7074"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550071e8-true-d12550144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12550071e8-true-d12550144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e108-true-d12550237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7073"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e108-true-d12550237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12548332e108-true-d12550237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550173e9-true-d12550297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7072"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550173e9-true-d12550297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12550173e9-true-d12550297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e113-true-d12550419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7071"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e113-true-d12550419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12548332e113-true-d12550419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550346e10-true-d12550511e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7070"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550346e10-true-d12550511e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12550346e10-true-d12550511e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550346e30-true-d12550550e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7069"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550346e30-true-d12550550e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12550346e30-true-d12550550e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550346e34-true-d12550589e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7068"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550346e34-true-d12550589e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12550346e34-true-d12550589e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550346e39-true-d12550650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7067"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550346e39-true-d12550650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12550346e39-true-d12550650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550613e12-true-d12550718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7066"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550613e12-true-d12550718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12550613e12-true-d12550718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550613e35-true-d12550777e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7065"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550613e35-true-d12550777e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12550613e35-true-d12550777e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e117-true-d12550874e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7064"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e117-true-d12550874e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12548332e117-true-d12550874e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550808e7-true-d12550949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7063"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550808e7-true-d12550949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12550808e7-true-d12550949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550879e9-true-d12550988e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7062"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550879e9-true-d12550988e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12550879e9-true-d12550988e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550879e10-true-d12551036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7061"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550879e10-true-d12551036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12550879e10-true-d12551036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550999e12-true-d12551104e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7060"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550999e12-true-d12551104e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12550999e12-true-d12551104e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550999e35-true-d12551163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7059"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550999e35-true-d12551163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12550999e35-true-d12551163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12550808e11-true-d12551240e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7058"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12550808e11-true-d12551240e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12550808e11-true-d12551240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12551194e16-true-d12551281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7057"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12551194e16-true-d12551281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12551194e16-true-d12551281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e121-true-d12551353e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7056"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e121-true-d12551353e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12548332e121-true-d12551353e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12551292e15-true-d12551429e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7055"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12551292e15-true-d12551429e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12551292e15-true-d12551429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12551292e35-true-d12551484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7054"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12551292e35-true-d12551484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12551292e35-true-d12551484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12551292e39-true-d12551541e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7053"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12551292e39-true-d12551541e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12551292e39-true-d12551541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12551292e42-true-d12551595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7052"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12551292e42-true-d12551595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12551292e42-true-d12551595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e126-true-d12556702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="7051"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e126-true-d12556702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12548332e126-true-d12556702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e16-true-d12558167e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7050"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e16-true-d12558167e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12556717e16-true-d12558167e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e77-true-d12558247e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7049"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e77-true-d12558247e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12556717e77-true-d12558247e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558224e9-true-d12558291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7048"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558224e9-true-d12558291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12558224e9-true-d12558291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558224e29-true-d12558340e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7047"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558224e29-true-d12558340e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12558224e29-true-d12558340e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e81-true-d12558376e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7046"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e81-true-d12558376e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12556717e81-true-d12558376e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558364e2-true-d12558396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7045"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558364e2-true-d12558396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12558364e2-true-d12558396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558364e8-true-d12558437e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7044"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558364e8-true-d12558437e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12558364e8-true-d12558437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e85-true-d12558530e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7043"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e85-true-d12558530e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12556717e85-true-d12558530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558466e9-true-d12558590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7042"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558466e9-true-d12558590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12558466e9-true-d12558590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e90-true-d12558712e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7041"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e90-true-d12558712e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12556717e90-true-d12558712e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558639e10-true-d12558804e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7040"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558639e10-true-d12558804e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12558639e10-true-d12558804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558639e30-true-d12558843e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7039"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558639e30-true-d12558843e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12558639e30-true-d12558843e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558639e34-true-d12558882e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7038"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558639e34-true-d12558882e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12558639e34-true-d12558882e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558639e39-true-d12558943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7037"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558639e39-true-d12558943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12558639e39-true-d12558943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558906e12-true-d12559011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7036"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558906e12-true-d12559011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12558906e12-true-d12559011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12558906e35-true-d12559070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7035"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12558906e35-true-d12559070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12558906e35-true-d12559070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e94-true-d12559167e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="7034"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e94-true-d12559167e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12556717e94-true-d12559167e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559101e7-true-d12559242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7033"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559101e7-true-d12559242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12559101e7-true-d12559242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559172e9-true-d12559281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7032"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559172e9-true-d12559281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12559172e9-true-d12559281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559172e10-true-d12559329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7031"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559172e10-true-d12559329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12559172e10-true-d12559329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559292e12-true-d12559397e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7030"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559292e12-true-d12559397e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12559292e12-true-d12559397e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559292e35-true-d12559456e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="7029"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559292e35-true-d12559456e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12559292e35-true-d12559456e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559101e11-true-d12559533e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="7028"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559101e11-true-d12559533e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12559101e11-true-d12559533e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559487e16-true-d12559574e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="7027"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559487e16-true-d12559574e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12559487e16-true-d12559574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e98-true-d12559646e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="7026"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e98-true-d12559646e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12556717e98-true-d12559646e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559585e15-true-d12559722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="7025"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559585e15-true-d12559722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12559585e15-true-d12559722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559585e35-true-d12559777e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7024"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559585e35-true-d12559777e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12559585e35-true-d12559777e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559585e39-true-d12559834e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7023"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559585e39-true-d12559834e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12559585e39-true-d12559834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559585e42-true-d12559888e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="7022"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12559585e42-true-d12559888e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12559585e42-true-d12559888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e126-true-d12559957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="7021"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e126-true-d12559957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12556717e126-true-d12559957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12559967e13-true-d12559991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7020"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12559967e13-true-d12559991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12559967e13-true-d12559991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560012e13-true-d12560036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7019"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12560012e13-true-d12560036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12560012e13-true-d12560036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560057e13-true-d12560081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="7018"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12560057e13-true-d12560081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12560057e13-true-d12560081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560102e13-true-d12560136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="7017"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12560102e13-true-d12560136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12560102e13-true-d12560136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12556717e130-true-d12560180e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="7016"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12556717e130-true-d12560180e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12556717e130-true-d12560180e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560168e2-true-d12560207e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="7015"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12560168e2-true-d12560207e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12560168e2-true-d12560207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e16-true-d12561671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="7014"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e16-true-d12561671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12560228e16-true-d12561671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e65-true-d12561745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="7013"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e65-true-d12561745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12560228e65-true-d12561745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12561722e9-true-d12561789e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="7012"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12561722e9-true-d12561789e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12561722e9-true-d12561789e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12561722e29-true-d12561838e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="7011"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12561722e29-true-d12561838e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12561722e29-true-d12561838e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e69-true-d12561874e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="7010"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e69-true-d12561874e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12560228e69-true-d12561874e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12561862e2-true-d12561894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="7009"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12561862e2-true-d12561894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12561862e2-true-d12561894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12561862e8-true-d12561935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="7008"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12561862e8-true-d12561935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12561862e8-true-d12561935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e73-true-d12562028e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="7007"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e73-true-d12562028e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12560228e73-true-d12562028e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12561964e9-true-d12562088e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="7006"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12561964e9-true-d12562088e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12561964e9-true-d12562088e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e78-true-d12562210e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="7005"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e78-true-d12562210e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12560228e78-true-d12562210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562137e10-true-d12562302e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="7004"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562137e10-true-d12562302e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12562137e10-true-d12562302e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562137e30-true-d12562341e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="7003"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562137e30-true-d12562341e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12562137e30-true-d12562341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562137e34-true-d12562380e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="7002"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562137e34-true-d12562380e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12562137e34-true-d12562380e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562137e39-true-d12562441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="7001"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562137e39-true-d12562441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12562137e39-true-d12562441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562404e12-true-d12562509e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="7000"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562404e12-true-d12562509e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12562404e12-true-d12562509e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562404e35-true-d12562568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6999"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562404e35-true-d12562568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12562404e35-true-d12562568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e82-true-d12562665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6998"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e82-true-d12562665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12560228e82-true-d12562665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562599e7-true-d12562740e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6997"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562599e7-true-d12562740e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12562599e7-true-d12562740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562670e9-true-d12562779e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6996"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562670e9-true-d12562779e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12562670e9-true-d12562779e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562670e10-true-d12562827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6995"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562670e10-true-d12562827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12562670e10-true-d12562827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562790e12-true-d12562895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6994"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562790e12-true-d12562895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12562790e12-true-d12562895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562790e35-true-d12562954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6993"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562790e35-true-d12562954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12562790e35-true-d12562954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562599e11-true-d12563031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6992"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562599e11-true-d12563031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12562599e11-true-d12563031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12562985e16-true-d12563072e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6991"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12562985e16-true-d12563072e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12562985e16-true-d12563072e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e86-true-d12563144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6990"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e86-true-d12563144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12560228e86-true-d12563144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563083e15-true-d12563220e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6989"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12563083e15-true-d12563220e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12563083e15-true-d12563220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563083e35-true-d12563275e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6988"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12563083e35-true-d12563275e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12563083e35-true-d12563275e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563083e39-true-d12563332e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6987"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12563083e39-true-d12563332e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12563083e39-true-d12563332e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563083e42-true-d12563386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6986"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12563083e42-true-d12563386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12563083e42-true-d12563386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e114-true-d12563455e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6985"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e114-true-d12563455e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12560228e114-true-d12563455e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563465e13-true-d12563489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6984"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12563465e13-true-d12563489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12563465e13-true-d12563489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563510e13-true-d12563534e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6983"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12563510e13-true-d12563534e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12563510e13-true-d12563534e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563555e13-true-d12563579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6982"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12563555e13-true-d12563579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12563555e13-true-d12563579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563600e13-true-d12563634e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6981"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12563600e13-true-d12563634e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12563600e13-true-d12563634e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12560228e118-true-d12563678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6980"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12560228e118-true-d12563678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12560228e118-true-d12563678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563666e2-true-d12563705e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6979"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12563666e2-true-d12563705e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12563666e2-true-d12563705e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e16-true-d12565229e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="6978"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e16-true-d12565229e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12563726e16-true-d12565229e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e100-true-d12565348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6977"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e100-true-d12565348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12563726e100-true-d12565348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565325e9-true-d12565392e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6976"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565325e9-true-d12565392e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12565325e9-true-d12565392e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565325e29-true-d12565441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6975"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565325e29-true-d12565441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12565325e29-true-d12565441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e104-true-d12565477e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6974"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e104-true-d12565477e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12563726e104-true-d12565477e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565465e2-true-d12565497e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6973"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565465e2-true-d12565497e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12565465e2-true-d12565497e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565465e8-true-d12565538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6972"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565465e8-true-d12565538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12565465e8-true-d12565538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e108-true-d12565631e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6971"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e108-true-d12565631e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12563726e108-true-d12565631e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565567e9-true-d12565691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6970"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565567e9-true-d12565691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12565567e9-true-d12565691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e113-true-d12565813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6969"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e113-true-d12565813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12563726e113-true-d12565813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565740e10-true-d12565905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6968"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565740e10-true-d12565905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12565740e10-true-d12565905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565740e30-true-d12565944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6967"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565740e30-true-d12565944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12565740e30-true-d12565944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565740e34-true-d12565983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6966"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565740e34-true-d12565983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12565740e34-true-d12565983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12565740e39-true-d12566044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6965"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12565740e39-true-d12566044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12565740e39-true-d12566044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566007e12-true-d12566112e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6964"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566007e12-true-d12566112e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12566007e12-true-d12566112e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566007e35-true-d12566171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6963"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566007e35-true-d12566171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12566007e35-true-d12566171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e117-true-d12566268e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6962"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e117-true-d12566268e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12563726e117-true-d12566268e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566202e7-true-d12566343e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6961"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566202e7-true-d12566343e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12566202e7-true-d12566343e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566273e9-true-d12566382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6960"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566273e9-true-d12566382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12566273e9-true-d12566382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566273e10-true-d12566430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6959"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566273e10-true-d12566430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12566273e10-true-d12566430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566393e12-true-d12566498e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6958"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566393e12-true-d12566498e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12566393e12-true-d12566498e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566393e35-true-d12566557e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6957"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566393e35-true-d12566557e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12566393e35-true-d12566557e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566202e11-true-d12566634e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6956"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566202e11-true-d12566634e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12566202e11-true-d12566634e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566588e16-true-d12566675e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6955"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566588e16-true-d12566675e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12566588e16-true-d12566675e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e121-true-d12566747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6954"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e121-true-d12566747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12563726e121-true-d12566747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566686e15-true-d12566823e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6953"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566686e15-true-d12566823e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12566686e15-true-d12566823e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566686e35-true-d12566878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6952"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566686e35-true-d12566878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12566686e35-true-d12566878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566686e39-true-d12566935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6951"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566686e39-true-d12566935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12566686e39-true-d12566935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12566686e42-true-d12566989e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6950"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12566686e42-true-d12566989e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12566686e42-true-d12566989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e149-true-d12567058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6949"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e149-true-d12567058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12563726e149-true-d12567058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567068e13-true-d12567092e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6948"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12567068e13-true-d12567092e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12567068e13-true-d12567092e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567113e13-true-d12567137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6947"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12567113e13-true-d12567137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12567113e13-true-d12567137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567158e13-true-d12567182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6946"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12567158e13-true-d12567182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12567158e13-true-d12567182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567203e13-true-d12567237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6945"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12567203e13-true-d12567237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12567203e13-true-d12567237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e153-true-d12567281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6944"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e153-true-d12567281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12563726e153-true-d12567281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567269e2-true-d12567308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6943"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12567269e2-true-d12567308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12567269e2-true-d12567308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e158-true-d12567339e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="6942"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e158-true-d12567339e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12563726e158-true-d12567339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12563726e162-true-d12567377e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="6941"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12563726e162-true-d12567377e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12563726e162-true-d12567377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e16-true-d12568822e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6940"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e16-true-d12568822e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12567406e16-true-d12568822e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e43-true-d12568875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6939"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e43-true-d12568875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12567406e43-true-d12568875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12568852e9-true-d12568919e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6938"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12568852e9-true-d12568919e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12568852e9-true-d12568919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12568852e29-true-d12568968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6937"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12568852e29-true-d12568968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12568852e29-true-d12568968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e47-true-d12569004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6936"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e47-true-d12569004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12567406e47-true-d12569004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12568992e2-true-d12569024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6935"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12568992e2-true-d12569024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12568992e2-true-d12569024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12568992e8-true-d12569065e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6934"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12568992e8-true-d12569065e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12568992e8-true-d12569065e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e52-true-d12569158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6933"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e52-true-d12569158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12567406e52-true-d12569158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569094e9-true-d12569218e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6932"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569094e9-true-d12569218e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12569094e9-true-d12569218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e56-true-d12569340e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6931"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e56-true-d12569340e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12567406e56-true-d12569340e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569267e10-true-d12569432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6930"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569267e10-true-d12569432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12569267e10-true-d12569432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569267e30-true-d12569471e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6929"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569267e30-true-d12569471e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12569267e30-true-d12569471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569267e34-true-d12569510e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6928"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569267e34-true-d12569510e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12569267e34-true-d12569510e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569267e39-true-d12569571e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6927"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569267e39-true-d12569571e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12569267e39-true-d12569571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569534e12-true-d12569639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6926"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569534e12-true-d12569639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12569534e12-true-d12569639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569534e35-true-d12569698e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6925"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569534e35-true-d12569698e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12569534e35-true-d12569698e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e60-true-d12569795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6924"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e60-true-d12569795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12567406e60-true-d12569795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569729e7-true-d12569870e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6923"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569729e7-true-d12569870e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12569729e7-true-d12569870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569800e9-true-d12569909e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6922"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569800e9-true-d12569909e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12569800e9-true-d12569909e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569800e10-true-d12569957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6921"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569800e10-true-d12569957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12569800e10-true-d12569957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569920e12-true-d12570025e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6920"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569920e12-true-d12570025e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12569920e12-true-d12570025e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569920e35-true-d12570084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6919"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569920e35-true-d12570084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12569920e35-true-d12570084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12569729e11-true-d12570161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6918"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12569729e11-true-d12570161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12569729e11-true-d12570161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570115e16-true-d12570202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6917"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12570115e16-true-d12570202e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12570115e16-true-d12570202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e65-true-d12570274e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6916"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e65-true-d12570274e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12567406e65-true-d12570274e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570213e15-true-d12570350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6915"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12570213e15-true-d12570350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12570213e15-true-d12570350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570213e35-true-d12570405e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6914"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12570213e35-true-d12570405e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12570213e35-true-d12570405e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570213e39-true-d12570462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6913"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12570213e39-true-d12570462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12570213e39-true-d12570462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570213e42-true-d12570516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6912"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12570213e42-true-d12570516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12570213e42-true-d12570516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e92-true-d12570585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6911"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e92-true-d12570585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12567406e92-true-d12570585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570595e13-true-d12570619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6910"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12570595e13-true-d12570619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12570595e13-true-d12570619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570640e13-true-d12570664e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6909"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12570640e13-true-d12570664e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12570640e13-true-d12570664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570685e13-true-d12570709e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6908"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12570685e13-true-d12570709e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12570685e13-true-d12570709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570730e13-true-d12570764e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6907"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12570730e13-true-d12570764e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12570730e13-true-d12570764e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12567406e97-true-d12570808e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6906"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12567406e97-true-d12570808e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12567406e97-true-d12570808e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570796e2-true-d12570835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6905"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12570796e2-true-d12570835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12570796e2-true-d12570835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e16-true-d12572279e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="6904"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e16-true-d12572279e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12570856e16-true-d12572279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e53-true-d12572338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6903"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e53-true-d12572338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12570856e53-true-d12572338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572315e9-true-d12572382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6902"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572315e9-true-d12572382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12572315e9-true-d12572382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572315e29-true-d12572431e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6901"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572315e29-true-d12572431e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12572315e29-true-d12572431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e58-true-d12572467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6900"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e58-true-d12572467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12570856e58-true-d12572467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572455e2-true-d12572487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6899"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572455e2-true-d12572487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12572455e2-true-d12572487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572455e8-true-d12572528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6898"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572455e8-true-d12572528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12572455e8-true-d12572528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e62-true-d12572621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6897"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e62-true-d12572621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12570856e62-true-d12572621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572557e9-true-d12572681e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6896"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572557e9-true-d12572681e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12572557e9-true-d12572681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e66-true-d12572803e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6895"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e66-true-d12572803e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12570856e66-true-d12572803e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572730e10-true-d12572895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6894"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572730e10-true-d12572895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12572730e10-true-d12572895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572730e30-true-d12572934e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6893"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572730e30-true-d12572934e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12572730e30-true-d12572934e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572730e34-true-d12572973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6892"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572730e34-true-d12572973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12572730e34-true-d12572973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572730e39-true-d12573034e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6891"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572730e39-true-d12573034e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12572730e39-true-d12573034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572997e12-true-d12573102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6890"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572997e12-true-d12573102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12572997e12-true-d12573102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12572997e35-true-d12573161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6889"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12572997e35-true-d12573161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12572997e35-true-d12573161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e71-true-d12573258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6888"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e71-true-d12573258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12570856e71-true-d12573258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573192e7-true-d12573333e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6887"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573192e7-true-d12573333e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12573192e7-true-d12573333e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573263e9-true-d12573372e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6886"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573263e9-true-d12573372e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12573263e9-true-d12573372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573263e10-true-d12573420e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6885"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573263e10-true-d12573420e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12573263e10-true-d12573420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573383e12-true-d12573488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6884"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573383e12-true-d12573488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12573383e12-true-d12573488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573383e35-true-d12573547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6883"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573383e35-true-d12573547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12573383e35-true-d12573547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573192e11-true-d12573624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6882"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573192e11-true-d12573624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12573192e11-true-d12573624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573578e16-true-d12573665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6881"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573578e16-true-d12573665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12573578e16-true-d12573665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e75-true-d12573737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6880"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e75-true-d12573737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12570856e75-true-d12573737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573676e15-true-d12573813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6879"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573676e15-true-d12573813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12573676e15-true-d12573813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573676e35-true-d12573868e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6878"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573676e35-true-d12573868e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12573676e35-true-d12573868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573676e39-true-d12573925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6877"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573676e39-true-d12573925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12573676e39-true-d12573925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12573676e42-true-d12573979e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6876"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12573676e42-true-d12573979e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12573676e42-true-d12573979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e81-true-d12574039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6875"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e81-true-d12574039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12570856e81-true-d12574039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574049e13-true-d12574073e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6874"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12574049e13-true-d12574073e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12574049e13-true-d12574073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574094e13-true-d12574118e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6873"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12574094e13-true-d12574118e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12574094e13-true-d12574118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574139e13-true-d12574163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6872"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12574139e13-true-d12574163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12574139e13-true-d12574163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574184e13-true-d12574218e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6871"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12574184e13-true-d12574218e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12574184e13-true-d12574218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12570856e86-true-d12574262e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6870"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12570856e86-true-d12574262e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12570856e86-true-d12574262e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574250e2-true-d12574289e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6869"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12574250e2-true-d12574289e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12574250e2-true-d12574289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e16-true-d12575790e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6868"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e16-true-d12575790e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12574319e16-true-d12575790e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e87-true-d12575888e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6867"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e87-true-d12575888e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12574319e87-true-d12575888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12575865e9-true-d12575932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6866"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12575865e9-true-d12575932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12575865e9-true-d12575932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12575865e29-true-d12575981e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6865"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12575865e29-true-d12575981e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12575865e29-true-d12575981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e92-true-d12576017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6864"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e92-true-d12576017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12574319e92-true-d12576017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576005e2-true-d12576037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6863"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576005e2-true-d12576037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12576005e2-true-d12576037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576005e8-true-d12576078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6862"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576005e8-true-d12576078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12576005e8-true-d12576078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e96-true-d12576171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6861"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e96-true-d12576171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12574319e96-true-d12576171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576107e9-true-d12576231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6860"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576107e9-true-d12576231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12576107e9-true-d12576231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e100-true-d12576353e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6859"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e100-true-d12576353e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12574319e100-true-d12576353e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576280e10-true-d12576445e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6858"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576280e10-true-d12576445e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12576280e10-true-d12576445e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576280e30-true-d12576484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6857"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576280e30-true-d12576484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12576280e30-true-d12576484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576280e34-true-d12576523e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6856"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576280e34-true-d12576523e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12576280e34-true-d12576523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576280e39-true-d12576584e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6855"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576280e39-true-d12576584e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12576280e39-true-d12576584e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576547e12-true-d12576652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6854"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576547e12-true-d12576652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12576547e12-true-d12576652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576547e35-true-d12576711e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6853"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576547e35-true-d12576711e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12576547e35-true-d12576711e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e105-true-d12576808e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6852"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e105-true-d12576808e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12574319e105-true-d12576808e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576742e7-true-d12576883e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6851"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576742e7-true-d12576883e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12576742e7-true-d12576883e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576813e9-true-d12576922e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6850"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576813e9-true-d12576922e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12576813e9-true-d12576922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576813e10-true-d12576970e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6849"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576813e10-true-d12576970e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12576813e10-true-d12576970e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576933e12-true-d12577038e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6848"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576933e12-true-d12577038e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12576933e12-true-d12577038e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576933e35-true-d12577097e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6847"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576933e35-true-d12577097e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12576933e35-true-d12577097e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12576742e11-true-d12577174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6846"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12576742e11-true-d12577174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12576742e11-true-d12577174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577128e16-true-d12577215e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6845"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12577128e16-true-d12577215e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12577128e16-true-d12577215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e109-true-d12577287e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6844"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e109-true-d12577287e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12574319e109-true-d12577287e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577226e15-true-d12577363e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6843"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12577226e15-true-d12577363e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12577226e15-true-d12577363e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577226e35-true-d12577418e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6842"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12577226e35-true-d12577418e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12577226e35-true-d12577418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577226e39-true-d12577475e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6841"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12577226e39-true-d12577475e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12577226e39-true-d12577475e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577226e42-true-d12577529e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6840"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12577226e42-true-d12577529e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12577226e42-true-d12577529e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e137-true-d12577598e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6839"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e137-true-d12577598e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12574319e137-true-d12577598e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577608e13-true-d12577632e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6838"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12577608e13-true-d12577632e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12577608e13-true-d12577632e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577653e13-true-d12577677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6837"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12577653e13-true-d12577677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12577653e13-true-d12577677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577698e13-true-d12577722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6836"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12577698e13-true-d12577722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12577698e13-true-d12577722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577743e13-true-d12577777e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6835"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12577743e13-true-d12577777e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12577743e13-true-d12577777e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12574319e141-true-d12577821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6834"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12574319e141-true-d12577821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12574319e141-true-d12577821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577809e2-true-d12577848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6833"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12577809e2-true-d12577848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12577809e2-true-d12577848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e16-true-d12579285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6832"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e16-true-d12579285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12577869e16-true-d12579285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e43-true-d12579338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6831"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e43-true-d12579338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12577869e43-true-d12579338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579315e9-true-d12579382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6830"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579315e9-true-d12579382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12579315e9-true-d12579382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579315e29-true-d12579431e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6829"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579315e29-true-d12579431e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12579315e29-true-d12579431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e47-true-d12579467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6828"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e47-true-d12579467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12577869e47-true-d12579467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579455e2-true-d12579487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6827"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579455e2-true-d12579487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12579455e2-true-d12579487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579455e8-true-d12579528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6826"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579455e8-true-d12579528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12579455e8-true-d12579528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e52-true-d12579621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6825"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e52-true-d12579621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12577869e52-true-d12579621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579557e9-true-d12579681e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6824"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579557e9-true-d12579681e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12579557e9-true-d12579681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e56-true-d12579803e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6823"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e56-true-d12579803e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12577869e56-true-d12579803e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579730e10-true-d12579895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6822"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579730e10-true-d12579895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12579730e10-true-d12579895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579730e30-true-d12579934e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6821"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579730e30-true-d12579934e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12579730e30-true-d12579934e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579730e34-true-d12579973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6820"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579730e34-true-d12579973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12579730e34-true-d12579973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579730e39-true-d12580034e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6819"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579730e39-true-d12580034e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12579730e39-true-d12580034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579997e12-true-d12580102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6818"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579997e12-true-d12580102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12579997e12-true-d12580102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12579997e35-true-d12580161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6817"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12579997e35-true-d12580161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12579997e35-true-d12580161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e60-true-d12580258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6816"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e60-true-d12580258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12577869e60-true-d12580258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580192e7-true-d12580333e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6815"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580192e7-true-d12580333e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12580192e7-true-d12580333e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580263e9-true-d12580372e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6814"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580263e9-true-d12580372e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12580263e9-true-d12580372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580263e10-true-d12580420e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6813"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580263e10-true-d12580420e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12580263e10-true-d12580420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580383e12-true-d12580488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6812"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580383e12-true-d12580488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12580383e12-true-d12580488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580383e35-true-d12580547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6811"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580383e35-true-d12580547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12580383e35-true-d12580547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580192e11-true-d12580624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6810"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580192e11-true-d12580624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12580192e11-true-d12580624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580578e16-true-d12580665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6809"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580578e16-true-d12580665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12580578e16-true-d12580665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e65-true-d12580737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6808"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e65-true-d12580737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12577869e65-true-d12580737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580676e15-true-d12580813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6807"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580676e15-true-d12580813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12580676e15-true-d12580813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580676e35-true-d12580868e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6806"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580676e35-true-d12580868e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12580676e35-true-d12580868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580676e39-true-d12580925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6805"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580676e39-true-d12580925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12580676e39-true-d12580925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12580676e42-true-d12580979e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6804"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12580676e42-true-d12580979e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12580676e42-true-d12580979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e92-true-d12581048e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6803"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e92-true-d12581048e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12577869e92-true-d12581048e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581058e13-true-d12581082e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6802"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12581058e13-true-d12581082e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12581058e13-true-d12581082e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581103e13-true-d12581127e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6801"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12581103e13-true-d12581127e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12581103e13-true-d12581127e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581148e13-true-d12581172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6800"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12581148e13-true-d12581172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12581148e13-true-d12581172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581193e13-true-d12581227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6799"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12581193e13-true-d12581227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12581193e13-true-d12581227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12577869e97-true-d12581271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6798"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12577869e97-true-d12581271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12577869e97-true-d12581271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581259e2-true-d12581298e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6797"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12581259e2-true-d12581298e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12581259e2-true-d12581298e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e16-true-d12582858e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6796"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e16-true-d12582858e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12581319e16-true-d12582858e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e95-true-d12582974e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6795"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e95-true-d12582974e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12581319e95-true-d12582974e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12582951e9-true-d12583018e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6794"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12582951e9-true-d12583018e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12582951e9-true-d12583018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12582951e29-true-d12583067e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6793"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12582951e29-true-d12583067e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12582951e29-true-d12583067e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e99-true-d12583103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6792"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e99-true-d12583103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12581319e99-true-d12583103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583091e2-true-d12583123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6791"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583091e2-true-d12583123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12583091e2-true-d12583123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583091e8-true-d12583164e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6790"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583091e8-true-d12583164e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12583091e8-true-d12583164e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e103-true-d12583241e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="6789"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e103-true-d12583241e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12581319e103-true-d12583241e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583193e5-true-d12583297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="6788"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583193e5-true-d12583297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12583193e5-true-d12583297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583307e13-true-d12583324e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="6787"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12583307e13-true-d12583324e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12583307e13-true-d12583324e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583339e13-true-d12583367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="6786"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12583339e13-true-d12583367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12583339e13-true-d12583367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583193e24-true-d12583428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6785"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583193e24-true-d12583428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12583193e24-true-d12583428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583391e12-true-d12583496e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6784"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583391e12-true-d12583496e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12583391e12-true-d12583496e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583391e35-true-d12583555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6783"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583391e35-true-d12583555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12583391e35-true-d12583555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e111-true-d12583650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6782"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e111-true-d12583650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12581319e111-true-d12583650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583586e9-true-d12583710e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6781"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583586e9-true-d12583710e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12583586e9-true-d12583710e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e115-true-d12583832e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6780"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e115-true-d12583832e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12581319e115-true-d12583832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583759e10-true-d12583924e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6779"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583759e10-true-d12583924e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12583759e10-true-d12583924e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583759e30-true-d12583963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6778"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583759e30-true-d12583963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12583759e30-true-d12583963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583759e34-true-d12584002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6777"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583759e34-true-d12584002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12583759e34-true-d12584002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12583759e39-true-d12584063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6776"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12583759e39-true-d12584063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12583759e39-true-d12584063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584026e12-true-d12584131e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6775"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584026e12-true-d12584131e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12584026e12-true-d12584131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584026e35-true-d12584190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6774"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584026e35-true-d12584190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12584026e35-true-d12584190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e119-true-d12584287e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6773"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e119-true-d12584287e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12581319e119-true-d12584287e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584221e7-true-d12584362e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6772"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584221e7-true-d12584362e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12584221e7-true-d12584362e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584292e9-true-d12584401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6771"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584292e9-true-d12584401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12584292e9-true-d12584401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584292e10-true-d12584449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6770"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584292e10-true-d12584449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12584292e10-true-d12584449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584412e12-true-d12584517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6769"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584412e12-true-d12584517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12584412e12-true-d12584517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584412e35-true-d12584576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6768"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584412e35-true-d12584576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12584412e35-true-d12584576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584221e11-true-d12584653e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6767"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584221e11-true-d12584653e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12584221e11-true-d12584653e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584607e16-true-d12584694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6766"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584607e16-true-d12584694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12584607e16-true-d12584694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e124-true-d12584766e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6765"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e124-true-d12584766e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12581319e124-true-d12584766e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584705e15-true-d12584842e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6764"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584705e15-true-d12584842e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12584705e15-true-d12584842e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584705e35-true-d12584897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6763"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584705e35-true-d12584897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12584705e35-true-d12584897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584705e39-true-d12584954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6762"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584705e39-true-d12584954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12584705e39-true-d12584954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12584705e42-true-d12585008e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6761"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12584705e42-true-d12585008e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12584705e42-true-d12585008e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e151-true-d12585077e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6760"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e151-true-d12585077e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12581319e151-true-d12585077e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585087e13-true-d12585111e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6759"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12585087e13-true-d12585111e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12585087e13-true-d12585111e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585132e13-true-d12585156e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6758"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12585132e13-true-d12585156e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12585132e13-true-d12585156e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585177e13-true-d12585201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6757"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12585177e13-true-d12585201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12585177e13-true-d12585201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585222e13-true-d12585256e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6756"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12585222e13-true-d12585256e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12585222e13-true-d12585256e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12581319e156-true-d12585300e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6755"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12581319e156-true-d12585300e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12581319e156-true-d12585300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585288e2-true-d12585327e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6754"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12585288e2-true-d12585327e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12585288e2-true-d12585327e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e16-true-d12586854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6753"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e16-true-d12586854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12585348e16-true-d12586854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e71-true-d12586946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6752"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e71-true-d12586946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12585348e71-true-d12586946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12586923e9-true-d12586990e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6751"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12586923e9-true-d12586990e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12586923e9-true-d12586990e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12586923e29-true-d12587039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6750"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12586923e29-true-d12587039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12586923e29-true-d12587039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e76-true-d12587075e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6749"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e76-true-d12587075e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12585348e76-true-d12587075e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587063e2-true-d12587095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6748"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587063e2-true-d12587095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12587063e2-true-d12587095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587063e8-true-d12587136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6747"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587063e8-true-d12587136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12587063e8-true-d12587136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e80-true-d12587213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="6746"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e80-true-d12587213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12585348e80-true-d12587213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587165e5-true-d12587269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="6745"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587165e5-true-d12587269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12587165e5-true-d12587269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587279e13-true-d12587296e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="6744"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12587279e13-true-d12587296e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12587279e13-true-d12587296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587311e13-true-d12587339e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="6743"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12587311e13-true-d12587339e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12587311e13-true-d12587339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587165e24-true-d12587400e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6742"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587165e24-true-d12587400e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12587165e24-true-d12587400e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587363e12-true-d12587468e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6741"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587363e12-true-d12587468e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12587363e12-true-d12587468e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587363e35-true-d12587527e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6740"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587363e35-true-d12587527e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12587363e35-true-d12587527e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e87-true-d12587622e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6739"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e87-true-d12587622e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12585348e87-true-d12587622e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587558e9-true-d12587682e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6738"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587558e9-true-d12587682e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12587558e9-true-d12587682e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e92-true-d12587804e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6737"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e92-true-d12587804e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12585348e92-true-d12587804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587731e10-true-d12587896e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6736"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587731e10-true-d12587896e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12587731e10-true-d12587896e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587731e30-true-d12587935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6735"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587731e30-true-d12587935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12587731e30-true-d12587935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587731e34-true-d12587974e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6734"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587731e34-true-d12587974e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12587731e34-true-d12587974e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587731e39-true-d12588035e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6733"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587731e39-true-d12588035e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12587731e39-true-d12588035e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587998e12-true-d12588103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6732"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587998e12-true-d12588103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12587998e12-true-d12588103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12587998e35-true-d12588162e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6731"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12587998e35-true-d12588162e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12587998e35-true-d12588162e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e96-true-d12588259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6730"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e96-true-d12588259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12585348e96-true-d12588259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588193e7-true-d12588334e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6729"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588193e7-true-d12588334e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12588193e7-true-d12588334e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588264e9-true-d12588373e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6728"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588264e9-true-d12588373e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12588264e9-true-d12588373e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588264e10-true-d12588421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6727"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588264e10-true-d12588421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12588264e10-true-d12588421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588384e12-true-d12588489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6726"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588384e12-true-d12588489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12588384e12-true-d12588489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588384e35-true-d12588548e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6725"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588384e35-true-d12588548e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12588384e35-true-d12588548e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588193e11-true-d12588625e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6724"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588193e11-true-d12588625e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12588193e11-true-d12588625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588579e16-true-d12588666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6723"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588579e16-true-d12588666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12588579e16-true-d12588666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e100-true-d12588738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6722"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e100-true-d12588738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12585348e100-true-d12588738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588677e15-true-d12588814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6721"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588677e15-true-d12588814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12588677e15-true-d12588814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588677e35-true-d12588869e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6720"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588677e35-true-d12588869e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12588677e35-true-d12588869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588677e39-true-d12588926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6719"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588677e39-true-d12588926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12588677e39-true-d12588926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12588677e42-true-d12588980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6718"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12588677e42-true-d12588980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12588677e42-true-d12588980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e128-true-d12589049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6717"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e128-true-d12589049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12585348e128-true-d12589049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589059e13-true-d12589083e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6716"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12589059e13-true-d12589083e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12589059e13-true-d12589083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589104e13-true-d12589128e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6715"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12589104e13-true-d12589128e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12589104e13-true-d12589128e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589149e13-true-d12589173e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6714"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12589149e13-true-d12589173e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12589149e13-true-d12589173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589194e13-true-d12589228e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6713"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12589194e13-true-d12589228e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12589194e13-true-d12589228e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12585348e132-true-d12589272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6712"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12585348e132-true-d12589272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12585348e132-true-d12589272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589260e2-true-d12589299e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6711"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12589260e2-true-d12589299e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12589260e2-true-d12589299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e149-true-d12589357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6710"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e149-true-d12589357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12548332e149-true-d12589357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589367e13-true-d12589391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6709"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12589367e13-true-d12589391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12589367e13-true-d12589391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589412e13-true-d12589436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6708"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12589412e13-true-d12589436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12589412e13-true-d12589436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589457e13-true-d12589481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6707"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12589457e13-true-d12589481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12589457e13-true-d12589481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589502e13-true-d12589536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6706"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12589502e13-true-d12589536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12589502e13-true-d12589536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e153-true-d12589580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6705"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e153-true-d12589580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12548332e153-true-d12589580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589568e2-true-d12589607e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6704"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12589568e2-true-d12589607e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12589568e2-true-d12589607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e158-true-d12589638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="6703"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e158-true-d12589638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12548332e158-true-d12589638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12548332e162-true-d12589676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="6702"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12548332e162-true-d12589676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12548332e162-true-d12589676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e16-true-d12591121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6701"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e16-true-d12591121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12589705e16-true-d12591121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e43-true-d12591174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6700"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e43-true-d12591174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12589705e43-true-d12591174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591151e9-true-d12591218e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6699"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591151e9-true-d12591218e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12591151e9-true-d12591218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591151e29-true-d12591267e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6698"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591151e29-true-d12591267e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12591151e29-true-d12591267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e47-true-d12591303e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6697"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e47-true-d12591303e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12589705e47-true-d12591303e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591291e2-true-d12591323e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6696"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591291e2-true-d12591323e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12591291e2-true-d12591323e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591291e8-true-d12591364e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6695"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591291e8-true-d12591364e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12591291e8-true-d12591364e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e52-true-d12591457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6694"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e52-true-d12591457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12589705e52-true-d12591457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591393e9-true-d12591517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6693"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591393e9-true-d12591517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12591393e9-true-d12591517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e56-true-d12591639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6692"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e56-true-d12591639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12589705e56-true-d12591639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591566e10-true-d12591731e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6691"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591566e10-true-d12591731e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12591566e10-true-d12591731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591566e30-true-d12591770e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6690"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591566e30-true-d12591770e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12591566e30-true-d12591770e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591566e34-true-d12591809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6689"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591566e34-true-d12591809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12591566e34-true-d12591809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591566e39-true-d12591870e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6688"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591566e39-true-d12591870e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12591566e39-true-d12591870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591833e12-true-d12591938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6687"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591833e12-true-d12591938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12591833e12-true-d12591938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12591833e35-true-d12591997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6686"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12591833e35-true-d12591997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12591833e35-true-d12591997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e60-true-d12592094e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6685"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e60-true-d12592094e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12589705e60-true-d12592094e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592028e7-true-d12592169e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6684"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592028e7-true-d12592169e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12592028e7-true-d12592169e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592099e9-true-d12592208e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6683"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592099e9-true-d12592208e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12592099e9-true-d12592208e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592099e10-true-d12592256e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6682"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592099e10-true-d12592256e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12592099e10-true-d12592256e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592219e12-true-d12592324e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6681"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592219e12-true-d12592324e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12592219e12-true-d12592324e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592219e35-true-d12592383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6680"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592219e35-true-d12592383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12592219e35-true-d12592383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592028e11-true-d12592460e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6679"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592028e11-true-d12592460e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12592028e11-true-d12592460e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592414e16-true-d12592501e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6678"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592414e16-true-d12592501e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12592414e16-true-d12592501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e65-true-d12592573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6677"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e65-true-d12592573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12589705e65-true-d12592573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592512e15-true-d12592649e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6676"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592512e15-true-d12592649e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12592512e15-true-d12592649e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592512e35-true-d12592704e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6675"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592512e35-true-d12592704e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12592512e35-true-d12592704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592512e39-true-d12592761e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6674"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592512e39-true-d12592761e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12592512e39-true-d12592761e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12592512e42-true-d12592815e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6673"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12592512e42-true-d12592815e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12592512e42-true-d12592815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e69-true-d12597922e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="6672"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e69-true-d12597922e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12589705e69-true-d12597922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e16-true-d12599387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6671"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e16-true-d12599387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12597937e16-true-d12599387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e77-true-d12599467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6670"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e77-true-d12599467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12597937e77-true-d12599467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599444e9-true-d12599511e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6669"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599444e9-true-d12599511e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12599444e9-true-d12599511e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599444e29-true-d12599560e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6668"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599444e29-true-d12599560e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12599444e29-true-d12599560e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e81-true-d12599596e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6667"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e81-true-d12599596e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12597937e81-true-d12599596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599584e2-true-d12599616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6666"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599584e2-true-d12599616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12599584e2-true-d12599616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599584e8-true-d12599657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6665"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599584e8-true-d12599657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12599584e8-true-d12599657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e85-true-d12599750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6664"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e85-true-d12599750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12597937e85-true-d12599750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599686e9-true-d12599810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6663"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599686e9-true-d12599810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12599686e9-true-d12599810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e90-true-d12599932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6662"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e90-true-d12599932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12597937e90-true-d12599932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599859e10-true-d12600024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6661"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599859e10-true-d12600024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12599859e10-true-d12600024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599859e30-true-d12600063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6660"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599859e30-true-d12600063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12599859e30-true-d12600063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599859e34-true-d12600102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6659"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599859e34-true-d12600102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12599859e34-true-d12600102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12599859e39-true-d12600163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6658"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12599859e39-true-d12600163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12599859e39-true-d12600163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600126e12-true-d12600231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6657"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600126e12-true-d12600231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12600126e12-true-d12600231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600126e35-true-d12600290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6656"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600126e35-true-d12600290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12600126e35-true-d12600290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e94-true-d12600387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6655"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e94-true-d12600387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12597937e94-true-d12600387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600321e7-true-d12600462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6654"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600321e7-true-d12600462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12600321e7-true-d12600462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600392e9-true-d12600501e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6653"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600392e9-true-d12600501e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12600392e9-true-d12600501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600392e10-true-d12600549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6652"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600392e10-true-d12600549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12600392e10-true-d12600549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600512e12-true-d12600617e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6651"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600512e12-true-d12600617e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12600512e12-true-d12600617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600512e35-true-d12600676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6650"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600512e35-true-d12600676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12600512e35-true-d12600676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600321e11-true-d12600753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6649"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600321e11-true-d12600753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12600321e11-true-d12600753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600707e16-true-d12600794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6648"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600707e16-true-d12600794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12600707e16-true-d12600794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e98-true-d12600866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6647"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e98-true-d12600866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12597937e98-true-d12600866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600805e15-true-d12600942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6646"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600805e15-true-d12600942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12600805e15-true-d12600942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600805e35-true-d12600997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6645"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600805e35-true-d12600997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12600805e35-true-d12600997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600805e39-true-d12601054e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6644"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600805e39-true-d12601054e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12600805e39-true-d12601054e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12600805e42-true-d12601108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6643"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12600805e42-true-d12601108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12600805e42-true-d12601108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e126-true-d12601177e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6642"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e126-true-d12601177e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12597937e126-true-d12601177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601187e13-true-d12601211e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6641"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12601187e13-true-d12601211e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12601187e13-true-d12601211e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601232e13-true-d12601256e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6640"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12601232e13-true-d12601256e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12601232e13-true-d12601256e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601277e13-true-d12601301e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6639"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12601277e13-true-d12601301e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12601277e13-true-d12601301e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601322e13-true-d12601356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6638"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12601322e13-true-d12601356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12601322e13-true-d12601356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12597937e130-true-d12601400e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6637"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12597937e130-true-d12601400e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12597937e130-true-d12601400e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601388e2-true-d12601427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6636"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12601388e2-true-d12601427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12601388e2-true-d12601427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e16-true-d12602891e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6635"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e16-true-d12602891e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12601448e16-true-d12602891e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e65-true-d12602965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6634"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e65-true-d12602965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12601448e65-true-d12602965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12602942e9-true-d12603009e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6633"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12602942e9-true-d12603009e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12602942e9-true-d12603009e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12602942e29-true-d12603058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6632"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12602942e29-true-d12603058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12602942e29-true-d12603058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e69-true-d12603094e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6631"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e69-true-d12603094e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12601448e69-true-d12603094e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603082e2-true-d12603114e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6630"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603082e2-true-d12603114e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12603082e2-true-d12603114e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603082e8-true-d12603155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6629"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603082e8-true-d12603155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12603082e8-true-d12603155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e73-true-d12603248e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6628"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e73-true-d12603248e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12601448e73-true-d12603248e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603184e9-true-d12603308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6627"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603184e9-true-d12603308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12603184e9-true-d12603308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e78-true-d12603430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6626"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e78-true-d12603430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12601448e78-true-d12603430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603357e10-true-d12603522e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6625"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603357e10-true-d12603522e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12603357e10-true-d12603522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603357e30-true-d12603561e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6624"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603357e30-true-d12603561e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12603357e30-true-d12603561e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603357e34-true-d12603600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6623"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603357e34-true-d12603600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12603357e34-true-d12603600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603357e39-true-d12603661e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6622"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603357e39-true-d12603661e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12603357e39-true-d12603661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603624e12-true-d12603729e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6621"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603624e12-true-d12603729e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12603624e12-true-d12603729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603624e35-true-d12603788e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6620"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603624e35-true-d12603788e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12603624e35-true-d12603788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e82-true-d12603885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6619"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e82-true-d12603885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12601448e82-true-d12603885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603819e7-true-d12603960e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6618"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603819e7-true-d12603960e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12603819e7-true-d12603960e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603890e9-true-d12603999e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6617"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603890e9-true-d12603999e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12603890e9-true-d12603999e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603890e10-true-d12604047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6616"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603890e10-true-d12604047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12603890e10-true-d12604047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604010e12-true-d12604115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6615"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604010e12-true-d12604115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12604010e12-true-d12604115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604010e35-true-d12604174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6614"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604010e35-true-d12604174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12604010e35-true-d12604174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12603819e11-true-d12604251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6613"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12603819e11-true-d12604251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12603819e11-true-d12604251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604205e16-true-d12604292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6612"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604205e16-true-d12604292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12604205e16-true-d12604292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e86-true-d12604364e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6611"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e86-true-d12604364e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12601448e86-true-d12604364e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604303e15-true-d12604440e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6610"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604303e15-true-d12604440e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12604303e15-true-d12604440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604303e35-true-d12604495e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6609"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604303e35-true-d12604495e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12604303e35-true-d12604495e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604303e39-true-d12604552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6608"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604303e39-true-d12604552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12604303e39-true-d12604552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604303e42-true-d12604606e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6607"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604303e42-true-d12604606e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12604303e42-true-d12604606e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e114-true-d12604675e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6606"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e114-true-d12604675e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12601448e114-true-d12604675e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604685e13-true-d12604709e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6605"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12604685e13-true-d12604709e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12604685e13-true-d12604709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604730e13-true-d12604754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6604"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12604730e13-true-d12604754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12604730e13-true-d12604754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604775e13-true-d12604799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6603"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12604775e13-true-d12604799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12604775e13-true-d12604799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604820e13-true-d12604854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6602"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12604820e13-true-d12604854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12604820e13-true-d12604854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12601448e118-true-d12604898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6601"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12601448e118-true-d12604898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12601448e118-true-d12604898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604886e2-true-d12604925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6600"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12604886e2-true-d12604925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12604886e2-true-d12604925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e16-true-d12606449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="6599"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e16-true-d12606449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12604946e16-true-d12606449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e100-true-d12606568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6598"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e100-true-d12606568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12604946e100-true-d12606568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606545e9-true-d12606612e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6597"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606545e9-true-d12606612e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12606545e9-true-d12606612e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606545e29-true-d12606661e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6596"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606545e29-true-d12606661e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12606545e29-true-d12606661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e104-true-d12606697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6595"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e104-true-d12606697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12604946e104-true-d12606697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606685e2-true-d12606717e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6594"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606685e2-true-d12606717e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12606685e2-true-d12606717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606685e8-true-d12606758e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6593"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606685e8-true-d12606758e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12606685e8-true-d12606758e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e108-true-d12606851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6592"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e108-true-d12606851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12604946e108-true-d12606851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606787e9-true-d12606911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6591"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606787e9-true-d12606911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12606787e9-true-d12606911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e113-true-d12607033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6590"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e113-true-d12607033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12604946e113-true-d12607033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606960e10-true-d12607125e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6589"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606960e10-true-d12607125e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12606960e10-true-d12607125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606960e30-true-d12607164e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6588"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606960e30-true-d12607164e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12606960e30-true-d12607164e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606960e34-true-d12607203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6587"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606960e34-true-d12607203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12606960e34-true-d12607203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12606960e39-true-d12607264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6586"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12606960e39-true-d12607264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12606960e39-true-d12607264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607227e12-true-d12607332e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6585"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607227e12-true-d12607332e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12607227e12-true-d12607332e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607227e35-true-d12607391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6584"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607227e35-true-d12607391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12607227e35-true-d12607391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e117-true-d12607488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6583"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e117-true-d12607488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12604946e117-true-d12607488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607422e7-true-d12607563e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6582"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607422e7-true-d12607563e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12607422e7-true-d12607563e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607493e9-true-d12607602e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6581"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607493e9-true-d12607602e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12607493e9-true-d12607602e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607493e10-true-d12607650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6580"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607493e10-true-d12607650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12607493e10-true-d12607650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607613e12-true-d12607718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6579"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607613e12-true-d12607718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12607613e12-true-d12607718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607613e35-true-d12607777e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6578"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607613e35-true-d12607777e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12607613e35-true-d12607777e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607422e11-true-d12607854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6577"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607422e11-true-d12607854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12607422e11-true-d12607854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607808e16-true-d12607895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6576"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607808e16-true-d12607895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12607808e16-true-d12607895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e121-true-d12607967e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6575"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e121-true-d12607967e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12604946e121-true-d12607967e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607906e15-true-d12608043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6574"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607906e15-true-d12608043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12607906e15-true-d12608043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607906e35-true-d12608098e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6573"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607906e35-true-d12608098e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12607906e35-true-d12608098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607906e39-true-d12608155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6572"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607906e39-true-d12608155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12607906e39-true-d12608155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12607906e42-true-d12608209e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6571"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12607906e42-true-d12608209e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12607906e42-true-d12608209e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e149-true-d12608278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6570"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e149-true-d12608278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12604946e149-true-d12608278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608288e13-true-d12608312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6569"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12608288e13-true-d12608312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12608288e13-true-d12608312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608333e13-true-d12608357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6568"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12608333e13-true-d12608357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12608333e13-true-d12608357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608378e13-true-d12608402e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6567"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12608378e13-true-d12608402e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12608378e13-true-d12608402e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608423e13-true-d12608457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6566"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12608423e13-true-d12608457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12608423e13-true-d12608457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e153-true-d12608501e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6565"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e153-true-d12608501e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12604946e153-true-d12608501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608489e2-true-d12608528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6564"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12608489e2-true-d12608528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12608489e2-true-d12608528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e158-true-d12608559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="6563"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e158-true-d12608559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12604946e158-true-d12608559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12604946e162-true-d12608597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="6562"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12604946e162-true-d12608597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12604946e162-true-d12608597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e16-true-d12610042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6561"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e16-true-d12610042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12608626e16-true-d12610042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e43-true-d12610095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6560"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e43-true-d12610095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12608626e43-true-d12610095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610072e9-true-d12610139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6559"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610072e9-true-d12610139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12610072e9-true-d12610139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610072e29-true-d12610188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6558"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610072e29-true-d12610188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12610072e29-true-d12610188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e47-true-d12610224e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6557"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e47-true-d12610224e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12608626e47-true-d12610224e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610212e2-true-d12610244e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6556"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610212e2-true-d12610244e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12610212e2-true-d12610244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610212e8-true-d12610285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6555"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610212e8-true-d12610285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12610212e8-true-d12610285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e52-true-d12610378e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6554"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e52-true-d12610378e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12608626e52-true-d12610378e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610314e9-true-d12610438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6553"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610314e9-true-d12610438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12610314e9-true-d12610438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e56-true-d12610560e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6552"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e56-true-d12610560e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12608626e56-true-d12610560e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610487e10-true-d12610652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6551"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610487e10-true-d12610652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12610487e10-true-d12610652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610487e30-true-d12610691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6550"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610487e30-true-d12610691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12610487e30-true-d12610691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610487e34-true-d12610730e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6549"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610487e34-true-d12610730e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12610487e34-true-d12610730e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610487e39-true-d12610791e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6548"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610487e39-true-d12610791e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12610487e39-true-d12610791e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610754e12-true-d12610859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6547"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610754e12-true-d12610859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12610754e12-true-d12610859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610754e35-true-d12610918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6546"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610754e35-true-d12610918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12610754e35-true-d12610918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e60-true-d12611015e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6545"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e60-true-d12611015e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12608626e60-true-d12611015e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610949e7-true-d12611090e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6544"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610949e7-true-d12611090e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12610949e7-true-d12611090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611020e9-true-d12611129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6543"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611020e9-true-d12611129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12611020e9-true-d12611129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611020e10-true-d12611177e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6542"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611020e10-true-d12611177e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12611020e10-true-d12611177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611140e12-true-d12611245e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6541"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611140e12-true-d12611245e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12611140e12-true-d12611245e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611140e35-true-d12611304e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6540"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611140e35-true-d12611304e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12611140e35-true-d12611304e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12610949e11-true-d12611381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6539"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12610949e11-true-d12611381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12610949e11-true-d12611381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611335e16-true-d12611422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6538"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611335e16-true-d12611422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12611335e16-true-d12611422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e65-true-d12611494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6537"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e65-true-d12611494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12608626e65-true-d12611494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611433e15-true-d12611570e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6536"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611433e15-true-d12611570e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12611433e15-true-d12611570e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611433e35-true-d12611625e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6535"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611433e35-true-d12611625e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12611433e35-true-d12611625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611433e39-true-d12611682e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6534"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611433e39-true-d12611682e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12611433e39-true-d12611682e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611433e42-true-d12611736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6533"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12611433e42-true-d12611736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12611433e42-true-d12611736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e92-true-d12611805e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6532"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e92-true-d12611805e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12608626e92-true-d12611805e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611815e13-true-d12611839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6531"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12611815e13-true-d12611839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12611815e13-true-d12611839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611860e13-true-d12611884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6530"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12611860e13-true-d12611884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12611860e13-true-d12611884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611905e13-true-d12611929e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6529"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12611905e13-true-d12611929e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12611905e13-true-d12611929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12611950e13-true-d12611984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6528"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12611950e13-true-d12611984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12611950e13-true-d12611984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12608626e97-true-d12612028e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6527"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12608626e97-true-d12612028e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12608626e97-true-d12612028e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612016e2-true-d12612055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6526"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12612016e2-true-d12612055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12612016e2-true-d12612055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e16-true-d12613499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="6525"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e16-true-d12613499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12612076e16-true-d12613499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e53-true-d12613558e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6524"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e53-true-d12613558e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12612076e53-true-d12613558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613535e9-true-d12613602e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6523"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613535e9-true-d12613602e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12613535e9-true-d12613602e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613535e29-true-d12613651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6522"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613535e29-true-d12613651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12613535e29-true-d12613651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e58-true-d12613687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6521"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e58-true-d12613687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12612076e58-true-d12613687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613675e2-true-d12613707e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6520"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613675e2-true-d12613707e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12613675e2-true-d12613707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613675e8-true-d12613748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6519"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613675e8-true-d12613748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12613675e8-true-d12613748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e62-true-d12613841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6518"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e62-true-d12613841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12612076e62-true-d12613841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613777e9-true-d12613901e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6517"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613777e9-true-d12613901e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12613777e9-true-d12613901e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e66-true-d12614023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6516"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e66-true-d12614023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12612076e66-true-d12614023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613950e10-true-d12614115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6515"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613950e10-true-d12614115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12613950e10-true-d12614115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613950e30-true-d12614154e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6514"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613950e30-true-d12614154e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12613950e30-true-d12614154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613950e34-true-d12614193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6513"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613950e34-true-d12614193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12613950e34-true-d12614193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12613950e39-true-d12614254e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6512"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12613950e39-true-d12614254e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12613950e39-true-d12614254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614217e12-true-d12614322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6511"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614217e12-true-d12614322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12614217e12-true-d12614322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614217e35-true-d12614381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6510"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614217e35-true-d12614381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12614217e35-true-d12614381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e71-true-d12614478e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6509"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e71-true-d12614478e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12612076e71-true-d12614478e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614412e7-true-d12614553e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6508"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614412e7-true-d12614553e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12614412e7-true-d12614553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614483e9-true-d12614592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6507"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614483e9-true-d12614592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12614483e9-true-d12614592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614483e10-true-d12614640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6506"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614483e10-true-d12614640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12614483e10-true-d12614640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614603e12-true-d12614708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6505"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614603e12-true-d12614708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12614603e12-true-d12614708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614603e35-true-d12614767e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6504"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614603e35-true-d12614767e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12614603e35-true-d12614767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614412e11-true-d12614844e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6503"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614412e11-true-d12614844e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12614412e11-true-d12614844e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614798e16-true-d12614885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6502"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614798e16-true-d12614885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12614798e16-true-d12614885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e75-true-d12614957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6501"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e75-true-d12614957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12612076e75-true-d12614957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614896e15-true-d12615033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6500"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614896e15-true-d12615033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12614896e15-true-d12615033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614896e35-true-d12615088e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6499"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614896e35-true-d12615088e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12614896e35-true-d12615088e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614896e39-true-d12615145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6498"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614896e39-true-d12615145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12614896e39-true-d12615145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12614896e42-true-d12615199e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6497"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12614896e42-true-d12615199e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12614896e42-true-d12615199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e81-true-d12615259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6496"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e81-true-d12615259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12612076e81-true-d12615259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615269e13-true-d12615293e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6495"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12615269e13-true-d12615293e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12615269e13-true-d12615293e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615314e13-true-d12615338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6494"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12615314e13-true-d12615338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12615314e13-true-d12615338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615359e13-true-d12615383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6493"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12615359e13-true-d12615383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12615359e13-true-d12615383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615404e13-true-d12615438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6492"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12615404e13-true-d12615438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12615404e13-true-d12615438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12612076e86-true-d12615482e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6491"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12612076e86-true-d12615482e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12612076e86-true-d12615482e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615470e2-true-d12615509e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6490"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12615470e2-true-d12615509e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12615470e2-true-d12615509e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e16-true-d12617010e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6489"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e16-true-d12617010e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12615539e16-true-d12617010e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e87-true-d12617108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6488"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e87-true-d12617108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12615539e87-true-d12617108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617085e9-true-d12617152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6487"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617085e9-true-d12617152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12617085e9-true-d12617152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617085e29-true-d12617201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6486"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617085e29-true-d12617201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12617085e29-true-d12617201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e92-true-d12617237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6485"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e92-true-d12617237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12615539e92-true-d12617237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617225e2-true-d12617257e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6484"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617225e2-true-d12617257e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12617225e2-true-d12617257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617225e8-true-d12617298e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6483"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617225e8-true-d12617298e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12617225e8-true-d12617298e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e96-true-d12617391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6482"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e96-true-d12617391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12615539e96-true-d12617391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617327e9-true-d12617451e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6481"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617327e9-true-d12617451e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12617327e9-true-d12617451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e100-true-d12617573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6480"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e100-true-d12617573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12615539e100-true-d12617573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617500e10-true-d12617665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6479"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617500e10-true-d12617665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12617500e10-true-d12617665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617500e30-true-d12617704e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6478"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617500e30-true-d12617704e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12617500e30-true-d12617704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617500e34-true-d12617743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6477"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617500e34-true-d12617743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12617500e34-true-d12617743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617500e39-true-d12617804e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6476"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617500e39-true-d12617804e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12617500e39-true-d12617804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617767e12-true-d12617872e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6475"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617767e12-true-d12617872e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12617767e12-true-d12617872e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617767e35-true-d12617931e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6474"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617767e35-true-d12617931e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12617767e35-true-d12617931e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e105-true-d12618028e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6473"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e105-true-d12618028e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12615539e105-true-d12618028e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617962e7-true-d12618103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6472"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617962e7-true-d12618103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12617962e7-true-d12618103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618033e9-true-d12618142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6471"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618033e9-true-d12618142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12618033e9-true-d12618142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618033e10-true-d12618190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6470"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618033e10-true-d12618190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12618033e10-true-d12618190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618153e12-true-d12618258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6469"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618153e12-true-d12618258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12618153e12-true-d12618258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618153e35-true-d12618317e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6468"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618153e35-true-d12618317e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12618153e35-true-d12618317e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12617962e11-true-d12618394e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6467"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12617962e11-true-d12618394e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12617962e11-true-d12618394e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618348e16-true-d12618435e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6466"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618348e16-true-d12618435e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12618348e16-true-d12618435e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e109-true-d12618507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6465"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e109-true-d12618507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12615539e109-true-d12618507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618446e15-true-d12618583e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6464"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618446e15-true-d12618583e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12618446e15-true-d12618583e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618446e35-true-d12618638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6463"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618446e35-true-d12618638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12618446e35-true-d12618638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618446e39-true-d12618695e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6462"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618446e39-true-d12618695e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12618446e39-true-d12618695e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618446e42-true-d12618749e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6461"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12618446e42-true-d12618749e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12618446e42-true-d12618749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e137-true-d12618818e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6460"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e137-true-d12618818e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12615539e137-true-d12618818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618828e13-true-d12618852e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6459"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12618828e13-true-d12618852e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12618828e13-true-d12618852e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618873e13-true-d12618897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6458"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12618873e13-true-d12618897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12618873e13-true-d12618897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618918e13-true-d12618942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6457"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12618918e13-true-d12618942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12618918e13-true-d12618942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12618963e13-true-d12618997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6456"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12618963e13-true-d12618997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12618963e13-true-d12618997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12615539e141-true-d12619041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6455"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12615539e141-true-d12619041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12615539e141-true-d12619041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619029e2-true-d12619068e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6454"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12619029e2-true-d12619068e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12619029e2-true-d12619068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e16-true-d12620505e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6453"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e16-true-d12620505e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12619089e16-true-d12620505e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e43-true-d12620558e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6452"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e43-true-d12620558e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12619089e43-true-d12620558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620535e9-true-d12620602e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6451"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620535e9-true-d12620602e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12620535e9-true-d12620602e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620535e29-true-d12620651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6450"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620535e29-true-d12620651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12620535e29-true-d12620651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e47-true-d12620687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6449"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e47-true-d12620687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12619089e47-true-d12620687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620675e2-true-d12620707e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6448"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620675e2-true-d12620707e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12620675e2-true-d12620707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620675e8-true-d12620748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6447"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620675e8-true-d12620748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12620675e8-true-d12620748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e52-true-d12620841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6446"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e52-true-d12620841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12619089e52-true-d12620841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620777e9-true-d12620901e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6445"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620777e9-true-d12620901e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12620777e9-true-d12620901e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e56-true-d12621023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6444"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e56-true-d12621023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12619089e56-true-d12621023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620950e10-true-d12621115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6443"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620950e10-true-d12621115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12620950e10-true-d12621115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620950e30-true-d12621154e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6442"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620950e30-true-d12621154e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12620950e30-true-d12621154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620950e34-true-d12621193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6441"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620950e34-true-d12621193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12620950e34-true-d12621193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12620950e39-true-d12621254e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6440"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12620950e39-true-d12621254e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12620950e39-true-d12621254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621217e12-true-d12621322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6439"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621217e12-true-d12621322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12621217e12-true-d12621322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621217e35-true-d12621381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6438"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621217e35-true-d12621381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12621217e35-true-d12621381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e60-true-d12621478e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6437"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e60-true-d12621478e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12619089e60-true-d12621478e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621412e7-true-d12621553e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6436"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621412e7-true-d12621553e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12621412e7-true-d12621553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621483e9-true-d12621592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6435"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621483e9-true-d12621592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12621483e9-true-d12621592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621483e10-true-d12621640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6434"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621483e10-true-d12621640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12621483e10-true-d12621640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621603e12-true-d12621708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6433"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621603e12-true-d12621708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12621603e12-true-d12621708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621603e35-true-d12621767e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6432"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621603e35-true-d12621767e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12621603e35-true-d12621767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621412e11-true-d12621844e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6431"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621412e11-true-d12621844e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12621412e11-true-d12621844e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621798e16-true-d12621885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6430"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621798e16-true-d12621885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12621798e16-true-d12621885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e65-true-d12621957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6429"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e65-true-d12621957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12619089e65-true-d12621957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621896e15-true-d12622033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6428"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621896e15-true-d12622033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12621896e15-true-d12622033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621896e35-true-d12622088e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6427"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621896e35-true-d12622088e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12621896e35-true-d12622088e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621896e39-true-d12622145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6426"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621896e39-true-d12622145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12621896e39-true-d12622145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12621896e42-true-d12622199e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6425"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12621896e42-true-d12622199e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12621896e42-true-d12622199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e92-true-d12622268e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6424"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e92-true-d12622268e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12619089e92-true-d12622268e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622278e13-true-d12622302e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6423"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12622278e13-true-d12622302e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12622278e13-true-d12622302e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622323e13-true-d12622347e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6422"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12622323e13-true-d12622347e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12622323e13-true-d12622347e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622368e13-true-d12622392e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6421"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12622368e13-true-d12622392e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12622368e13-true-d12622392e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622413e13-true-d12622447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6420"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12622413e13-true-d12622447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12622413e13-true-d12622447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12619089e97-true-d12622491e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6419"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12619089e97-true-d12622491e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12619089e97-true-d12622491e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622479e2-true-d12622518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6418"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12622479e2-true-d12622518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12622479e2-true-d12622518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e16-true-d12624078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6417"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e16-true-d12624078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12622539e16-true-d12624078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e95-true-d12624194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6416"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e95-true-d12624194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12622539e95-true-d12624194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624171e9-true-d12624238e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6415"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624171e9-true-d12624238e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12624171e9-true-d12624238e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624171e29-true-d12624287e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6414"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624171e29-true-d12624287e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12624171e29-true-d12624287e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e99-true-d12624323e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6413"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e99-true-d12624323e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12622539e99-true-d12624323e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624311e2-true-d12624343e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6412"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624311e2-true-d12624343e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12624311e2-true-d12624343e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624311e8-true-d12624384e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6411"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624311e8-true-d12624384e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12624311e8-true-d12624384e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e103-true-d12624461e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="6410"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e103-true-d12624461e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12622539e103-true-d12624461e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624413e5-true-d12624517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="6409"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624413e5-true-d12624517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12624413e5-true-d12624517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624527e13-true-d12624544e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="6408"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12624527e13-true-d12624544e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12624527e13-true-d12624544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624559e13-true-d12624587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="6407"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12624559e13-true-d12624587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12624559e13-true-d12624587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624413e24-true-d12624648e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6406"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624413e24-true-d12624648e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12624413e24-true-d12624648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624611e12-true-d12624716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6405"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624611e12-true-d12624716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12624611e12-true-d12624716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624611e35-true-d12624775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6404"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624611e35-true-d12624775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12624611e35-true-d12624775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e111-true-d12624870e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6403"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e111-true-d12624870e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12622539e111-true-d12624870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624806e9-true-d12624930e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6402"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624806e9-true-d12624930e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12624806e9-true-d12624930e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e115-true-d12625052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6401"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e115-true-d12625052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12622539e115-true-d12625052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624979e10-true-d12625144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6400"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624979e10-true-d12625144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12624979e10-true-d12625144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624979e30-true-d12625183e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6399"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624979e30-true-d12625183e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12624979e30-true-d12625183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624979e34-true-d12625222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6398"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624979e34-true-d12625222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12624979e34-true-d12625222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12624979e39-true-d12625283e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6397"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12624979e39-true-d12625283e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12624979e39-true-d12625283e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625246e12-true-d12625351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6396"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625246e12-true-d12625351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12625246e12-true-d12625351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625246e35-true-d12625410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6395"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625246e35-true-d12625410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12625246e35-true-d12625410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e119-true-d12625507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6394"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e119-true-d12625507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12622539e119-true-d12625507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625441e7-true-d12625582e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6393"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625441e7-true-d12625582e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12625441e7-true-d12625582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625512e9-true-d12625621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6392"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625512e9-true-d12625621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12625512e9-true-d12625621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625512e10-true-d12625669e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6391"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625512e10-true-d12625669e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12625512e10-true-d12625669e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625632e12-true-d12625737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6390"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625632e12-true-d12625737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12625632e12-true-d12625737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625632e35-true-d12625796e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6389"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625632e35-true-d12625796e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12625632e35-true-d12625796e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625441e11-true-d12625873e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6388"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625441e11-true-d12625873e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12625441e11-true-d12625873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625827e16-true-d12625914e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6387"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625827e16-true-d12625914e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12625827e16-true-d12625914e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e124-true-d12625986e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6386"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e124-true-d12625986e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12622539e124-true-d12625986e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625925e15-true-d12626062e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6385"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625925e15-true-d12626062e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12625925e15-true-d12626062e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625925e35-true-d12626117e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6384"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625925e35-true-d12626117e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12625925e35-true-d12626117e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625925e39-true-d12626174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6383"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625925e39-true-d12626174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12625925e39-true-d12626174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12625925e42-true-d12626228e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6382"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12625925e42-true-d12626228e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12625925e42-true-d12626228e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e151-true-d12626297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6381"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e151-true-d12626297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12622539e151-true-d12626297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626307e13-true-d12626331e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6380"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12626307e13-true-d12626331e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12626307e13-true-d12626331e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626352e13-true-d12626376e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6379"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12626352e13-true-d12626376e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12626352e13-true-d12626376e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626397e13-true-d12626421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6378"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12626397e13-true-d12626421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12626397e13-true-d12626421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626442e13-true-d12626476e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6377"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12626442e13-true-d12626476e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12626442e13-true-d12626476e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12622539e156-true-d12626520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6376"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12622539e156-true-d12626520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12622539e156-true-d12626520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626508e2-true-d12626547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6375"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12626508e2-true-d12626547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12626508e2-true-d12626547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e16-true-d12628074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6374"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e16-true-d12628074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12626568e16-true-d12628074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e71-true-d12628166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6373"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e71-true-d12628166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12626568e71-true-d12628166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628143e9-true-d12628210e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6372"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628143e9-true-d12628210e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12628143e9-true-d12628210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628143e29-true-d12628259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6371"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628143e29-true-d12628259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12628143e29-true-d12628259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e76-true-d12628295e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6370"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e76-true-d12628295e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12626568e76-true-d12628295e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628283e2-true-d12628315e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6369"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628283e2-true-d12628315e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12628283e2-true-d12628315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628283e8-true-d12628356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6368"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628283e8-true-d12628356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12628283e8-true-d12628356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e80-true-d12628433e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="6367"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e80-true-d12628433e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12626568e80-true-d12628433e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628385e5-true-d12628489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="6366"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628385e5-true-d12628489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12628385e5-true-d12628489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628499e13-true-d12628516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="6365"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12628499e13-true-d12628516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12628499e13-true-d12628516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628531e13-true-d12628559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="6364"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12628531e13-true-d12628559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12628531e13-true-d12628559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628385e24-true-d12628620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6363"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628385e24-true-d12628620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12628385e24-true-d12628620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628583e12-true-d12628688e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6362"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628583e12-true-d12628688e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12628583e12-true-d12628688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628583e35-true-d12628747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6361"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628583e35-true-d12628747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12628583e35-true-d12628747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e87-true-d12628842e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6360"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e87-true-d12628842e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12626568e87-true-d12628842e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628778e9-true-d12628902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6359"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628778e9-true-d12628902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12628778e9-true-d12628902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e92-true-d12629024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6358"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e92-true-d12629024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12626568e92-true-d12629024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628951e10-true-d12629116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6357"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628951e10-true-d12629116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12628951e10-true-d12629116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628951e30-true-d12629155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6356"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628951e30-true-d12629155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12628951e30-true-d12629155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628951e34-true-d12629194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6355"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628951e34-true-d12629194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12628951e34-true-d12629194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12628951e39-true-d12629255e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6354"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12628951e39-true-d12629255e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12628951e39-true-d12629255e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629218e12-true-d12629323e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6353"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629218e12-true-d12629323e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12629218e12-true-d12629323e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629218e35-true-d12629382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6352"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629218e35-true-d12629382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12629218e35-true-d12629382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e96-true-d12629479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6351"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e96-true-d12629479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12626568e96-true-d12629479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629413e7-true-d12629554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6350"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629413e7-true-d12629554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12629413e7-true-d12629554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629484e9-true-d12629593e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6349"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629484e9-true-d12629593e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12629484e9-true-d12629593e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629484e10-true-d12629641e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6348"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629484e10-true-d12629641e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12629484e10-true-d12629641e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629604e12-true-d12629709e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6347"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629604e12-true-d12629709e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12629604e12-true-d12629709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629604e35-true-d12629768e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6346"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629604e35-true-d12629768e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12629604e35-true-d12629768e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629413e11-true-d12629845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6345"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629413e11-true-d12629845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12629413e11-true-d12629845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629799e16-true-d12629886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6344"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629799e16-true-d12629886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12629799e16-true-d12629886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e100-true-d12629958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6343"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e100-true-d12629958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12626568e100-true-d12629958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629897e15-true-d12630034e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6342"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629897e15-true-d12630034e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12629897e15-true-d12630034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629897e35-true-d12630089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6341"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629897e35-true-d12630089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12629897e35-true-d12630089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629897e39-true-d12630146e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6340"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629897e39-true-d12630146e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12629897e39-true-d12630146e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12629897e42-true-d12630200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6339"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12629897e42-true-d12630200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12629897e42-true-d12630200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e128-true-d12630269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6338"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e128-true-d12630269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12626568e128-true-d12630269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630279e13-true-d12630303e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6337"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12630279e13-true-d12630303e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12630279e13-true-d12630303e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630324e13-true-d12630348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6336"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12630324e13-true-d12630348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12630324e13-true-d12630348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630369e13-true-d12630393e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6335"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12630369e13-true-d12630393e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12630369e13-true-d12630393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630414e13-true-d12630448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6334"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12630414e13-true-d12630448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12630414e13-true-d12630448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12626568e132-true-d12630492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6333"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12626568e132-true-d12630492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12626568e132-true-d12630492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630480e2-true-d12630519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6332"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12630480e2-true-d12630519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12630480e2-true-d12630519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e92-true-d12630577e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6331"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e92-true-d12630577e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12589705e92-true-d12630577e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630587e13-true-d12630611e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6330"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12630587e13-true-d12630611e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12630587e13-true-d12630611e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630632e13-true-d12630656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6329"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12630632e13-true-d12630656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12630632e13-true-d12630656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630677e13-true-d12630701e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6328"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12630677e13-true-d12630701e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12630677e13-true-d12630701e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630722e13-true-d12630756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6327"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12630722e13-true-d12630756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12630722e13-true-d12630756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12589705e97-true-d12630800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6326"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12589705e97-true-d12630800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12589705e97-true-d12630800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630788e2-true-d12630827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6325"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12630788e2-true-d12630827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12630788e2-true-d12630827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e16-true-d12632271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="6324"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e16-true-d12632271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12630848e16-true-d12632271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e53-true-d12632330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6323"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e53-true-d12632330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12630848e53-true-d12632330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632307e9-true-d12632374e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6322"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632307e9-true-d12632374e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12632307e9-true-d12632374e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632307e29-true-d12632423e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6321"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632307e29-true-d12632423e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12632307e29-true-d12632423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e58-true-d12632459e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6320"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e58-true-d12632459e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12630848e58-true-d12632459e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632447e2-true-d12632479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6319"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632447e2-true-d12632479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12632447e2-true-d12632479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632447e8-true-d12632520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6318"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632447e8-true-d12632520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12632447e8-true-d12632520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e62-true-d12632613e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6317"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e62-true-d12632613e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12630848e62-true-d12632613e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632549e9-true-d12632673e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6316"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632549e9-true-d12632673e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12632549e9-true-d12632673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e66-true-d12632795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6315"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e66-true-d12632795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12630848e66-true-d12632795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632722e10-true-d12632887e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6314"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632722e10-true-d12632887e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12632722e10-true-d12632887e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632722e30-true-d12632926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6313"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632722e30-true-d12632926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12632722e30-true-d12632926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632722e34-true-d12632965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6312"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632722e34-true-d12632965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12632722e34-true-d12632965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632722e39-true-d12633026e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6311"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632722e39-true-d12633026e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12632722e39-true-d12633026e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632989e12-true-d12633094e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6310"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632989e12-true-d12633094e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12632989e12-true-d12633094e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12632989e35-true-d12633153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6309"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12632989e35-true-d12633153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12632989e35-true-d12633153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e71-true-d12633250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6308"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e71-true-d12633250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12630848e71-true-d12633250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633184e7-true-d12633325e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6307"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633184e7-true-d12633325e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12633184e7-true-d12633325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633255e9-true-d12633364e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6306"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633255e9-true-d12633364e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12633255e9-true-d12633364e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633255e10-true-d12633412e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6305"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633255e10-true-d12633412e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12633255e10-true-d12633412e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633375e12-true-d12633480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6304"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633375e12-true-d12633480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12633375e12-true-d12633480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633375e35-true-d12633539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6303"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633375e35-true-d12633539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12633375e35-true-d12633539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633184e11-true-d12633616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6302"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633184e11-true-d12633616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12633184e11-true-d12633616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633570e16-true-d12633657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6301"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633570e16-true-d12633657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12633570e16-true-d12633657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e75-true-d12633729e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6300"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e75-true-d12633729e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12630848e75-true-d12633729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633668e15-true-d12633805e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6299"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633668e15-true-d12633805e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12633668e15-true-d12633805e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633668e35-true-d12633860e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6298"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633668e35-true-d12633860e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12633668e35-true-d12633860e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633668e39-true-d12633917e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6297"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633668e39-true-d12633917e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12633668e39-true-d12633917e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12633668e42-true-d12633971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6296"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12633668e42-true-d12633971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12633668e42-true-d12633971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e81-true-d12634031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6295"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e81-true-d12634031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12630848e81-true-d12634031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12634041e13-true-d12634065e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6294"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12634041e13-true-d12634065e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12634041e13-true-d12634065e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12634086e13-true-d12634110e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6293"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12634086e13-true-d12634110e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12634086e13-true-d12634110e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12634131e13-true-d12634155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6292"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12634131e13-true-d12634155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12634131e13-true-d12634155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12634176e13-true-d12634210e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6291"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12634176e13-true-d12634210e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12634176e13-true-d12634210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e86-true-d12634254e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6290"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e86-true-d12634254e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12630848e86-true-d12634254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12634242e2-true-d12634281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6289"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12634242e2-true-d12634281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12634242e2-true-d12634281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12630848e92-true-d12639386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="6288"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12630848e92-true-d12639386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12630848e92-true-d12639386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e16-true-d12640851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6287"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e16-true-d12640851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12639401e16-true-d12640851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e77-true-d12640931e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6286"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e77-true-d12640931e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12639401e77-true-d12640931e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12640908e9-true-d12640975e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6285"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12640908e9-true-d12640975e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12640908e9-true-d12640975e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12640908e29-true-d12641024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6284"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12640908e29-true-d12641024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12640908e29-true-d12641024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e81-true-d12641060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6283"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e81-true-d12641060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12639401e81-true-d12641060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641048e2-true-d12641080e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6282"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641048e2-true-d12641080e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12641048e2-true-d12641080e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641048e8-true-d12641121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6281"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641048e8-true-d12641121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12641048e8-true-d12641121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e85-true-d12641214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6280"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e85-true-d12641214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12639401e85-true-d12641214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641150e9-true-d12641274e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6279"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641150e9-true-d12641274e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12641150e9-true-d12641274e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e90-true-d12641396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6278"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e90-true-d12641396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12639401e90-true-d12641396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641323e10-true-d12641488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6277"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641323e10-true-d12641488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12641323e10-true-d12641488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641323e30-true-d12641527e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6276"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641323e30-true-d12641527e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12641323e30-true-d12641527e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641323e34-true-d12641566e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6275"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641323e34-true-d12641566e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12641323e34-true-d12641566e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641323e39-true-d12641627e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6274"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641323e39-true-d12641627e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12641323e39-true-d12641627e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641590e12-true-d12641695e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6273"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641590e12-true-d12641695e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12641590e12-true-d12641695e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641590e35-true-d12641754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6272"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641590e35-true-d12641754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12641590e35-true-d12641754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e94-true-d12641851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6271"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e94-true-d12641851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12639401e94-true-d12641851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641785e7-true-d12641926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6270"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641785e7-true-d12641926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12641785e7-true-d12641926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641856e9-true-d12641965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6269"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641856e9-true-d12641965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12641856e9-true-d12641965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641856e10-true-d12642013e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6268"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641856e10-true-d12642013e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12641856e10-true-d12642013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641976e12-true-d12642081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6267"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641976e12-true-d12642081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12641976e12-true-d12642081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641976e35-true-d12642140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6266"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641976e35-true-d12642140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12641976e35-true-d12642140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12641785e11-true-d12642217e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6265"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12641785e11-true-d12642217e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12641785e11-true-d12642217e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642171e16-true-d12642258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6264"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12642171e16-true-d12642258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12642171e16-true-d12642258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e98-true-d12642330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6263"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e98-true-d12642330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12639401e98-true-d12642330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642269e15-true-d12642406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6262"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12642269e15-true-d12642406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12642269e15-true-d12642406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642269e35-true-d12642461e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6261"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12642269e35-true-d12642461e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12642269e35-true-d12642461e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642269e39-true-d12642518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6260"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12642269e39-true-d12642518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12642269e39-true-d12642518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642269e42-true-d12642572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6259"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12642269e42-true-d12642572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12642269e42-true-d12642572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e126-true-d12642641e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6258"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e126-true-d12642641e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12639401e126-true-d12642641e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642651e13-true-d12642675e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6257"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12642651e13-true-d12642675e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12642651e13-true-d12642675e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642696e13-true-d12642720e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6256"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12642696e13-true-d12642720e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12642696e13-true-d12642720e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642741e13-true-d12642765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6255"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12642741e13-true-d12642765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12642741e13-true-d12642765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642786e13-true-d12642820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6254"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12642786e13-true-d12642820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12642786e13-true-d12642820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12639401e130-true-d12642864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6253"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12639401e130-true-d12642864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12639401e130-true-d12642864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642852e2-true-d12642891e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6252"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12642852e2-true-d12642891e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12642852e2-true-d12642891e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e16-true-d12644355e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6251"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e16-true-d12644355e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12642912e16-true-d12644355e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e65-true-d12644429e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6250"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e65-true-d12644429e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12642912e65-true-d12644429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644406e9-true-d12644473e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6249"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644406e9-true-d12644473e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12644406e9-true-d12644473e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644406e29-true-d12644522e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6248"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644406e29-true-d12644522e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12644406e29-true-d12644522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e69-true-d12644558e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6247"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e69-true-d12644558e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12642912e69-true-d12644558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644546e2-true-d12644578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6246"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644546e2-true-d12644578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12644546e2-true-d12644578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644546e8-true-d12644619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6245"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644546e8-true-d12644619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12644546e8-true-d12644619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e73-true-d12644712e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6244"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e73-true-d12644712e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12642912e73-true-d12644712e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644648e9-true-d12644772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6243"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644648e9-true-d12644772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12644648e9-true-d12644772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e78-true-d12644894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6242"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e78-true-d12644894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12642912e78-true-d12644894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644821e10-true-d12644986e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6241"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644821e10-true-d12644986e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12644821e10-true-d12644986e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644821e30-true-d12645025e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6240"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644821e30-true-d12645025e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12644821e30-true-d12645025e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644821e34-true-d12645064e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6239"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644821e34-true-d12645064e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12644821e34-true-d12645064e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12644821e39-true-d12645125e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6238"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12644821e39-true-d12645125e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12644821e39-true-d12645125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645088e12-true-d12645193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6237"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645088e12-true-d12645193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12645088e12-true-d12645193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645088e35-true-d12645252e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6236"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645088e35-true-d12645252e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12645088e35-true-d12645252e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e82-true-d12645349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6235"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e82-true-d12645349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12642912e82-true-d12645349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645283e7-true-d12645424e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6234"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645283e7-true-d12645424e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12645283e7-true-d12645424e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645354e9-true-d12645463e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6233"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645354e9-true-d12645463e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12645354e9-true-d12645463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645354e10-true-d12645511e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6232"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645354e10-true-d12645511e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12645354e10-true-d12645511e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645474e12-true-d12645579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6231"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645474e12-true-d12645579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12645474e12-true-d12645579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645474e35-true-d12645638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6230"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645474e35-true-d12645638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12645474e35-true-d12645638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645283e11-true-d12645715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6229"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645283e11-true-d12645715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12645283e11-true-d12645715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645669e16-true-d12645756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6228"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645669e16-true-d12645756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12645669e16-true-d12645756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e86-true-d12645828e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6227"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e86-true-d12645828e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12642912e86-true-d12645828e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645767e15-true-d12645904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6226"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645767e15-true-d12645904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12645767e15-true-d12645904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645767e35-true-d12645959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6225"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645767e35-true-d12645959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12645767e35-true-d12645959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645767e39-true-d12646016e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6224"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645767e39-true-d12646016e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12645767e39-true-d12646016e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12645767e42-true-d12646070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6223"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12645767e42-true-d12646070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12645767e42-true-d12646070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e114-true-d12646139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6222"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e114-true-d12646139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12642912e114-true-d12646139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646149e13-true-d12646173e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6221"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12646149e13-true-d12646173e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12646149e13-true-d12646173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646194e13-true-d12646218e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6220"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12646194e13-true-d12646218e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12646194e13-true-d12646218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646239e13-true-d12646263e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6219"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12646239e13-true-d12646263e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12646239e13-true-d12646263e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646284e13-true-d12646318e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6218"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12646284e13-true-d12646318e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12646284e13-true-d12646318e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12642912e118-true-d12646362e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6217"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12642912e118-true-d12646362e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12642912e118-true-d12646362e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646350e2-true-d12646389e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6216"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12646350e2-true-d12646389e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12646350e2-true-d12646389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e16-true-d12647913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="6215"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e16-true-d12647913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12646410e16-true-d12647913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e100-true-d12648032e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6214"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e100-true-d12648032e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12646410e100-true-d12648032e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648009e9-true-d12648076e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6213"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648009e9-true-d12648076e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12648009e9-true-d12648076e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648009e29-true-d12648125e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6212"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648009e29-true-d12648125e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12648009e29-true-d12648125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e104-true-d12648161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6211"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e104-true-d12648161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12646410e104-true-d12648161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648149e2-true-d12648181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6210"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648149e2-true-d12648181e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12648149e2-true-d12648181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648149e8-true-d12648222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6209"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648149e8-true-d12648222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12648149e8-true-d12648222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e108-true-d12648315e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6208"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e108-true-d12648315e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12646410e108-true-d12648315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648251e9-true-d12648375e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6207"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648251e9-true-d12648375e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12648251e9-true-d12648375e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e113-true-d12648497e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6206"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e113-true-d12648497e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12646410e113-true-d12648497e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648424e10-true-d12648589e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6205"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648424e10-true-d12648589e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12648424e10-true-d12648589e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648424e30-true-d12648628e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6204"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648424e30-true-d12648628e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12648424e30-true-d12648628e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648424e34-true-d12648667e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6203"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648424e34-true-d12648667e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12648424e34-true-d12648667e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648424e39-true-d12648728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6202"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648424e39-true-d12648728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12648424e39-true-d12648728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648691e12-true-d12648796e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6201"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648691e12-true-d12648796e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12648691e12-true-d12648796e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648691e35-true-d12648855e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6200"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648691e35-true-d12648855e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12648691e35-true-d12648855e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e117-true-d12648952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6199"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e117-true-d12648952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12646410e117-true-d12648952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648886e7-true-d12649027e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6198"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648886e7-true-d12649027e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12648886e7-true-d12649027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648957e9-true-d12649066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6197"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648957e9-true-d12649066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12648957e9-true-d12649066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648957e10-true-d12649114e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6196"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648957e10-true-d12649114e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12648957e10-true-d12649114e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649077e12-true-d12649182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6195"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649077e12-true-d12649182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12649077e12-true-d12649182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649077e35-true-d12649241e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6194"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649077e35-true-d12649241e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12649077e35-true-d12649241e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12648886e11-true-d12649318e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6193"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12648886e11-true-d12649318e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12648886e11-true-d12649318e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649272e16-true-d12649359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6192"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649272e16-true-d12649359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12649272e16-true-d12649359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e121-true-d12649431e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6191"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e121-true-d12649431e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12646410e121-true-d12649431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649370e15-true-d12649507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6190"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649370e15-true-d12649507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12649370e15-true-d12649507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649370e35-true-d12649562e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6189"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649370e35-true-d12649562e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12649370e35-true-d12649562e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649370e39-true-d12649619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6188"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649370e39-true-d12649619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12649370e39-true-d12649619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649370e42-true-d12649673e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6187"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649370e42-true-d12649673e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12649370e42-true-d12649673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e149-true-d12649742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6186"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e149-true-d12649742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12646410e149-true-d12649742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649752e13-true-d12649776e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6185"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12649752e13-true-d12649776e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12649752e13-true-d12649776e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649797e13-true-d12649821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6184"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12649797e13-true-d12649821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12649797e13-true-d12649821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649842e13-true-d12649866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6183"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12649842e13-true-d12649866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12649842e13-true-d12649866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649887e13-true-d12649921e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6182"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12649887e13-true-d12649921e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12649887e13-true-d12649921e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e153-true-d12649965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6181"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e153-true-d12649965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12646410e153-true-d12649965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12649953e2-true-d12649992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6180"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12649953e2-true-d12649992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12649953e2-true-d12649992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e158-true-d12650023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="6179"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e158-true-d12650023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12646410e158-true-d12650023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12646410e162-true-d12650061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="6178"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12646410e162-true-d12650061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12646410e162-true-d12650061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e16-true-d12651506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6177"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e16-true-d12651506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12650090e16-true-d12651506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e43-true-d12651559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6176"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e43-true-d12651559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12650090e43-true-d12651559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651536e9-true-d12651603e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6175"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651536e9-true-d12651603e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12651536e9-true-d12651603e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651536e29-true-d12651652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6174"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651536e29-true-d12651652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12651536e29-true-d12651652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e47-true-d12651688e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6173"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e47-true-d12651688e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12650090e47-true-d12651688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651676e2-true-d12651708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6172"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651676e2-true-d12651708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12651676e2-true-d12651708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651676e8-true-d12651749e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6171"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651676e8-true-d12651749e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12651676e8-true-d12651749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e52-true-d12651842e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6170"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e52-true-d12651842e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12650090e52-true-d12651842e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651778e9-true-d12651902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6169"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651778e9-true-d12651902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12651778e9-true-d12651902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e56-true-d12652024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6168"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e56-true-d12652024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12650090e56-true-d12652024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651951e10-true-d12652116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6167"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651951e10-true-d12652116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12651951e10-true-d12652116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651951e30-true-d12652155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6166"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651951e30-true-d12652155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12651951e30-true-d12652155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651951e34-true-d12652194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6165"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651951e34-true-d12652194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12651951e34-true-d12652194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12651951e39-true-d12652255e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6164"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12651951e39-true-d12652255e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12651951e39-true-d12652255e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652218e12-true-d12652323e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6163"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652218e12-true-d12652323e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12652218e12-true-d12652323e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652218e35-true-d12652382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6162"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652218e35-true-d12652382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12652218e35-true-d12652382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e60-true-d12652479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6161"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e60-true-d12652479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12650090e60-true-d12652479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652413e7-true-d12652554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6160"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652413e7-true-d12652554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12652413e7-true-d12652554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652484e9-true-d12652593e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6159"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652484e9-true-d12652593e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12652484e9-true-d12652593e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652484e10-true-d12652641e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6158"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652484e10-true-d12652641e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12652484e10-true-d12652641e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652604e12-true-d12652709e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6157"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652604e12-true-d12652709e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12652604e12-true-d12652709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652604e35-true-d12652768e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6156"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652604e35-true-d12652768e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12652604e35-true-d12652768e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652413e11-true-d12652845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6155"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652413e11-true-d12652845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12652413e11-true-d12652845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652799e16-true-d12652886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6154"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652799e16-true-d12652886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12652799e16-true-d12652886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e65-true-d12652958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6153"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e65-true-d12652958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12650090e65-true-d12652958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652897e15-true-d12653034e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6152"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652897e15-true-d12653034e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12652897e15-true-d12653034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652897e35-true-d12653089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6151"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652897e35-true-d12653089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12652897e35-true-d12653089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652897e39-true-d12653146e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6150"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652897e39-true-d12653146e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12652897e39-true-d12653146e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12652897e42-true-d12653200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6149"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12652897e42-true-d12653200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12652897e42-true-d12653200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e92-true-d12653269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6148"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e92-true-d12653269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12650090e92-true-d12653269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653279e13-true-d12653303e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6147"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12653279e13-true-d12653303e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12653279e13-true-d12653303e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653324e13-true-d12653348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6146"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12653324e13-true-d12653348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12653324e13-true-d12653348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653369e13-true-d12653393e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6145"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12653369e13-true-d12653393e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12653369e13-true-d12653393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653414e13-true-d12653448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6144"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12653414e13-true-d12653448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12653414e13-true-d12653448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12650090e97-true-d12653492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6143"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12650090e97-true-d12653492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12650090e97-true-d12653492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653480e2-true-d12653519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6142"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12653480e2-true-d12653519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12653480e2-true-d12653519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e16-true-d12654963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="6141"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e16-true-d12654963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12653540e16-true-d12654963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e53-true-d12655022e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6140"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e53-true-d12655022e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12653540e53-true-d12655022e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12654999e9-true-d12655066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6139"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12654999e9-true-d12655066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12654999e9-true-d12655066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12654999e29-true-d12655115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6138"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12654999e29-true-d12655115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12654999e29-true-d12655115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e58-true-d12655151e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6137"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e58-true-d12655151e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12653540e58-true-d12655151e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655139e2-true-d12655171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6136"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655139e2-true-d12655171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12655139e2-true-d12655171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655139e8-true-d12655212e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6135"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655139e8-true-d12655212e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12655139e8-true-d12655212e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e62-true-d12655305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6134"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e62-true-d12655305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12653540e62-true-d12655305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655241e9-true-d12655365e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6133"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655241e9-true-d12655365e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12655241e9-true-d12655365e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e66-true-d12655487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6132"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e66-true-d12655487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12653540e66-true-d12655487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655414e10-true-d12655579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6131"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655414e10-true-d12655579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12655414e10-true-d12655579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655414e30-true-d12655618e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6130"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655414e30-true-d12655618e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12655414e30-true-d12655618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655414e34-true-d12655657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6129"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655414e34-true-d12655657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12655414e34-true-d12655657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655414e39-true-d12655718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6128"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655414e39-true-d12655718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12655414e39-true-d12655718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655681e12-true-d12655786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6127"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655681e12-true-d12655786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12655681e12-true-d12655786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655681e35-true-d12655845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6126"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655681e35-true-d12655845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12655681e35-true-d12655845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e71-true-d12655942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6125"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e71-true-d12655942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12653540e71-true-d12655942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655876e7-true-d12656017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6124"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655876e7-true-d12656017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12655876e7-true-d12656017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655947e9-true-d12656056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6123"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655947e9-true-d12656056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12655947e9-true-d12656056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655947e10-true-d12656104e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6122"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655947e10-true-d12656104e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12655947e10-true-d12656104e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656067e12-true-d12656172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6121"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656067e12-true-d12656172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12656067e12-true-d12656172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656067e35-true-d12656231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6120"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656067e35-true-d12656231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12656067e35-true-d12656231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12655876e11-true-d12656308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6119"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12655876e11-true-d12656308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12655876e11-true-d12656308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656262e16-true-d12656349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6118"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656262e16-true-d12656349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12656262e16-true-d12656349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e75-true-d12656421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6117"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e75-true-d12656421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12653540e75-true-d12656421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656360e15-true-d12656497e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6116"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656360e15-true-d12656497e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12656360e15-true-d12656497e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656360e35-true-d12656552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6115"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656360e35-true-d12656552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12656360e35-true-d12656552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656360e39-true-d12656609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6114"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656360e39-true-d12656609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12656360e39-true-d12656609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656360e42-true-d12656663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6113"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656360e42-true-d12656663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12656360e42-true-d12656663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e81-true-d12656723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6112"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e81-true-d12656723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12653540e81-true-d12656723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656733e13-true-d12656757e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6111"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12656733e13-true-d12656757e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12656733e13-true-d12656757e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656778e13-true-d12656802e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6110"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12656778e13-true-d12656802e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12656778e13-true-d12656802e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656823e13-true-d12656847e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6109"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12656823e13-true-d12656847e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12656823e13-true-d12656847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656868e13-true-d12656902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6108"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12656868e13-true-d12656902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12656868e13-true-d12656902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12653540e86-true-d12656946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6107"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12653540e86-true-d12656946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12653540e86-true-d12656946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12656934e2-true-d12656973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6106"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12656934e2-true-d12656973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12656934e2-true-d12656973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e16-true-d12658474e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6105"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e16-true-d12658474e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12657003e16-true-d12658474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e87-true-d12658572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6104"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e87-true-d12658572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12657003e87-true-d12658572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658549e9-true-d12658616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6103"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658549e9-true-d12658616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12658549e9-true-d12658616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658549e29-true-d12658665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6102"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658549e29-true-d12658665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12658549e29-true-d12658665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e92-true-d12658701e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6101"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e92-true-d12658701e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12657003e92-true-d12658701e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658689e2-true-d12658721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6100"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658689e2-true-d12658721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12658689e2-true-d12658721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658689e8-true-d12658762e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6099"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658689e8-true-d12658762e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12658689e8-true-d12658762e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e96-true-d12658855e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6098"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e96-true-d12658855e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12657003e96-true-d12658855e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658791e9-true-d12658915e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6097"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658791e9-true-d12658915e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12658791e9-true-d12658915e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e100-true-d12659037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6096"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e100-true-d12659037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12657003e100-true-d12659037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658964e10-true-d12659129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6095"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658964e10-true-d12659129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12658964e10-true-d12659129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658964e30-true-d12659168e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6094"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658964e30-true-d12659168e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12658964e30-true-d12659168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658964e34-true-d12659207e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6093"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658964e34-true-d12659207e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12658964e34-true-d12659207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12658964e39-true-d12659268e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6092"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12658964e39-true-d12659268e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12658964e39-true-d12659268e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659231e12-true-d12659336e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6091"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659231e12-true-d12659336e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12659231e12-true-d12659336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659231e35-true-d12659395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6090"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659231e35-true-d12659395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12659231e35-true-d12659395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e105-true-d12659492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6089"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e105-true-d12659492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12657003e105-true-d12659492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659426e7-true-d12659567e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6088"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659426e7-true-d12659567e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12659426e7-true-d12659567e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659497e9-true-d12659606e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6087"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659497e9-true-d12659606e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12659497e9-true-d12659606e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659497e10-true-d12659654e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6086"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659497e10-true-d12659654e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12659497e10-true-d12659654e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659617e12-true-d12659722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6085"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659617e12-true-d12659722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12659617e12-true-d12659722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659617e35-true-d12659781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6084"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659617e35-true-d12659781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12659617e35-true-d12659781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659426e11-true-d12659858e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6083"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659426e11-true-d12659858e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12659426e11-true-d12659858e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659812e16-true-d12659899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6082"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659812e16-true-d12659899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12659812e16-true-d12659899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e109-true-d12659971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6081"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e109-true-d12659971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12657003e109-true-d12659971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659910e15-true-d12660047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6080"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659910e15-true-d12660047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12659910e15-true-d12660047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659910e35-true-d12660102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6079"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659910e35-true-d12660102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12659910e35-true-d12660102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659910e39-true-d12660159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6078"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659910e39-true-d12660159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12659910e39-true-d12660159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12659910e42-true-d12660213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6077"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12659910e42-true-d12660213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12659910e42-true-d12660213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e137-true-d12660282e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6076"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e137-true-d12660282e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12657003e137-true-d12660282e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660292e13-true-d12660316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6075"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12660292e13-true-d12660316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12660292e13-true-d12660316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660337e13-true-d12660361e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6074"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12660337e13-true-d12660361e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12660337e13-true-d12660361e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660382e13-true-d12660406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6073"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12660382e13-true-d12660406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12660382e13-true-d12660406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660427e13-true-d12660461e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6072"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12660427e13-true-d12660461e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12660427e13-true-d12660461e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12657003e141-true-d12660505e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6071"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12657003e141-true-d12660505e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12657003e141-true-d12660505e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660493e2-true-d12660532e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6070"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12660493e2-true-d12660532e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12660493e2-true-d12660532e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e16-true-d12661969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6069"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e16-true-d12661969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12660553e16-true-d12661969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e43-true-d12662022e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6068"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e43-true-d12662022e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12660553e43-true-d12662022e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12661999e9-true-d12662066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6067"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12661999e9-true-d12662066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12661999e9-true-d12662066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12661999e29-true-d12662115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6066"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12661999e29-true-d12662115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12661999e29-true-d12662115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e47-true-d12662151e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6065"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e47-true-d12662151e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12660553e47-true-d12662151e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662139e2-true-d12662171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6064"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662139e2-true-d12662171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12662139e2-true-d12662171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662139e8-true-d12662212e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6063"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662139e8-true-d12662212e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12662139e8-true-d12662212e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e52-true-d12662305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6062"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e52-true-d12662305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12660553e52-true-d12662305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662241e9-true-d12662365e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6061"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662241e9-true-d12662365e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12662241e9-true-d12662365e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e56-true-d12662487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6060"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e56-true-d12662487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12660553e56-true-d12662487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662414e10-true-d12662579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6059"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662414e10-true-d12662579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12662414e10-true-d12662579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662414e30-true-d12662618e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6058"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662414e30-true-d12662618e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12662414e30-true-d12662618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662414e34-true-d12662657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6057"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662414e34-true-d12662657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12662414e34-true-d12662657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662414e39-true-d12662718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6056"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662414e39-true-d12662718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12662414e39-true-d12662718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662681e12-true-d12662786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6055"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662681e12-true-d12662786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12662681e12-true-d12662786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662681e35-true-d12662845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6054"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662681e35-true-d12662845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12662681e35-true-d12662845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e60-true-d12662942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6053"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e60-true-d12662942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12660553e60-true-d12662942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662876e7-true-d12663017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6052"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662876e7-true-d12663017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12662876e7-true-d12663017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662947e9-true-d12663056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6051"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662947e9-true-d12663056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12662947e9-true-d12663056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662947e10-true-d12663104e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6050"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662947e10-true-d12663104e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12662947e10-true-d12663104e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663067e12-true-d12663172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6049"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663067e12-true-d12663172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12663067e12-true-d12663172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663067e35-true-d12663231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6048"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663067e35-true-d12663231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12663067e35-true-d12663231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12662876e11-true-d12663308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6047"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12662876e11-true-d12663308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12662876e11-true-d12663308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663262e16-true-d12663349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6046"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663262e16-true-d12663349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12663262e16-true-d12663349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e65-true-d12663421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6045"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e65-true-d12663421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12660553e65-true-d12663421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663360e15-true-d12663497e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6044"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663360e15-true-d12663497e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12663360e15-true-d12663497e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663360e35-true-d12663552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6043"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663360e35-true-d12663552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12663360e35-true-d12663552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663360e39-true-d12663609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6042"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663360e39-true-d12663609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12663360e39-true-d12663609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663360e42-true-d12663663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="6041"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663360e42-true-d12663663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12663360e42-true-d12663663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e92-true-d12663732e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="6040"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e92-true-d12663732e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12660553e92-true-d12663732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663742e13-true-d12663766e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6039"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12663742e13-true-d12663766e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12663742e13-true-d12663766e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663787e13-true-d12663811e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6038"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12663787e13-true-d12663811e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12663787e13-true-d12663811e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663832e13-true-d12663856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="6037"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12663832e13-true-d12663856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12663832e13-true-d12663856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663877e13-true-d12663911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="6036"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12663877e13-true-d12663911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12663877e13-true-d12663911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12660553e97-true-d12663955e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="6035"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12660553e97-true-d12663955e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12660553e97-true-d12663955e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12663943e2-true-d12663982e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="6034"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12663943e2-true-d12663982e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12663943e2-true-d12663982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e16-true-d12665542e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="6033"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e16-true-d12665542e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12664003e16-true-d12665542e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e95-true-d12665658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="6032"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e95-true-d12665658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12664003e95-true-d12665658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12665635e9-true-d12665702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="6031"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12665635e9-true-d12665702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12665635e9-true-d12665702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12665635e29-true-d12665751e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="6030"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12665635e29-true-d12665751e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12665635e29-true-d12665751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e99-true-d12665787e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="6029"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e99-true-d12665787e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12664003e99-true-d12665787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12665775e2-true-d12665807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="6028"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12665775e2-true-d12665807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12665775e2-true-d12665807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12665775e8-true-d12665848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="6027"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12665775e8-true-d12665848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12665775e8-true-d12665848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e103-true-d12665925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="6026"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e103-true-d12665925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12664003e103-true-d12665925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12665877e5-true-d12665981e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="6025"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12665877e5-true-d12665981e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12665877e5-true-d12665981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12665991e13-true-d12666008e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="6024"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12665991e13-true-d12666008e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12665991e13-true-d12666008e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666023e13-true-d12666051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="6023"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12666023e13-true-d12666051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12666023e13-true-d12666051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12665877e24-true-d12666112e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6022"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12665877e24-true-d12666112e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12665877e24-true-d12666112e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666075e12-true-d12666180e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6021"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666075e12-true-d12666180e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12666075e12-true-d12666180e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666075e35-true-d12666239e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6020"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666075e35-true-d12666239e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12666075e35-true-d12666239e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e111-true-d12666334e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="6019"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e111-true-d12666334e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12664003e111-true-d12666334e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666270e9-true-d12666394e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6018"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666270e9-true-d12666394e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12666270e9-true-d12666394e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e115-true-d12666516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="6017"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e115-true-d12666516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12664003e115-true-d12666516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666443e10-true-d12666608e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="6016"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666443e10-true-d12666608e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12666443e10-true-d12666608e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666443e30-true-d12666647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6015"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666443e30-true-d12666647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12666443e30-true-d12666647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666443e34-true-d12666686e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6014"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666443e34-true-d12666686e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12666443e34-true-d12666686e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666443e39-true-d12666747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6013"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666443e39-true-d12666747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12666443e39-true-d12666747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666710e12-true-d12666815e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6012"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666710e12-true-d12666815e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12666710e12-true-d12666815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666710e35-true-d12666874e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6011"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666710e35-true-d12666874e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12666710e35-true-d12666874e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e119-true-d12666971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="6010"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e119-true-d12666971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12664003e119-true-d12666971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666905e7-true-d12667046e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="6009"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666905e7-true-d12667046e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12666905e7-true-d12667046e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666976e9-true-d12667085e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="6008"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666976e9-true-d12667085e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12666976e9-true-d12667085e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666976e10-true-d12667133e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="6007"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666976e10-true-d12667133e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12666976e10-true-d12667133e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667096e12-true-d12667201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="6006"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667096e12-true-d12667201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12667096e12-true-d12667201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667096e35-true-d12667260e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="6005"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667096e35-true-d12667260e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12667096e35-true-d12667260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12666905e11-true-d12667337e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="6004"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12666905e11-true-d12667337e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12666905e11-true-d12667337e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667291e16-true-d12667378e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="6003"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667291e16-true-d12667378e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12667291e16-true-d12667378e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e124-true-d12667450e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="6002"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e124-true-d12667450e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12664003e124-true-d12667450e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667389e15-true-d12667526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="6001"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667389e15-true-d12667526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12667389e15-true-d12667526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667389e35-true-d12667581e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="6000"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667389e35-true-d12667581e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12667389e35-true-d12667581e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667389e39-true-d12667638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5999"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667389e39-true-d12667638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12667389e39-true-d12667638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667389e42-true-d12667692e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5998"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667389e42-true-d12667692e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12667389e42-true-d12667692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e151-true-d12667761e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5997"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e151-true-d12667761e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12664003e151-true-d12667761e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667771e13-true-d12667795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5996"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12667771e13-true-d12667795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12667771e13-true-d12667795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667816e13-true-d12667840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5995"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12667816e13-true-d12667840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12667816e13-true-d12667840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667861e13-true-d12667885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5994"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12667861e13-true-d12667885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12667861e13-true-d12667885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667906e13-true-d12667940e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5993"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12667906e13-true-d12667940e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12667906e13-true-d12667940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12664003e156-true-d12667984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5992"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12664003e156-true-d12667984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12664003e156-true-d12667984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12667972e2-true-d12668011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5991"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12667972e2-true-d12668011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12667972e2-true-d12668011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e16-true-d12669538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5990"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e16-true-d12669538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12668032e16-true-d12669538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e71-true-d12669630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5989"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e71-true-d12669630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12668032e71-true-d12669630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669607e9-true-d12669674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5988"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12669607e9-true-d12669674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12669607e9-true-d12669674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669607e29-true-d12669723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5987"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12669607e29-true-d12669723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12669607e29-true-d12669723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e76-true-d12669759e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5986"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e76-true-d12669759e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12668032e76-true-d12669759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669747e2-true-d12669779e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5985"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12669747e2-true-d12669779e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12669747e2-true-d12669779e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669747e8-true-d12669820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5984"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12669747e8-true-d12669820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12669747e8-true-d12669820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e80-true-d12669897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="5983"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e80-true-d12669897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12668032e80-true-d12669897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669849e5-true-d12669953e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="5982"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12669849e5-true-d12669953e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12669849e5-true-d12669953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669963e13-true-d12669980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="5981"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12669963e13-true-d12669980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12669963e13-true-d12669980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669995e13-true-d12670023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="5980"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12669995e13-true-d12670023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12669995e13-true-d12670023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12669849e24-true-d12670084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5979"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12669849e24-true-d12670084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12669849e24-true-d12670084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670047e12-true-d12670152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5978"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670047e12-true-d12670152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12670047e12-true-d12670152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670047e35-true-d12670211e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5977"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670047e35-true-d12670211e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12670047e35-true-d12670211e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e87-true-d12670306e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5976"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e87-true-d12670306e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12668032e87-true-d12670306e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670242e9-true-d12670366e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5975"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670242e9-true-d12670366e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12670242e9-true-d12670366e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e92-true-d12670488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5974"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e92-true-d12670488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12668032e92-true-d12670488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670415e10-true-d12670580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5973"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670415e10-true-d12670580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12670415e10-true-d12670580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670415e30-true-d12670619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5972"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670415e30-true-d12670619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12670415e30-true-d12670619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670415e34-true-d12670658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5971"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670415e34-true-d12670658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12670415e34-true-d12670658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670415e39-true-d12670719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5970"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670415e39-true-d12670719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12670415e39-true-d12670719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670682e12-true-d12670787e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5969"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670682e12-true-d12670787e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12670682e12-true-d12670787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670682e35-true-d12670846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5968"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670682e35-true-d12670846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12670682e35-true-d12670846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e96-true-d12670943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5967"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e96-true-d12670943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12668032e96-true-d12670943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670877e7-true-d12671018e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5966"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670877e7-true-d12671018e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12670877e7-true-d12671018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670948e9-true-d12671057e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5965"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670948e9-true-d12671057e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12670948e9-true-d12671057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670948e10-true-d12671105e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5964"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670948e10-true-d12671105e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12670948e10-true-d12671105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671068e12-true-d12671173e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5963"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671068e12-true-d12671173e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12671068e12-true-d12671173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671068e35-true-d12671232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5962"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671068e35-true-d12671232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12671068e35-true-d12671232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12670877e11-true-d12671309e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5961"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12670877e11-true-d12671309e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12670877e11-true-d12671309e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671263e16-true-d12671350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5960"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671263e16-true-d12671350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12671263e16-true-d12671350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e100-true-d12671422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5959"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e100-true-d12671422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12668032e100-true-d12671422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671361e15-true-d12671498e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5958"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671361e15-true-d12671498e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12671361e15-true-d12671498e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671361e35-true-d12671553e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5957"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671361e35-true-d12671553e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12671361e35-true-d12671553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671361e39-true-d12671610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5956"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671361e39-true-d12671610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12671361e39-true-d12671610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671361e42-true-d12671664e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5955"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671361e42-true-d12671664e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12671361e42-true-d12671664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e128-true-d12671733e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5954"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e128-true-d12671733e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12668032e128-true-d12671733e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671743e13-true-d12671767e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5953"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12671743e13-true-d12671767e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12671743e13-true-d12671767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671788e13-true-d12671812e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5952"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12671788e13-true-d12671812e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12671788e13-true-d12671812e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671833e13-true-d12671857e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5951"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12671833e13-true-d12671857e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12671833e13-true-d12671857e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671878e13-true-d12671912e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5950"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12671878e13-true-d12671912e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12671878e13-true-d12671912e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12668032e132-true-d12671956e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5949"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12668032e132-true-d12671956e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12668032e132-true-d12671956e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12671944e2-true-d12671983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5948"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12671944e2-true-d12671983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12671944e2-true-d12671983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e16-true-d12673475e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5947"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e16-true-d12673475e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12672004e16-true-d12673475e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e87-true-d12673573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5946"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e87-true-d12673573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12672004e87-true-d12673573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673550e9-true-d12673617e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5945"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673550e9-true-d12673617e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12673550e9-true-d12673617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673550e29-true-d12673666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5944"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673550e29-true-d12673666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12673550e29-true-d12673666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e92-true-d12673702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5943"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e92-true-d12673702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12672004e92-true-d12673702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673690e2-true-d12673722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5942"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673690e2-true-d12673722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12673690e2-true-d12673722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673690e8-true-d12673763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5941"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673690e8-true-d12673763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12673690e8-true-d12673763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e96-true-d12673856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5940"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e96-true-d12673856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12672004e96-true-d12673856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673792e9-true-d12673916e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5939"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673792e9-true-d12673916e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12673792e9-true-d12673916e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e100-true-d12674038e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5938"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e100-true-d12674038e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12672004e100-true-d12674038e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673965e10-true-d12674130e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5937"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673965e10-true-d12674130e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12673965e10-true-d12674130e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673965e30-true-d12674169e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5936"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673965e30-true-d12674169e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12673965e30-true-d12674169e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673965e34-true-d12674208e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5935"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673965e34-true-d12674208e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12673965e34-true-d12674208e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12673965e39-true-d12674269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5934"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12673965e39-true-d12674269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12673965e39-true-d12674269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674232e12-true-d12674337e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5933"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674232e12-true-d12674337e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12674232e12-true-d12674337e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674232e35-true-d12674396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5932"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674232e35-true-d12674396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12674232e35-true-d12674396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e105-true-d12674493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5931"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e105-true-d12674493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12672004e105-true-d12674493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674427e7-true-d12674568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5930"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674427e7-true-d12674568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12674427e7-true-d12674568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674498e9-true-d12674607e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5929"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674498e9-true-d12674607e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12674498e9-true-d12674607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674498e10-true-d12674655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5928"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674498e10-true-d12674655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12674498e10-true-d12674655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674618e12-true-d12674723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5927"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674618e12-true-d12674723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12674618e12-true-d12674723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674618e35-true-d12674782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5926"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674618e35-true-d12674782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12674618e35-true-d12674782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674427e11-true-d12674859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5925"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674427e11-true-d12674859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12674427e11-true-d12674859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674813e16-true-d12674900e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5924"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674813e16-true-d12674900e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12674813e16-true-d12674900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e109-true-d12674972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5923"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e109-true-d12674972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12672004e109-true-d12674972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674911e15-true-d12675048e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5922"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674911e15-true-d12675048e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12674911e15-true-d12675048e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674911e35-true-d12675103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5921"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674911e35-true-d12675103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12674911e35-true-d12675103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674911e39-true-d12675160e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5920"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674911e39-true-d12675160e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12674911e39-true-d12675160e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12674911e42-true-d12675214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5919"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12674911e42-true-d12675214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12674911e42-true-d12675214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e113-true-d12680321e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="5918"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e113-true-d12680321e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12672004e113-true-d12680321e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e16-true-d12681786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5917"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e16-true-d12681786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12680336e16-true-d12681786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e77-true-d12681866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5916"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e77-true-d12681866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12680336e77-true-d12681866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12681843e9-true-d12681910e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5915"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12681843e9-true-d12681910e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12681843e9-true-d12681910e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12681843e29-true-d12681959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5914"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12681843e29-true-d12681959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12681843e29-true-d12681959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e81-true-d12681995e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5913"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e81-true-d12681995e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12680336e81-true-d12681995e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12681983e2-true-d12682015e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5912"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12681983e2-true-d12682015e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12681983e2-true-d12682015e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12681983e8-true-d12682056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5911"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12681983e8-true-d12682056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12681983e8-true-d12682056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e85-true-d12682149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5910"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e85-true-d12682149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12680336e85-true-d12682149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682085e9-true-d12682209e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5909"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682085e9-true-d12682209e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12682085e9-true-d12682209e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e90-true-d12682331e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5908"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e90-true-d12682331e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12680336e90-true-d12682331e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682258e10-true-d12682423e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5907"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682258e10-true-d12682423e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12682258e10-true-d12682423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682258e30-true-d12682462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5906"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682258e30-true-d12682462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12682258e30-true-d12682462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682258e34-true-d12682501e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5905"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682258e34-true-d12682501e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12682258e34-true-d12682501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682258e39-true-d12682562e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5904"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682258e39-true-d12682562e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12682258e39-true-d12682562e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682525e12-true-d12682630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5903"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682525e12-true-d12682630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12682525e12-true-d12682630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682525e35-true-d12682689e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5902"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682525e35-true-d12682689e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12682525e35-true-d12682689e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e94-true-d12682786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5901"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e94-true-d12682786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12680336e94-true-d12682786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682720e7-true-d12682861e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5900"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682720e7-true-d12682861e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12682720e7-true-d12682861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682791e9-true-d12682900e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5899"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682791e9-true-d12682900e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12682791e9-true-d12682900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682791e10-true-d12682948e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5898"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682791e10-true-d12682948e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12682791e10-true-d12682948e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682911e12-true-d12683016e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5897"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682911e12-true-d12683016e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12682911e12-true-d12683016e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682911e35-true-d12683075e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5896"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682911e35-true-d12683075e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12682911e35-true-d12683075e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12682720e11-true-d12683152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5895"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12682720e11-true-d12683152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12682720e11-true-d12683152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683106e16-true-d12683193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5894"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12683106e16-true-d12683193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12683106e16-true-d12683193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e98-true-d12683265e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5893"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e98-true-d12683265e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12680336e98-true-d12683265e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683204e15-true-d12683341e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5892"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12683204e15-true-d12683341e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12683204e15-true-d12683341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683204e35-true-d12683396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5891"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12683204e35-true-d12683396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12683204e35-true-d12683396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683204e39-true-d12683453e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5890"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12683204e39-true-d12683453e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12683204e39-true-d12683453e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683204e42-true-d12683507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5889"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12683204e42-true-d12683507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12683204e42-true-d12683507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e126-true-d12683576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5888"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e126-true-d12683576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12680336e126-true-d12683576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683586e13-true-d12683610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5887"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12683586e13-true-d12683610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12683586e13-true-d12683610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683631e13-true-d12683655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5886"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12683631e13-true-d12683655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12683631e13-true-d12683655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683676e13-true-d12683700e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5885"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12683676e13-true-d12683700e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12683676e13-true-d12683700e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683721e13-true-d12683755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5884"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12683721e13-true-d12683755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12683721e13-true-d12683755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12680336e130-true-d12683799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5883"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12680336e130-true-d12683799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12680336e130-true-d12683799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683787e2-true-d12683826e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5882"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12683787e2-true-d12683826e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12683787e2-true-d12683826e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e16-true-d12685290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5881"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e16-true-d12685290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12683847e16-true-d12685290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e65-true-d12685364e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5880"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e65-true-d12685364e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12683847e65-true-d12685364e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685341e9-true-d12685408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5879"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685341e9-true-d12685408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12685341e9-true-d12685408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685341e29-true-d12685457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5878"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685341e29-true-d12685457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12685341e29-true-d12685457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e69-true-d12685493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5877"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e69-true-d12685493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12683847e69-true-d12685493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685481e2-true-d12685513e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5876"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685481e2-true-d12685513e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12685481e2-true-d12685513e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685481e8-true-d12685554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5875"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685481e8-true-d12685554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12685481e8-true-d12685554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e73-true-d12685647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5874"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e73-true-d12685647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12683847e73-true-d12685647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685583e9-true-d12685707e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5873"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685583e9-true-d12685707e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12685583e9-true-d12685707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e78-true-d12685829e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5872"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e78-true-d12685829e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12683847e78-true-d12685829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685756e10-true-d12685921e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5871"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685756e10-true-d12685921e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12685756e10-true-d12685921e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685756e30-true-d12685960e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5870"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685756e30-true-d12685960e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12685756e30-true-d12685960e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685756e34-true-d12685999e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5869"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685756e34-true-d12685999e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12685756e34-true-d12685999e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12685756e39-true-d12686060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5868"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12685756e39-true-d12686060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12685756e39-true-d12686060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686023e12-true-d12686128e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5867"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686023e12-true-d12686128e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12686023e12-true-d12686128e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686023e35-true-d12686187e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5866"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686023e35-true-d12686187e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12686023e35-true-d12686187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e82-true-d12686284e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5865"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e82-true-d12686284e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12683847e82-true-d12686284e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686218e7-true-d12686359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5864"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686218e7-true-d12686359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12686218e7-true-d12686359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686289e9-true-d12686398e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5863"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686289e9-true-d12686398e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12686289e9-true-d12686398e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686289e10-true-d12686446e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5862"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686289e10-true-d12686446e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12686289e10-true-d12686446e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686409e12-true-d12686514e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5861"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686409e12-true-d12686514e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12686409e12-true-d12686514e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686409e35-true-d12686573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5860"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686409e35-true-d12686573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12686409e35-true-d12686573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686218e11-true-d12686650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5859"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686218e11-true-d12686650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12686218e11-true-d12686650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686604e16-true-d12686691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5858"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686604e16-true-d12686691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12686604e16-true-d12686691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e86-true-d12686763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5857"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e86-true-d12686763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12683847e86-true-d12686763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686702e15-true-d12686839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5856"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686702e15-true-d12686839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12686702e15-true-d12686839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686702e35-true-d12686894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5855"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686702e35-true-d12686894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12686702e35-true-d12686894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686702e39-true-d12686951e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5854"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686702e39-true-d12686951e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12686702e39-true-d12686951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12686702e42-true-d12687005e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5853"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12686702e42-true-d12687005e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12686702e42-true-d12687005e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e114-true-d12687074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5852"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e114-true-d12687074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12683847e114-true-d12687074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687084e13-true-d12687108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5851"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12687084e13-true-d12687108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12687084e13-true-d12687108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687129e13-true-d12687153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5850"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12687129e13-true-d12687153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12687129e13-true-d12687153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687174e13-true-d12687198e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5849"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12687174e13-true-d12687198e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12687174e13-true-d12687198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687219e13-true-d12687253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5848"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12687219e13-true-d12687253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12687219e13-true-d12687253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12683847e118-true-d12687297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5847"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12683847e118-true-d12687297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12683847e118-true-d12687297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687285e2-true-d12687324e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5846"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12687285e2-true-d12687324e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12687285e2-true-d12687324e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e16-true-d12688848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="5845"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e16-true-d12688848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12687345e16-true-d12688848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e100-true-d12688967e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5844"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e100-true-d12688967e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12687345e100-true-d12688967e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12688944e9-true-d12689011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5843"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12688944e9-true-d12689011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12688944e9-true-d12689011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12688944e29-true-d12689060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5842"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12688944e29-true-d12689060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12688944e29-true-d12689060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e104-true-d12689096e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5841"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e104-true-d12689096e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12687345e104-true-d12689096e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689084e2-true-d12689116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5840"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689084e2-true-d12689116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12689084e2-true-d12689116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689084e8-true-d12689157e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5839"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689084e8-true-d12689157e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12689084e8-true-d12689157e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e108-true-d12689250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5838"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e108-true-d12689250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12687345e108-true-d12689250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689186e9-true-d12689310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5837"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689186e9-true-d12689310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12689186e9-true-d12689310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e113-true-d12689432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5836"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e113-true-d12689432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12687345e113-true-d12689432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689359e10-true-d12689524e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5835"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689359e10-true-d12689524e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12689359e10-true-d12689524e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689359e30-true-d12689563e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5834"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689359e30-true-d12689563e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12689359e30-true-d12689563e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689359e34-true-d12689602e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5833"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689359e34-true-d12689602e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12689359e34-true-d12689602e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689359e39-true-d12689663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5832"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689359e39-true-d12689663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12689359e39-true-d12689663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689626e12-true-d12689731e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5831"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689626e12-true-d12689731e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12689626e12-true-d12689731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689626e35-true-d12689790e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5830"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689626e35-true-d12689790e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12689626e35-true-d12689790e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e117-true-d12689887e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5829"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e117-true-d12689887e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12687345e117-true-d12689887e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689821e7-true-d12689962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5828"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689821e7-true-d12689962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12689821e7-true-d12689962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689892e9-true-d12690001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5827"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689892e9-true-d12690001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12689892e9-true-d12690001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689892e10-true-d12690049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5826"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689892e10-true-d12690049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12689892e10-true-d12690049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690012e12-true-d12690117e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5825"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690012e12-true-d12690117e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12690012e12-true-d12690117e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690012e35-true-d12690176e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5824"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690012e35-true-d12690176e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12690012e35-true-d12690176e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12689821e11-true-d12690253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5823"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12689821e11-true-d12690253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12689821e11-true-d12690253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690207e16-true-d12690294e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5822"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690207e16-true-d12690294e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12690207e16-true-d12690294e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e121-true-d12690366e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5821"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e121-true-d12690366e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12687345e121-true-d12690366e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690305e15-true-d12690442e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5820"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690305e15-true-d12690442e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12690305e15-true-d12690442e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690305e35-true-d12690497e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5819"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690305e35-true-d12690497e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12690305e35-true-d12690497e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690305e39-true-d12690554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5818"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690305e39-true-d12690554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12690305e39-true-d12690554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690305e42-true-d12690608e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5817"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690305e42-true-d12690608e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12690305e42-true-d12690608e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e149-true-d12690677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5816"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e149-true-d12690677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12687345e149-true-d12690677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690687e13-true-d12690711e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5815"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12690687e13-true-d12690711e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12690687e13-true-d12690711e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690732e13-true-d12690756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5814"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12690732e13-true-d12690756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12690732e13-true-d12690756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690777e13-true-d12690801e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5813"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12690777e13-true-d12690801e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12690777e13-true-d12690801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690822e13-true-d12690856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5812"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12690822e13-true-d12690856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12690822e13-true-d12690856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e153-true-d12690900e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5811"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e153-true-d12690900e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12687345e153-true-d12690900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12690888e2-true-d12690927e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5810"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12690888e2-true-d12690927e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12690888e2-true-d12690927e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e158-true-d12690958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="5809"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e158-true-d12690958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12687345e158-true-d12690958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12687345e162-true-d12690996e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="5808"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12687345e162-true-d12690996e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12687345e162-true-d12690996e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e16-true-d12692441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5807"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e16-true-d12692441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12691025e16-true-d12692441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e43-true-d12692494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5806"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e43-true-d12692494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12691025e43-true-d12692494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692471e9-true-d12692538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5805"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692471e9-true-d12692538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12692471e9-true-d12692538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692471e29-true-d12692587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5804"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692471e29-true-d12692587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12692471e29-true-d12692587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e47-true-d12692623e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5803"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e47-true-d12692623e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12691025e47-true-d12692623e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692611e2-true-d12692643e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5802"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692611e2-true-d12692643e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12692611e2-true-d12692643e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692611e8-true-d12692684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5801"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692611e8-true-d12692684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12692611e8-true-d12692684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e52-true-d12692777e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5800"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e52-true-d12692777e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12691025e52-true-d12692777e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692713e9-true-d12692837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5799"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692713e9-true-d12692837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12692713e9-true-d12692837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e56-true-d12692959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5798"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e56-true-d12692959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12691025e56-true-d12692959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692886e10-true-d12693051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5797"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692886e10-true-d12693051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12692886e10-true-d12693051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692886e30-true-d12693090e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5796"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692886e30-true-d12693090e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12692886e30-true-d12693090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692886e34-true-d12693129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5795"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692886e34-true-d12693129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12692886e34-true-d12693129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12692886e39-true-d12693190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5794"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12692886e39-true-d12693190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12692886e39-true-d12693190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693153e12-true-d12693258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5793"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693153e12-true-d12693258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12693153e12-true-d12693258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693153e35-true-d12693317e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5792"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693153e35-true-d12693317e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12693153e35-true-d12693317e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e60-true-d12693414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5791"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e60-true-d12693414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12691025e60-true-d12693414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693348e7-true-d12693489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5790"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693348e7-true-d12693489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12693348e7-true-d12693489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693419e9-true-d12693528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5789"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693419e9-true-d12693528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12693419e9-true-d12693528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693419e10-true-d12693576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5788"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693419e10-true-d12693576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12693419e10-true-d12693576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693539e12-true-d12693644e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5787"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693539e12-true-d12693644e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12693539e12-true-d12693644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693539e35-true-d12693703e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5786"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693539e35-true-d12693703e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12693539e35-true-d12693703e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693348e11-true-d12693780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5785"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693348e11-true-d12693780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12693348e11-true-d12693780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693734e16-true-d12693821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5784"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693734e16-true-d12693821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12693734e16-true-d12693821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e65-true-d12693893e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5783"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e65-true-d12693893e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12691025e65-true-d12693893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693832e15-true-d12693969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5782"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693832e15-true-d12693969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12693832e15-true-d12693969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693832e35-true-d12694024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5781"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693832e35-true-d12694024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12693832e35-true-d12694024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693832e39-true-d12694081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5780"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693832e39-true-d12694081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12693832e39-true-d12694081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12693832e42-true-d12694135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5779"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12693832e42-true-d12694135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12693832e42-true-d12694135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e92-true-d12694204e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5778"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e92-true-d12694204e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12691025e92-true-d12694204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694214e13-true-d12694238e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5777"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12694214e13-true-d12694238e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12694214e13-true-d12694238e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694259e13-true-d12694283e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5776"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12694259e13-true-d12694283e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12694259e13-true-d12694283e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694304e13-true-d12694328e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5775"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12694304e13-true-d12694328e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12694304e13-true-d12694328e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694349e13-true-d12694383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5774"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12694349e13-true-d12694383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12694349e13-true-d12694383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12691025e97-true-d12694427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5773"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12691025e97-true-d12694427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12691025e97-true-d12694427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694415e2-true-d12694454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5772"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12694415e2-true-d12694454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12694415e2-true-d12694454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e16-true-d12695898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="5771"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e16-true-d12695898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12694475e16-true-d12695898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e53-true-d12695957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5770"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e53-true-d12695957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12694475e53-true-d12695957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12695934e9-true-d12696001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5769"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12695934e9-true-d12696001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12695934e9-true-d12696001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12695934e29-true-d12696050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5768"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12695934e29-true-d12696050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12695934e29-true-d12696050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e58-true-d12696086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5767"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e58-true-d12696086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12694475e58-true-d12696086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696074e2-true-d12696106e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5766"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696074e2-true-d12696106e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12696074e2-true-d12696106e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696074e8-true-d12696147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5765"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696074e8-true-d12696147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12696074e8-true-d12696147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e62-true-d12696240e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5764"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e62-true-d12696240e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12694475e62-true-d12696240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696176e9-true-d12696300e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5763"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696176e9-true-d12696300e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12696176e9-true-d12696300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e66-true-d12696422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5762"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e66-true-d12696422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12694475e66-true-d12696422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696349e10-true-d12696514e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5761"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696349e10-true-d12696514e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12696349e10-true-d12696514e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696349e30-true-d12696553e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5760"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696349e30-true-d12696553e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12696349e30-true-d12696553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696349e34-true-d12696592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5759"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696349e34-true-d12696592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12696349e34-true-d12696592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696349e39-true-d12696653e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5758"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696349e39-true-d12696653e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12696349e39-true-d12696653e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696616e12-true-d12696721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5757"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696616e12-true-d12696721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12696616e12-true-d12696721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696616e35-true-d12696780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5756"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696616e35-true-d12696780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12696616e35-true-d12696780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e71-true-d12696877e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5755"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e71-true-d12696877e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12694475e71-true-d12696877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696811e7-true-d12696952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5754"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696811e7-true-d12696952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12696811e7-true-d12696952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696882e9-true-d12696991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5753"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696882e9-true-d12696991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12696882e9-true-d12696991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696882e10-true-d12697039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5752"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696882e10-true-d12697039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12696882e10-true-d12697039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697002e12-true-d12697107e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5751"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697002e12-true-d12697107e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12697002e12-true-d12697107e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697002e35-true-d12697166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5750"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697002e35-true-d12697166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12697002e35-true-d12697166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12696811e11-true-d12697243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5749"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12696811e11-true-d12697243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12696811e11-true-d12697243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697197e16-true-d12697284e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5748"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697197e16-true-d12697284e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12697197e16-true-d12697284e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e75-true-d12697356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5747"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e75-true-d12697356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12694475e75-true-d12697356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697295e15-true-d12697432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5746"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697295e15-true-d12697432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12697295e15-true-d12697432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697295e35-true-d12697487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5745"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697295e35-true-d12697487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12697295e35-true-d12697487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697295e39-true-d12697544e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5744"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697295e39-true-d12697544e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12697295e39-true-d12697544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697295e42-true-d12697598e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5743"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697295e42-true-d12697598e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12697295e42-true-d12697598e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e81-true-d12697658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5742"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e81-true-d12697658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12694475e81-true-d12697658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697668e13-true-d12697692e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5741"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12697668e13-true-d12697692e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12697668e13-true-d12697692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697713e13-true-d12697737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5740"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12697713e13-true-d12697737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12697713e13-true-d12697737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697758e13-true-d12697782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5739"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12697758e13-true-d12697782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12697758e13-true-d12697782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697803e13-true-d12697837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5738"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12697803e13-true-d12697837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12697803e13-true-d12697837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12694475e86-true-d12697881e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5737"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12694475e86-true-d12697881e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12694475e86-true-d12697881e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697869e2-true-d12697908e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5736"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12697869e2-true-d12697908e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12697869e2-true-d12697908e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e16-true-d12699409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5735"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e16-true-d12699409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12697938e16-true-d12699409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e87-true-d12699507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5734"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e87-true-d12699507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12697938e87-true-d12699507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699484e9-true-d12699551e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5733"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699484e9-true-d12699551e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12699484e9-true-d12699551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699484e29-true-d12699600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5732"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699484e29-true-d12699600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12699484e29-true-d12699600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e92-true-d12699636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5731"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e92-true-d12699636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12697938e92-true-d12699636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699624e2-true-d12699656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5730"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699624e2-true-d12699656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12699624e2-true-d12699656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699624e8-true-d12699697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5729"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699624e8-true-d12699697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12699624e8-true-d12699697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e96-true-d12699790e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5728"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e96-true-d12699790e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12697938e96-true-d12699790e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699726e9-true-d12699850e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5727"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699726e9-true-d12699850e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12699726e9-true-d12699850e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e100-true-d12699972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5726"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e100-true-d12699972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12697938e100-true-d12699972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699899e10-true-d12700064e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5725"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699899e10-true-d12700064e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12699899e10-true-d12700064e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699899e30-true-d12700103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5724"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699899e30-true-d12700103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12699899e30-true-d12700103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699899e34-true-d12700142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5723"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699899e34-true-d12700142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12699899e34-true-d12700142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12699899e39-true-d12700203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5722"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12699899e39-true-d12700203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12699899e39-true-d12700203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700166e12-true-d12700271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5721"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700166e12-true-d12700271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12700166e12-true-d12700271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700166e35-true-d12700330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5720"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700166e35-true-d12700330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12700166e35-true-d12700330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e105-true-d12700427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5719"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e105-true-d12700427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12697938e105-true-d12700427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700361e7-true-d12700502e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5718"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700361e7-true-d12700502e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12700361e7-true-d12700502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700432e9-true-d12700541e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5717"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700432e9-true-d12700541e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12700432e9-true-d12700541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700432e10-true-d12700589e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5716"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700432e10-true-d12700589e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12700432e10-true-d12700589e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700552e12-true-d12700657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5715"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700552e12-true-d12700657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12700552e12-true-d12700657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700552e35-true-d12700716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5714"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700552e35-true-d12700716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12700552e35-true-d12700716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700361e11-true-d12700793e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5713"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700361e11-true-d12700793e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12700361e11-true-d12700793e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700747e16-true-d12700834e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5712"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700747e16-true-d12700834e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12700747e16-true-d12700834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e109-true-d12700906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5711"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e109-true-d12700906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12697938e109-true-d12700906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700845e15-true-d12700982e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5710"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700845e15-true-d12700982e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12700845e15-true-d12700982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700845e35-true-d12701037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5709"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700845e35-true-d12701037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12700845e35-true-d12701037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700845e39-true-d12701094e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5708"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700845e39-true-d12701094e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12700845e39-true-d12701094e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12700845e42-true-d12701148e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5707"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12700845e42-true-d12701148e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12700845e42-true-d12701148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e137-true-d12701217e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5706"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e137-true-d12701217e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12697938e137-true-d12701217e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701227e13-true-d12701251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5705"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12701227e13-true-d12701251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12701227e13-true-d12701251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701272e13-true-d12701296e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5704"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12701272e13-true-d12701296e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12701272e13-true-d12701296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701317e13-true-d12701341e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5703"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12701317e13-true-d12701341e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12701317e13-true-d12701341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701362e13-true-d12701396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5702"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12701362e13-true-d12701396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12701362e13-true-d12701396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12697938e141-true-d12701440e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5701"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12697938e141-true-d12701440e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12697938e141-true-d12701440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701428e2-true-d12701467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5700"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12701428e2-true-d12701467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12701428e2-true-d12701467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e16-true-d12702904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5699"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e16-true-d12702904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12701488e16-true-d12702904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e43-true-d12702957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5698"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e43-true-d12702957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12701488e43-true-d12702957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12702934e9-true-d12703001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5697"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12702934e9-true-d12703001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12702934e9-true-d12703001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12702934e29-true-d12703050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5696"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12702934e29-true-d12703050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12702934e29-true-d12703050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e47-true-d12703086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5695"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e47-true-d12703086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12701488e47-true-d12703086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703074e2-true-d12703106e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5694"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703074e2-true-d12703106e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12703074e2-true-d12703106e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703074e8-true-d12703147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5693"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703074e8-true-d12703147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12703074e8-true-d12703147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e52-true-d12703240e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5692"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e52-true-d12703240e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12701488e52-true-d12703240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703176e9-true-d12703300e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5691"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703176e9-true-d12703300e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12703176e9-true-d12703300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e56-true-d12703422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5690"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e56-true-d12703422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12701488e56-true-d12703422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703349e10-true-d12703514e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5689"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703349e10-true-d12703514e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12703349e10-true-d12703514e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703349e30-true-d12703553e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5688"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703349e30-true-d12703553e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12703349e30-true-d12703553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703349e34-true-d12703592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5687"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703349e34-true-d12703592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12703349e34-true-d12703592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703349e39-true-d12703653e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5686"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703349e39-true-d12703653e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12703349e39-true-d12703653e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703616e12-true-d12703721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5685"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703616e12-true-d12703721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12703616e12-true-d12703721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703616e35-true-d12703780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5684"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703616e35-true-d12703780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12703616e35-true-d12703780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e60-true-d12703877e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5683"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e60-true-d12703877e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12701488e60-true-d12703877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703811e7-true-d12703952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5682"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703811e7-true-d12703952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12703811e7-true-d12703952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703882e9-true-d12703991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5681"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703882e9-true-d12703991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12703882e9-true-d12703991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703882e10-true-d12704039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5680"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703882e10-true-d12704039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12703882e10-true-d12704039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704002e12-true-d12704107e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5679"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704002e12-true-d12704107e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12704002e12-true-d12704107e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704002e35-true-d12704166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5678"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704002e35-true-d12704166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12704002e35-true-d12704166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12703811e11-true-d12704243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5677"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12703811e11-true-d12704243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12703811e11-true-d12704243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704197e16-true-d12704284e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5676"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704197e16-true-d12704284e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12704197e16-true-d12704284e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e65-true-d12704356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5675"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e65-true-d12704356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12701488e65-true-d12704356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704295e15-true-d12704432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5674"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704295e15-true-d12704432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12704295e15-true-d12704432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704295e35-true-d12704487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5673"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704295e35-true-d12704487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12704295e35-true-d12704487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704295e39-true-d12704544e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5672"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704295e39-true-d12704544e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12704295e39-true-d12704544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704295e42-true-d12704598e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5671"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704295e42-true-d12704598e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12704295e42-true-d12704598e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e92-true-d12704667e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5670"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e92-true-d12704667e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12701488e92-true-d12704667e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704677e13-true-d12704701e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5669"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12704677e13-true-d12704701e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12704677e13-true-d12704701e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704722e13-true-d12704746e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5668"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12704722e13-true-d12704746e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12704722e13-true-d12704746e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704767e13-true-d12704791e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5667"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12704767e13-true-d12704791e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12704767e13-true-d12704791e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704812e13-true-d12704846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5666"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12704812e13-true-d12704846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12704812e13-true-d12704846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12701488e97-true-d12704890e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5665"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12701488e97-true-d12704890e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12701488e97-true-d12704890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704878e2-true-d12704917e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5664"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12704878e2-true-d12704917e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12704878e2-true-d12704917e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e16-true-d12706477e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5663"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e16-true-d12706477e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12704938e16-true-d12706477e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e95-true-d12706593e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5662"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e95-true-d12706593e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12704938e95-true-d12706593e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706570e9-true-d12706637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5661"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12706570e9-true-d12706637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12706570e9-true-d12706637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706570e29-true-d12706686e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5660"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12706570e29-true-d12706686e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12706570e29-true-d12706686e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e99-true-d12706722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5659"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e99-true-d12706722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12704938e99-true-d12706722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706710e2-true-d12706742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5658"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12706710e2-true-d12706742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12706710e2-true-d12706742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706710e8-true-d12706783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5657"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12706710e8-true-d12706783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12706710e8-true-d12706783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e103-true-d12706860e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="5656"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e103-true-d12706860e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12704938e103-true-d12706860e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706812e5-true-d12706916e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="5655"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12706812e5-true-d12706916e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12706812e5-true-d12706916e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706926e13-true-d12706943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="5654"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12706926e13-true-d12706943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12706926e13-true-d12706943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706958e13-true-d12706986e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="5653"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12706958e13-true-d12706986e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12706958e13-true-d12706986e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12706812e24-true-d12707047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5652"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12706812e24-true-d12707047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12706812e24-true-d12707047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707010e12-true-d12707115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5651"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707010e12-true-d12707115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12707010e12-true-d12707115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707010e35-true-d12707174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5650"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707010e35-true-d12707174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12707010e35-true-d12707174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e111-true-d12707269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5649"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e111-true-d12707269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12704938e111-true-d12707269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707205e9-true-d12707329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5648"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707205e9-true-d12707329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12707205e9-true-d12707329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e115-true-d12707451e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5647"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e115-true-d12707451e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12704938e115-true-d12707451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707378e10-true-d12707543e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5646"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707378e10-true-d12707543e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12707378e10-true-d12707543e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707378e30-true-d12707582e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5645"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707378e30-true-d12707582e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12707378e30-true-d12707582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707378e34-true-d12707621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5644"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707378e34-true-d12707621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12707378e34-true-d12707621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707378e39-true-d12707682e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5643"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707378e39-true-d12707682e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12707378e39-true-d12707682e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707645e12-true-d12707750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5642"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707645e12-true-d12707750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12707645e12-true-d12707750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707645e35-true-d12707809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5641"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707645e35-true-d12707809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12707645e35-true-d12707809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e119-true-d12707906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5640"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e119-true-d12707906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12704938e119-true-d12707906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707840e7-true-d12707981e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5639"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707840e7-true-d12707981e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12707840e7-true-d12707981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707911e9-true-d12708020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5638"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707911e9-true-d12708020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12707911e9-true-d12708020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707911e10-true-d12708068e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5637"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707911e10-true-d12708068e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12707911e10-true-d12708068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708031e12-true-d12708136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5636"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708031e12-true-d12708136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12708031e12-true-d12708136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708031e35-true-d12708195e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5635"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708031e35-true-d12708195e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12708031e35-true-d12708195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12707840e11-true-d12708272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5634"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12707840e11-true-d12708272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12707840e11-true-d12708272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708226e16-true-d12708313e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5633"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708226e16-true-d12708313e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12708226e16-true-d12708313e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e124-true-d12708385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5632"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e124-true-d12708385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12704938e124-true-d12708385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708324e15-true-d12708461e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5631"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708324e15-true-d12708461e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12708324e15-true-d12708461e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708324e35-true-d12708516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5630"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708324e35-true-d12708516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12708324e35-true-d12708516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708324e39-true-d12708573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5629"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708324e39-true-d12708573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12708324e39-true-d12708573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708324e42-true-d12708627e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5628"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708324e42-true-d12708627e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12708324e42-true-d12708627e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e151-true-d12708696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5627"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e151-true-d12708696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12704938e151-true-d12708696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708706e13-true-d12708730e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5626"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12708706e13-true-d12708730e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12708706e13-true-d12708730e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708751e13-true-d12708775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5625"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12708751e13-true-d12708775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12708751e13-true-d12708775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708796e13-true-d12708820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5624"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12708796e13-true-d12708820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12708796e13-true-d12708820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708841e13-true-d12708875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5623"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12708841e13-true-d12708875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12708841e13-true-d12708875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12704938e156-true-d12708919e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5622"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12704938e156-true-d12708919e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12704938e156-true-d12708919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708907e2-true-d12708946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5621"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12708907e2-true-d12708946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12708907e2-true-d12708946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e16-true-d12710473e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5620"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e16-true-d12710473e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12708967e16-true-d12710473e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e71-true-d12710565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5619"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e71-true-d12710565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12708967e71-true-d12710565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710542e9-true-d12710609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5618"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710542e9-true-d12710609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12710542e9-true-d12710609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710542e29-true-d12710658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5617"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710542e29-true-d12710658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12710542e29-true-d12710658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e76-true-d12710694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5616"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e76-true-d12710694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12708967e76-true-d12710694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710682e2-true-d12710714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5615"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710682e2-true-d12710714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12710682e2-true-d12710714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710682e8-true-d12710755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5614"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710682e8-true-d12710755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12710682e8-true-d12710755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e80-true-d12710832e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="5613"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e80-true-d12710832e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12708967e80-true-d12710832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710784e5-true-d12710888e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="5612"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710784e5-true-d12710888e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12710784e5-true-d12710888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710898e13-true-d12710915e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="5611"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12710898e13-true-d12710915e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12710898e13-true-d12710915e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710930e13-true-d12710958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="5610"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12710930e13-true-d12710958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12710930e13-true-d12710958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710784e24-true-d12711019e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5609"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710784e24-true-d12711019e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12710784e24-true-d12711019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710982e12-true-d12711087e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5608"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710982e12-true-d12711087e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12710982e12-true-d12711087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12710982e35-true-d12711146e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5607"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12710982e35-true-d12711146e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12710982e35-true-d12711146e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e87-true-d12711241e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5606"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e87-true-d12711241e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12708967e87-true-d12711241e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711177e9-true-d12711301e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5605"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711177e9-true-d12711301e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12711177e9-true-d12711301e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e92-true-d12711423e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5604"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e92-true-d12711423e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12708967e92-true-d12711423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711350e10-true-d12711515e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5603"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711350e10-true-d12711515e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12711350e10-true-d12711515e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711350e30-true-d12711554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5602"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711350e30-true-d12711554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12711350e30-true-d12711554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711350e34-true-d12711593e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5601"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711350e34-true-d12711593e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12711350e34-true-d12711593e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711350e39-true-d12711654e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5600"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711350e39-true-d12711654e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12711350e39-true-d12711654e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711617e12-true-d12711722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5599"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711617e12-true-d12711722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12711617e12-true-d12711722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711617e35-true-d12711781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5598"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711617e35-true-d12711781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12711617e35-true-d12711781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e96-true-d12711878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5597"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e96-true-d12711878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12708967e96-true-d12711878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711812e7-true-d12711953e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5596"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711812e7-true-d12711953e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12711812e7-true-d12711953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711883e9-true-d12711992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5595"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711883e9-true-d12711992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12711883e9-true-d12711992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711883e10-true-d12712040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5594"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711883e10-true-d12712040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12711883e10-true-d12712040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712003e12-true-d12712108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5593"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712003e12-true-d12712108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12712003e12-true-d12712108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712003e35-true-d12712167e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5592"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712003e35-true-d12712167e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12712003e35-true-d12712167e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12711812e11-true-d12712244e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5591"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12711812e11-true-d12712244e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12711812e11-true-d12712244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712198e16-true-d12712285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5590"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712198e16-true-d12712285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12712198e16-true-d12712285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e100-true-d12712357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5589"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e100-true-d12712357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12708967e100-true-d12712357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712296e15-true-d12712433e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5588"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712296e15-true-d12712433e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12712296e15-true-d12712433e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712296e35-true-d12712488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5587"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712296e35-true-d12712488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12712296e35-true-d12712488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712296e39-true-d12712545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5586"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712296e39-true-d12712545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12712296e39-true-d12712545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712296e42-true-d12712599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5585"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712296e42-true-d12712599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12712296e42-true-d12712599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e128-true-d12712668e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5584"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e128-true-d12712668e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12708967e128-true-d12712668e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712678e13-true-d12712702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5583"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12712678e13-true-d12712702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12712678e13-true-d12712702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712723e13-true-d12712747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5582"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12712723e13-true-d12712747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12712723e13-true-d12712747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712768e13-true-d12712792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5581"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12712768e13-true-d12712792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12712768e13-true-d12712792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712813e13-true-d12712847e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5580"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12712813e13-true-d12712847e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12712813e13-true-d12712847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12708967e132-true-d12712891e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5579"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12708967e132-true-d12712891e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12708967e132-true-d12712891e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712879e2-true-d12712918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5578"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12712879e2-true-d12712918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12712879e2-true-d12712918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e137-true-d12712976e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5577"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e137-true-d12712976e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12672004e137-true-d12712976e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12712986e13-true-d12713010e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5576"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12712986e13-true-d12713010e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12712986e13-true-d12713010e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713031e13-true-d12713055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5575"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12713031e13-true-d12713055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12713031e13-true-d12713055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713076e13-true-d12713100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5574"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12713076e13-true-d12713100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12713076e13-true-d12713100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713121e13-true-d12713155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5573"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12713121e13-true-d12713155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12713121e13-true-d12713155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12672004e141-true-d12713199e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5572"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12672004e141-true-d12713199e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12672004e141-true-d12713199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713187e2-true-d12713226e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5571"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12713187e2-true-d12713226e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12713187e2-true-d12713226e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e16-true-d12714663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5570"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e16-true-d12714663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12713247e16-true-d12714663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e43-true-d12714716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5569"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e43-true-d12714716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12713247e43-true-d12714716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12714693e9-true-d12714760e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5568"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12714693e9-true-d12714760e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12714693e9-true-d12714760e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12714693e29-true-d12714809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5567"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12714693e29-true-d12714809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12714693e29-true-d12714809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e47-true-d12714845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5566"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e47-true-d12714845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12713247e47-true-d12714845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12714833e2-true-d12714865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5565"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12714833e2-true-d12714865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12714833e2-true-d12714865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12714833e8-true-d12714906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5564"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12714833e8-true-d12714906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12714833e8-true-d12714906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e52-true-d12714999e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5563"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e52-true-d12714999e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12713247e52-true-d12714999e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12714935e9-true-d12715059e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5562"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12714935e9-true-d12715059e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12714935e9-true-d12715059e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e56-true-d12715181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5561"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e56-true-d12715181e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12713247e56-true-d12715181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715108e10-true-d12715273e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5560"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715108e10-true-d12715273e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12715108e10-true-d12715273e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715108e30-true-d12715312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5559"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715108e30-true-d12715312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12715108e30-true-d12715312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715108e34-true-d12715351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5558"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715108e34-true-d12715351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12715108e34-true-d12715351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715108e39-true-d12715412e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5557"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715108e39-true-d12715412e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12715108e39-true-d12715412e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715375e12-true-d12715480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5556"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715375e12-true-d12715480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12715375e12-true-d12715480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715375e35-true-d12715539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5555"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715375e35-true-d12715539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12715375e35-true-d12715539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e60-true-d12715636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5554"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e60-true-d12715636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12713247e60-true-d12715636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715570e7-true-d12715711e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5553"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715570e7-true-d12715711e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12715570e7-true-d12715711e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715641e9-true-d12715750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5552"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715641e9-true-d12715750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12715641e9-true-d12715750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715641e10-true-d12715798e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5551"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715641e10-true-d12715798e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12715641e10-true-d12715798e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715761e12-true-d12715866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5550"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715761e12-true-d12715866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12715761e12-true-d12715866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715761e35-true-d12715925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5549"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715761e35-true-d12715925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12715761e35-true-d12715925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715570e11-true-d12716002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5548"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715570e11-true-d12716002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12715570e11-true-d12716002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12715956e16-true-d12716043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5547"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12715956e16-true-d12716043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12715956e16-true-d12716043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e65-true-d12716115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5546"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e65-true-d12716115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12713247e65-true-d12716115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12716054e15-true-d12716191e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5545"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12716054e15-true-d12716191e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12716054e15-true-d12716191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12716054e35-true-d12716246e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5544"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12716054e35-true-d12716246e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12716054e35-true-d12716246e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12716054e39-true-d12716303e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5543"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12716054e39-true-d12716303e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12716054e39-true-d12716303e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12716054e42-true-d12716357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5542"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12716054e42-true-d12716357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12716054e42-true-d12716357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e69-true-d12721464e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="5541"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e69-true-d12721464e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12713247e69-true-d12721464e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e16-true-d12722929e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5540"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e16-true-d12722929e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12721479e16-true-d12722929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e77-true-d12723009e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5539"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e77-true-d12723009e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12721479e77-true-d12723009e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12722986e9-true-d12723053e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5538"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12722986e9-true-d12723053e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12722986e9-true-d12723053e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12722986e29-true-d12723102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5537"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12722986e29-true-d12723102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12722986e29-true-d12723102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e81-true-d12723138e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5536"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e81-true-d12723138e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12721479e81-true-d12723138e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723126e2-true-d12723158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5535"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723126e2-true-d12723158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12723126e2-true-d12723158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723126e8-true-d12723199e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5534"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723126e8-true-d12723199e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12723126e8-true-d12723199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e85-true-d12723292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5533"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e85-true-d12723292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12721479e85-true-d12723292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723228e9-true-d12723352e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5532"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723228e9-true-d12723352e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12723228e9-true-d12723352e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e90-true-d12723474e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5531"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e90-true-d12723474e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12721479e90-true-d12723474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723401e10-true-d12723566e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5530"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723401e10-true-d12723566e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12723401e10-true-d12723566e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723401e30-true-d12723605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5529"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723401e30-true-d12723605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12723401e30-true-d12723605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723401e34-true-d12723644e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5528"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723401e34-true-d12723644e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12723401e34-true-d12723644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723401e39-true-d12723705e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5527"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723401e39-true-d12723705e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12723401e39-true-d12723705e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723668e12-true-d12723773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5526"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723668e12-true-d12723773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12723668e12-true-d12723773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723668e35-true-d12723832e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5525"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723668e35-true-d12723832e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12723668e35-true-d12723832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e94-true-d12723929e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5524"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e94-true-d12723929e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12721479e94-true-d12723929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723863e7-true-d12724004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5523"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723863e7-true-d12724004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12723863e7-true-d12724004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723934e9-true-d12724043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5522"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723934e9-true-d12724043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12723934e9-true-d12724043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723934e10-true-d12724091e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5521"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723934e10-true-d12724091e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12723934e10-true-d12724091e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724054e12-true-d12724159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5520"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724054e12-true-d12724159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12724054e12-true-d12724159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724054e35-true-d12724218e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5519"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724054e35-true-d12724218e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12724054e35-true-d12724218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12723863e11-true-d12724295e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5518"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12723863e11-true-d12724295e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12723863e11-true-d12724295e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724249e16-true-d12724336e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5517"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724249e16-true-d12724336e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12724249e16-true-d12724336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e98-true-d12724408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5516"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e98-true-d12724408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12721479e98-true-d12724408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724347e15-true-d12724484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5515"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724347e15-true-d12724484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12724347e15-true-d12724484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724347e35-true-d12724539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5514"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724347e35-true-d12724539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12724347e35-true-d12724539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724347e39-true-d12724596e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5513"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724347e39-true-d12724596e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12724347e39-true-d12724596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724347e42-true-d12724650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5512"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724347e42-true-d12724650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12724347e42-true-d12724650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e126-true-d12724719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5511"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e126-true-d12724719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12721479e126-true-d12724719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724729e13-true-d12724753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5510"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12724729e13-true-d12724753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12724729e13-true-d12724753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724774e13-true-d12724798e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5509"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12724774e13-true-d12724798e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12724774e13-true-d12724798e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724819e13-true-d12724843e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5508"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12724819e13-true-d12724843e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12724819e13-true-d12724843e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724864e13-true-d12724898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5507"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12724864e13-true-d12724898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12724864e13-true-d12724898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12721479e130-true-d12724942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5506"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12721479e130-true-d12724942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12721479e130-true-d12724942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724930e2-true-d12724969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5505"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12724930e2-true-d12724969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12724930e2-true-d12724969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e16-true-d12726433e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5504"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e16-true-d12726433e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12724990e16-true-d12726433e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e65-true-d12726507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5503"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e65-true-d12726507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12724990e65-true-d12726507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726484e9-true-d12726551e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5502"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726484e9-true-d12726551e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12726484e9-true-d12726551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726484e29-true-d12726600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5501"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726484e29-true-d12726600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12726484e29-true-d12726600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e69-true-d12726636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5500"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e69-true-d12726636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12724990e69-true-d12726636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726624e2-true-d12726656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5499"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726624e2-true-d12726656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12726624e2-true-d12726656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726624e8-true-d12726697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5498"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726624e8-true-d12726697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12726624e8-true-d12726697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e73-true-d12726790e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5497"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e73-true-d12726790e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12724990e73-true-d12726790e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726726e9-true-d12726850e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5496"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726726e9-true-d12726850e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12726726e9-true-d12726850e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e78-true-d12726972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5495"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e78-true-d12726972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12724990e78-true-d12726972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726899e10-true-d12727064e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5494"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726899e10-true-d12727064e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12726899e10-true-d12727064e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726899e30-true-d12727103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5493"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726899e30-true-d12727103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12726899e30-true-d12727103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726899e34-true-d12727142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5492"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726899e34-true-d12727142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12726899e34-true-d12727142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12726899e39-true-d12727203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5491"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12726899e39-true-d12727203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12726899e39-true-d12727203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727166e12-true-d12727271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5490"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727166e12-true-d12727271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12727166e12-true-d12727271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727166e35-true-d12727330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5489"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727166e35-true-d12727330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12727166e35-true-d12727330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e82-true-d12727427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5488"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e82-true-d12727427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12724990e82-true-d12727427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727361e7-true-d12727502e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5487"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727361e7-true-d12727502e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12727361e7-true-d12727502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727432e9-true-d12727541e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5486"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727432e9-true-d12727541e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12727432e9-true-d12727541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727432e10-true-d12727589e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5485"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727432e10-true-d12727589e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12727432e10-true-d12727589e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727552e12-true-d12727657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5484"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727552e12-true-d12727657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12727552e12-true-d12727657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727552e35-true-d12727716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5483"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727552e35-true-d12727716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12727552e35-true-d12727716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727361e11-true-d12727793e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5482"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727361e11-true-d12727793e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12727361e11-true-d12727793e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727747e16-true-d12727834e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5481"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727747e16-true-d12727834e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12727747e16-true-d12727834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e86-true-d12727906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5480"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e86-true-d12727906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12724990e86-true-d12727906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727845e15-true-d12727982e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5479"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727845e15-true-d12727982e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12727845e15-true-d12727982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727845e35-true-d12728037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5478"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727845e35-true-d12728037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12727845e35-true-d12728037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727845e39-true-d12728094e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5477"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727845e39-true-d12728094e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12727845e39-true-d12728094e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12727845e42-true-d12728148e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5476"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12727845e42-true-d12728148e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12727845e42-true-d12728148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e114-true-d12728217e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5475"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e114-true-d12728217e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12724990e114-true-d12728217e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728227e13-true-d12728251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5474"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12728227e13-true-d12728251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12728227e13-true-d12728251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728272e13-true-d12728296e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5473"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12728272e13-true-d12728296e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12728272e13-true-d12728296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728317e13-true-d12728341e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5472"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12728317e13-true-d12728341e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12728317e13-true-d12728341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728362e13-true-d12728396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5471"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12728362e13-true-d12728396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12728362e13-true-d12728396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12724990e118-true-d12728440e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5470"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12724990e118-true-d12728440e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12724990e118-true-d12728440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728428e2-true-d12728467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5469"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12728428e2-true-d12728467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12728428e2-true-d12728467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e16-true-d12729991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="5468"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e16-true-d12729991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12728488e16-true-d12729991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e100-true-d12730110e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5467"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e100-true-d12730110e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12728488e100-true-d12730110e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730087e9-true-d12730154e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5466"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730087e9-true-d12730154e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12730087e9-true-d12730154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730087e29-true-d12730203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5465"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730087e29-true-d12730203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12730087e29-true-d12730203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e104-true-d12730239e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5464"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e104-true-d12730239e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12728488e104-true-d12730239e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730227e2-true-d12730259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5463"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730227e2-true-d12730259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12730227e2-true-d12730259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730227e8-true-d12730300e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5462"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730227e8-true-d12730300e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12730227e8-true-d12730300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e108-true-d12730393e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5461"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e108-true-d12730393e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12728488e108-true-d12730393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730329e9-true-d12730453e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5460"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730329e9-true-d12730453e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12730329e9-true-d12730453e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e113-true-d12730575e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5459"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e113-true-d12730575e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12728488e113-true-d12730575e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730502e10-true-d12730667e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5458"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730502e10-true-d12730667e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12730502e10-true-d12730667e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730502e30-true-d12730706e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5457"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730502e30-true-d12730706e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12730502e30-true-d12730706e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730502e34-true-d12730745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5456"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730502e34-true-d12730745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12730502e34-true-d12730745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730502e39-true-d12730806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5455"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730502e39-true-d12730806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12730502e39-true-d12730806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730769e12-true-d12730874e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5454"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730769e12-true-d12730874e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12730769e12-true-d12730874e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730769e35-true-d12730933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5453"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730769e35-true-d12730933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12730769e35-true-d12730933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e117-true-d12731030e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5452"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e117-true-d12731030e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12728488e117-true-d12731030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730964e7-true-d12731105e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5451"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730964e7-true-d12731105e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12730964e7-true-d12731105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731035e9-true-d12731144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5450"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731035e9-true-d12731144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12731035e9-true-d12731144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731035e10-true-d12731192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5449"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731035e10-true-d12731192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12731035e10-true-d12731192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731155e12-true-d12731260e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5448"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731155e12-true-d12731260e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12731155e12-true-d12731260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731155e35-true-d12731319e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5447"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731155e35-true-d12731319e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12731155e35-true-d12731319e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12730964e11-true-d12731396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5446"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12730964e11-true-d12731396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12730964e11-true-d12731396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731350e16-true-d12731437e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5445"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731350e16-true-d12731437e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12731350e16-true-d12731437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e121-true-d12731509e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5444"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e121-true-d12731509e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12728488e121-true-d12731509e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731448e15-true-d12731585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5443"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731448e15-true-d12731585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12731448e15-true-d12731585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731448e35-true-d12731640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5442"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731448e35-true-d12731640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12731448e35-true-d12731640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731448e39-true-d12731697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5441"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731448e39-true-d12731697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12731448e39-true-d12731697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731448e42-true-d12731751e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5440"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12731448e42-true-d12731751e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12731448e42-true-d12731751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e149-true-d12731820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5439"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e149-true-d12731820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12728488e149-true-d12731820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731830e13-true-d12731854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5438"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12731830e13-true-d12731854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12731830e13-true-d12731854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731875e13-true-d12731899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5437"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12731875e13-true-d12731899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12731875e13-true-d12731899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731920e13-true-d12731944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5436"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12731920e13-true-d12731944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12731920e13-true-d12731944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12731965e13-true-d12731999e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5435"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12731965e13-true-d12731999e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12731965e13-true-d12731999e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e153-true-d12732043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5434"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e153-true-d12732043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12728488e153-true-d12732043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732031e2-true-d12732070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5433"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12732031e2-true-d12732070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12732031e2-true-d12732070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e158-true-d12732101e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="5432"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e158-true-d12732101e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12728488e158-true-d12732101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12728488e162-true-d12732139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="5431"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12728488e162-true-d12732139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12728488e162-true-d12732139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e16-true-d12733584e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5430"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e16-true-d12733584e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12732168e16-true-d12733584e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e43-true-d12733637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5429"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e43-true-d12733637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12732168e43-true-d12733637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12733614e9-true-d12733681e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5428"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12733614e9-true-d12733681e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12733614e9-true-d12733681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12733614e29-true-d12733730e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5427"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12733614e29-true-d12733730e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12733614e29-true-d12733730e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e47-true-d12733766e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5426"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e47-true-d12733766e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12732168e47-true-d12733766e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12733754e2-true-d12733786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5425"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12733754e2-true-d12733786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12733754e2-true-d12733786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12733754e8-true-d12733827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5424"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12733754e8-true-d12733827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12733754e8-true-d12733827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e52-true-d12733920e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5423"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e52-true-d12733920e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12732168e52-true-d12733920e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12733856e9-true-d12733980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5422"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12733856e9-true-d12733980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12733856e9-true-d12733980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e56-true-d12734102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5421"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e56-true-d12734102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12732168e56-true-d12734102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734029e10-true-d12734194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5420"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734029e10-true-d12734194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12734029e10-true-d12734194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734029e30-true-d12734233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5419"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734029e30-true-d12734233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12734029e30-true-d12734233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734029e34-true-d12734272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5418"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734029e34-true-d12734272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12734029e34-true-d12734272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734029e39-true-d12734333e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5417"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734029e39-true-d12734333e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12734029e39-true-d12734333e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734296e12-true-d12734401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5416"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734296e12-true-d12734401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12734296e12-true-d12734401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734296e35-true-d12734460e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5415"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734296e35-true-d12734460e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12734296e35-true-d12734460e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e60-true-d12734557e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5414"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e60-true-d12734557e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12732168e60-true-d12734557e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734491e7-true-d12734632e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5413"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734491e7-true-d12734632e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12734491e7-true-d12734632e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734562e9-true-d12734671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5412"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734562e9-true-d12734671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12734562e9-true-d12734671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734562e10-true-d12734719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5411"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734562e10-true-d12734719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12734562e10-true-d12734719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734682e12-true-d12734787e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5410"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734682e12-true-d12734787e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12734682e12-true-d12734787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734682e35-true-d12734846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5409"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734682e35-true-d12734846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12734682e35-true-d12734846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734491e11-true-d12734923e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5408"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734491e11-true-d12734923e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12734491e11-true-d12734923e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734877e16-true-d12734964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5407"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734877e16-true-d12734964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12734877e16-true-d12734964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e65-true-d12735036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5406"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e65-true-d12735036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12732168e65-true-d12735036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734975e15-true-d12735112e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5405"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734975e15-true-d12735112e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12734975e15-true-d12735112e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734975e35-true-d12735167e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5404"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734975e35-true-d12735167e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12734975e35-true-d12735167e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734975e39-true-d12735224e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5403"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734975e39-true-d12735224e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12734975e39-true-d12735224e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12734975e42-true-d12735278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5402"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12734975e42-true-d12735278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12734975e42-true-d12735278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e92-true-d12735347e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5401"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e92-true-d12735347e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12732168e92-true-d12735347e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735357e13-true-d12735381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5400"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12735357e13-true-d12735381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12735357e13-true-d12735381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735402e13-true-d12735426e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5399"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12735402e13-true-d12735426e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12735402e13-true-d12735426e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735447e13-true-d12735471e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5398"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12735447e13-true-d12735471e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12735447e13-true-d12735471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735492e13-true-d12735526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5397"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12735492e13-true-d12735526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12735492e13-true-d12735526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12732168e97-true-d12735570e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5396"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12732168e97-true-d12735570e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12732168e97-true-d12735570e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735558e2-true-d12735597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5395"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12735558e2-true-d12735597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12735558e2-true-d12735597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e16-true-d12737041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="5394"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e16-true-d12737041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12735618e16-true-d12737041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e53-true-d12737100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5393"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e53-true-d12737100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12735618e53-true-d12737100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737077e9-true-d12737144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5392"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737077e9-true-d12737144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12737077e9-true-d12737144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737077e29-true-d12737193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5391"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737077e29-true-d12737193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12737077e29-true-d12737193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e58-true-d12737229e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5390"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e58-true-d12737229e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12735618e58-true-d12737229e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737217e2-true-d12737249e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5389"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737217e2-true-d12737249e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12737217e2-true-d12737249e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737217e8-true-d12737290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5388"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737217e8-true-d12737290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12737217e8-true-d12737290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e62-true-d12737383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5387"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e62-true-d12737383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12735618e62-true-d12737383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737319e9-true-d12737443e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5386"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737319e9-true-d12737443e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12737319e9-true-d12737443e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e66-true-d12737565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5385"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e66-true-d12737565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12735618e66-true-d12737565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737492e10-true-d12737657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5384"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737492e10-true-d12737657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12737492e10-true-d12737657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737492e30-true-d12737696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5383"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737492e30-true-d12737696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12737492e30-true-d12737696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737492e34-true-d12737735e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5382"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737492e34-true-d12737735e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12737492e34-true-d12737735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737492e39-true-d12737796e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5381"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737492e39-true-d12737796e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12737492e39-true-d12737796e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737759e12-true-d12737864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5380"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737759e12-true-d12737864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12737759e12-true-d12737864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737759e35-true-d12737923e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5379"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737759e35-true-d12737923e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12737759e35-true-d12737923e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e71-true-d12738020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5378"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e71-true-d12738020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12735618e71-true-d12738020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737954e7-true-d12738095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5377"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737954e7-true-d12738095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12737954e7-true-d12738095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738025e9-true-d12738134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5376"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738025e9-true-d12738134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12738025e9-true-d12738134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738025e10-true-d12738182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5375"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738025e10-true-d12738182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12738025e10-true-d12738182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738145e12-true-d12738250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5374"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738145e12-true-d12738250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12738145e12-true-d12738250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738145e35-true-d12738309e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5373"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738145e35-true-d12738309e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12738145e35-true-d12738309e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12737954e11-true-d12738386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5372"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12737954e11-true-d12738386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12737954e11-true-d12738386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738340e16-true-d12738427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5371"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738340e16-true-d12738427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12738340e16-true-d12738427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e75-true-d12738499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5370"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e75-true-d12738499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12735618e75-true-d12738499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738438e15-true-d12738575e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5369"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738438e15-true-d12738575e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12738438e15-true-d12738575e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738438e35-true-d12738630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5368"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738438e35-true-d12738630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12738438e35-true-d12738630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738438e39-true-d12738687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5367"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738438e39-true-d12738687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12738438e39-true-d12738687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738438e42-true-d12738741e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5366"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12738438e42-true-d12738741e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12738438e42-true-d12738741e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e81-true-d12738801e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5365"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e81-true-d12738801e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12735618e81-true-d12738801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738811e13-true-d12738835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5364"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12738811e13-true-d12738835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12738811e13-true-d12738835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738856e13-true-d12738880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5363"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12738856e13-true-d12738880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12738856e13-true-d12738880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738901e13-true-d12738925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5362"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12738901e13-true-d12738925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12738901e13-true-d12738925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12738946e13-true-d12738980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5361"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12738946e13-true-d12738980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12738946e13-true-d12738980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12735618e86-true-d12739024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5360"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12735618e86-true-d12739024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12735618e86-true-d12739024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739012e2-true-d12739051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5359"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12739012e2-true-d12739051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12739012e2-true-d12739051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e16-true-d12740552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5358"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e16-true-d12740552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12739081e16-true-d12740552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e87-true-d12740650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5357"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e87-true-d12740650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12739081e87-true-d12740650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12740627e9-true-d12740694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5356"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12740627e9-true-d12740694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12740627e9-true-d12740694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12740627e29-true-d12740743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5355"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12740627e29-true-d12740743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12740627e29-true-d12740743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e92-true-d12740779e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5354"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e92-true-d12740779e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12739081e92-true-d12740779e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12740767e2-true-d12740799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5353"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12740767e2-true-d12740799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12740767e2-true-d12740799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12740767e8-true-d12740840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5352"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12740767e8-true-d12740840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12740767e8-true-d12740840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e96-true-d12740933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5351"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e96-true-d12740933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12739081e96-true-d12740933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12740869e9-true-d12740993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5350"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12740869e9-true-d12740993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12740869e9-true-d12740993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e100-true-d12741115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5349"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e100-true-d12741115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12739081e100-true-d12741115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741042e10-true-d12741207e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5348"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741042e10-true-d12741207e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12741042e10-true-d12741207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741042e30-true-d12741246e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5347"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741042e30-true-d12741246e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12741042e30-true-d12741246e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741042e34-true-d12741285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5346"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741042e34-true-d12741285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12741042e34-true-d12741285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741042e39-true-d12741346e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5345"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741042e39-true-d12741346e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12741042e39-true-d12741346e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741309e12-true-d12741414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5344"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741309e12-true-d12741414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12741309e12-true-d12741414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741309e35-true-d12741473e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5343"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741309e35-true-d12741473e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12741309e35-true-d12741473e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e105-true-d12741570e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5342"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e105-true-d12741570e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12739081e105-true-d12741570e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741504e7-true-d12741645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5341"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741504e7-true-d12741645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12741504e7-true-d12741645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741575e9-true-d12741684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5340"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741575e9-true-d12741684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12741575e9-true-d12741684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741575e10-true-d12741732e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5339"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741575e10-true-d12741732e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12741575e10-true-d12741732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741695e12-true-d12741800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5338"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741695e12-true-d12741800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12741695e12-true-d12741800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741695e35-true-d12741859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5337"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741695e35-true-d12741859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12741695e35-true-d12741859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741504e11-true-d12741936e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5336"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741504e11-true-d12741936e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12741504e11-true-d12741936e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741890e16-true-d12741977e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5335"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741890e16-true-d12741977e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12741890e16-true-d12741977e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e109-true-d12742049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5334"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e109-true-d12742049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12739081e109-true-d12742049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741988e15-true-d12742125e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5333"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741988e15-true-d12742125e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12741988e15-true-d12742125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741988e35-true-d12742180e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5332"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741988e35-true-d12742180e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12741988e35-true-d12742180e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741988e39-true-d12742237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5331"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741988e39-true-d12742237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12741988e39-true-d12742237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12741988e42-true-d12742291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5330"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12741988e42-true-d12742291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12741988e42-true-d12742291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e137-true-d12742360e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5329"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e137-true-d12742360e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12739081e137-true-d12742360e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742370e13-true-d12742394e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5328"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12742370e13-true-d12742394e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12742370e13-true-d12742394e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742415e13-true-d12742439e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5327"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12742415e13-true-d12742439e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12742415e13-true-d12742439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742460e13-true-d12742484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5326"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12742460e13-true-d12742484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12742460e13-true-d12742484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742505e13-true-d12742539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5325"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12742505e13-true-d12742539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12742505e13-true-d12742539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12739081e141-true-d12742583e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5324"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12739081e141-true-d12742583e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12739081e141-true-d12742583e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742571e2-true-d12742610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5323"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12742571e2-true-d12742610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12742571e2-true-d12742610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e16-true-d12744047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5322"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e16-true-d12744047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12742631e16-true-d12744047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e43-true-d12744100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5321"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e43-true-d12744100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12742631e43-true-d12744100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744077e9-true-d12744144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5320"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744077e9-true-d12744144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12744077e9-true-d12744144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744077e29-true-d12744193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5319"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744077e29-true-d12744193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12744077e29-true-d12744193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e47-true-d12744229e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5318"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e47-true-d12744229e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12742631e47-true-d12744229e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744217e2-true-d12744249e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5317"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744217e2-true-d12744249e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12744217e2-true-d12744249e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744217e8-true-d12744290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5316"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744217e8-true-d12744290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12744217e8-true-d12744290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e52-true-d12744383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5315"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e52-true-d12744383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12742631e52-true-d12744383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744319e9-true-d12744443e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5314"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744319e9-true-d12744443e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12744319e9-true-d12744443e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e56-true-d12744565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5313"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e56-true-d12744565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12742631e56-true-d12744565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744492e10-true-d12744657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5312"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744492e10-true-d12744657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12744492e10-true-d12744657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744492e30-true-d12744696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5311"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744492e30-true-d12744696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12744492e30-true-d12744696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744492e34-true-d12744735e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5310"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744492e34-true-d12744735e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12744492e34-true-d12744735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744492e39-true-d12744796e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5309"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744492e39-true-d12744796e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12744492e39-true-d12744796e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744759e12-true-d12744864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5308"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744759e12-true-d12744864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12744759e12-true-d12744864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744759e35-true-d12744923e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5307"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744759e35-true-d12744923e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12744759e35-true-d12744923e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e60-true-d12745020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5306"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e60-true-d12745020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12742631e60-true-d12745020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744954e7-true-d12745095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5305"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744954e7-true-d12745095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12744954e7-true-d12745095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745025e9-true-d12745134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5304"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745025e9-true-d12745134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12745025e9-true-d12745134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745025e10-true-d12745182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5303"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745025e10-true-d12745182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12745025e10-true-d12745182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745145e12-true-d12745250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5302"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745145e12-true-d12745250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12745145e12-true-d12745250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745145e35-true-d12745309e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5301"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745145e35-true-d12745309e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12745145e35-true-d12745309e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12744954e11-true-d12745386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5300"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12744954e11-true-d12745386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12744954e11-true-d12745386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745340e16-true-d12745427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5299"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745340e16-true-d12745427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12745340e16-true-d12745427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e65-true-d12745499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5298"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e65-true-d12745499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12742631e65-true-d12745499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745438e15-true-d12745575e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5297"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745438e15-true-d12745575e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12745438e15-true-d12745575e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745438e35-true-d12745630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5296"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745438e35-true-d12745630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12745438e35-true-d12745630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745438e39-true-d12745687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5295"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745438e39-true-d12745687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12745438e39-true-d12745687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745438e42-true-d12745741e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5294"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12745438e42-true-d12745741e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12745438e42-true-d12745741e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e92-true-d12745810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5293"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e92-true-d12745810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12742631e92-true-d12745810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745820e13-true-d12745844e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5292"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12745820e13-true-d12745844e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12745820e13-true-d12745844e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745865e13-true-d12745889e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5291"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12745865e13-true-d12745889e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12745865e13-true-d12745889e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745910e13-true-d12745934e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5290"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12745910e13-true-d12745934e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12745910e13-true-d12745934e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12745955e13-true-d12745989e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5289"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12745955e13-true-d12745989e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12745955e13-true-d12745989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12742631e97-true-d12746033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5288"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12742631e97-true-d12746033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12742631e97-true-d12746033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746021e2-true-d12746060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5287"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12746021e2-true-d12746060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12746021e2-true-d12746060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e16-true-d12747620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5286"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e16-true-d12747620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12746081e16-true-d12747620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e95-true-d12747736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5285"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e95-true-d12747736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12746081e95-true-d12747736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12747713e9-true-d12747780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5284"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12747713e9-true-d12747780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12747713e9-true-d12747780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12747713e29-true-d12747829e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5283"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12747713e29-true-d12747829e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12747713e29-true-d12747829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e99-true-d12747865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5282"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e99-true-d12747865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12746081e99-true-d12747865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12747853e2-true-d12747885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5281"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12747853e2-true-d12747885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12747853e2-true-d12747885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12747853e8-true-d12747926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5280"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12747853e8-true-d12747926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12747853e8-true-d12747926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e103-true-d12748003e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="5279"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e103-true-d12748003e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12746081e103-true-d12748003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12747955e5-true-d12748059e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="5278"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12747955e5-true-d12748059e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12747955e5-true-d12748059e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748069e13-true-d12748086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="5277"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12748069e13-true-d12748086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12748069e13-true-d12748086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748101e13-true-d12748129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="5276"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12748101e13-true-d12748129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12748101e13-true-d12748129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12747955e24-true-d12748190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5275"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12747955e24-true-d12748190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12747955e24-true-d12748190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748153e12-true-d12748258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5274"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748153e12-true-d12748258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12748153e12-true-d12748258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748153e35-true-d12748317e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5273"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748153e35-true-d12748317e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12748153e35-true-d12748317e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e111-true-d12748412e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5272"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e111-true-d12748412e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12746081e111-true-d12748412e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748348e9-true-d12748472e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5271"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748348e9-true-d12748472e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12748348e9-true-d12748472e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e115-true-d12748594e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5270"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e115-true-d12748594e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12746081e115-true-d12748594e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748521e10-true-d12748686e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5269"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748521e10-true-d12748686e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12748521e10-true-d12748686e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748521e30-true-d12748725e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5268"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748521e30-true-d12748725e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12748521e30-true-d12748725e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748521e34-true-d12748764e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5267"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748521e34-true-d12748764e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12748521e34-true-d12748764e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748521e39-true-d12748825e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5266"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748521e39-true-d12748825e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12748521e39-true-d12748825e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748788e12-true-d12748893e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5265"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748788e12-true-d12748893e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12748788e12-true-d12748893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748788e35-true-d12748952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5264"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748788e35-true-d12748952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12748788e35-true-d12748952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e119-true-d12749049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5263"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e119-true-d12749049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12746081e119-true-d12749049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748983e7-true-d12749124e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5262"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748983e7-true-d12749124e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12748983e7-true-d12749124e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749054e9-true-d12749163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5261"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749054e9-true-d12749163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12749054e9-true-d12749163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749054e10-true-d12749211e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5260"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749054e10-true-d12749211e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12749054e10-true-d12749211e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749174e12-true-d12749279e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5259"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749174e12-true-d12749279e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12749174e12-true-d12749279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749174e35-true-d12749338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5258"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749174e35-true-d12749338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12749174e35-true-d12749338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12748983e11-true-d12749415e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5257"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12748983e11-true-d12749415e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12748983e11-true-d12749415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749369e16-true-d12749456e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5256"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749369e16-true-d12749456e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12749369e16-true-d12749456e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e124-true-d12749528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5255"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e124-true-d12749528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12746081e124-true-d12749528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749467e15-true-d12749604e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5254"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749467e15-true-d12749604e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12749467e15-true-d12749604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749467e35-true-d12749659e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5253"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749467e35-true-d12749659e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12749467e35-true-d12749659e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749467e39-true-d12749716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5252"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749467e39-true-d12749716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12749467e39-true-d12749716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749467e42-true-d12749770e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5251"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12749467e42-true-d12749770e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12749467e42-true-d12749770e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e151-true-d12749839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5250"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e151-true-d12749839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12746081e151-true-d12749839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749849e13-true-d12749873e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5249"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12749849e13-true-d12749873e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12749849e13-true-d12749873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749894e13-true-d12749918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5248"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12749894e13-true-d12749918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12749894e13-true-d12749918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749939e13-true-d12749963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5247"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12749939e13-true-d12749963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12749939e13-true-d12749963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12749984e13-true-d12750018e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5246"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12749984e13-true-d12750018e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12749984e13-true-d12750018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12746081e156-true-d12750062e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5245"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12746081e156-true-d12750062e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12746081e156-true-d12750062e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750050e2-true-d12750089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5244"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12750050e2-true-d12750089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12750050e2-true-d12750089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e16-true-d12751616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5243"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e16-true-d12751616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12750110e16-true-d12751616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e71-true-d12751708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5242"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e71-true-d12751708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12750110e71-true-d12751708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12751685e9-true-d12751752e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5241"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12751685e9-true-d12751752e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12751685e9-true-d12751752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12751685e29-true-d12751801e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5240"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12751685e29-true-d12751801e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12751685e29-true-d12751801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e76-true-d12751837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5239"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e76-true-d12751837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12750110e76-true-d12751837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12751825e2-true-d12751857e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5238"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12751825e2-true-d12751857e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12751825e2-true-d12751857e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12751825e8-true-d12751898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5237"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12751825e8-true-d12751898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12751825e8-true-d12751898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e80-true-d12751975e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="5236"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e80-true-d12751975e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12750110e80-true-d12751975e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12751927e5-true-d12752031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="5235"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12751927e5-true-d12752031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12751927e5-true-d12752031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752041e13-true-d12752058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="5234"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12752041e13-true-d12752058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12752041e13-true-d12752058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752073e13-true-d12752101e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="5233"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12752073e13-true-d12752101e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12752073e13-true-d12752101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12751927e24-true-d12752162e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5232"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12751927e24-true-d12752162e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12751927e24-true-d12752162e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752125e12-true-d12752230e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5231"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752125e12-true-d12752230e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12752125e12-true-d12752230e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752125e35-true-d12752289e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5230"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752125e35-true-d12752289e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12752125e35-true-d12752289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e87-true-d12752384e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5229"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e87-true-d12752384e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12750110e87-true-d12752384e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752320e9-true-d12752444e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5228"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752320e9-true-d12752444e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12752320e9-true-d12752444e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e92-true-d12752566e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5227"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e92-true-d12752566e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12750110e92-true-d12752566e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752493e10-true-d12752658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5226"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752493e10-true-d12752658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12752493e10-true-d12752658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752493e30-true-d12752697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5225"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752493e30-true-d12752697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12752493e30-true-d12752697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752493e34-true-d12752736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5224"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752493e34-true-d12752736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12752493e34-true-d12752736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752493e39-true-d12752797e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5223"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752493e39-true-d12752797e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12752493e39-true-d12752797e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752760e12-true-d12752865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5222"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752760e12-true-d12752865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12752760e12-true-d12752865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752760e35-true-d12752924e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5221"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752760e35-true-d12752924e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12752760e35-true-d12752924e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e96-true-d12753021e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5220"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e96-true-d12753021e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12750110e96-true-d12753021e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752955e7-true-d12753096e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5219"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752955e7-true-d12753096e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12752955e7-true-d12753096e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753026e9-true-d12753135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5218"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753026e9-true-d12753135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12753026e9-true-d12753135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753026e10-true-d12753183e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5217"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753026e10-true-d12753183e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12753026e10-true-d12753183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753146e12-true-d12753251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5216"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753146e12-true-d12753251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12753146e12-true-d12753251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753146e35-true-d12753310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5215"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753146e35-true-d12753310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12753146e35-true-d12753310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12752955e11-true-d12753387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5214"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12752955e11-true-d12753387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12752955e11-true-d12753387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753341e16-true-d12753428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5213"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753341e16-true-d12753428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12753341e16-true-d12753428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e100-true-d12753500e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5212"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e100-true-d12753500e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12750110e100-true-d12753500e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753439e15-true-d12753576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5211"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753439e15-true-d12753576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12753439e15-true-d12753576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753439e35-true-d12753631e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5210"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753439e35-true-d12753631e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12753439e35-true-d12753631e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753439e39-true-d12753688e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5209"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753439e39-true-d12753688e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12753439e39-true-d12753688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753439e42-true-d12753742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5208"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12753439e42-true-d12753742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12753439e42-true-d12753742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e128-true-d12753811e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5207"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e128-true-d12753811e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12750110e128-true-d12753811e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753821e13-true-d12753845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5206"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12753821e13-true-d12753845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12753821e13-true-d12753845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753866e13-true-d12753890e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5205"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12753866e13-true-d12753890e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12753866e13-true-d12753890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753911e13-true-d12753935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5204"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12753911e13-true-d12753935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12753911e13-true-d12753935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12753956e13-true-d12753990e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5203"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12753956e13-true-d12753990e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12753956e13-true-d12753990e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12750110e132-true-d12754034e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5202"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12750110e132-true-d12754034e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12750110e132-true-d12754034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754022e2-true-d12754061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5201"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12754022e2-true-d12754061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12754022e2-true-d12754061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e92-true-d12754119e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5200"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e92-true-d12754119e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12713247e92-true-d12754119e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754129e13-true-d12754153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5199"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12754129e13-true-d12754153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12754129e13-true-d12754153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754174e13-true-d12754198e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5198"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12754174e13-true-d12754198e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12754174e13-true-d12754198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754219e13-true-d12754243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5197"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12754219e13-true-d12754243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12754219e13-true-d12754243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754264e13-true-d12754298e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5196"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12754264e13-true-d12754298e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12754264e13-true-d12754298e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12713247e97-true-d12754342e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5195"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12713247e97-true-d12754342e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12713247e97-true-d12754342e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754330e2-true-d12754369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5194"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12754330e2-true-d12754369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12754330e2-true-d12754369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e16-true-d12755929e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5193"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e16-true-d12755929e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12754390e16-true-d12755929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e95-true-d12756045e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5192"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e95-true-d12756045e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12754390e95-true-d12756045e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756022e9-true-d12756089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5191"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756022e9-true-d12756089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12756022e9-true-d12756089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756022e29-true-d12756138e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5190"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756022e29-true-d12756138e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12756022e29-true-d12756138e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e99-true-d12756174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5189"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e99-true-d12756174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12754390e99-true-d12756174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756162e2-true-d12756194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5188"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756162e2-true-d12756194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12756162e2-true-d12756194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756162e8-true-d12756235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5187"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756162e8-true-d12756235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12756162e8-true-d12756235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e103-true-d12756312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="5186"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e103-true-d12756312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12754390e103-true-d12756312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756264e5-true-d12756368e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="5185"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756264e5-true-d12756368e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12756264e5-true-d12756368e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756378e13-true-d12756395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="5184"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12756378e13-true-d12756395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12756378e13-true-d12756395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756410e13-true-d12756438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="5183"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12756410e13-true-d12756438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12756410e13-true-d12756438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756264e24-true-d12756499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5182"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756264e24-true-d12756499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12756264e24-true-d12756499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756462e12-true-d12756567e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5181"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756462e12-true-d12756567e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12756462e12-true-d12756567e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756462e35-true-d12756626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5180"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756462e35-true-d12756626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12756462e35-true-d12756626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e111-true-d12756721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5179"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e111-true-d12756721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12754390e111-true-d12756721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756657e9-true-d12756781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5178"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756657e9-true-d12756781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12756657e9-true-d12756781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e115-true-d12756903e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5177"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e115-true-d12756903e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12754390e115-true-d12756903e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756830e10-true-d12756995e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5176"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756830e10-true-d12756995e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12756830e10-true-d12756995e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756830e30-true-d12757034e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5175"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756830e30-true-d12757034e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12756830e30-true-d12757034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756830e34-true-d12757073e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5174"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756830e34-true-d12757073e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12756830e34-true-d12757073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12756830e39-true-d12757134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5173"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12756830e39-true-d12757134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12756830e39-true-d12757134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757097e12-true-d12757202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5172"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757097e12-true-d12757202e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12757097e12-true-d12757202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757097e35-true-d12757261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5171"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757097e35-true-d12757261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12757097e35-true-d12757261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e119-true-d12757358e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5170"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e119-true-d12757358e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12754390e119-true-d12757358e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757292e7-true-d12757433e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5169"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757292e7-true-d12757433e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12757292e7-true-d12757433e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757363e9-true-d12757472e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5168"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757363e9-true-d12757472e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12757363e9-true-d12757472e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757363e10-true-d12757520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5167"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757363e10-true-d12757520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12757363e10-true-d12757520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757483e12-true-d12757588e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5166"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757483e12-true-d12757588e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12757483e12-true-d12757588e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757483e35-true-d12757647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5165"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757483e35-true-d12757647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12757483e35-true-d12757647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757292e11-true-d12757724e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5164"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757292e11-true-d12757724e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12757292e11-true-d12757724e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757678e16-true-d12757765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5163"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757678e16-true-d12757765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12757678e16-true-d12757765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e124-true-d12757837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5162"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e124-true-d12757837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12754390e124-true-d12757837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757776e15-true-d12757913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5161"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757776e15-true-d12757913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12757776e15-true-d12757913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757776e35-true-d12757968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5160"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757776e35-true-d12757968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12757776e35-true-d12757968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757776e39-true-d12758025e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5159"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757776e39-true-d12758025e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12757776e39-true-d12758025e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12757776e42-true-d12758079e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5158"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12757776e42-true-d12758079e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12757776e42-true-d12758079e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e128-true-d12763186e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="5157"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e128-true-d12763186e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12754390e128-true-d12763186e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e16-true-d12764651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5156"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e16-true-d12764651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12763201e16-true-d12764651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e77-true-d12764731e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5155"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e77-true-d12764731e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12763201e77-true-d12764731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12764708e9-true-d12764775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5154"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12764708e9-true-d12764775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12764708e9-true-d12764775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12764708e29-true-d12764824e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5153"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12764708e29-true-d12764824e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12764708e29-true-d12764824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e81-true-d12764860e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5152"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e81-true-d12764860e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12763201e81-true-d12764860e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12764848e2-true-d12764880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5151"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12764848e2-true-d12764880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12764848e2-true-d12764880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12764848e8-true-d12764921e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5150"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12764848e8-true-d12764921e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12764848e8-true-d12764921e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e85-true-d12765014e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5149"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e85-true-d12765014e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12763201e85-true-d12765014e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12764950e9-true-d12765074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5148"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12764950e9-true-d12765074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12764950e9-true-d12765074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e90-true-d12765196e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5147"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e90-true-d12765196e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12763201e90-true-d12765196e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765123e10-true-d12765288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5146"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765123e10-true-d12765288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12765123e10-true-d12765288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765123e30-true-d12765327e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5145"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765123e30-true-d12765327e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12765123e30-true-d12765327e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765123e34-true-d12765366e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5144"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765123e34-true-d12765366e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12765123e34-true-d12765366e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765123e39-true-d12765427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5143"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765123e39-true-d12765427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12765123e39-true-d12765427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765390e12-true-d12765495e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5142"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765390e12-true-d12765495e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12765390e12-true-d12765495e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765390e35-true-d12765554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5141"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765390e35-true-d12765554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12765390e35-true-d12765554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e94-true-d12765651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5140"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e94-true-d12765651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12763201e94-true-d12765651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765585e7-true-d12765726e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5139"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765585e7-true-d12765726e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12765585e7-true-d12765726e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765656e9-true-d12765765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5138"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765656e9-true-d12765765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12765656e9-true-d12765765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765656e10-true-d12765813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5137"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765656e10-true-d12765813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12765656e10-true-d12765813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765776e12-true-d12765881e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5136"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765776e12-true-d12765881e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12765776e12-true-d12765881e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765776e35-true-d12765940e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5135"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765776e35-true-d12765940e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12765776e35-true-d12765940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765585e11-true-d12766017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5134"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765585e11-true-d12766017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12765585e11-true-d12766017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12765971e16-true-d12766058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5133"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12765971e16-true-d12766058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12765971e16-true-d12766058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e98-true-d12766130e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5132"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e98-true-d12766130e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12763201e98-true-d12766130e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766069e15-true-d12766206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5131"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12766069e15-true-d12766206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12766069e15-true-d12766206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766069e35-true-d12766261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5130"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12766069e35-true-d12766261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12766069e35-true-d12766261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766069e39-true-d12766318e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5129"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12766069e39-true-d12766318e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12766069e39-true-d12766318e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766069e42-true-d12766372e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5128"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12766069e42-true-d12766372e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12766069e42-true-d12766372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e126-true-d12766441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5127"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e126-true-d12766441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12763201e126-true-d12766441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766451e13-true-d12766475e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5126"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12766451e13-true-d12766475e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12766451e13-true-d12766475e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766496e13-true-d12766520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5125"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12766496e13-true-d12766520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12766496e13-true-d12766520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766541e13-true-d12766565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5124"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12766541e13-true-d12766565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12766541e13-true-d12766565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766586e13-true-d12766620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5123"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12766586e13-true-d12766620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12766586e13-true-d12766620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12763201e130-true-d12766664e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5122"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12763201e130-true-d12766664e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12763201e130-true-d12766664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766652e2-true-d12766691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5121"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12766652e2-true-d12766691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12766652e2-true-d12766691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e16-true-d12768155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5120"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e16-true-d12768155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12766712e16-true-d12768155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e65-true-d12768229e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5119"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e65-true-d12768229e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12766712e65-true-d12768229e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768206e9-true-d12768273e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5118"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768206e9-true-d12768273e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12768206e9-true-d12768273e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768206e29-true-d12768322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5117"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768206e29-true-d12768322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12768206e29-true-d12768322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e69-true-d12768358e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5116"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e69-true-d12768358e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12766712e69-true-d12768358e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768346e2-true-d12768378e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5115"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768346e2-true-d12768378e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12768346e2-true-d12768378e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768346e8-true-d12768419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5114"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768346e8-true-d12768419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12768346e8-true-d12768419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e73-true-d12768512e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5113"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e73-true-d12768512e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12766712e73-true-d12768512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768448e9-true-d12768572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5112"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768448e9-true-d12768572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12768448e9-true-d12768572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e78-true-d12768694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5111"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e78-true-d12768694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12766712e78-true-d12768694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768621e10-true-d12768786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5110"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768621e10-true-d12768786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12768621e10-true-d12768786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768621e30-true-d12768825e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5109"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768621e30-true-d12768825e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12768621e30-true-d12768825e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768621e34-true-d12768864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5108"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768621e34-true-d12768864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12768621e34-true-d12768864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768621e39-true-d12768925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5107"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768621e39-true-d12768925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12768621e39-true-d12768925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768888e12-true-d12768993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5106"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768888e12-true-d12768993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12768888e12-true-d12768993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12768888e35-true-d12769052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5105"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12768888e35-true-d12769052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12768888e35-true-d12769052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e82-true-d12769149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5104"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e82-true-d12769149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12766712e82-true-d12769149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769083e7-true-d12769224e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5103"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769083e7-true-d12769224e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12769083e7-true-d12769224e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769154e9-true-d12769263e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5102"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769154e9-true-d12769263e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12769154e9-true-d12769263e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769154e10-true-d12769311e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5101"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769154e10-true-d12769311e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12769154e10-true-d12769311e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769274e12-true-d12769379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5100"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769274e12-true-d12769379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12769274e12-true-d12769379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769274e35-true-d12769438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5099"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769274e35-true-d12769438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12769274e35-true-d12769438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769083e11-true-d12769515e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5098"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769083e11-true-d12769515e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12769083e11-true-d12769515e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769469e16-true-d12769556e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5097"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769469e16-true-d12769556e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12769469e16-true-d12769556e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e86-true-d12769628e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5096"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e86-true-d12769628e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12766712e86-true-d12769628e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769567e15-true-d12769704e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5095"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769567e15-true-d12769704e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12769567e15-true-d12769704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769567e35-true-d12769759e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5094"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769567e35-true-d12769759e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12769567e35-true-d12769759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769567e39-true-d12769816e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5093"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769567e39-true-d12769816e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12769567e39-true-d12769816e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769567e42-true-d12769870e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5092"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12769567e42-true-d12769870e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12769567e42-true-d12769870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e114-true-d12769939e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5091"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e114-true-d12769939e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12766712e114-true-d12769939e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769949e13-true-d12769973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5090"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12769949e13-true-d12769973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12769949e13-true-d12769973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12769994e13-true-d12770018e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5089"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12769994e13-true-d12770018e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12769994e13-true-d12770018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770039e13-true-d12770063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5088"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12770039e13-true-d12770063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12770039e13-true-d12770063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770084e13-true-d12770118e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5087"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12770084e13-true-d12770118e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12770084e13-true-d12770118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12766712e118-true-d12770162e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5086"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12766712e118-true-d12770162e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12766712e118-true-d12770162e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770150e2-true-d12770189e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5085"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12770150e2-true-d12770189e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12770150e2-true-d12770189e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e16-true-d12771713e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="5084"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e16-true-d12771713e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12770210e16-true-d12771713e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e100-true-d12771832e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5083"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e100-true-d12771832e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12770210e100-true-d12771832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12771809e9-true-d12771876e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5082"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12771809e9-true-d12771876e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12771809e9-true-d12771876e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12771809e29-true-d12771925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5081"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12771809e29-true-d12771925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12771809e29-true-d12771925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e104-true-d12771961e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5080"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e104-true-d12771961e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12770210e104-true-d12771961e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12771949e2-true-d12771981e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5079"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12771949e2-true-d12771981e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12771949e2-true-d12771981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12771949e8-true-d12772022e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5078"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12771949e8-true-d12772022e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12771949e8-true-d12772022e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e108-true-d12772115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5077"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e108-true-d12772115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12770210e108-true-d12772115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772051e9-true-d12772175e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5076"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772051e9-true-d12772175e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12772051e9-true-d12772175e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e113-true-d12772297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5075"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e113-true-d12772297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12770210e113-true-d12772297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772224e10-true-d12772389e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5074"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772224e10-true-d12772389e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12772224e10-true-d12772389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772224e30-true-d12772428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5073"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772224e30-true-d12772428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12772224e30-true-d12772428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772224e34-true-d12772467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5072"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772224e34-true-d12772467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12772224e34-true-d12772467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772224e39-true-d12772528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5071"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772224e39-true-d12772528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12772224e39-true-d12772528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772491e12-true-d12772596e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5070"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772491e12-true-d12772596e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12772491e12-true-d12772596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772491e35-true-d12772655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5069"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772491e35-true-d12772655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12772491e35-true-d12772655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e117-true-d12772752e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5068"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e117-true-d12772752e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12770210e117-true-d12772752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772686e7-true-d12772827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5067"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772686e7-true-d12772827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12772686e7-true-d12772827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772757e9-true-d12772866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5066"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772757e9-true-d12772866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12772757e9-true-d12772866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772757e10-true-d12772914e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5065"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772757e10-true-d12772914e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12772757e10-true-d12772914e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772877e12-true-d12772982e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5064"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772877e12-true-d12772982e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12772877e12-true-d12772982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772877e35-true-d12773041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5063"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772877e35-true-d12773041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12772877e35-true-d12773041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12772686e11-true-d12773118e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5062"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12772686e11-true-d12773118e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12772686e11-true-d12773118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773072e16-true-d12773159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5061"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12773072e16-true-d12773159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12773072e16-true-d12773159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e121-true-d12773231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5060"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e121-true-d12773231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12770210e121-true-d12773231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773170e15-true-d12773307e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5059"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12773170e15-true-d12773307e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12773170e15-true-d12773307e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773170e35-true-d12773362e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5058"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12773170e35-true-d12773362e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12773170e35-true-d12773362e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773170e39-true-d12773419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5057"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12773170e39-true-d12773419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12773170e39-true-d12773419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773170e42-true-d12773473e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5056"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12773170e42-true-d12773473e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12773170e42-true-d12773473e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e149-true-d12773542e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5055"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e149-true-d12773542e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12770210e149-true-d12773542e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773552e13-true-d12773576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5054"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12773552e13-true-d12773576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12773552e13-true-d12773576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773597e13-true-d12773621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5053"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12773597e13-true-d12773621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12773597e13-true-d12773621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773642e13-true-d12773666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5052"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12773642e13-true-d12773666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12773642e13-true-d12773666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773687e13-true-d12773721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5051"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12773687e13-true-d12773721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12773687e13-true-d12773721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e153-true-d12773765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5050"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e153-true-d12773765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12770210e153-true-d12773765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773753e2-true-d12773792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5049"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12773753e2-true-d12773792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12773753e2-true-d12773792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e158-true-d12773823e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="5048"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e158-true-d12773823e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12770210e158-true-d12773823e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12770210e162-true-d12773861e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="5047"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12770210e162-true-d12773861e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12770210e162-true-d12773861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e16-true-d12775306e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="5046"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e16-true-d12775306e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12773890e16-true-d12775306e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e43-true-d12775359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5045"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e43-true-d12775359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12773890e43-true-d12775359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775336e9-true-d12775403e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5044"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775336e9-true-d12775403e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12775336e9-true-d12775403e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775336e29-true-d12775452e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5043"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775336e29-true-d12775452e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12775336e29-true-d12775452e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e47-true-d12775488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5042"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e47-true-d12775488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12773890e47-true-d12775488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775476e2-true-d12775508e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5041"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775476e2-true-d12775508e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12775476e2-true-d12775508e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775476e8-true-d12775549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5040"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775476e8-true-d12775549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12775476e8-true-d12775549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e52-true-d12775642e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5039"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e52-true-d12775642e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12773890e52-true-d12775642e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775578e9-true-d12775702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5038"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775578e9-true-d12775702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12775578e9-true-d12775702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e56-true-d12775824e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5037"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e56-true-d12775824e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12773890e56-true-d12775824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775751e10-true-d12775916e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5036"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775751e10-true-d12775916e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12775751e10-true-d12775916e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775751e30-true-d12775955e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5035"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775751e30-true-d12775955e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12775751e30-true-d12775955e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775751e34-true-d12775994e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5034"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775751e34-true-d12775994e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12775751e34-true-d12775994e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12775751e39-true-d12776055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5033"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12775751e39-true-d12776055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12775751e39-true-d12776055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776018e12-true-d12776123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5032"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776018e12-true-d12776123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12776018e12-true-d12776123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776018e35-true-d12776182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5031"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776018e35-true-d12776182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12776018e35-true-d12776182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e60-true-d12776279e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="5030"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e60-true-d12776279e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12773890e60-true-d12776279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776213e7-true-d12776354e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5029"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776213e7-true-d12776354e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12776213e7-true-d12776354e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776284e9-true-d12776393e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="5028"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776284e9-true-d12776393e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12776284e9-true-d12776393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776284e10-true-d12776441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="5027"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776284e10-true-d12776441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12776284e10-true-d12776441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776404e12-true-d12776509e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="5026"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776404e12-true-d12776509e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12776404e12-true-d12776509e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776404e35-true-d12776568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="5025"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776404e35-true-d12776568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12776404e35-true-d12776568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776213e11-true-d12776645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="5024"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776213e11-true-d12776645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12776213e11-true-d12776645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776599e16-true-d12776686e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="5023"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776599e16-true-d12776686e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12776599e16-true-d12776686e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e65-true-d12776758e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="5022"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e65-true-d12776758e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12773890e65-true-d12776758e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776697e15-true-d12776834e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="5021"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776697e15-true-d12776834e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12776697e15-true-d12776834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776697e35-true-d12776889e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="5020"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776697e35-true-d12776889e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12776697e35-true-d12776889e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776697e39-true-d12776946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5019"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776697e39-true-d12776946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12776697e39-true-d12776946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12776697e42-true-d12777000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="5018"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12776697e42-true-d12777000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12776697e42-true-d12777000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e92-true-d12777069e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="5017"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e92-true-d12777069e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12773890e92-true-d12777069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777079e13-true-d12777103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5016"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12777079e13-true-d12777103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12777079e13-true-d12777103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777124e13-true-d12777148e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5015"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12777124e13-true-d12777148e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12777124e13-true-d12777148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777169e13-true-d12777193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="5014"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12777169e13-true-d12777193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12777169e13-true-d12777193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777214e13-true-d12777248e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="5013"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12777214e13-true-d12777248e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12777214e13-true-d12777248e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12773890e97-true-d12777292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="5012"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12773890e97-true-d12777292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12773890e97-true-d12777292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777280e2-true-d12777319e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="5011"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12777280e2-true-d12777319e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12777280e2-true-d12777319e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e16-true-d12778763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="5010"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e16-true-d12778763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12777340e16-true-d12778763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e53-true-d12778822e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="5009"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e53-true-d12778822e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12777340e53-true-d12778822e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12778799e9-true-d12778866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="5008"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12778799e9-true-d12778866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12778799e9-true-d12778866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12778799e29-true-d12778915e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="5007"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12778799e29-true-d12778915e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12778799e29-true-d12778915e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e58-true-d12778951e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="5006"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e58-true-d12778951e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12777340e58-true-d12778951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12778939e2-true-d12778971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="5005"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12778939e2-true-d12778971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12778939e2-true-d12778971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12778939e8-true-d12779012e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="5004"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12778939e8-true-d12779012e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12778939e8-true-d12779012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e62-true-d12779105e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="5003"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e62-true-d12779105e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12777340e62-true-d12779105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779041e9-true-d12779165e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="5002"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779041e9-true-d12779165e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12779041e9-true-d12779165e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e66-true-d12779287e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="5001"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e66-true-d12779287e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12777340e66-true-d12779287e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779214e10-true-d12779379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="5000"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779214e10-true-d12779379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12779214e10-true-d12779379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779214e30-true-d12779418e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4999"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779214e30-true-d12779418e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12779214e30-true-d12779418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779214e34-true-d12779457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4998"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779214e34-true-d12779457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12779214e34-true-d12779457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779214e39-true-d12779518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4997"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779214e39-true-d12779518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12779214e39-true-d12779518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779481e12-true-d12779586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4996"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779481e12-true-d12779586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12779481e12-true-d12779586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779481e35-true-d12779645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4995"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779481e35-true-d12779645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12779481e35-true-d12779645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e71-true-d12779742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4994"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e71-true-d12779742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12777340e71-true-d12779742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779676e7-true-d12779817e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4993"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779676e7-true-d12779817e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12779676e7-true-d12779817e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779747e9-true-d12779856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4992"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779747e9-true-d12779856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12779747e9-true-d12779856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779747e10-true-d12779904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4991"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779747e10-true-d12779904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12779747e10-true-d12779904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779867e12-true-d12779972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4990"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779867e12-true-d12779972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12779867e12-true-d12779972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779867e35-true-d12780031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4989"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779867e35-true-d12780031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12779867e35-true-d12780031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12779676e11-true-d12780108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4988"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12779676e11-true-d12780108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12779676e11-true-d12780108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780062e16-true-d12780149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4987"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12780062e16-true-d12780149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12780062e16-true-d12780149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e75-true-d12780221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4986"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e75-true-d12780221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12777340e75-true-d12780221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780160e15-true-d12780297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4985"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12780160e15-true-d12780297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12780160e15-true-d12780297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780160e35-true-d12780352e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4984"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12780160e35-true-d12780352e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12780160e35-true-d12780352e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780160e39-true-d12780409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4983"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12780160e39-true-d12780409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12780160e39-true-d12780409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780160e42-true-d12780463e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4982"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12780160e42-true-d12780463e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12780160e42-true-d12780463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e81-true-d12780523e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4981"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e81-true-d12780523e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12777340e81-true-d12780523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780533e13-true-d12780557e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4980"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12780533e13-true-d12780557e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12780533e13-true-d12780557e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780578e13-true-d12780602e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4979"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12780578e13-true-d12780602e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12780578e13-true-d12780602e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780623e13-true-d12780647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4978"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12780623e13-true-d12780647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12780623e13-true-d12780647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780668e13-true-d12780702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4977"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12780668e13-true-d12780702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12780668e13-true-d12780702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12777340e86-true-d12780746e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4976"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12777340e86-true-d12780746e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12777340e86-true-d12780746e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780734e2-true-d12780773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4975"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12780734e2-true-d12780773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12780734e2-true-d12780773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e16-true-d12782274e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4974"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e16-true-d12782274e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12780803e16-true-d12782274e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e87-true-d12782372e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4973"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e87-true-d12782372e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12780803e87-true-d12782372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782349e9-true-d12782416e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4972"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782349e9-true-d12782416e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12782349e9-true-d12782416e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782349e29-true-d12782465e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4971"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782349e29-true-d12782465e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12782349e29-true-d12782465e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e92-true-d12782501e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4970"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e92-true-d12782501e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12780803e92-true-d12782501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782489e2-true-d12782521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4969"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782489e2-true-d12782521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12782489e2-true-d12782521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782489e8-true-d12782562e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4968"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782489e8-true-d12782562e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12782489e8-true-d12782562e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e96-true-d12782655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4967"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e96-true-d12782655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12780803e96-true-d12782655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782591e9-true-d12782715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4966"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782591e9-true-d12782715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12782591e9-true-d12782715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e100-true-d12782837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4965"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e100-true-d12782837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12780803e100-true-d12782837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782764e10-true-d12782929e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4964"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782764e10-true-d12782929e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12782764e10-true-d12782929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782764e30-true-d12782968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4963"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782764e30-true-d12782968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12782764e30-true-d12782968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782764e34-true-d12783007e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4962"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782764e34-true-d12783007e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12782764e34-true-d12783007e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12782764e39-true-d12783068e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4961"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12782764e39-true-d12783068e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12782764e39-true-d12783068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783031e12-true-d12783136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4960"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783031e12-true-d12783136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12783031e12-true-d12783136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783031e35-true-d12783195e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4959"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783031e35-true-d12783195e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12783031e35-true-d12783195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e105-true-d12783292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4958"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e105-true-d12783292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12780803e105-true-d12783292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783226e7-true-d12783367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4957"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783226e7-true-d12783367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12783226e7-true-d12783367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783297e9-true-d12783406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4956"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783297e9-true-d12783406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12783297e9-true-d12783406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783297e10-true-d12783454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4955"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783297e10-true-d12783454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12783297e10-true-d12783454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783417e12-true-d12783522e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4954"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783417e12-true-d12783522e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12783417e12-true-d12783522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783417e35-true-d12783581e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4953"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783417e35-true-d12783581e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12783417e35-true-d12783581e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783226e11-true-d12783658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4952"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783226e11-true-d12783658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12783226e11-true-d12783658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783612e16-true-d12783699e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4951"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783612e16-true-d12783699e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12783612e16-true-d12783699e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e109-true-d12783771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4950"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e109-true-d12783771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12780803e109-true-d12783771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783710e15-true-d12783847e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4949"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783710e15-true-d12783847e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12783710e15-true-d12783847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783710e35-true-d12783902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4948"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783710e35-true-d12783902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12783710e35-true-d12783902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783710e39-true-d12783959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4947"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783710e39-true-d12783959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12783710e39-true-d12783959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12783710e42-true-d12784013e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4946"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12783710e42-true-d12784013e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12783710e42-true-d12784013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e137-true-d12784082e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4945"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e137-true-d12784082e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12780803e137-true-d12784082e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784092e13-true-d12784116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4944"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12784092e13-true-d12784116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12784092e13-true-d12784116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784137e13-true-d12784161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4943"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12784137e13-true-d12784161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12784137e13-true-d12784161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784182e13-true-d12784206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4942"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12784182e13-true-d12784206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12784182e13-true-d12784206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784227e13-true-d12784261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4941"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12784227e13-true-d12784261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12784227e13-true-d12784261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12780803e141-true-d12784305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4940"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12780803e141-true-d12784305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12780803e141-true-d12784305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784293e2-true-d12784332e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4939"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12784293e2-true-d12784332e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12784293e2-true-d12784332e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e16-true-d12785769e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4938"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e16-true-d12785769e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12784353e16-true-d12785769e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e43-true-d12785822e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4937"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e43-true-d12785822e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12784353e43-true-d12785822e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12785799e9-true-d12785866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4936"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12785799e9-true-d12785866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12785799e9-true-d12785866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12785799e29-true-d12785915e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4935"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12785799e29-true-d12785915e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12785799e29-true-d12785915e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e47-true-d12785951e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4934"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e47-true-d12785951e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12784353e47-true-d12785951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12785939e2-true-d12785971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4933"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12785939e2-true-d12785971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12785939e2-true-d12785971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12785939e8-true-d12786012e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4932"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12785939e8-true-d12786012e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12785939e8-true-d12786012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e52-true-d12786105e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4931"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e52-true-d12786105e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12784353e52-true-d12786105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786041e9-true-d12786165e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4930"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786041e9-true-d12786165e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12786041e9-true-d12786165e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e56-true-d12786287e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4929"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e56-true-d12786287e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12784353e56-true-d12786287e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786214e10-true-d12786379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4928"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786214e10-true-d12786379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12786214e10-true-d12786379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786214e30-true-d12786418e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4927"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786214e30-true-d12786418e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12786214e30-true-d12786418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786214e34-true-d12786457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4926"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786214e34-true-d12786457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12786214e34-true-d12786457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786214e39-true-d12786518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4925"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786214e39-true-d12786518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12786214e39-true-d12786518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786481e12-true-d12786586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4924"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786481e12-true-d12786586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12786481e12-true-d12786586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786481e35-true-d12786645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4923"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786481e35-true-d12786645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12786481e35-true-d12786645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e60-true-d12786742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4922"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e60-true-d12786742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12784353e60-true-d12786742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786676e7-true-d12786817e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4921"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786676e7-true-d12786817e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12786676e7-true-d12786817e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786747e9-true-d12786856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4920"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786747e9-true-d12786856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12786747e9-true-d12786856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786747e10-true-d12786904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4919"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786747e10-true-d12786904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12786747e10-true-d12786904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786867e12-true-d12786972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4918"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786867e12-true-d12786972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12786867e12-true-d12786972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786867e35-true-d12787031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4917"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786867e35-true-d12787031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12786867e35-true-d12787031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12786676e11-true-d12787108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4916"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12786676e11-true-d12787108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12786676e11-true-d12787108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787062e16-true-d12787149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4915"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12787062e16-true-d12787149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12787062e16-true-d12787149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e65-true-d12787221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4914"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e65-true-d12787221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12784353e65-true-d12787221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787160e15-true-d12787297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4913"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12787160e15-true-d12787297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12787160e15-true-d12787297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787160e35-true-d12787352e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4912"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12787160e35-true-d12787352e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12787160e35-true-d12787352e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787160e39-true-d12787409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4911"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12787160e39-true-d12787409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12787160e39-true-d12787409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787160e42-true-d12787463e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4910"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12787160e42-true-d12787463e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12787160e42-true-d12787463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e92-true-d12787532e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4909"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e92-true-d12787532e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12784353e92-true-d12787532e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787542e13-true-d12787566e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4908"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12787542e13-true-d12787566e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12787542e13-true-d12787566e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787587e13-true-d12787611e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4907"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12787587e13-true-d12787611e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12787587e13-true-d12787611e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787632e13-true-d12787656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4906"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12787632e13-true-d12787656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12787632e13-true-d12787656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787677e13-true-d12787711e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4905"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12787677e13-true-d12787711e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12787677e13-true-d12787711e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12784353e97-true-d12787755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4904"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12784353e97-true-d12787755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12784353e97-true-d12787755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787743e2-true-d12787782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4903"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12787743e2-true-d12787782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12787743e2-true-d12787782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e16-true-d12789342e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4902"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e16-true-d12789342e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12787803e16-true-d12789342e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e95-true-d12789458e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4901"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e95-true-d12789458e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12787803e95-true-d12789458e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789435e9-true-d12789502e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4900"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789435e9-true-d12789502e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12789435e9-true-d12789502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789435e29-true-d12789551e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4899"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789435e29-true-d12789551e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12789435e29-true-d12789551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e99-true-d12789587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4898"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e99-true-d12789587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12787803e99-true-d12789587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789575e2-true-d12789607e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4897"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789575e2-true-d12789607e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12789575e2-true-d12789607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789575e8-true-d12789648e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4896"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789575e8-true-d12789648e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12789575e8-true-d12789648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e103-true-d12789725e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="4895"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e103-true-d12789725e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12787803e103-true-d12789725e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789677e5-true-d12789781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="4894"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789677e5-true-d12789781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12789677e5-true-d12789781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789791e13-true-d12789808e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="4893"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12789791e13-true-d12789808e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12789791e13-true-d12789808e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789823e13-true-d12789851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="4892"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12789823e13-true-d12789851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12789823e13-true-d12789851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789677e24-true-d12789912e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4891"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789677e24-true-d12789912e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12789677e24-true-d12789912e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789875e12-true-d12789980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4890"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789875e12-true-d12789980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12789875e12-true-d12789980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12789875e35-true-d12790039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4889"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12789875e35-true-d12790039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12789875e35-true-d12790039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e111-true-d12790134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4888"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e111-true-d12790134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12787803e111-true-d12790134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790070e9-true-d12790194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4887"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790070e9-true-d12790194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12790070e9-true-d12790194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e115-true-d12790316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4886"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e115-true-d12790316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12787803e115-true-d12790316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790243e10-true-d12790408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4885"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790243e10-true-d12790408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12790243e10-true-d12790408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790243e30-true-d12790447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4884"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790243e30-true-d12790447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12790243e30-true-d12790447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790243e34-true-d12790486e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4883"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790243e34-true-d12790486e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12790243e34-true-d12790486e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790243e39-true-d12790547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4882"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790243e39-true-d12790547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12790243e39-true-d12790547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790510e12-true-d12790615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4881"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790510e12-true-d12790615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12790510e12-true-d12790615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790510e35-true-d12790674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4880"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790510e35-true-d12790674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12790510e35-true-d12790674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e119-true-d12790771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4879"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e119-true-d12790771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12787803e119-true-d12790771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790705e7-true-d12790846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4878"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790705e7-true-d12790846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12790705e7-true-d12790846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790776e9-true-d12790885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4877"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790776e9-true-d12790885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12790776e9-true-d12790885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790776e10-true-d12790933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4876"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790776e10-true-d12790933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12790776e10-true-d12790933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790896e12-true-d12791001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4875"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790896e12-true-d12791001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12790896e12-true-d12791001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790896e35-true-d12791060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4874"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790896e35-true-d12791060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12790896e35-true-d12791060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12790705e11-true-d12791137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4873"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12790705e11-true-d12791137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12790705e11-true-d12791137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791091e16-true-d12791178e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4872"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12791091e16-true-d12791178e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12791091e16-true-d12791178e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e124-true-d12791250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4871"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e124-true-d12791250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12787803e124-true-d12791250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791189e15-true-d12791326e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4870"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12791189e15-true-d12791326e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12791189e15-true-d12791326e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791189e35-true-d12791381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4869"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12791189e35-true-d12791381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12791189e35-true-d12791381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791189e39-true-d12791438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4868"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12791189e39-true-d12791438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12791189e39-true-d12791438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791189e42-true-d12791492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4867"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12791189e42-true-d12791492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12791189e42-true-d12791492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e151-true-d12791561e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4866"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e151-true-d12791561e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12787803e151-true-d12791561e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791571e13-true-d12791595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4865"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12791571e13-true-d12791595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12791571e13-true-d12791595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791616e13-true-d12791640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4864"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12791616e13-true-d12791640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12791616e13-true-d12791640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791661e13-true-d12791685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4863"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12791661e13-true-d12791685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12791661e13-true-d12791685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791706e13-true-d12791740e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4862"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12791706e13-true-d12791740e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12791706e13-true-d12791740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12787803e156-true-d12791784e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4861"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12787803e156-true-d12791784e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12787803e156-true-d12791784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791772e2-true-d12791811e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4860"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12791772e2-true-d12791811e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12791772e2-true-d12791811e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e16-true-d12793338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4859"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e16-true-d12793338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12791832e16-true-d12793338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e71-true-d12793430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4858"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e71-true-d12793430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12791832e71-true-d12793430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793407e9-true-d12793474e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4857"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793407e9-true-d12793474e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12793407e9-true-d12793474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793407e29-true-d12793523e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4856"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793407e29-true-d12793523e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12793407e29-true-d12793523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e76-true-d12793559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4855"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e76-true-d12793559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12791832e76-true-d12793559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793547e2-true-d12793579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4854"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793547e2-true-d12793579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12793547e2-true-d12793579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793547e8-true-d12793620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4853"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793547e8-true-d12793620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12793547e8-true-d12793620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e80-true-d12793697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="4852"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e80-true-d12793697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12791832e80-true-d12793697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793649e5-true-d12793753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="4851"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793649e5-true-d12793753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12793649e5-true-d12793753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793763e13-true-d12793780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="4850"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12793763e13-true-d12793780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12793763e13-true-d12793780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793795e13-true-d12793823e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="4849"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12793795e13-true-d12793823e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12793795e13-true-d12793823e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793649e24-true-d12793884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4848"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793649e24-true-d12793884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12793649e24-true-d12793884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793847e12-true-d12793952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4847"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793847e12-true-d12793952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12793847e12-true-d12793952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12793847e35-true-d12794011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4846"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12793847e35-true-d12794011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12793847e35-true-d12794011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e87-true-d12794106e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4845"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e87-true-d12794106e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12791832e87-true-d12794106e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794042e9-true-d12794166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4844"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794042e9-true-d12794166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12794042e9-true-d12794166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e92-true-d12794288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4843"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e92-true-d12794288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12791832e92-true-d12794288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794215e10-true-d12794380e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4842"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794215e10-true-d12794380e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12794215e10-true-d12794380e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794215e30-true-d12794419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4841"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794215e30-true-d12794419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12794215e30-true-d12794419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794215e34-true-d12794458e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4840"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794215e34-true-d12794458e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12794215e34-true-d12794458e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794215e39-true-d12794519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4839"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794215e39-true-d12794519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12794215e39-true-d12794519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794482e12-true-d12794587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4838"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794482e12-true-d12794587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12794482e12-true-d12794587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794482e35-true-d12794646e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4837"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794482e35-true-d12794646e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12794482e35-true-d12794646e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e96-true-d12794743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4836"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e96-true-d12794743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12791832e96-true-d12794743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794677e7-true-d12794818e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4835"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794677e7-true-d12794818e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12794677e7-true-d12794818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794748e9-true-d12794857e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4834"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794748e9-true-d12794857e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12794748e9-true-d12794857e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794748e10-true-d12794905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4833"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794748e10-true-d12794905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12794748e10-true-d12794905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794868e12-true-d12794973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4832"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794868e12-true-d12794973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12794868e12-true-d12794973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794868e35-true-d12795032e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4831"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794868e35-true-d12795032e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12794868e35-true-d12795032e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12794677e11-true-d12795109e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4830"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12794677e11-true-d12795109e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12794677e11-true-d12795109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795063e16-true-d12795150e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4829"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12795063e16-true-d12795150e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12795063e16-true-d12795150e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e100-true-d12795222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4828"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e100-true-d12795222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12791832e100-true-d12795222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795161e15-true-d12795298e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4827"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12795161e15-true-d12795298e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12795161e15-true-d12795298e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795161e35-true-d12795353e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4826"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12795161e35-true-d12795353e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12795161e35-true-d12795353e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795161e39-true-d12795410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4825"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12795161e39-true-d12795410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12795161e39-true-d12795410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795161e42-true-d12795464e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4824"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12795161e42-true-d12795464e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12795161e42-true-d12795464e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e128-true-d12795533e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4823"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e128-true-d12795533e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12791832e128-true-d12795533e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795543e13-true-d12795567e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4822"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12795543e13-true-d12795567e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12795543e13-true-d12795567e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795588e13-true-d12795612e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4821"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12795588e13-true-d12795612e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12795588e13-true-d12795612e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795633e13-true-d12795657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4820"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12795633e13-true-d12795657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12795633e13-true-d12795657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795678e13-true-d12795712e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4819"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12795678e13-true-d12795712e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12795678e13-true-d12795712e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12791832e132-true-d12795756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4818"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12791832e132-true-d12795756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12791832e132-true-d12795756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795744e2-true-d12795783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4817"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12795744e2-true-d12795783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12795744e2-true-d12795783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e151-true-d12795841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4816"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e151-true-d12795841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12754390e151-true-d12795841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795851e13-true-d12795875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4815"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12795851e13-true-d12795875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12795851e13-true-d12795875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795896e13-true-d12795920e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4814"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12795896e13-true-d12795920e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12795896e13-true-d12795920e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795941e13-true-d12795965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4813"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12795941e13-true-d12795965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12795941e13-true-d12795965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12795986e13-true-d12796020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4812"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12795986e13-true-d12796020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12795986e13-true-d12796020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12754390e156-true-d12796064e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4811"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12754390e156-true-d12796064e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12754390e156-true-d12796064e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796052e2-true-d12796091e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4810"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12796052e2-true-d12796091e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12796052e2-true-d12796091e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e16-true-d12797618e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4809"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e16-true-d12797618e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12796112e16-true-d12797618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e71-true-d12797710e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4808"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e71-true-d12797710e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12796112e71-true-d12797710e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12797687e9-true-d12797754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4807"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12797687e9-true-d12797754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12797687e9-true-d12797754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12797687e29-true-d12797803e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4806"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12797687e29-true-d12797803e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12797687e29-true-d12797803e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e76-true-d12797839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4805"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e76-true-d12797839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12796112e76-true-d12797839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12797827e2-true-d12797859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4804"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12797827e2-true-d12797859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12797827e2-true-d12797859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12797827e8-true-d12797900e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4803"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12797827e8-true-d12797900e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12797827e8-true-d12797900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e80-true-d12797977e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="4802"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e80-true-d12797977e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12796112e80-true-d12797977e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12797929e5-true-d12798033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="4801"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12797929e5-true-d12798033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12797929e5-true-d12798033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798043e13-true-d12798060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="4800"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12798043e13-true-d12798060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12798043e13-true-d12798060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798075e13-true-d12798103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="4799"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12798075e13-true-d12798103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12798075e13-true-d12798103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12797929e24-true-d12798164e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4798"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12797929e24-true-d12798164e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12797929e24-true-d12798164e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798127e12-true-d12798232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4797"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798127e12-true-d12798232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12798127e12-true-d12798232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798127e35-true-d12798291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4796"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798127e35-true-d12798291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12798127e35-true-d12798291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e87-true-d12798386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4795"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e87-true-d12798386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12796112e87-true-d12798386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798322e9-true-d12798446e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4794"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798322e9-true-d12798446e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12798322e9-true-d12798446e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e92-true-d12798568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4793"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e92-true-d12798568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12796112e92-true-d12798568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798495e10-true-d12798660e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4792"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798495e10-true-d12798660e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12798495e10-true-d12798660e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798495e30-true-d12798699e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4791"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798495e30-true-d12798699e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12798495e30-true-d12798699e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798495e34-true-d12798738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4790"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798495e34-true-d12798738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12798495e34-true-d12798738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798495e39-true-d12798799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4789"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798495e39-true-d12798799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12798495e39-true-d12798799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798762e12-true-d12798867e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4788"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798762e12-true-d12798867e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12798762e12-true-d12798867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798762e35-true-d12798926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4787"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798762e35-true-d12798926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12798762e35-true-d12798926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e96-true-d12799023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4786"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e96-true-d12799023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12796112e96-true-d12799023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798957e7-true-d12799098e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4785"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798957e7-true-d12799098e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12798957e7-true-d12799098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799028e9-true-d12799137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4784"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799028e9-true-d12799137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12799028e9-true-d12799137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799028e10-true-d12799185e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4783"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799028e10-true-d12799185e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12799028e10-true-d12799185e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799148e12-true-d12799253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4782"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799148e12-true-d12799253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12799148e12-true-d12799253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799148e35-true-d12799312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4781"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799148e35-true-d12799312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12799148e35-true-d12799312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12798957e11-true-d12799389e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4780"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12798957e11-true-d12799389e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12798957e11-true-d12799389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799343e16-true-d12799430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4779"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799343e16-true-d12799430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12799343e16-true-d12799430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e100-true-d12799502e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4778"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e100-true-d12799502e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12796112e100-true-d12799502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799441e15-true-d12799578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4777"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799441e15-true-d12799578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12799441e15-true-d12799578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799441e35-true-d12799633e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4776"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799441e35-true-d12799633e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12799441e35-true-d12799633e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799441e39-true-d12799690e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4775"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799441e39-true-d12799690e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12799441e39-true-d12799690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12799441e42-true-d12799744e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4774"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12799441e42-true-d12799744e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12799441e42-true-d12799744e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e105-true-d12804851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="4773"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e105-true-d12804851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12796112e105-true-d12804851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e16-true-d12806316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4772"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e16-true-d12806316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12804866e16-true-d12806316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e77-true-d12806396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4771"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e77-true-d12806396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12804866e77-true-d12806396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806373e9-true-d12806440e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4770"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806373e9-true-d12806440e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12806373e9-true-d12806440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806373e29-true-d12806489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4769"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806373e29-true-d12806489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12806373e29-true-d12806489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e81-true-d12806525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4768"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e81-true-d12806525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12804866e81-true-d12806525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806513e2-true-d12806545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4767"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806513e2-true-d12806545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12806513e2-true-d12806545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806513e8-true-d12806586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4766"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806513e8-true-d12806586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12806513e8-true-d12806586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e85-true-d12806679e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4765"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e85-true-d12806679e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12804866e85-true-d12806679e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806615e9-true-d12806739e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4764"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806615e9-true-d12806739e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12806615e9-true-d12806739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e90-true-d12806861e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4763"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e90-true-d12806861e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12804866e90-true-d12806861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806788e10-true-d12806953e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4762"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806788e10-true-d12806953e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12806788e10-true-d12806953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806788e30-true-d12806992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4761"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806788e30-true-d12806992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12806788e30-true-d12806992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806788e34-true-d12807031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4760"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806788e34-true-d12807031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12806788e34-true-d12807031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12806788e39-true-d12807092e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4759"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12806788e39-true-d12807092e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12806788e39-true-d12807092e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807055e12-true-d12807160e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4758"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807055e12-true-d12807160e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12807055e12-true-d12807160e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807055e35-true-d12807219e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4757"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807055e35-true-d12807219e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12807055e35-true-d12807219e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e94-true-d12807316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4756"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e94-true-d12807316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12804866e94-true-d12807316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807250e7-true-d12807391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4755"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807250e7-true-d12807391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12807250e7-true-d12807391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807321e9-true-d12807430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4754"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807321e9-true-d12807430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12807321e9-true-d12807430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807321e10-true-d12807478e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4753"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807321e10-true-d12807478e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12807321e10-true-d12807478e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807441e12-true-d12807546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4752"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807441e12-true-d12807546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12807441e12-true-d12807546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807441e35-true-d12807605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4751"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807441e35-true-d12807605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12807441e35-true-d12807605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807250e11-true-d12807682e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4750"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807250e11-true-d12807682e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12807250e11-true-d12807682e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807636e16-true-d12807723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4749"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807636e16-true-d12807723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12807636e16-true-d12807723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e98-true-d12807795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4748"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e98-true-d12807795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12804866e98-true-d12807795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807734e15-true-d12807871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4747"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807734e15-true-d12807871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12807734e15-true-d12807871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807734e35-true-d12807926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4746"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807734e35-true-d12807926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12807734e35-true-d12807926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807734e39-true-d12807983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4745"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807734e39-true-d12807983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12807734e39-true-d12807983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12807734e42-true-d12808037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4744"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12807734e42-true-d12808037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12807734e42-true-d12808037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e126-true-d12808106e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4743"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e126-true-d12808106e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12804866e126-true-d12808106e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808116e13-true-d12808140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4742"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12808116e13-true-d12808140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12808116e13-true-d12808140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808161e13-true-d12808185e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4741"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12808161e13-true-d12808185e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12808161e13-true-d12808185e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808206e13-true-d12808230e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4740"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12808206e13-true-d12808230e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12808206e13-true-d12808230e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808251e13-true-d12808285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4739"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12808251e13-true-d12808285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12808251e13-true-d12808285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12804866e130-true-d12808329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4738"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12804866e130-true-d12808329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12804866e130-true-d12808329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808317e2-true-d12808356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4737"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12808317e2-true-d12808356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12808317e2-true-d12808356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e16-true-d12809820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4736"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e16-true-d12809820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12808377e16-true-d12809820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e65-true-d12809894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4735"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e65-true-d12809894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12808377e65-true-d12809894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12809871e9-true-d12809938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4734"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12809871e9-true-d12809938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12809871e9-true-d12809938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12809871e29-true-d12809987e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4733"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12809871e29-true-d12809987e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12809871e29-true-d12809987e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e69-true-d12810023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4732"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e69-true-d12810023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12808377e69-true-d12810023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810011e2-true-d12810043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4731"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810011e2-true-d12810043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12810011e2-true-d12810043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810011e8-true-d12810084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4730"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810011e8-true-d12810084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12810011e8-true-d12810084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e73-true-d12810177e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4729"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e73-true-d12810177e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12808377e73-true-d12810177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810113e9-true-d12810237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4728"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810113e9-true-d12810237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12810113e9-true-d12810237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e78-true-d12810359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4727"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e78-true-d12810359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12808377e78-true-d12810359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810286e10-true-d12810451e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4726"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810286e10-true-d12810451e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12810286e10-true-d12810451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810286e30-true-d12810490e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4725"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810286e30-true-d12810490e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12810286e30-true-d12810490e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810286e34-true-d12810529e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4724"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810286e34-true-d12810529e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12810286e34-true-d12810529e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810286e39-true-d12810590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4723"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810286e39-true-d12810590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12810286e39-true-d12810590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810553e12-true-d12810658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4722"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810553e12-true-d12810658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12810553e12-true-d12810658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810553e35-true-d12810717e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4721"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810553e35-true-d12810717e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12810553e35-true-d12810717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e82-true-d12810814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4720"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e82-true-d12810814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12808377e82-true-d12810814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810748e7-true-d12810889e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4719"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810748e7-true-d12810889e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12810748e7-true-d12810889e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810819e9-true-d12810928e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4718"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810819e9-true-d12810928e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12810819e9-true-d12810928e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810819e10-true-d12810976e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4717"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810819e10-true-d12810976e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12810819e10-true-d12810976e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810939e12-true-d12811044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4716"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810939e12-true-d12811044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12810939e12-true-d12811044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810939e35-true-d12811103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4715"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810939e35-true-d12811103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12810939e35-true-d12811103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12810748e11-true-d12811180e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4714"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12810748e11-true-d12811180e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12810748e11-true-d12811180e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811134e16-true-d12811221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4713"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12811134e16-true-d12811221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12811134e16-true-d12811221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e86-true-d12811293e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4712"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e86-true-d12811293e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12808377e86-true-d12811293e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811232e15-true-d12811369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4711"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12811232e15-true-d12811369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12811232e15-true-d12811369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811232e35-true-d12811424e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4710"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12811232e35-true-d12811424e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12811232e35-true-d12811424e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811232e39-true-d12811481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4709"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12811232e39-true-d12811481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12811232e39-true-d12811481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811232e42-true-d12811535e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4708"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12811232e42-true-d12811535e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12811232e42-true-d12811535e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e114-true-d12811604e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4707"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e114-true-d12811604e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12808377e114-true-d12811604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811614e13-true-d12811638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4706"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12811614e13-true-d12811638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12811614e13-true-d12811638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811659e13-true-d12811683e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4705"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12811659e13-true-d12811683e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12811659e13-true-d12811683e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811704e13-true-d12811728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4704"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12811704e13-true-d12811728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12811704e13-true-d12811728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811749e13-true-d12811783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4703"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12811749e13-true-d12811783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12811749e13-true-d12811783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12808377e118-true-d12811827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4702"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12808377e118-true-d12811827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12808377e118-true-d12811827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811815e2-true-d12811854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4701"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12811815e2-true-d12811854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12811815e2-true-d12811854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e16-true-d12813378e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="4700"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e16-true-d12813378e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12811875e16-true-d12813378e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e100-true-d12813497e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4699"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e100-true-d12813497e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12811875e100-true-d12813497e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813474e9-true-d12813541e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4698"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813474e9-true-d12813541e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12813474e9-true-d12813541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813474e29-true-d12813590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4697"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813474e29-true-d12813590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12813474e29-true-d12813590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e104-true-d12813626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4696"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e104-true-d12813626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12811875e104-true-d12813626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813614e2-true-d12813646e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4695"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813614e2-true-d12813646e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12813614e2-true-d12813646e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813614e8-true-d12813687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4694"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813614e8-true-d12813687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12813614e8-true-d12813687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e108-true-d12813780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4693"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e108-true-d12813780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12811875e108-true-d12813780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813716e9-true-d12813840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4692"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813716e9-true-d12813840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12813716e9-true-d12813840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e113-true-d12813962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4691"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e113-true-d12813962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12811875e113-true-d12813962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813889e10-true-d12814054e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4690"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813889e10-true-d12814054e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12813889e10-true-d12814054e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813889e30-true-d12814093e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4689"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813889e30-true-d12814093e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12813889e30-true-d12814093e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813889e34-true-d12814132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4688"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813889e34-true-d12814132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12813889e34-true-d12814132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12813889e39-true-d12814193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4687"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12813889e39-true-d12814193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12813889e39-true-d12814193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814156e12-true-d12814261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4686"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814156e12-true-d12814261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12814156e12-true-d12814261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814156e35-true-d12814320e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4685"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814156e35-true-d12814320e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12814156e35-true-d12814320e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e117-true-d12814417e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4684"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e117-true-d12814417e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12811875e117-true-d12814417e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814351e7-true-d12814492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4683"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814351e7-true-d12814492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12814351e7-true-d12814492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814422e9-true-d12814531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4682"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814422e9-true-d12814531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12814422e9-true-d12814531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814422e10-true-d12814579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4681"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814422e10-true-d12814579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12814422e10-true-d12814579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814542e12-true-d12814647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4680"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814542e12-true-d12814647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12814542e12-true-d12814647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814542e35-true-d12814706e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4679"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814542e35-true-d12814706e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12814542e35-true-d12814706e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814351e11-true-d12814783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4678"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814351e11-true-d12814783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12814351e11-true-d12814783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814737e16-true-d12814824e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4677"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814737e16-true-d12814824e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12814737e16-true-d12814824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e121-true-d12814896e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4676"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e121-true-d12814896e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12811875e121-true-d12814896e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814835e15-true-d12814972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4675"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814835e15-true-d12814972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12814835e15-true-d12814972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814835e35-true-d12815027e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4674"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814835e35-true-d12815027e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12814835e35-true-d12815027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814835e39-true-d12815084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4673"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814835e39-true-d12815084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12814835e39-true-d12815084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12814835e42-true-d12815138e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4672"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12814835e42-true-d12815138e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12814835e42-true-d12815138e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e149-true-d12815207e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4671"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e149-true-d12815207e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12811875e149-true-d12815207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815217e13-true-d12815241e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4670"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12815217e13-true-d12815241e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12815217e13-true-d12815241e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815262e13-true-d12815286e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4669"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12815262e13-true-d12815286e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12815262e13-true-d12815286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815307e13-true-d12815331e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4668"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12815307e13-true-d12815331e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12815307e13-true-d12815331e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815352e13-true-d12815386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4667"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12815352e13-true-d12815386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12815352e13-true-d12815386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e153-true-d12815430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4666"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e153-true-d12815430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12811875e153-true-d12815430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815418e2-true-d12815457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4665"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12815418e2-true-d12815457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12815418e2-true-d12815457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e158-true-d12815488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="4664"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e158-true-d12815488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12811875e158-true-d12815488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12811875e162-true-d12815526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="4663"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12811875e162-true-d12815526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12811875e162-true-d12815526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e16-true-d12816971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4662"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e16-true-d12816971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12815555e16-true-d12816971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e43-true-d12817024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4661"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e43-true-d12817024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12815555e43-true-d12817024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817001e9-true-d12817068e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4660"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817001e9-true-d12817068e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12817001e9-true-d12817068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817001e29-true-d12817117e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4659"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817001e29-true-d12817117e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12817001e29-true-d12817117e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e47-true-d12817153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4658"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e47-true-d12817153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12815555e47-true-d12817153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817141e2-true-d12817173e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4657"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817141e2-true-d12817173e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12817141e2-true-d12817173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817141e8-true-d12817214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4656"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817141e8-true-d12817214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12817141e8-true-d12817214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e52-true-d12817307e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4655"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e52-true-d12817307e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12815555e52-true-d12817307e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817243e9-true-d12817367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4654"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817243e9-true-d12817367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12817243e9-true-d12817367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e56-true-d12817489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4653"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e56-true-d12817489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12815555e56-true-d12817489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817416e10-true-d12817581e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4652"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817416e10-true-d12817581e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12817416e10-true-d12817581e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817416e30-true-d12817620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4651"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817416e30-true-d12817620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12817416e30-true-d12817620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817416e34-true-d12817659e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4650"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817416e34-true-d12817659e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12817416e34-true-d12817659e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817416e39-true-d12817720e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4649"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817416e39-true-d12817720e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12817416e39-true-d12817720e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817683e12-true-d12817788e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4648"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817683e12-true-d12817788e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12817683e12-true-d12817788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817683e35-true-d12817847e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4647"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817683e35-true-d12817847e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12817683e35-true-d12817847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e60-true-d12817944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4646"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e60-true-d12817944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12815555e60-true-d12817944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817878e7-true-d12818019e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4645"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817878e7-true-d12818019e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12817878e7-true-d12818019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817949e9-true-d12818058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4644"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817949e9-true-d12818058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12817949e9-true-d12818058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817949e10-true-d12818106e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4643"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817949e10-true-d12818106e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12817949e10-true-d12818106e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818069e12-true-d12818174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4642"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818069e12-true-d12818174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12818069e12-true-d12818174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818069e35-true-d12818233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4641"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818069e35-true-d12818233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12818069e35-true-d12818233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12817878e11-true-d12818310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4640"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12817878e11-true-d12818310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12817878e11-true-d12818310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818264e16-true-d12818351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4639"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818264e16-true-d12818351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12818264e16-true-d12818351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e65-true-d12818423e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4638"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e65-true-d12818423e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12815555e65-true-d12818423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818362e15-true-d12818499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4637"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818362e15-true-d12818499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12818362e15-true-d12818499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818362e35-true-d12818554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4636"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818362e35-true-d12818554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12818362e35-true-d12818554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818362e39-true-d12818611e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4635"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818362e39-true-d12818611e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12818362e39-true-d12818611e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818362e42-true-d12818665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4634"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818362e42-true-d12818665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12818362e42-true-d12818665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e92-true-d12818734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4633"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e92-true-d12818734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12815555e92-true-d12818734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818744e13-true-d12818768e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4632"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12818744e13-true-d12818768e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12818744e13-true-d12818768e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818789e13-true-d12818813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4631"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12818789e13-true-d12818813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12818789e13-true-d12818813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818834e13-true-d12818858e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4630"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12818834e13-true-d12818858e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12818834e13-true-d12818858e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818879e13-true-d12818913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4629"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12818879e13-true-d12818913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12818879e13-true-d12818913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12815555e97-true-d12818957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4628"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12815555e97-true-d12818957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12815555e97-true-d12818957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12818945e2-true-d12818984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4627"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12818945e2-true-d12818984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12818945e2-true-d12818984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e16-true-d12820428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="4626"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e16-true-d12820428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12819005e16-true-d12820428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e53-true-d12820487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4625"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e53-true-d12820487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12819005e53-true-d12820487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820464e9-true-d12820531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4624"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820464e9-true-d12820531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12820464e9-true-d12820531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820464e29-true-d12820580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4623"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820464e29-true-d12820580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12820464e29-true-d12820580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e58-true-d12820616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4622"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e58-true-d12820616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12819005e58-true-d12820616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820604e2-true-d12820636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4621"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820604e2-true-d12820636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12820604e2-true-d12820636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820604e8-true-d12820677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4620"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820604e8-true-d12820677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12820604e8-true-d12820677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e62-true-d12820770e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4619"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e62-true-d12820770e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12819005e62-true-d12820770e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820706e9-true-d12820830e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4618"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820706e9-true-d12820830e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12820706e9-true-d12820830e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e66-true-d12820952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4617"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e66-true-d12820952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12819005e66-true-d12820952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820879e10-true-d12821044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4616"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820879e10-true-d12821044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12820879e10-true-d12821044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820879e30-true-d12821083e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4615"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820879e30-true-d12821083e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12820879e30-true-d12821083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820879e34-true-d12821122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4614"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820879e34-true-d12821122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12820879e34-true-d12821122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12820879e39-true-d12821183e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4613"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12820879e39-true-d12821183e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12820879e39-true-d12821183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821146e12-true-d12821251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4612"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821146e12-true-d12821251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12821146e12-true-d12821251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821146e35-true-d12821310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4611"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821146e35-true-d12821310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12821146e35-true-d12821310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e71-true-d12821407e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4610"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e71-true-d12821407e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12819005e71-true-d12821407e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821341e7-true-d12821482e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4609"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821341e7-true-d12821482e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12821341e7-true-d12821482e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821412e9-true-d12821521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4608"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821412e9-true-d12821521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12821412e9-true-d12821521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821412e10-true-d12821569e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4607"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821412e10-true-d12821569e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12821412e10-true-d12821569e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821532e12-true-d12821637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4606"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821532e12-true-d12821637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12821532e12-true-d12821637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821532e35-true-d12821696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4605"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821532e35-true-d12821696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12821532e35-true-d12821696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821341e11-true-d12821773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4604"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821341e11-true-d12821773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12821341e11-true-d12821773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821727e16-true-d12821814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4603"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821727e16-true-d12821814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12821727e16-true-d12821814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e75-true-d12821886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4602"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e75-true-d12821886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12819005e75-true-d12821886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821825e15-true-d12821962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4601"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821825e15-true-d12821962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12821825e15-true-d12821962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821825e35-true-d12822017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4600"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821825e35-true-d12822017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12821825e35-true-d12822017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821825e39-true-d12822074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4599"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821825e39-true-d12822074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12821825e39-true-d12822074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12821825e42-true-d12822128e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4598"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12821825e42-true-d12822128e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12821825e42-true-d12822128e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e81-true-d12822188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4597"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e81-true-d12822188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12819005e81-true-d12822188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822198e13-true-d12822222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4596"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12822198e13-true-d12822222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12822198e13-true-d12822222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822243e13-true-d12822267e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4595"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12822243e13-true-d12822267e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12822243e13-true-d12822267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822288e13-true-d12822312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4594"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12822288e13-true-d12822312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12822288e13-true-d12822312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822333e13-true-d12822367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4593"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12822333e13-true-d12822367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12822333e13-true-d12822367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12819005e86-true-d12822411e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4592"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12819005e86-true-d12822411e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12819005e86-true-d12822411e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822399e2-true-d12822438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4591"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12822399e2-true-d12822438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12822399e2-true-d12822438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e16-true-d12823939e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4590"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e16-true-d12823939e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12822468e16-true-d12823939e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e87-true-d12824037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4589"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e87-true-d12824037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12822468e87-true-d12824037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824014e9-true-d12824081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4588"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824014e9-true-d12824081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12824014e9-true-d12824081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824014e29-true-d12824130e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4587"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824014e29-true-d12824130e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12824014e29-true-d12824130e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e92-true-d12824166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4586"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e92-true-d12824166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12822468e92-true-d12824166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824154e2-true-d12824186e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4585"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824154e2-true-d12824186e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12824154e2-true-d12824186e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824154e8-true-d12824227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4584"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824154e8-true-d12824227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12824154e8-true-d12824227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e96-true-d12824320e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4583"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e96-true-d12824320e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12822468e96-true-d12824320e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824256e9-true-d12824380e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4582"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824256e9-true-d12824380e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12824256e9-true-d12824380e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e100-true-d12824502e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4581"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e100-true-d12824502e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12822468e100-true-d12824502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824429e10-true-d12824594e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4580"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824429e10-true-d12824594e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12824429e10-true-d12824594e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824429e30-true-d12824633e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4579"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824429e30-true-d12824633e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12824429e30-true-d12824633e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824429e34-true-d12824672e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4578"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824429e34-true-d12824672e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12824429e34-true-d12824672e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824429e39-true-d12824733e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4577"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824429e39-true-d12824733e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12824429e39-true-d12824733e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824696e12-true-d12824801e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4576"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824696e12-true-d12824801e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12824696e12-true-d12824801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824696e35-true-d12824860e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4575"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824696e35-true-d12824860e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12824696e35-true-d12824860e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e105-true-d12824957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4574"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e105-true-d12824957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12822468e105-true-d12824957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824891e7-true-d12825032e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4573"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824891e7-true-d12825032e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12824891e7-true-d12825032e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824962e9-true-d12825071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4572"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824962e9-true-d12825071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12824962e9-true-d12825071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824962e10-true-d12825119e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4571"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824962e10-true-d12825119e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12824962e10-true-d12825119e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825082e12-true-d12825187e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4570"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825082e12-true-d12825187e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12825082e12-true-d12825187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825082e35-true-d12825246e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4569"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825082e35-true-d12825246e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12825082e35-true-d12825246e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12824891e11-true-d12825323e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4568"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12824891e11-true-d12825323e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12824891e11-true-d12825323e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825277e16-true-d12825364e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4567"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825277e16-true-d12825364e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12825277e16-true-d12825364e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e109-true-d12825436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4566"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e109-true-d12825436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12822468e109-true-d12825436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825375e15-true-d12825512e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4565"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825375e15-true-d12825512e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12825375e15-true-d12825512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825375e35-true-d12825567e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4564"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825375e35-true-d12825567e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12825375e35-true-d12825567e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825375e39-true-d12825624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4563"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825375e39-true-d12825624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12825375e39-true-d12825624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825375e42-true-d12825678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4562"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825375e42-true-d12825678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12825375e42-true-d12825678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e137-true-d12825747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4561"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e137-true-d12825747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12822468e137-true-d12825747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825757e13-true-d12825781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4560"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12825757e13-true-d12825781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12825757e13-true-d12825781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825802e13-true-d12825826e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4559"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12825802e13-true-d12825826e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12825802e13-true-d12825826e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825847e13-true-d12825871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4558"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12825847e13-true-d12825871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12825847e13-true-d12825871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825892e13-true-d12825926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4557"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12825892e13-true-d12825926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12825892e13-true-d12825926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12822468e141-true-d12825970e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4556"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12822468e141-true-d12825970e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12822468e141-true-d12825970e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12825958e2-true-d12825997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4555"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12825958e2-true-d12825997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12825958e2-true-d12825997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e16-true-d12827434e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4554"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e16-true-d12827434e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12826018e16-true-d12827434e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e43-true-d12827487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4553"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e43-true-d12827487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12826018e43-true-d12827487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827464e9-true-d12827531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4552"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827464e9-true-d12827531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12827464e9-true-d12827531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827464e29-true-d12827580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4551"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827464e29-true-d12827580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12827464e29-true-d12827580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e47-true-d12827616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4550"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e47-true-d12827616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12826018e47-true-d12827616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827604e2-true-d12827636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4549"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827604e2-true-d12827636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12827604e2-true-d12827636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827604e8-true-d12827677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4548"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827604e8-true-d12827677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12827604e8-true-d12827677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e52-true-d12827770e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4547"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e52-true-d12827770e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12826018e52-true-d12827770e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827706e9-true-d12827830e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4546"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827706e9-true-d12827830e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12827706e9-true-d12827830e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e56-true-d12827952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4545"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e56-true-d12827952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12826018e56-true-d12827952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827879e10-true-d12828044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4544"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827879e10-true-d12828044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12827879e10-true-d12828044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827879e30-true-d12828083e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4543"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827879e30-true-d12828083e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12827879e30-true-d12828083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827879e34-true-d12828122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4542"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827879e34-true-d12828122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12827879e34-true-d12828122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12827879e39-true-d12828183e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4541"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12827879e39-true-d12828183e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12827879e39-true-d12828183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828146e12-true-d12828251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4540"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828146e12-true-d12828251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12828146e12-true-d12828251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828146e35-true-d12828310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4539"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828146e35-true-d12828310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12828146e35-true-d12828310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e60-true-d12828407e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4538"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e60-true-d12828407e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12826018e60-true-d12828407e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828341e7-true-d12828482e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4537"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828341e7-true-d12828482e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12828341e7-true-d12828482e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828412e9-true-d12828521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4536"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828412e9-true-d12828521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12828412e9-true-d12828521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828412e10-true-d12828569e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4535"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828412e10-true-d12828569e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12828412e10-true-d12828569e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828532e12-true-d12828637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4534"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828532e12-true-d12828637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12828532e12-true-d12828637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828532e35-true-d12828696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4533"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828532e35-true-d12828696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12828532e35-true-d12828696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828341e11-true-d12828773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4532"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828341e11-true-d12828773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12828341e11-true-d12828773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828727e16-true-d12828814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4531"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828727e16-true-d12828814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12828727e16-true-d12828814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e65-true-d12828886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4530"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e65-true-d12828886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12826018e65-true-d12828886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828825e15-true-d12828962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4529"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828825e15-true-d12828962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12828825e15-true-d12828962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828825e35-true-d12829017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4528"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828825e35-true-d12829017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12828825e35-true-d12829017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828825e39-true-d12829074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4527"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828825e39-true-d12829074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12828825e39-true-d12829074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12828825e42-true-d12829128e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4526"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12828825e42-true-d12829128e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12828825e42-true-d12829128e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e92-true-d12829197e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4525"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e92-true-d12829197e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12826018e92-true-d12829197e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829207e13-true-d12829231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4524"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12829207e13-true-d12829231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12829207e13-true-d12829231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829252e13-true-d12829276e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4523"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12829252e13-true-d12829276e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12829252e13-true-d12829276e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829297e13-true-d12829321e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4522"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12829297e13-true-d12829321e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12829297e13-true-d12829321e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829342e13-true-d12829376e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4521"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12829342e13-true-d12829376e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12829342e13-true-d12829376e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12826018e97-true-d12829420e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4520"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12826018e97-true-d12829420e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12826018e97-true-d12829420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829408e2-true-d12829447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4519"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12829408e2-true-d12829447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12829408e2-true-d12829447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e16-true-d12831007e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4518"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e16-true-d12831007e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12829468e16-true-d12831007e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e95-true-d12831123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4517"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e95-true-d12831123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12829468e95-true-d12831123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831100e9-true-d12831167e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4516"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831100e9-true-d12831167e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12831100e9-true-d12831167e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831100e29-true-d12831216e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4515"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831100e29-true-d12831216e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12831100e29-true-d12831216e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e99-true-d12831252e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4514"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e99-true-d12831252e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12829468e99-true-d12831252e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831240e2-true-d12831272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4513"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831240e2-true-d12831272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12831240e2-true-d12831272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831240e8-true-d12831313e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4512"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831240e8-true-d12831313e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12831240e8-true-d12831313e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e103-true-d12831390e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="4511"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e103-true-d12831390e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12829468e103-true-d12831390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831342e5-true-d12831446e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="4510"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831342e5-true-d12831446e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12831342e5-true-d12831446e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831456e13-true-d12831473e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="4509"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12831456e13-true-d12831473e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12831456e13-true-d12831473e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831488e13-true-d12831516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="4508"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12831488e13-true-d12831516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12831488e13-true-d12831516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831342e24-true-d12831577e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4507"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831342e24-true-d12831577e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12831342e24-true-d12831577e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831540e12-true-d12831645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4506"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831540e12-true-d12831645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12831540e12-true-d12831645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831540e35-true-d12831704e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4505"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831540e35-true-d12831704e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12831540e35-true-d12831704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e111-true-d12831799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4504"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e111-true-d12831799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12829468e111-true-d12831799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831735e9-true-d12831859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4503"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831735e9-true-d12831859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12831735e9-true-d12831859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e115-true-d12831981e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4502"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e115-true-d12831981e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12829468e115-true-d12831981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831908e10-true-d12832073e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4501"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831908e10-true-d12832073e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12831908e10-true-d12832073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831908e30-true-d12832112e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4500"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831908e30-true-d12832112e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12831908e30-true-d12832112e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831908e34-true-d12832151e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4499"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831908e34-true-d12832151e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12831908e34-true-d12832151e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12831908e39-true-d12832212e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4498"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12831908e39-true-d12832212e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12831908e39-true-d12832212e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832175e12-true-d12832280e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4497"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832175e12-true-d12832280e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12832175e12-true-d12832280e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832175e35-true-d12832339e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4496"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832175e35-true-d12832339e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12832175e35-true-d12832339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e119-true-d12832436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4495"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e119-true-d12832436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12829468e119-true-d12832436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832370e7-true-d12832511e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4494"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832370e7-true-d12832511e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12832370e7-true-d12832511e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832441e9-true-d12832550e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4493"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832441e9-true-d12832550e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12832441e9-true-d12832550e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832441e10-true-d12832598e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4492"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832441e10-true-d12832598e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12832441e10-true-d12832598e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832561e12-true-d12832666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4491"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832561e12-true-d12832666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12832561e12-true-d12832666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832561e35-true-d12832725e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4490"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832561e35-true-d12832725e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12832561e35-true-d12832725e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832370e11-true-d12832802e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4489"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832370e11-true-d12832802e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12832370e11-true-d12832802e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832756e16-true-d12832843e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4488"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832756e16-true-d12832843e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12832756e16-true-d12832843e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e124-true-d12832915e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4487"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e124-true-d12832915e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12829468e124-true-d12832915e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832854e15-true-d12832991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4486"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832854e15-true-d12832991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12832854e15-true-d12832991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832854e35-true-d12833046e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4485"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832854e35-true-d12833046e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12832854e35-true-d12833046e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832854e39-true-d12833103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4484"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832854e39-true-d12833103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12832854e39-true-d12833103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12832854e42-true-d12833157e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4483"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12832854e42-true-d12833157e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12832854e42-true-d12833157e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e151-true-d12833226e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4482"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e151-true-d12833226e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12829468e151-true-d12833226e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833236e13-true-d12833260e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4481"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12833236e13-true-d12833260e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12833236e13-true-d12833260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833281e13-true-d12833305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4480"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12833281e13-true-d12833305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12833281e13-true-d12833305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833326e13-true-d12833350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4479"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12833326e13-true-d12833350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12833326e13-true-d12833350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833371e13-true-d12833405e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4478"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12833371e13-true-d12833405e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12833371e13-true-d12833405e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12829468e156-true-d12833449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4477"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12829468e156-true-d12833449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12829468e156-true-d12833449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833437e2-true-d12833476e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4476"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12833437e2-true-d12833476e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12833437e2-true-d12833476e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e16-true-d12835003e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4475"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e16-true-d12835003e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12833497e16-true-d12835003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e71-true-d12835095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4474"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e71-true-d12835095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12833497e71-true-d12835095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835072e9-true-d12835139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4473"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835072e9-true-d12835139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12835072e9-true-d12835139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835072e29-true-d12835188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4472"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835072e29-true-d12835188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12835072e29-true-d12835188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e76-true-d12835224e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4471"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e76-true-d12835224e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12833497e76-true-d12835224e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835212e2-true-d12835244e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4470"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835212e2-true-d12835244e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12835212e2-true-d12835244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835212e8-true-d12835285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4469"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835212e8-true-d12835285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12835212e8-true-d12835285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e80-true-d12835362e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="4468"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e80-true-d12835362e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12833497e80-true-d12835362e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835314e5-true-d12835418e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="4467"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835314e5-true-d12835418e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12835314e5-true-d12835418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835428e13-true-d12835445e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="4466"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12835428e13-true-d12835445e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12835428e13-true-d12835445e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835460e13-true-d12835488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="4465"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12835460e13-true-d12835488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12835460e13-true-d12835488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835314e24-true-d12835549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4464"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835314e24-true-d12835549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12835314e24-true-d12835549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835512e12-true-d12835617e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4463"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835512e12-true-d12835617e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12835512e12-true-d12835617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835512e35-true-d12835676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4462"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835512e35-true-d12835676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12835512e35-true-d12835676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e87-true-d12835771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4461"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e87-true-d12835771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12833497e87-true-d12835771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835707e9-true-d12835831e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4460"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835707e9-true-d12835831e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12835707e9-true-d12835831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e92-true-d12835953e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4459"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e92-true-d12835953e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12833497e92-true-d12835953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835880e10-true-d12836045e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4458"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835880e10-true-d12836045e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12835880e10-true-d12836045e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835880e30-true-d12836084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4457"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835880e30-true-d12836084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12835880e30-true-d12836084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835880e34-true-d12836123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4456"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835880e34-true-d12836123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12835880e34-true-d12836123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12835880e39-true-d12836184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4455"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12835880e39-true-d12836184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12835880e39-true-d12836184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836147e12-true-d12836252e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4454"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836147e12-true-d12836252e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12836147e12-true-d12836252e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836147e35-true-d12836311e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4453"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836147e35-true-d12836311e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12836147e35-true-d12836311e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e96-true-d12836408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4452"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e96-true-d12836408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12833497e96-true-d12836408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836342e7-true-d12836483e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4451"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836342e7-true-d12836483e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12836342e7-true-d12836483e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836413e9-true-d12836522e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4450"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836413e9-true-d12836522e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12836413e9-true-d12836522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836413e10-true-d12836570e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4449"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836413e10-true-d12836570e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12836413e10-true-d12836570e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836533e12-true-d12836638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4448"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836533e12-true-d12836638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12836533e12-true-d12836638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836533e35-true-d12836697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4447"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836533e35-true-d12836697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12836533e35-true-d12836697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836342e11-true-d12836774e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4446"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836342e11-true-d12836774e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12836342e11-true-d12836774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836728e16-true-d12836815e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4445"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836728e16-true-d12836815e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12836728e16-true-d12836815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e100-true-d12836887e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4444"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e100-true-d12836887e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12833497e100-true-d12836887e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836826e15-true-d12836963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4443"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836826e15-true-d12836963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12836826e15-true-d12836963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836826e35-true-d12837018e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4442"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836826e35-true-d12837018e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12836826e35-true-d12837018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836826e39-true-d12837075e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4441"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836826e39-true-d12837075e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12836826e39-true-d12837075e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12836826e42-true-d12837129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4440"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12836826e42-true-d12837129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12836826e42-true-d12837129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e128-true-d12837198e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4439"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e128-true-d12837198e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12833497e128-true-d12837198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837208e13-true-d12837232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4438"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12837208e13-true-d12837232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12837208e13-true-d12837232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837253e13-true-d12837277e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4437"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12837253e13-true-d12837277e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12837253e13-true-d12837277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837298e13-true-d12837322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4436"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12837298e13-true-d12837322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12837298e13-true-d12837322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837343e13-true-d12837377e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4435"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12837343e13-true-d12837377e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12837343e13-true-d12837377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12833497e132-true-d12837421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4434"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12833497e132-true-d12837421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12833497e132-true-d12837421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837409e2-true-d12837448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4433"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12837409e2-true-d12837448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12837409e2-true-d12837448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e128-true-d12837506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4432"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e128-true-d12837506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12796112e128-true-d12837506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837516e13-true-d12837540e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4431"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12837516e13-true-d12837540e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12837516e13-true-d12837540e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837561e13-true-d12837585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4430"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12837561e13-true-d12837585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12837561e13-true-d12837585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837606e13-true-d12837630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4429"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12837606e13-true-d12837630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12837606e13-true-d12837630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837651e13-true-d12837685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4428"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12837651e13-true-d12837685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12837651e13-true-d12837685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12796112e132-true-d12837729e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4427"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12796112e132-true-d12837729e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12796112e132-true-d12837729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837717e2-true-d12837756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4426"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12837717e2-true-d12837756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12837717e2-true-d12837756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12456834e50-true-d12837799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="4425"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12456834e50-true-d12837799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d12456834e50-true-d12837799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837784e1-true-d12837864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="4424"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12837784e1-true-d12837864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12837784e1-true-d12837864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5481-true-d12837937e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="4423"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5481-true-d12837937e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5481-true-d12837937e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12837916e8-true-d12838002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="4422"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12837916e8-true-d12838002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12837916e8-true-d12838002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5488-true-d12838075e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="4421"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5488-true-d12838075e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5488-true-d12838075e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838054e8-true-d12838140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="4420"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838054e8-true-d12838140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12838054e8-true-d12838140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5495-true-d12838213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="4419"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5495-true-d12838213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5495-true-d12838213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838192e8-true-d12838278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="4418"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838192e8-true-d12838278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12838192e8-true-d12838278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5502-true-d12838368e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="4417"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5502-true-d12838368e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5502-true-d12838368e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838330e8-true-d12838471e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | self::hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]])]"
                 priority="4416"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838330e8-true-d12838471e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] | hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] (rule-reference: d12838330e8-true-d12838471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838330e44-true-d12838545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="4415"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838330e44-true-d12838545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12838330e44-true-d12838545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838524e14-true-d12838604e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode | self::hl7:value)]"
                 priority="4414"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838524e14-true-d12838604e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode | hl7:value (rule-reference: d12838524e14-true-d12838604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838330e54-true-d12838674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/*[not(self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']])]"
                 priority="4413"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838330e54-true-d12838674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] (rule-reference: d12838330e54-true-d12838674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838653e14-true-d12838739e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value)]"
                 priority="4412"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838653e14-true-d12838739e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value (rule-reference: d12838653e14-true-d12838739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d19e5509-true-d12839832e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/*[not(self::hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']])]"
                 priority="4411"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d19e5509-true-d12839832e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']] (rule-reference: d19e5509-true-d12839832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838791e8-true-d12840917e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] | self::hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | self::hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:title | self::hl7:text | self::hl7:entry[@typeCode])]"
                 priority="4410"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838791e8-true-d12840917e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] | hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] | hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:title | hl7:text | hl7:entry[@typeCode] (rule-reference: d12838791e8-true-d12840917e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12838791e39-true-d12846031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/*[not(self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="4409"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.44-2018-05-08T152009.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASIC)/d12838791e39-true-d12846031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12838791e39-true-d12846031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e28-true-d12847485e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4408"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e28-true-d12847485e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12846031e28-true-d12847485e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e89-true-d12847565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4407"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e89-true-d12847565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12846031e89-true-d12847565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847542e9-true-d12847609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4406"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847542e9-true-d12847609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12847542e9-true-d12847609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847542e29-true-d12847658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4405"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847542e29-true-d12847658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12847542e29-true-d12847658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e93-true-d12847694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4404"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e93-true-d12847694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12846031e93-true-d12847694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847682e2-true-d12847714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4403"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847682e2-true-d12847714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12847682e2-true-d12847714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847682e8-true-d12847755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4402"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847682e8-true-d12847755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12847682e8-true-d12847755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e97-true-d12847848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4401"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e97-true-d12847848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12846031e97-true-d12847848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847784e9-true-d12847908e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4400"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847784e9-true-d12847908e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12847784e9-true-d12847908e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e102-true-d12848030e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4399"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e102-true-d12848030e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12846031e102-true-d12848030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847957e10-true-d12848122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4398"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847957e10-true-d12848122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12847957e10-true-d12848122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847957e30-true-d12848161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4397"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847957e30-true-d12848161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12847957e30-true-d12848161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847957e34-true-d12848200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4396"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847957e34-true-d12848200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12847957e34-true-d12848200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12847957e39-true-d12848261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4395"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12847957e39-true-d12848261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12847957e39-true-d12848261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848224e12-true-d12848329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4394"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848224e12-true-d12848329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12848224e12-true-d12848329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848224e35-true-d12848388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4393"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848224e35-true-d12848388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12848224e35-true-d12848388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e106-true-d12848485e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4392"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e106-true-d12848485e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12846031e106-true-d12848485e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848419e7-true-d12848560e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4391"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848419e7-true-d12848560e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12848419e7-true-d12848560e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848490e9-true-d12848599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4390"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848490e9-true-d12848599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12848490e9-true-d12848599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848490e10-true-d12848647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4389"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848490e10-true-d12848647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12848490e10-true-d12848647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848610e12-true-d12848715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4388"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848610e12-true-d12848715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12848610e12-true-d12848715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848610e35-true-d12848774e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4387"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848610e35-true-d12848774e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12848610e35-true-d12848774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848419e11-true-d12848851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4386"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848419e11-true-d12848851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12848419e11-true-d12848851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848805e16-true-d12848892e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4385"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848805e16-true-d12848892e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12848805e16-true-d12848892e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e110-true-d12848964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4384"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e110-true-d12848964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12846031e110-true-d12848964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848903e15-true-d12849040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4383"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848903e15-true-d12849040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12848903e15-true-d12849040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848903e35-true-d12849095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4382"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848903e35-true-d12849095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12848903e35-true-d12849095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848903e39-true-d12849152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4381"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848903e39-true-d12849152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12848903e39-true-d12849152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12848903e42-true-d12849206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4380"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12848903e42-true-d12849206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12848903e42-true-d12849206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e115-true-d12854313e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="4379"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e115-true-d12854313e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12846031e115-true-d12854313e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e16-true-d12855778e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4378"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e16-true-d12855778e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12854328e16-true-d12855778e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e77-true-d12855858e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4377"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e77-true-d12855858e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12854328e77-true-d12855858e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12855835e9-true-d12855902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4376"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12855835e9-true-d12855902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12855835e9-true-d12855902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12855835e29-true-d12855951e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4375"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12855835e29-true-d12855951e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12855835e29-true-d12855951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e81-true-d12855987e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4374"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e81-true-d12855987e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12854328e81-true-d12855987e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12855975e2-true-d12856007e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4373"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12855975e2-true-d12856007e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12855975e2-true-d12856007e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12855975e8-true-d12856048e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4372"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12855975e8-true-d12856048e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12855975e8-true-d12856048e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e85-true-d12856141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4371"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e85-true-d12856141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12854328e85-true-d12856141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856077e9-true-d12856201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4370"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856077e9-true-d12856201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12856077e9-true-d12856201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e90-true-d12856323e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4369"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e90-true-d12856323e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12854328e90-true-d12856323e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856250e10-true-d12856415e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4368"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856250e10-true-d12856415e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12856250e10-true-d12856415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856250e30-true-d12856454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4367"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856250e30-true-d12856454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12856250e30-true-d12856454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856250e34-true-d12856493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4366"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856250e34-true-d12856493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12856250e34-true-d12856493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856250e39-true-d12856554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4365"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856250e39-true-d12856554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12856250e39-true-d12856554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856517e12-true-d12856622e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4364"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856517e12-true-d12856622e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12856517e12-true-d12856622e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856517e35-true-d12856681e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4363"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856517e35-true-d12856681e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12856517e35-true-d12856681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e94-true-d12856778e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4362"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e94-true-d12856778e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12854328e94-true-d12856778e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856712e7-true-d12856853e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4361"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856712e7-true-d12856853e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12856712e7-true-d12856853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856783e9-true-d12856892e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4360"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856783e9-true-d12856892e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12856783e9-true-d12856892e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856783e10-true-d12856940e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4359"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856783e10-true-d12856940e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12856783e10-true-d12856940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856903e12-true-d12857008e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4358"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856903e12-true-d12857008e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12856903e12-true-d12857008e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856903e35-true-d12857067e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4357"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856903e35-true-d12857067e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12856903e35-true-d12857067e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12856712e11-true-d12857144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4356"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12856712e11-true-d12857144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12856712e11-true-d12857144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857098e16-true-d12857185e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4355"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12857098e16-true-d12857185e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12857098e16-true-d12857185e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e98-true-d12857257e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4354"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e98-true-d12857257e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12854328e98-true-d12857257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857196e15-true-d12857333e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4353"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12857196e15-true-d12857333e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12857196e15-true-d12857333e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857196e35-true-d12857388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4352"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12857196e35-true-d12857388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12857196e35-true-d12857388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857196e39-true-d12857445e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4351"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12857196e39-true-d12857445e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12857196e39-true-d12857445e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857196e42-true-d12857499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4350"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12857196e42-true-d12857499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12857196e42-true-d12857499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e126-true-d12857568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4349"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e126-true-d12857568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12854328e126-true-d12857568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857578e13-true-d12857602e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4348"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12857578e13-true-d12857602e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12857578e13-true-d12857602e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857623e13-true-d12857647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4347"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12857623e13-true-d12857647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12857623e13-true-d12857647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857668e13-true-d12857692e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4346"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12857668e13-true-d12857692e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12857668e13-true-d12857692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857713e13-true-d12857747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4345"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12857713e13-true-d12857747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12857713e13-true-d12857747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12854328e130-true-d12857791e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4344"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12854328e130-true-d12857791e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12854328e130-true-d12857791e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857779e2-true-d12857818e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4343"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12857779e2-true-d12857818e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12857779e2-true-d12857818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e16-true-d12859282e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4342"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e16-true-d12859282e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12857839e16-true-d12859282e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e65-true-d12859356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4341"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e65-true-d12859356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12857839e65-true-d12859356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859333e9-true-d12859400e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4340"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859333e9-true-d12859400e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12859333e9-true-d12859400e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859333e29-true-d12859449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4339"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859333e29-true-d12859449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12859333e29-true-d12859449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e69-true-d12859485e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4338"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e69-true-d12859485e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12857839e69-true-d12859485e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859473e2-true-d12859505e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4337"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859473e2-true-d12859505e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12859473e2-true-d12859505e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859473e8-true-d12859546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4336"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859473e8-true-d12859546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12859473e8-true-d12859546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e73-true-d12859639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4335"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e73-true-d12859639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12857839e73-true-d12859639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859575e9-true-d12859699e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4334"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859575e9-true-d12859699e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12859575e9-true-d12859699e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e78-true-d12859821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4333"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e78-true-d12859821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12857839e78-true-d12859821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859748e10-true-d12859913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4332"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859748e10-true-d12859913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12859748e10-true-d12859913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859748e30-true-d12859952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4331"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859748e30-true-d12859952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12859748e30-true-d12859952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859748e34-true-d12859991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4330"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859748e34-true-d12859991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12859748e34-true-d12859991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12859748e39-true-d12860052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4329"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12859748e39-true-d12860052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12859748e39-true-d12860052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860015e12-true-d12860120e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4328"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860015e12-true-d12860120e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12860015e12-true-d12860120e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860015e35-true-d12860179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4327"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860015e35-true-d12860179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12860015e35-true-d12860179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e82-true-d12860276e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4326"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e82-true-d12860276e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12857839e82-true-d12860276e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860210e7-true-d12860351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4325"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860210e7-true-d12860351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12860210e7-true-d12860351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860281e9-true-d12860390e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4324"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860281e9-true-d12860390e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12860281e9-true-d12860390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860281e10-true-d12860438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4323"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860281e10-true-d12860438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12860281e10-true-d12860438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860401e12-true-d12860506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4322"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860401e12-true-d12860506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12860401e12-true-d12860506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860401e35-true-d12860565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4321"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860401e35-true-d12860565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12860401e35-true-d12860565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860210e11-true-d12860642e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4320"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860210e11-true-d12860642e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12860210e11-true-d12860642e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860596e16-true-d12860683e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4319"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860596e16-true-d12860683e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12860596e16-true-d12860683e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e86-true-d12860755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4318"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e86-true-d12860755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12857839e86-true-d12860755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860694e15-true-d12860831e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4317"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860694e15-true-d12860831e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12860694e15-true-d12860831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860694e35-true-d12860886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4316"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860694e35-true-d12860886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12860694e35-true-d12860886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860694e39-true-d12860943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4315"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860694e39-true-d12860943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12860694e39-true-d12860943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12860694e42-true-d12860997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4314"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12860694e42-true-d12860997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12860694e42-true-d12860997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e114-true-d12861066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4313"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e114-true-d12861066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12857839e114-true-d12861066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861076e13-true-d12861100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4312"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12861076e13-true-d12861100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12861076e13-true-d12861100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861121e13-true-d12861145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4311"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12861121e13-true-d12861145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12861121e13-true-d12861145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861166e13-true-d12861190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4310"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12861166e13-true-d12861190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12861166e13-true-d12861190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861211e13-true-d12861245e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4309"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12861211e13-true-d12861245e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12861211e13-true-d12861245e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12857839e118-true-d12861289e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4308"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12857839e118-true-d12861289e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12857839e118-true-d12861289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861277e2-true-d12861316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4307"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12861277e2-true-d12861316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12861277e2-true-d12861316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e16-true-d12862840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="4306"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e16-true-d12862840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12861337e16-true-d12862840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e100-true-d12862959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4305"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e100-true-d12862959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12861337e100-true-d12862959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12862936e9-true-d12863003e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4304"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12862936e9-true-d12863003e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12862936e9-true-d12863003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12862936e29-true-d12863052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4303"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12862936e29-true-d12863052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12862936e29-true-d12863052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e104-true-d12863088e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4302"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e104-true-d12863088e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12861337e104-true-d12863088e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863076e2-true-d12863108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4301"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863076e2-true-d12863108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12863076e2-true-d12863108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863076e8-true-d12863149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4300"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863076e8-true-d12863149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12863076e8-true-d12863149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e108-true-d12863242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4299"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e108-true-d12863242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12861337e108-true-d12863242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863178e9-true-d12863302e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4298"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863178e9-true-d12863302e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12863178e9-true-d12863302e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e113-true-d12863424e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4297"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e113-true-d12863424e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12861337e113-true-d12863424e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863351e10-true-d12863516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4296"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863351e10-true-d12863516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12863351e10-true-d12863516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863351e30-true-d12863555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4295"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863351e30-true-d12863555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12863351e30-true-d12863555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863351e34-true-d12863594e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4294"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863351e34-true-d12863594e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12863351e34-true-d12863594e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863351e39-true-d12863655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4293"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863351e39-true-d12863655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12863351e39-true-d12863655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863618e12-true-d12863723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4292"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863618e12-true-d12863723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12863618e12-true-d12863723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863618e35-true-d12863782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4291"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863618e35-true-d12863782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12863618e35-true-d12863782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e117-true-d12863879e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4290"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e117-true-d12863879e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12861337e117-true-d12863879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863813e7-true-d12863954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4289"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863813e7-true-d12863954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12863813e7-true-d12863954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863884e9-true-d12863993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4288"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863884e9-true-d12863993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12863884e9-true-d12863993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863884e10-true-d12864041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4287"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863884e10-true-d12864041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12863884e10-true-d12864041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864004e12-true-d12864109e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4286"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864004e12-true-d12864109e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12864004e12-true-d12864109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864004e35-true-d12864168e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4285"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864004e35-true-d12864168e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12864004e35-true-d12864168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12863813e11-true-d12864245e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4284"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12863813e11-true-d12864245e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12863813e11-true-d12864245e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864199e16-true-d12864286e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4283"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864199e16-true-d12864286e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12864199e16-true-d12864286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e121-true-d12864358e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4282"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e121-true-d12864358e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12861337e121-true-d12864358e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864297e15-true-d12864434e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4281"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864297e15-true-d12864434e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12864297e15-true-d12864434e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864297e35-true-d12864489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4280"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864297e35-true-d12864489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12864297e35-true-d12864489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864297e39-true-d12864546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4279"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864297e39-true-d12864546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12864297e39-true-d12864546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864297e42-true-d12864600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4278"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864297e42-true-d12864600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12864297e42-true-d12864600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e149-true-d12864669e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4277"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e149-true-d12864669e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12861337e149-true-d12864669e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864679e13-true-d12864703e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4276"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12864679e13-true-d12864703e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12864679e13-true-d12864703e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864724e13-true-d12864748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4275"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12864724e13-true-d12864748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12864724e13-true-d12864748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864769e13-true-d12864793e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4274"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12864769e13-true-d12864793e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12864769e13-true-d12864793e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864814e13-true-d12864848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4273"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12864814e13-true-d12864848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12864814e13-true-d12864848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e153-true-d12864892e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4272"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e153-true-d12864892e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12861337e153-true-d12864892e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12864880e2-true-d12864919e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4271"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12864880e2-true-d12864919e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12864880e2-true-d12864919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e158-true-d12864950e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="4270"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e158-true-d12864950e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12861337e158-true-d12864950e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12861337e162-true-d12864988e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="4269"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12861337e162-true-d12864988e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12861337e162-true-d12864988e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e16-true-d12866433e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4268"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e16-true-d12866433e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12865017e16-true-d12866433e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e43-true-d12866486e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4267"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e43-true-d12866486e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12865017e43-true-d12866486e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866463e9-true-d12866530e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4266"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866463e9-true-d12866530e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12866463e9-true-d12866530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866463e29-true-d12866579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4265"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866463e29-true-d12866579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12866463e29-true-d12866579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e47-true-d12866615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4264"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e47-true-d12866615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12865017e47-true-d12866615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866603e2-true-d12866635e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4263"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866603e2-true-d12866635e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12866603e2-true-d12866635e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866603e8-true-d12866676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4262"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866603e8-true-d12866676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12866603e8-true-d12866676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e52-true-d12866769e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4261"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e52-true-d12866769e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12865017e52-true-d12866769e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866705e9-true-d12866829e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4260"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866705e9-true-d12866829e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12866705e9-true-d12866829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e56-true-d12866951e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4259"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e56-true-d12866951e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12865017e56-true-d12866951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866878e10-true-d12867043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4258"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866878e10-true-d12867043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12866878e10-true-d12867043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866878e30-true-d12867082e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4257"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866878e30-true-d12867082e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12866878e30-true-d12867082e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866878e34-true-d12867121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4256"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866878e34-true-d12867121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12866878e34-true-d12867121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12866878e39-true-d12867182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4255"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12866878e39-true-d12867182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12866878e39-true-d12867182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867145e12-true-d12867250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4254"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867145e12-true-d12867250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12867145e12-true-d12867250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867145e35-true-d12867309e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4253"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867145e35-true-d12867309e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12867145e35-true-d12867309e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e60-true-d12867406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4252"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e60-true-d12867406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12865017e60-true-d12867406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867340e7-true-d12867481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4251"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867340e7-true-d12867481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12867340e7-true-d12867481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867411e9-true-d12867520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4250"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867411e9-true-d12867520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12867411e9-true-d12867520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867411e10-true-d12867568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4249"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867411e10-true-d12867568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12867411e10-true-d12867568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867531e12-true-d12867636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4248"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867531e12-true-d12867636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12867531e12-true-d12867636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867531e35-true-d12867695e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4247"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867531e35-true-d12867695e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12867531e35-true-d12867695e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867340e11-true-d12867772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4246"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867340e11-true-d12867772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12867340e11-true-d12867772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867726e16-true-d12867813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4245"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867726e16-true-d12867813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12867726e16-true-d12867813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e65-true-d12867885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4244"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e65-true-d12867885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12865017e65-true-d12867885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867824e15-true-d12867961e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4243"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867824e15-true-d12867961e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12867824e15-true-d12867961e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867824e35-true-d12868016e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4242"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867824e35-true-d12868016e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12867824e35-true-d12868016e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867824e39-true-d12868073e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4241"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867824e39-true-d12868073e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12867824e39-true-d12868073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12867824e42-true-d12868127e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4240"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12867824e42-true-d12868127e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12867824e42-true-d12868127e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e92-true-d12868196e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4239"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e92-true-d12868196e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12865017e92-true-d12868196e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868206e13-true-d12868230e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4238"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12868206e13-true-d12868230e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12868206e13-true-d12868230e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868251e13-true-d12868275e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4237"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12868251e13-true-d12868275e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12868251e13-true-d12868275e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868296e13-true-d12868320e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4236"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12868296e13-true-d12868320e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12868296e13-true-d12868320e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868341e13-true-d12868375e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4235"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12868341e13-true-d12868375e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12868341e13-true-d12868375e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12865017e97-true-d12868419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4234"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12865017e97-true-d12868419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12865017e97-true-d12868419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868407e2-true-d12868446e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4233"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12868407e2-true-d12868446e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12868407e2-true-d12868446e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e16-true-d12869890e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="4232"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e16-true-d12869890e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12868467e16-true-d12869890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e53-true-d12869949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4231"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e53-true-d12869949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12868467e53-true-d12869949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12869926e9-true-d12869993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4230"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12869926e9-true-d12869993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12869926e9-true-d12869993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12869926e29-true-d12870042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4229"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12869926e29-true-d12870042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12869926e29-true-d12870042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e58-true-d12870078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4228"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e58-true-d12870078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12868467e58-true-d12870078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870066e2-true-d12870098e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4227"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870066e2-true-d12870098e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12870066e2-true-d12870098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870066e8-true-d12870139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4226"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870066e8-true-d12870139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12870066e8-true-d12870139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e62-true-d12870232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4225"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e62-true-d12870232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12868467e62-true-d12870232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870168e9-true-d12870292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4224"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870168e9-true-d12870292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12870168e9-true-d12870292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e66-true-d12870414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4223"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e66-true-d12870414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12868467e66-true-d12870414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870341e10-true-d12870506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4222"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870341e10-true-d12870506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12870341e10-true-d12870506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870341e30-true-d12870545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4221"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870341e30-true-d12870545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12870341e30-true-d12870545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870341e34-true-d12870584e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4220"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870341e34-true-d12870584e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12870341e34-true-d12870584e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870341e39-true-d12870645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4219"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870341e39-true-d12870645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12870341e39-true-d12870645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870608e12-true-d12870713e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4218"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870608e12-true-d12870713e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12870608e12-true-d12870713e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870608e35-true-d12870772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4217"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870608e35-true-d12870772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12870608e35-true-d12870772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e71-true-d12870869e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4216"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e71-true-d12870869e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12868467e71-true-d12870869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870803e7-true-d12870944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4215"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870803e7-true-d12870944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12870803e7-true-d12870944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870874e9-true-d12870983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4214"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870874e9-true-d12870983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12870874e9-true-d12870983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870874e10-true-d12871031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4213"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870874e10-true-d12871031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12870874e10-true-d12871031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870994e12-true-d12871099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4212"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870994e12-true-d12871099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12870994e12-true-d12871099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870994e35-true-d12871158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4211"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870994e35-true-d12871158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12870994e35-true-d12871158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12870803e11-true-d12871235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4210"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12870803e11-true-d12871235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12870803e11-true-d12871235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871189e16-true-d12871276e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4209"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12871189e16-true-d12871276e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12871189e16-true-d12871276e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e75-true-d12871348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4208"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e75-true-d12871348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12868467e75-true-d12871348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871287e15-true-d12871424e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4207"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12871287e15-true-d12871424e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12871287e15-true-d12871424e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871287e35-true-d12871479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4206"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12871287e35-true-d12871479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12871287e35-true-d12871479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871287e39-true-d12871536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4205"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12871287e39-true-d12871536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12871287e39-true-d12871536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871287e42-true-d12871590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4204"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12871287e42-true-d12871590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12871287e42-true-d12871590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e81-true-d12871650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4203"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e81-true-d12871650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12868467e81-true-d12871650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871660e13-true-d12871684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4202"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12871660e13-true-d12871684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12871660e13-true-d12871684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871705e13-true-d12871729e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4201"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12871705e13-true-d12871729e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12871705e13-true-d12871729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871750e13-true-d12871774e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4200"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12871750e13-true-d12871774e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12871750e13-true-d12871774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871795e13-true-d12871829e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4199"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12871795e13-true-d12871829e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12871795e13-true-d12871829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12868467e86-true-d12871873e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4198"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12868467e86-true-d12871873e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12868467e86-true-d12871873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871861e2-true-d12871900e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4197"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12871861e2-true-d12871900e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12871861e2-true-d12871900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e16-true-d12873401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4196"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e16-true-d12873401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12871930e16-true-d12873401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e87-true-d12873499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4195"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e87-true-d12873499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12871930e87-true-d12873499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873476e9-true-d12873543e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4194"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873476e9-true-d12873543e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12873476e9-true-d12873543e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873476e29-true-d12873592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4193"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873476e29-true-d12873592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12873476e29-true-d12873592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e92-true-d12873628e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4192"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e92-true-d12873628e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12871930e92-true-d12873628e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873616e2-true-d12873648e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4191"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873616e2-true-d12873648e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12873616e2-true-d12873648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873616e8-true-d12873689e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4190"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873616e8-true-d12873689e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12873616e8-true-d12873689e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e96-true-d12873782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4189"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e96-true-d12873782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12871930e96-true-d12873782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873718e9-true-d12873842e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4188"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873718e9-true-d12873842e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12873718e9-true-d12873842e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e100-true-d12873964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4187"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e100-true-d12873964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12871930e100-true-d12873964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873891e10-true-d12874056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4186"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873891e10-true-d12874056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12873891e10-true-d12874056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873891e30-true-d12874095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4185"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873891e30-true-d12874095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12873891e30-true-d12874095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873891e34-true-d12874134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4184"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873891e34-true-d12874134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12873891e34-true-d12874134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12873891e39-true-d12874195e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4183"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12873891e39-true-d12874195e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12873891e39-true-d12874195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874158e12-true-d12874263e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4182"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874158e12-true-d12874263e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12874158e12-true-d12874263e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874158e35-true-d12874322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4181"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874158e35-true-d12874322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12874158e35-true-d12874322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e105-true-d12874419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4180"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e105-true-d12874419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12871930e105-true-d12874419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874353e7-true-d12874494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4179"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874353e7-true-d12874494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12874353e7-true-d12874494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874424e9-true-d12874533e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4178"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874424e9-true-d12874533e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12874424e9-true-d12874533e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874424e10-true-d12874581e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4177"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874424e10-true-d12874581e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12874424e10-true-d12874581e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874544e12-true-d12874649e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4176"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874544e12-true-d12874649e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12874544e12-true-d12874649e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874544e35-true-d12874708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4175"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874544e35-true-d12874708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12874544e35-true-d12874708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874353e11-true-d12874785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4174"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874353e11-true-d12874785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12874353e11-true-d12874785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874739e16-true-d12874826e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4173"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874739e16-true-d12874826e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12874739e16-true-d12874826e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e109-true-d12874898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4172"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e109-true-d12874898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12871930e109-true-d12874898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874837e15-true-d12874974e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4171"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874837e15-true-d12874974e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12874837e15-true-d12874974e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874837e35-true-d12875029e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4170"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874837e35-true-d12875029e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12874837e35-true-d12875029e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874837e39-true-d12875086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4169"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874837e39-true-d12875086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12874837e39-true-d12875086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12874837e42-true-d12875140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4168"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12874837e42-true-d12875140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12874837e42-true-d12875140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e137-true-d12875209e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4167"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e137-true-d12875209e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12871930e137-true-d12875209e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875219e13-true-d12875243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4166"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12875219e13-true-d12875243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12875219e13-true-d12875243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875264e13-true-d12875288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4165"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12875264e13-true-d12875288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12875264e13-true-d12875288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875309e13-true-d12875333e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4164"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12875309e13-true-d12875333e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12875309e13-true-d12875333e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875354e13-true-d12875388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4163"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12875354e13-true-d12875388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12875354e13-true-d12875388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12871930e141-true-d12875432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4162"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12871930e141-true-d12875432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12871930e141-true-d12875432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875420e2-true-d12875459e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4161"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12875420e2-true-d12875459e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12875420e2-true-d12875459e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e16-true-d12876896e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4160"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e16-true-d12876896e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12875480e16-true-d12876896e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e43-true-d12876949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4159"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e43-true-d12876949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12875480e43-true-d12876949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12876926e9-true-d12876993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4158"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12876926e9-true-d12876993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12876926e9-true-d12876993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12876926e29-true-d12877042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4157"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12876926e29-true-d12877042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12876926e29-true-d12877042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e47-true-d12877078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4156"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e47-true-d12877078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12875480e47-true-d12877078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877066e2-true-d12877098e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4155"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877066e2-true-d12877098e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12877066e2-true-d12877098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877066e8-true-d12877139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4154"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877066e8-true-d12877139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12877066e8-true-d12877139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e52-true-d12877232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4153"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e52-true-d12877232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12875480e52-true-d12877232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877168e9-true-d12877292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4152"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877168e9-true-d12877292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12877168e9-true-d12877292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e56-true-d12877414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4151"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e56-true-d12877414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12875480e56-true-d12877414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877341e10-true-d12877506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4150"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877341e10-true-d12877506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12877341e10-true-d12877506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877341e30-true-d12877545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4149"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877341e30-true-d12877545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12877341e30-true-d12877545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877341e34-true-d12877584e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4148"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877341e34-true-d12877584e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12877341e34-true-d12877584e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877341e39-true-d12877645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4147"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877341e39-true-d12877645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12877341e39-true-d12877645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877608e12-true-d12877713e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4146"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877608e12-true-d12877713e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12877608e12-true-d12877713e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877608e35-true-d12877772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4145"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877608e35-true-d12877772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12877608e35-true-d12877772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e60-true-d12877869e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4144"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e60-true-d12877869e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12875480e60-true-d12877869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877803e7-true-d12877944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4143"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877803e7-true-d12877944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12877803e7-true-d12877944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877874e9-true-d12877983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4142"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877874e9-true-d12877983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12877874e9-true-d12877983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877874e10-true-d12878031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4141"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877874e10-true-d12878031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12877874e10-true-d12878031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877994e12-true-d12878099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4140"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877994e12-true-d12878099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12877994e12-true-d12878099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877994e35-true-d12878158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4139"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877994e35-true-d12878158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12877994e35-true-d12878158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12877803e11-true-d12878235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4138"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12877803e11-true-d12878235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12877803e11-true-d12878235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878189e16-true-d12878276e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4137"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12878189e16-true-d12878276e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12878189e16-true-d12878276e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e65-true-d12878348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4136"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e65-true-d12878348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12875480e65-true-d12878348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878287e15-true-d12878424e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4135"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12878287e15-true-d12878424e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12878287e15-true-d12878424e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878287e35-true-d12878479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4134"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12878287e35-true-d12878479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12878287e35-true-d12878479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878287e39-true-d12878536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4133"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12878287e39-true-d12878536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12878287e39-true-d12878536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878287e42-true-d12878590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4132"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12878287e42-true-d12878590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12878287e42-true-d12878590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e92-true-d12878659e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4131"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e92-true-d12878659e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12875480e92-true-d12878659e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878669e13-true-d12878693e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4130"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12878669e13-true-d12878693e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12878669e13-true-d12878693e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878714e13-true-d12878738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4129"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12878714e13-true-d12878738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12878714e13-true-d12878738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878759e13-true-d12878783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4128"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12878759e13-true-d12878783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12878759e13-true-d12878783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878804e13-true-d12878838e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4127"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12878804e13-true-d12878838e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12878804e13-true-d12878838e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12875480e97-true-d12878882e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4126"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12875480e97-true-d12878882e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12875480e97-true-d12878882e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878870e2-true-d12878909e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4125"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12878870e2-true-d12878909e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12878870e2-true-d12878909e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e16-true-d12880469e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4124"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e16-true-d12880469e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12878930e16-true-d12880469e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e95-true-d12880585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4123"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e95-true-d12880585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12878930e95-true-d12880585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880562e9-true-d12880629e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4122"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12880562e9-true-d12880629e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12880562e9-true-d12880629e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880562e29-true-d12880678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4121"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12880562e29-true-d12880678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12880562e29-true-d12880678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e99-true-d12880714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4120"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e99-true-d12880714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12878930e99-true-d12880714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880702e2-true-d12880734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4119"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12880702e2-true-d12880734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12880702e2-true-d12880734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880702e8-true-d12880775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4118"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12880702e8-true-d12880775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12880702e8-true-d12880775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e103-true-d12880852e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="4117"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e103-true-d12880852e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12878930e103-true-d12880852e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880804e5-true-d12880908e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="4116"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12880804e5-true-d12880908e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12880804e5-true-d12880908e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880918e13-true-d12880935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="4115"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12880918e13-true-d12880935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12880918e13-true-d12880935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880950e13-true-d12880978e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="4114"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12880950e13-true-d12880978e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12880950e13-true-d12880978e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12880804e24-true-d12881039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4113"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12880804e24-true-d12881039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12880804e24-true-d12881039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881002e12-true-d12881107e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4112"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881002e12-true-d12881107e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12881002e12-true-d12881107e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881002e35-true-d12881166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4111"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881002e35-true-d12881166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12881002e35-true-d12881166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e111-true-d12881261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4110"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e111-true-d12881261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12878930e111-true-d12881261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881197e9-true-d12881321e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4109"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881197e9-true-d12881321e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12881197e9-true-d12881321e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e115-true-d12881443e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4108"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e115-true-d12881443e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12878930e115-true-d12881443e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881370e10-true-d12881535e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4107"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881370e10-true-d12881535e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12881370e10-true-d12881535e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881370e30-true-d12881574e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4106"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881370e30-true-d12881574e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12881370e30-true-d12881574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881370e34-true-d12881613e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4105"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881370e34-true-d12881613e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12881370e34-true-d12881613e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881370e39-true-d12881674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4104"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881370e39-true-d12881674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12881370e39-true-d12881674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881637e12-true-d12881742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4103"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881637e12-true-d12881742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12881637e12-true-d12881742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881637e35-true-d12881801e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4102"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881637e35-true-d12881801e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12881637e35-true-d12881801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e119-true-d12881898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4101"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e119-true-d12881898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12878930e119-true-d12881898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881832e7-true-d12881973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4100"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881832e7-true-d12881973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12881832e7-true-d12881973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881903e9-true-d12882012e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4099"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881903e9-true-d12882012e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12881903e9-true-d12882012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881903e10-true-d12882060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4098"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881903e10-true-d12882060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12881903e10-true-d12882060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882023e12-true-d12882128e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4097"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882023e12-true-d12882128e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12882023e12-true-d12882128e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882023e35-true-d12882187e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4096"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882023e35-true-d12882187e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12882023e35-true-d12882187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12881832e11-true-d12882264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4095"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12881832e11-true-d12882264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12881832e11-true-d12882264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882218e16-true-d12882305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4094"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882218e16-true-d12882305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12882218e16-true-d12882305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e124-true-d12882377e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4093"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e124-true-d12882377e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12878930e124-true-d12882377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882316e15-true-d12882453e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4092"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882316e15-true-d12882453e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12882316e15-true-d12882453e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882316e35-true-d12882508e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4091"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882316e35-true-d12882508e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12882316e35-true-d12882508e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882316e39-true-d12882565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4090"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882316e39-true-d12882565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12882316e39-true-d12882565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882316e42-true-d12882619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4089"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882316e42-true-d12882619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12882316e42-true-d12882619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e151-true-d12882688e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4088"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e151-true-d12882688e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12878930e151-true-d12882688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882698e13-true-d12882722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4087"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12882698e13-true-d12882722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12882698e13-true-d12882722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882743e13-true-d12882767e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4086"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12882743e13-true-d12882767e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12882743e13-true-d12882767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882788e13-true-d12882812e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4085"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12882788e13-true-d12882812e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12882788e13-true-d12882812e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882833e13-true-d12882867e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4084"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12882833e13-true-d12882867e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12882833e13-true-d12882867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12878930e156-true-d12882911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4083"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12878930e156-true-d12882911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12878930e156-true-d12882911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882899e2-true-d12882938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4082"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12882899e2-true-d12882938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12882899e2-true-d12882938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e16-true-d12884465e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4081"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e16-true-d12884465e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12882959e16-true-d12884465e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e71-true-d12884557e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4080"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e71-true-d12884557e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12882959e71-true-d12884557e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884534e9-true-d12884601e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4079"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884534e9-true-d12884601e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12884534e9-true-d12884601e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884534e29-true-d12884650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4078"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884534e29-true-d12884650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12884534e29-true-d12884650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e76-true-d12884686e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4077"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e76-true-d12884686e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12882959e76-true-d12884686e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884674e2-true-d12884706e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4076"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884674e2-true-d12884706e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12884674e2-true-d12884706e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884674e8-true-d12884747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4075"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884674e8-true-d12884747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12884674e8-true-d12884747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e80-true-d12884824e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="4074"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e80-true-d12884824e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12882959e80-true-d12884824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884776e5-true-d12884880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="4073"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884776e5-true-d12884880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12884776e5-true-d12884880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884890e13-true-d12884907e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="4072"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12884890e13-true-d12884907e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12884890e13-true-d12884907e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884922e13-true-d12884950e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="4071"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12884922e13-true-d12884950e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12884922e13-true-d12884950e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884776e24-true-d12885011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4070"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884776e24-true-d12885011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12884776e24-true-d12885011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884974e12-true-d12885079e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4069"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884974e12-true-d12885079e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12884974e12-true-d12885079e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12884974e35-true-d12885138e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4068"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12884974e35-true-d12885138e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12884974e35-true-d12885138e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e87-true-d12885233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4067"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e87-true-d12885233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12882959e87-true-d12885233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885169e9-true-d12885293e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4066"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885169e9-true-d12885293e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12885169e9-true-d12885293e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e92-true-d12885415e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4065"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e92-true-d12885415e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12882959e92-true-d12885415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885342e10-true-d12885507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4064"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885342e10-true-d12885507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12885342e10-true-d12885507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885342e30-true-d12885546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4063"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885342e30-true-d12885546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12885342e30-true-d12885546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885342e34-true-d12885585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4062"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885342e34-true-d12885585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12885342e34-true-d12885585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885342e39-true-d12885646e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4061"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885342e39-true-d12885646e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12885342e39-true-d12885646e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885609e12-true-d12885714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4060"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885609e12-true-d12885714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12885609e12-true-d12885714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885609e35-true-d12885773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4059"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885609e35-true-d12885773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12885609e35-true-d12885773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e96-true-d12885870e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4058"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e96-true-d12885870e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12882959e96-true-d12885870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885804e7-true-d12885945e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4057"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885804e7-true-d12885945e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12885804e7-true-d12885945e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885875e9-true-d12885984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4056"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885875e9-true-d12885984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12885875e9-true-d12885984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885875e10-true-d12886032e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4055"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885875e10-true-d12886032e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12885875e10-true-d12886032e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885995e12-true-d12886100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4054"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885995e12-true-d12886100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12885995e12-true-d12886100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885995e35-true-d12886159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4053"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885995e35-true-d12886159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12885995e35-true-d12886159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12885804e11-true-d12886236e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4052"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12885804e11-true-d12886236e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12885804e11-true-d12886236e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886190e16-true-d12886277e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4051"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12886190e16-true-d12886277e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12886190e16-true-d12886277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e100-true-d12886349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4050"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e100-true-d12886349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12882959e100-true-d12886349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886288e15-true-d12886425e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4049"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12886288e15-true-d12886425e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12886288e15-true-d12886425e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886288e35-true-d12886480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4048"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12886288e35-true-d12886480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12886288e35-true-d12886480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886288e39-true-d12886537e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4047"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12886288e39-true-d12886537e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12886288e39-true-d12886537e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886288e42-true-d12886591e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4046"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12886288e42-true-d12886591e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12886288e42-true-d12886591e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e128-true-d12886660e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4045"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e128-true-d12886660e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12882959e128-true-d12886660e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886670e13-true-d12886694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4044"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12886670e13-true-d12886694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12886670e13-true-d12886694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886715e13-true-d12886739e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4043"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12886715e13-true-d12886739e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12886715e13-true-d12886739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886760e13-true-d12886784e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4042"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12886760e13-true-d12886784e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12886760e13-true-d12886784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886805e13-true-d12886839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4041"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12886805e13-true-d12886839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12886805e13-true-d12886839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12882959e132-true-d12886883e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4040"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12882959e132-true-d12886883e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12882959e132-true-d12886883e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886871e2-true-d12886910e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4039"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12886871e2-true-d12886910e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12886871e2-true-d12886910e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e138-true-d12886968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="4038"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e138-true-d12886968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12846031e138-true-d12886968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12886978e13-true-d12887002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4037"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12886978e13-true-d12887002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12886978e13-true-d12887002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887023e13-true-d12887047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4036"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12887023e13-true-d12887047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12887023e13-true-d12887047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887068e13-true-d12887092e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="4035"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12887068e13-true-d12887092e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12887068e13-true-d12887092e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887113e13-true-d12887147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="4034"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12887113e13-true-d12887147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12887113e13-true-d12887147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12846031e142-true-d12887191e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="4033"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12846031e142-true-d12887191e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12846031e142-true-d12887191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887179e2-true-d12887218e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="4032"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12887179e2-true-d12887218e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12887179e2-true-d12887218e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e16-true-d12888682e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4031"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e16-true-d12888682e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12887239e16-true-d12888682e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e65-true-d12888756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4030"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e65-true-d12888756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12887239e65-true-d12888756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12888733e9-true-d12888800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="4029"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12888733e9-true-d12888800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12888733e9-true-d12888800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12888733e29-true-d12888849e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="4028"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12888733e29-true-d12888849e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12888733e29-true-d12888849e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e69-true-d12888885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="4027"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e69-true-d12888885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12887239e69-true-d12888885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12888873e2-true-d12888905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="4026"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12888873e2-true-d12888905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12888873e2-true-d12888905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12888873e8-true-d12888946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4025"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12888873e8-true-d12888946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12888873e8-true-d12888946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e73-true-d12889039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="4024"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e73-true-d12889039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12887239e73-true-d12889039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12888975e9-true-d12889099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4023"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12888975e9-true-d12889099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12888975e9-true-d12889099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e78-true-d12889221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="4022"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e78-true-d12889221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12887239e78-true-d12889221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889148e10-true-d12889313e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="4021"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889148e10-true-d12889313e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12889148e10-true-d12889313e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889148e30-true-d12889352e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4020"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889148e30-true-d12889352e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12889148e30-true-d12889352e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889148e34-true-d12889391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4019"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889148e34-true-d12889391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12889148e34-true-d12889391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889148e39-true-d12889452e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4018"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889148e39-true-d12889452e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12889148e39-true-d12889452e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889415e12-true-d12889520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4017"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889415e12-true-d12889520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12889415e12-true-d12889520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889415e35-true-d12889579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4016"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889415e35-true-d12889579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12889415e35-true-d12889579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e82-true-d12889676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="4015"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e82-true-d12889676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12887239e82-true-d12889676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889610e7-true-d12889751e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="4014"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889610e7-true-d12889751e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12889610e7-true-d12889751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889681e9-true-d12889790e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="4013"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889681e9-true-d12889790e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12889681e9-true-d12889790e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889681e10-true-d12889838e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="4012"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889681e10-true-d12889838e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12889681e10-true-d12889838e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889801e12-true-d12889906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="4011"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889801e12-true-d12889906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12889801e12-true-d12889906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889801e35-true-d12889965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="4010"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889801e35-true-d12889965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12889801e35-true-d12889965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889610e11-true-d12890042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="4009"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889610e11-true-d12890042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12889610e11-true-d12890042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12889996e16-true-d12890083e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="4008"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12889996e16-true-d12890083e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12889996e16-true-d12890083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e86-true-d12890155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="4007"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e86-true-d12890155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12887239e86-true-d12890155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12890094e15-true-d12890231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="4006"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12890094e15-true-d12890231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12890094e15-true-d12890231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12890094e35-true-d12890286e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="4005"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12890094e35-true-d12890286e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12890094e35-true-d12890286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12890094e39-true-d12890343e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="4004"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12890094e39-true-d12890343e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12890094e39-true-d12890343e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12890094e42-true-d12890397e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="4003"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12890094e42-true-d12890397e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12890094e42-true-d12890397e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e91-true-d12895504e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="4002"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e91-true-d12895504e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12887239e91-true-d12895504e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e16-true-d12896969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="4001"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e16-true-d12896969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12895519e16-true-d12896969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e77-true-d12897049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="4000"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e77-true-d12897049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12895519e77-true-d12897049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897026e9-true-d12897093e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3999"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897026e9-true-d12897093e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12897026e9-true-d12897093e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897026e29-true-d12897142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3998"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897026e29-true-d12897142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12897026e29-true-d12897142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e81-true-d12897178e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3997"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e81-true-d12897178e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12895519e81-true-d12897178e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897166e2-true-d12897198e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3996"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897166e2-true-d12897198e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12897166e2-true-d12897198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897166e8-true-d12897239e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3995"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897166e8-true-d12897239e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12897166e8-true-d12897239e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e85-true-d12897332e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3994"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e85-true-d12897332e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12895519e85-true-d12897332e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897268e9-true-d12897392e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3993"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897268e9-true-d12897392e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12897268e9-true-d12897392e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e90-true-d12897514e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3992"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e90-true-d12897514e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12895519e90-true-d12897514e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897441e10-true-d12897606e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3991"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897441e10-true-d12897606e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12897441e10-true-d12897606e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897441e30-true-d12897645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3990"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897441e30-true-d12897645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12897441e30-true-d12897645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897441e34-true-d12897684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3989"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897441e34-true-d12897684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12897441e34-true-d12897684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897441e39-true-d12897745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3988"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897441e39-true-d12897745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12897441e39-true-d12897745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897708e12-true-d12897813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3987"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897708e12-true-d12897813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12897708e12-true-d12897813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897708e35-true-d12897872e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3986"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897708e35-true-d12897872e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12897708e35-true-d12897872e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e94-true-d12897969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3985"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e94-true-d12897969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12895519e94-true-d12897969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897903e7-true-d12898044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3984"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897903e7-true-d12898044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12897903e7-true-d12898044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897974e9-true-d12898083e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3983"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897974e9-true-d12898083e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12897974e9-true-d12898083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897974e10-true-d12898131e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3982"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897974e10-true-d12898131e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12897974e10-true-d12898131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898094e12-true-d12898199e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3981"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898094e12-true-d12898199e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12898094e12-true-d12898199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898094e35-true-d12898258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3980"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898094e35-true-d12898258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12898094e35-true-d12898258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12897903e11-true-d12898335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3979"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12897903e11-true-d12898335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12897903e11-true-d12898335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898289e16-true-d12898376e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3978"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898289e16-true-d12898376e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12898289e16-true-d12898376e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e98-true-d12898448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3977"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e98-true-d12898448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12895519e98-true-d12898448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898387e15-true-d12898524e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3976"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898387e15-true-d12898524e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12898387e15-true-d12898524e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898387e35-true-d12898579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3975"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898387e35-true-d12898579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12898387e35-true-d12898579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898387e39-true-d12898636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3974"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898387e39-true-d12898636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12898387e39-true-d12898636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898387e42-true-d12898690e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3973"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898387e42-true-d12898690e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12898387e42-true-d12898690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e126-true-d12898759e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3972"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e126-true-d12898759e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12895519e126-true-d12898759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898769e13-true-d12898793e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3971"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12898769e13-true-d12898793e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12898769e13-true-d12898793e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898814e13-true-d12898838e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3970"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12898814e13-true-d12898838e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12898814e13-true-d12898838e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898859e13-true-d12898883e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3969"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12898859e13-true-d12898883e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12898859e13-true-d12898883e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898904e13-true-d12898938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3968"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12898904e13-true-d12898938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12898904e13-true-d12898938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12895519e130-true-d12898982e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3967"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12895519e130-true-d12898982e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12895519e130-true-d12898982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12898970e2-true-d12899009e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3966"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12898970e2-true-d12899009e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12898970e2-true-d12899009e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e16-true-d12900473e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3965"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e16-true-d12900473e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12899030e16-true-d12900473e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e65-true-d12900547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3964"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e65-true-d12900547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12899030e65-true-d12900547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900524e9-true-d12900591e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3963"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900524e9-true-d12900591e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12900524e9-true-d12900591e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900524e29-true-d12900640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3962"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900524e29-true-d12900640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12900524e29-true-d12900640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e69-true-d12900676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3961"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e69-true-d12900676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12899030e69-true-d12900676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900664e2-true-d12900696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3960"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900664e2-true-d12900696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12900664e2-true-d12900696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900664e8-true-d12900737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3959"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900664e8-true-d12900737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12900664e8-true-d12900737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e73-true-d12900830e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3958"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e73-true-d12900830e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12899030e73-true-d12900830e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900766e9-true-d12900890e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3957"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900766e9-true-d12900890e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12900766e9-true-d12900890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e78-true-d12901012e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3956"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e78-true-d12901012e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12899030e78-true-d12901012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900939e10-true-d12901104e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3955"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900939e10-true-d12901104e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12900939e10-true-d12901104e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900939e30-true-d12901143e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3954"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900939e30-true-d12901143e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12900939e30-true-d12901143e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900939e34-true-d12901182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3953"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900939e34-true-d12901182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12900939e34-true-d12901182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12900939e39-true-d12901243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3952"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12900939e39-true-d12901243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12900939e39-true-d12901243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901206e12-true-d12901311e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3951"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901206e12-true-d12901311e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12901206e12-true-d12901311e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901206e35-true-d12901370e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3950"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901206e35-true-d12901370e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12901206e35-true-d12901370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e82-true-d12901467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3949"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e82-true-d12901467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12899030e82-true-d12901467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901401e7-true-d12901542e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3948"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901401e7-true-d12901542e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12901401e7-true-d12901542e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901472e9-true-d12901581e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3947"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901472e9-true-d12901581e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12901472e9-true-d12901581e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901472e10-true-d12901629e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3946"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901472e10-true-d12901629e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12901472e10-true-d12901629e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901592e12-true-d12901697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3945"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901592e12-true-d12901697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12901592e12-true-d12901697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901592e35-true-d12901756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3944"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901592e35-true-d12901756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12901592e35-true-d12901756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901401e11-true-d12901833e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3943"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901401e11-true-d12901833e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12901401e11-true-d12901833e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901787e16-true-d12901874e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3942"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901787e16-true-d12901874e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12901787e16-true-d12901874e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e86-true-d12901946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3941"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e86-true-d12901946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12899030e86-true-d12901946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901885e15-true-d12902022e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3940"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901885e15-true-d12902022e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12901885e15-true-d12902022e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901885e35-true-d12902077e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3939"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901885e35-true-d12902077e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12901885e35-true-d12902077e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901885e39-true-d12902134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3938"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901885e39-true-d12902134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12901885e39-true-d12902134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12901885e42-true-d12902188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3937"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12901885e42-true-d12902188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12901885e42-true-d12902188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e114-true-d12902257e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3936"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e114-true-d12902257e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12899030e114-true-d12902257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902267e13-true-d12902291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3935"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12902267e13-true-d12902291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12902267e13-true-d12902291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902312e13-true-d12902336e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3934"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12902312e13-true-d12902336e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12902312e13-true-d12902336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902357e13-true-d12902381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3933"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12902357e13-true-d12902381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12902357e13-true-d12902381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902402e13-true-d12902436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3932"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12902402e13-true-d12902436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12902402e13-true-d12902436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12899030e118-true-d12902480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3931"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12899030e118-true-d12902480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12899030e118-true-d12902480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902468e2-true-d12902507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3930"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12902468e2-true-d12902507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12902468e2-true-d12902507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e16-true-d12904031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="3929"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e16-true-d12904031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12902528e16-true-d12904031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e100-true-d12904150e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3928"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e100-true-d12904150e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12902528e100-true-d12904150e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904127e9-true-d12904194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3927"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904127e9-true-d12904194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12904127e9-true-d12904194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904127e29-true-d12904243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3926"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904127e29-true-d12904243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12904127e29-true-d12904243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e104-true-d12904279e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3925"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e104-true-d12904279e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12902528e104-true-d12904279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904267e2-true-d12904299e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3924"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904267e2-true-d12904299e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12904267e2-true-d12904299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904267e8-true-d12904340e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3923"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904267e8-true-d12904340e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12904267e8-true-d12904340e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e108-true-d12904433e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3922"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e108-true-d12904433e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12902528e108-true-d12904433e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904369e9-true-d12904493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3921"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904369e9-true-d12904493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12904369e9-true-d12904493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e113-true-d12904615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3920"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e113-true-d12904615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12902528e113-true-d12904615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904542e10-true-d12904707e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3919"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904542e10-true-d12904707e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12904542e10-true-d12904707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904542e30-true-d12904746e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3918"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904542e30-true-d12904746e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12904542e30-true-d12904746e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904542e34-true-d12904785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3917"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904542e34-true-d12904785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12904542e34-true-d12904785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904542e39-true-d12904846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3916"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904542e39-true-d12904846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12904542e39-true-d12904846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904809e12-true-d12904914e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3915"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904809e12-true-d12904914e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12904809e12-true-d12904914e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12904809e35-true-d12904973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3914"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12904809e35-true-d12904973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12904809e35-true-d12904973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e117-true-d12905070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3913"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e117-true-d12905070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12902528e117-true-d12905070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905004e7-true-d12905145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3912"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905004e7-true-d12905145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12905004e7-true-d12905145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905075e9-true-d12905184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3911"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905075e9-true-d12905184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12905075e9-true-d12905184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905075e10-true-d12905232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3910"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905075e10-true-d12905232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12905075e10-true-d12905232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905195e12-true-d12905300e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3909"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905195e12-true-d12905300e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12905195e12-true-d12905300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905195e35-true-d12905359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3908"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905195e35-true-d12905359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12905195e35-true-d12905359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905004e11-true-d12905436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3907"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905004e11-true-d12905436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12905004e11-true-d12905436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905390e16-true-d12905477e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3906"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905390e16-true-d12905477e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12905390e16-true-d12905477e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e121-true-d12905549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3905"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e121-true-d12905549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12902528e121-true-d12905549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905488e15-true-d12905625e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3904"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905488e15-true-d12905625e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12905488e15-true-d12905625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905488e35-true-d12905680e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3903"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905488e35-true-d12905680e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12905488e35-true-d12905680e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905488e39-true-d12905737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3902"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905488e39-true-d12905737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12905488e39-true-d12905737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905488e42-true-d12905791e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3901"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12905488e42-true-d12905791e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12905488e42-true-d12905791e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e149-true-d12905860e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3900"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e149-true-d12905860e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12902528e149-true-d12905860e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905870e13-true-d12905894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3899"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12905870e13-true-d12905894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12905870e13-true-d12905894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905915e13-true-d12905939e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3898"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12905915e13-true-d12905939e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12905915e13-true-d12905939e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12905960e13-true-d12905984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3897"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12905960e13-true-d12905984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12905960e13-true-d12905984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906005e13-true-d12906039e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3896"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12906005e13-true-d12906039e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12906005e13-true-d12906039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e153-true-d12906083e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3895"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e153-true-d12906083e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12902528e153-true-d12906083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906071e2-true-d12906110e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3894"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12906071e2-true-d12906110e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12906071e2-true-d12906110e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e158-true-d12906141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="3893"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e158-true-d12906141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12902528e158-true-d12906141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12902528e162-true-d12906179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="3892"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12902528e162-true-d12906179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12902528e162-true-d12906179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e16-true-d12907624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3891"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e16-true-d12907624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12906208e16-true-d12907624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e43-true-d12907677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3890"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e43-true-d12907677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12906208e43-true-d12907677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12907654e9-true-d12907721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3889"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12907654e9-true-d12907721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12907654e9-true-d12907721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12907654e29-true-d12907770e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3888"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12907654e29-true-d12907770e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12907654e29-true-d12907770e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e47-true-d12907806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3887"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e47-true-d12907806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12906208e47-true-d12907806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12907794e2-true-d12907826e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3886"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12907794e2-true-d12907826e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12907794e2-true-d12907826e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12907794e8-true-d12907867e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3885"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12907794e8-true-d12907867e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12907794e8-true-d12907867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e52-true-d12907960e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3884"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e52-true-d12907960e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12906208e52-true-d12907960e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12907896e9-true-d12908020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3883"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12907896e9-true-d12908020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12907896e9-true-d12908020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e56-true-d12908142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3882"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e56-true-d12908142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12906208e56-true-d12908142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908069e10-true-d12908234e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3881"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908069e10-true-d12908234e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12908069e10-true-d12908234e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908069e30-true-d12908273e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3880"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908069e30-true-d12908273e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12908069e30-true-d12908273e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908069e34-true-d12908312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3879"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908069e34-true-d12908312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12908069e34-true-d12908312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908069e39-true-d12908373e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3878"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908069e39-true-d12908373e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12908069e39-true-d12908373e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908336e12-true-d12908441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3877"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908336e12-true-d12908441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12908336e12-true-d12908441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908336e35-true-d12908500e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3876"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908336e35-true-d12908500e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12908336e35-true-d12908500e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e60-true-d12908597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3875"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e60-true-d12908597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12906208e60-true-d12908597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908531e7-true-d12908672e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3874"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908531e7-true-d12908672e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12908531e7-true-d12908672e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908602e9-true-d12908711e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3873"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908602e9-true-d12908711e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12908602e9-true-d12908711e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908602e10-true-d12908759e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3872"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908602e10-true-d12908759e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12908602e10-true-d12908759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908722e12-true-d12908827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3871"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908722e12-true-d12908827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12908722e12-true-d12908827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908722e35-true-d12908886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3870"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908722e35-true-d12908886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12908722e35-true-d12908886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908531e11-true-d12908963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3869"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908531e11-true-d12908963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12908531e11-true-d12908963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12908917e16-true-d12909004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3868"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12908917e16-true-d12909004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12908917e16-true-d12909004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e65-true-d12909076e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3867"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e65-true-d12909076e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12906208e65-true-d12909076e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909015e15-true-d12909152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3866"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12909015e15-true-d12909152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12909015e15-true-d12909152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909015e35-true-d12909207e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3865"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12909015e35-true-d12909207e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12909015e35-true-d12909207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909015e39-true-d12909264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3864"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12909015e39-true-d12909264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12909015e39-true-d12909264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909015e42-true-d12909318e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3863"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12909015e42-true-d12909318e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12909015e42-true-d12909318e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e92-true-d12909387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3862"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e92-true-d12909387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12906208e92-true-d12909387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909397e13-true-d12909421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3861"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12909397e13-true-d12909421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12909397e13-true-d12909421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909442e13-true-d12909466e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3860"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12909442e13-true-d12909466e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12909442e13-true-d12909466e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909487e13-true-d12909511e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3859"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12909487e13-true-d12909511e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12909487e13-true-d12909511e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909532e13-true-d12909566e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3858"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12909532e13-true-d12909566e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12909532e13-true-d12909566e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12906208e97-true-d12909610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3857"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12906208e97-true-d12909610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12906208e97-true-d12909610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909598e2-true-d12909637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3856"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12909598e2-true-d12909637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12909598e2-true-d12909637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e16-true-d12911081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="3855"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e16-true-d12911081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12909658e16-true-d12911081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e53-true-d12911140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3854"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e53-true-d12911140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12909658e53-true-d12911140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911117e9-true-d12911184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3853"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911117e9-true-d12911184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12911117e9-true-d12911184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911117e29-true-d12911233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3852"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911117e29-true-d12911233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12911117e29-true-d12911233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e58-true-d12911269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3851"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e58-true-d12911269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12909658e58-true-d12911269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911257e2-true-d12911289e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3850"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911257e2-true-d12911289e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12911257e2-true-d12911289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911257e8-true-d12911330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3849"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911257e8-true-d12911330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12911257e8-true-d12911330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e62-true-d12911423e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3848"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e62-true-d12911423e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12909658e62-true-d12911423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911359e9-true-d12911483e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3847"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911359e9-true-d12911483e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12911359e9-true-d12911483e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e66-true-d12911605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3846"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e66-true-d12911605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12909658e66-true-d12911605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911532e10-true-d12911697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3845"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911532e10-true-d12911697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12911532e10-true-d12911697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911532e30-true-d12911736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3844"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911532e30-true-d12911736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12911532e30-true-d12911736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911532e34-true-d12911775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3843"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911532e34-true-d12911775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12911532e34-true-d12911775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911532e39-true-d12911836e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3842"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911532e39-true-d12911836e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12911532e39-true-d12911836e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911799e12-true-d12911904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3841"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911799e12-true-d12911904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12911799e12-true-d12911904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911799e35-true-d12911963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3840"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911799e35-true-d12911963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12911799e35-true-d12911963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e71-true-d12912060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3839"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e71-true-d12912060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12909658e71-true-d12912060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911994e7-true-d12912135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3838"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911994e7-true-d12912135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12911994e7-true-d12912135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912065e9-true-d12912174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3837"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912065e9-true-d12912174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12912065e9-true-d12912174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912065e10-true-d12912222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3836"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912065e10-true-d12912222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12912065e10-true-d12912222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912185e12-true-d12912290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3835"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912185e12-true-d12912290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12912185e12-true-d12912290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912185e35-true-d12912349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3834"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912185e35-true-d12912349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12912185e35-true-d12912349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12911994e11-true-d12912426e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3833"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12911994e11-true-d12912426e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12911994e11-true-d12912426e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912380e16-true-d12912467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3832"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912380e16-true-d12912467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12912380e16-true-d12912467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e75-true-d12912539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3831"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e75-true-d12912539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12909658e75-true-d12912539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912478e15-true-d12912615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3830"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912478e15-true-d12912615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12912478e15-true-d12912615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912478e35-true-d12912670e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3829"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912478e35-true-d12912670e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12912478e35-true-d12912670e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912478e39-true-d12912727e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3828"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912478e39-true-d12912727e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12912478e39-true-d12912727e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912478e42-true-d12912781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3827"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12912478e42-true-d12912781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12912478e42-true-d12912781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e81-true-d12912841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3826"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e81-true-d12912841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12909658e81-true-d12912841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912851e13-true-d12912875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3825"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12912851e13-true-d12912875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12912851e13-true-d12912875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912896e13-true-d12912920e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3824"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12912896e13-true-d12912920e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12912896e13-true-d12912920e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912941e13-true-d12912965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3823"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12912941e13-true-d12912965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12912941e13-true-d12912965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12912986e13-true-d12913020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3822"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12912986e13-true-d12913020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12912986e13-true-d12913020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12909658e86-true-d12913064e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3821"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12909658e86-true-d12913064e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12909658e86-true-d12913064e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913052e2-true-d12913091e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3820"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12913052e2-true-d12913091e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12913052e2-true-d12913091e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e16-true-d12914592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3819"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e16-true-d12914592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12913121e16-true-d12914592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e87-true-d12914690e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3818"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e87-true-d12914690e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12913121e87-true-d12914690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12914667e9-true-d12914734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3817"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12914667e9-true-d12914734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12914667e9-true-d12914734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12914667e29-true-d12914783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3816"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12914667e29-true-d12914783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12914667e29-true-d12914783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e92-true-d12914819e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3815"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e92-true-d12914819e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12913121e92-true-d12914819e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12914807e2-true-d12914839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3814"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12914807e2-true-d12914839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12914807e2-true-d12914839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12914807e8-true-d12914880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3813"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12914807e8-true-d12914880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12914807e8-true-d12914880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e96-true-d12914973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3812"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e96-true-d12914973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12913121e96-true-d12914973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12914909e9-true-d12915033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3811"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12914909e9-true-d12915033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12914909e9-true-d12915033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e100-true-d12915155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3810"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e100-true-d12915155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12913121e100-true-d12915155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915082e10-true-d12915247e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3809"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915082e10-true-d12915247e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12915082e10-true-d12915247e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915082e30-true-d12915286e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3808"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915082e30-true-d12915286e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12915082e30-true-d12915286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915082e34-true-d12915325e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3807"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915082e34-true-d12915325e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12915082e34-true-d12915325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915082e39-true-d12915386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3806"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915082e39-true-d12915386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12915082e39-true-d12915386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915349e12-true-d12915454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3805"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915349e12-true-d12915454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12915349e12-true-d12915454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915349e35-true-d12915513e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3804"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915349e35-true-d12915513e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12915349e35-true-d12915513e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e105-true-d12915610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3803"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e105-true-d12915610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12913121e105-true-d12915610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915544e7-true-d12915685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3802"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915544e7-true-d12915685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12915544e7-true-d12915685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915615e9-true-d12915724e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3801"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915615e9-true-d12915724e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12915615e9-true-d12915724e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915615e10-true-d12915772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3800"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915615e10-true-d12915772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12915615e10-true-d12915772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915735e12-true-d12915840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3799"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915735e12-true-d12915840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12915735e12-true-d12915840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915735e35-true-d12915899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3798"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915735e35-true-d12915899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12915735e35-true-d12915899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915544e11-true-d12915976e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3797"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915544e11-true-d12915976e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12915544e11-true-d12915976e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12915930e16-true-d12916017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3796"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12915930e16-true-d12916017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12915930e16-true-d12916017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e109-true-d12916089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3795"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e109-true-d12916089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12913121e109-true-d12916089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916028e15-true-d12916165e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3794"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12916028e15-true-d12916165e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12916028e15-true-d12916165e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916028e35-true-d12916220e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3793"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12916028e35-true-d12916220e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12916028e35-true-d12916220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916028e39-true-d12916277e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3792"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12916028e39-true-d12916277e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12916028e39-true-d12916277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916028e42-true-d12916331e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3791"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12916028e42-true-d12916331e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12916028e42-true-d12916331e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e137-true-d12916400e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3790"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e137-true-d12916400e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12913121e137-true-d12916400e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916410e13-true-d12916434e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3789"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12916410e13-true-d12916434e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12916410e13-true-d12916434e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916455e13-true-d12916479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3788"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12916455e13-true-d12916479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12916455e13-true-d12916479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916500e13-true-d12916524e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3787"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12916500e13-true-d12916524e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12916500e13-true-d12916524e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916545e13-true-d12916579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3786"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12916545e13-true-d12916579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12916545e13-true-d12916579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12913121e141-true-d12916623e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3785"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12913121e141-true-d12916623e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12913121e141-true-d12916623e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916611e2-true-d12916650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3784"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12916611e2-true-d12916650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12916611e2-true-d12916650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e16-true-d12918087e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3783"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e16-true-d12918087e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12916671e16-true-d12918087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e43-true-d12918140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3782"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e43-true-d12918140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12916671e43-true-d12918140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918117e9-true-d12918184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3781"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918117e9-true-d12918184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12918117e9-true-d12918184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918117e29-true-d12918233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3780"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918117e29-true-d12918233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12918117e29-true-d12918233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e47-true-d12918269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3779"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e47-true-d12918269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12916671e47-true-d12918269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918257e2-true-d12918289e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3778"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918257e2-true-d12918289e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12918257e2-true-d12918289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918257e8-true-d12918330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3777"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918257e8-true-d12918330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12918257e8-true-d12918330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e52-true-d12918423e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3776"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e52-true-d12918423e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12916671e52-true-d12918423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918359e9-true-d12918483e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3775"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918359e9-true-d12918483e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12918359e9-true-d12918483e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e56-true-d12918605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3774"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e56-true-d12918605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12916671e56-true-d12918605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918532e10-true-d12918697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3773"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918532e10-true-d12918697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12918532e10-true-d12918697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918532e30-true-d12918736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3772"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918532e30-true-d12918736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12918532e30-true-d12918736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918532e34-true-d12918775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3771"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918532e34-true-d12918775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12918532e34-true-d12918775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918532e39-true-d12918836e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3770"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918532e39-true-d12918836e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12918532e39-true-d12918836e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918799e12-true-d12918904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3769"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918799e12-true-d12918904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12918799e12-true-d12918904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918799e35-true-d12918963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3768"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918799e35-true-d12918963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12918799e35-true-d12918963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e60-true-d12919060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3767"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e60-true-d12919060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12916671e60-true-d12919060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918994e7-true-d12919135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3766"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918994e7-true-d12919135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12918994e7-true-d12919135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919065e9-true-d12919174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3765"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919065e9-true-d12919174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12919065e9-true-d12919174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919065e10-true-d12919222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3764"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919065e10-true-d12919222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12919065e10-true-d12919222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919185e12-true-d12919290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3763"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919185e12-true-d12919290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12919185e12-true-d12919290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919185e35-true-d12919349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3762"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919185e35-true-d12919349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12919185e35-true-d12919349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12918994e11-true-d12919426e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3761"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12918994e11-true-d12919426e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12918994e11-true-d12919426e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919380e16-true-d12919467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3760"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919380e16-true-d12919467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12919380e16-true-d12919467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e65-true-d12919539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3759"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e65-true-d12919539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12916671e65-true-d12919539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919478e15-true-d12919615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3758"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919478e15-true-d12919615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12919478e15-true-d12919615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919478e35-true-d12919670e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3757"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919478e35-true-d12919670e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12919478e35-true-d12919670e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919478e39-true-d12919727e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3756"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919478e39-true-d12919727e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12919478e39-true-d12919727e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919478e42-true-d12919781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3755"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12919478e42-true-d12919781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12919478e42-true-d12919781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e92-true-d12919850e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3754"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e92-true-d12919850e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12916671e92-true-d12919850e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919860e13-true-d12919884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3753"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12919860e13-true-d12919884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12919860e13-true-d12919884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919905e13-true-d12919929e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3752"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12919905e13-true-d12919929e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12919905e13-true-d12919929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919950e13-true-d12919974e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3751"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12919950e13-true-d12919974e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12919950e13-true-d12919974e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12919995e13-true-d12920029e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3750"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12919995e13-true-d12920029e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12919995e13-true-d12920029e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12916671e97-true-d12920073e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3749"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12916671e97-true-d12920073e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12916671e97-true-d12920073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920061e2-true-d12920100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3748"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12920061e2-true-d12920100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12920061e2-true-d12920100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e16-true-d12921660e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3747"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e16-true-d12921660e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12920121e16-true-d12921660e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e95-true-d12921776e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3746"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e95-true-d12921776e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12920121e95-true-d12921776e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12921753e9-true-d12921820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3745"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12921753e9-true-d12921820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12921753e9-true-d12921820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12921753e29-true-d12921869e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3744"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12921753e29-true-d12921869e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12921753e29-true-d12921869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e99-true-d12921905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3743"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e99-true-d12921905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12920121e99-true-d12921905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12921893e2-true-d12921925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3742"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12921893e2-true-d12921925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12921893e2-true-d12921925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12921893e8-true-d12921966e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3741"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12921893e8-true-d12921966e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12921893e8-true-d12921966e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e103-true-d12922043e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="3740"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e103-true-d12922043e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12920121e103-true-d12922043e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12921995e5-true-d12922099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="3739"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12921995e5-true-d12922099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12921995e5-true-d12922099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922109e13-true-d12922126e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="3738"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12922109e13-true-d12922126e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12922109e13-true-d12922126e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922141e13-true-d12922169e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="3737"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12922141e13-true-d12922169e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12922141e13-true-d12922169e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12921995e24-true-d12922230e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3736"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12921995e24-true-d12922230e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12921995e24-true-d12922230e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922193e12-true-d12922298e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3735"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922193e12-true-d12922298e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12922193e12-true-d12922298e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922193e35-true-d12922357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3734"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922193e35-true-d12922357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12922193e35-true-d12922357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e111-true-d12922452e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3733"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e111-true-d12922452e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12920121e111-true-d12922452e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922388e9-true-d12922512e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3732"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922388e9-true-d12922512e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12922388e9-true-d12922512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e115-true-d12922634e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3731"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e115-true-d12922634e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12920121e115-true-d12922634e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922561e10-true-d12922726e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3730"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922561e10-true-d12922726e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12922561e10-true-d12922726e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922561e30-true-d12922765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3729"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922561e30-true-d12922765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12922561e30-true-d12922765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922561e34-true-d12922804e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3728"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922561e34-true-d12922804e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12922561e34-true-d12922804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922561e39-true-d12922865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3727"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922561e39-true-d12922865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12922561e39-true-d12922865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922828e12-true-d12922933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3726"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922828e12-true-d12922933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12922828e12-true-d12922933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12922828e35-true-d12922992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3725"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12922828e35-true-d12922992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12922828e35-true-d12922992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e119-true-d12923089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3724"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e119-true-d12923089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12920121e119-true-d12923089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923023e7-true-d12923164e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3723"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923023e7-true-d12923164e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12923023e7-true-d12923164e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923094e9-true-d12923203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3722"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923094e9-true-d12923203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12923094e9-true-d12923203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923094e10-true-d12923251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3721"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923094e10-true-d12923251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12923094e10-true-d12923251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923214e12-true-d12923319e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3720"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923214e12-true-d12923319e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12923214e12-true-d12923319e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923214e35-true-d12923378e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3719"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923214e35-true-d12923378e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12923214e35-true-d12923378e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923023e11-true-d12923455e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3718"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923023e11-true-d12923455e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12923023e11-true-d12923455e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923409e16-true-d12923496e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3717"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923409e16-true-d12923496e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12923409e16-true-d12923496e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e124-true-d12923568e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3716"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e124-true-d12923568e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12920121e124-true-d12923568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923507e15-true-d12923644e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3715"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923507e15-true-d12923644e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12923507e15-true-d12923644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923507e35-true-d12923699e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3714"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923507e35-true-d12923699e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12923507e35-true-d12923699e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923507e39-true-d12923756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3713"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923507e39-true-d12923756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12923507e39-true-d12923756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923507e42-true-d12923810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3712"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12923507e42-true-d12923810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12923507e42-true-d12923810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e151-true-d12923879e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3711"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e151-true-d12923879e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12920121e151-true-d12923879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923889e13-true-d12923913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3710"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12923889e13-true-d12923913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12923889e13-true-d12923913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923934e13-true-d12923958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3709"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12923934e13-true-d12923958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12923934e13-true-d12923958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12923979e13-true-d12924003e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3708"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12923979e13-true-d12924003e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12923979e13-true-d12924003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924024e13-true-d12924058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3707"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12924024e13-true-d12924058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12924024e13-true-d12924058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12920121e156-true-d12924102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3706"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12920121e156-true-d12924102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12920121e156-true-d12924102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924090e2-true-d12924129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3705"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12924090e2-true-d12924129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12924090e2-true-d12924129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e16-true-d12925656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3704"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e16-true-d12925656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12924150e16-true-d12925656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e71-true-d12925748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3703"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e71-true-d12925748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12924150e71-true-d12925748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12925725e9-true-d12925792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3702"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12925725e9-true-d12925792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12925725e9-true-d12925792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12925725e29-true-d12925841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3701"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12925725e29-true-d12925841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12925725e29-true-d12925841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e76-true-d12925877e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3700"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e76-true-d12925877e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12924150e76-true-d12925877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12925865e2-true-d12925897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3699"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12925865e2-true-d12925897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12925865e2-true-d12925897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12925865e8-true-d12925938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3698"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12925865e8-true-d12925938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12925865e8-true-d12925938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e80-true-d12926015e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="3697"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e80-true-d12926015e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12924150e80-true-d12926015e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12925967e5-true-d12926071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="3696"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12925967e5-true-d12926071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12925967e5-true-d12926071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926081e13-true-d12926098e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="3695"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12926081e13-true-d12926098e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12926081e13-true-d12926098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926113e13-true-d12926141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="3694"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12926113e13-true-d12926141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12926113e13-true-d12926141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12925967e24-true-d12926202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3693"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12925967e24-true-d12926202e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12925967e24-true-d12926202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926165e12-true-d12926270e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3692"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926165e12-true-d12926270e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12926165e12-true-d12926270e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926165e35-true-d12926329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3691"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926165e35-true-d12926329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12926165e35-true-d12926329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e87-true-d12926424e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3690"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e87-true-d12926424e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12924150e87-true-d12926424e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926360e9-true-d12926484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3689"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926360e9-true-d12926484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12926360e9-true-d12926484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e92-true-d12926606e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3688"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e92-true-d12926606e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12924150e92-true-d12926606e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926533e10-true-d12926698e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3687"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926533e10-true-d12926698e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12926533e10-true-d12926698e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926533e30-true-d12926737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3686"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926533e30-true-d12926737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12926533e30-true-d12926737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926533e34-true-d12926776e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3685"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926533e34-true-d12926776e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12926533e34-true-d12926776e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926533e39-true-d12926837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3684"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926533e39-true-d12926837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12926533e39-true-d12926837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926800e12-true-d12926905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3683"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926800e12-true-d12926905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12926800e12-true-d12926905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926800e35-true-d12926964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3682"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926800e35-true-d12926964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12926800e35-true-d12926964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e96-true-d12927061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3681"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e96-true-d12927061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12924150e96-true-d12927061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926995e7-true-d12927136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3680"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926995e7-true-d12927136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12926995e7-true-d12927136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927066e9-true-d12927175e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3679"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927066e9-true-d12927175e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12927066e9-true-d12927175e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927066e10-true-d12927223e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3678"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927066e10-true-d12927223e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12927066e10-true-d12927223e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927186e12-true-d12927291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3677"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927186e12-true-d12927291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12927186e12-true-d12927291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927186e35-true-d12927350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3676"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927186e35-true-d12927350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12927186e35-true-d12927350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12926995e11-true-d12927427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3675"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12926995e11-true-d12927427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12926995e11-true-d12927427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927381e16-true-d12927468e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3674"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927381e16-true-d12927468e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12927381e16-true-d12927468e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e100-true-d12927540e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3673"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e100-true-d12927540e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12924150e100-true-d12927540e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927479e15-true-d12927616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3672"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927479e15-true-d12927616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12927479e15-true-d12927616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927479e35-true-d12927671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3671"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927479e35-true-d12927671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12927479e35-true-d12927671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927479e39-true-d12927728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3670"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927479e39-true-d12927728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12927479e39-true-d12927728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927479e42-true-d12927782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3669"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12927479e42-true-d12927782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12927479e42-true-d12927782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e128-true-d12927851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3668"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e128-true-d12927851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12924150e128-true-d12927851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927861e13-true-d12927885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3667"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12927861e13-true-d12927885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12927861e13-true-d12927885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927906e13-true-d12927930e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3666"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12927906e13-true-d12927930e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12927906e13-true-d12927930e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927951e13-true-d12927975e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3665"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12927951e13-true-d12927975e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12927951e13-true-d12927975e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12927996e13-true-d12928030e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3664"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12927996e13-true-d12928030e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12927996e13-true-d12928030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12924150e132-true-d12928074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3663"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12924150e132-true-d12928074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12924150e132-true-d12928074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928062e2-true-d12928101e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3662"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12928062e2-true-d12928101e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12928062e2-true-d12928101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e114-true-d12928159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3661"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e114-true-d12928159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12887239e114-true-d12928159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928169e13-true-d12928193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3660"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12928169e13-true-d12928193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12928169e13-true-d12928193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928214e13-true-d12928238e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3659"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12928214e13-true-d12928238e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12928214e13-true-d12928238e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928259e13-true-d12928283e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3658"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12928259e13-true-d12928283e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12928259e13-true-d12928283e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928304e13-true-d12928338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3657"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12928304e13-true-d12928338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12928304e13-true-d12928338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12887239e118-true-d12928382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3656"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12887239e118-true-d12928382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12887239e118-true-d12928382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928370e2-true-d12928409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3655"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12928370e2-true-d12928409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12928370e2-true-d12928409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e16-true-d12929933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="3654"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e16-true-d12929933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12928430e16-true-d12929933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e100-true-d12930052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3653"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e100-true-d12930052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12928430e100-true-d12930052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930029e9-true-d12930096e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3652"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930029e9-true-d12930096e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12930029e9-true-d12930096e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930029e29-true-d12930145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3651"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930029e29-true-d12930145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12930029e29-true-d12930145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e104-true-d12930181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3650"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e104-true-d12930181e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12928430e104-true-d12930181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930169e2-true-d12930201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3649"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930169e2-true-d12930201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12930169e2-true-d12930201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930169e8-true-d12930242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3648"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930169e8-true-d12930242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12930169e8-true-d12930242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e108-true-d12930335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3647"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e108-true-d12930335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12928430e108-true-d12930335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930271e9-true-d12930395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3646"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930271e9-true-d12930395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12930271e9-true-d12930395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e113-true-d12930517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3645"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e113-true-d12930517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12928430e113-true-d12930517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930444e10-true-d12930609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3644"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930444e10-true-d12930609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12930444e10-true-d12930609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930444e30-true-d12930648e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3643"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930444e30-true-d12930648e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12930444e30-true-d12930648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930444e34-true-d12930687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3642"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930444e34-true-d12930687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12930444e34-true-d12930687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930444e39-true-d12930748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3641"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930444e39-true-d12930748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12930444e39-true-d12930748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930711e12-true-d12930816e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3640"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930711e12-true-d12930816e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12930711e12-true-d12930816e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930711e35-true-d12930875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3639"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930711e35-true-d12930875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12930711e35-true-d12930875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e117-true-d12930972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3638"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e117-true-d12930972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12928430e117-true-d12930972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930906e7-true-d12931047e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3637"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930906e7-true-d12931047e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12930906e7-true-d12931047e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930977e9-true-d12931086e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3636"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930977e9-true-d12931086e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12930977e9-true-d12931086e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930977e10-true-d12931134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3635"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930977e10-true-d12931134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12930977e10-true-d12931134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12931097e12-true-d12931202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3634"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12931097e12-true-d12931202e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12931097e12-true-d12931202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12931097e35-true-d12931261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3633"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12931097e35-true-d12931261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12931097e35-true-d12931261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12930906e11-true-d12931338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3632"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12930906e11-true-d12931338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12930906e11-true-d12931338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12931292e16-true-d12931379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3631"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12931292e16-true-d12931379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12931292e16-true-d12931379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e121-true-d12931451e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3630"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e121-true-d12931451e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12928430e121-true-d12931451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12931390e15-true-d12931527e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3629"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12931390e15-true-d12931527e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12931390e15-true-d12931527e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12931390e35-true-d12931582e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3628"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12931390e35-true-d12931582e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12931390e35-true-d12931582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12931390e39-true-d12931639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3627"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12931390e39-true-d12931639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12931390e39-true-d12931639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12931390e42-true-d12931693e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3626"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12931390e42-true-d12931693e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12931390e42-true-d12931693e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e126-true-d12936800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="3625"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e126-true-d12936800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12928430e126-true-d12936800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e16-true-d12938265e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3624"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e16-true-d12938265e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12936815e16-true-d12938265e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e77-true-d12938345e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3623"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e77-true-d12938345e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12936815e77-true-d12938345e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938322e9-true-d12938389e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3622"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938322e9-true-d12938389e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12938322e9-true-d12938389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938322e29-true-d12938438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3621"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938322e29-true-d12938438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12938322e29-true-d12938438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e81-true-d12938474e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3620"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e81-true-d12938474e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12936815e81-true-d12938474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938462e2-true-d12938494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3619"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938462e2-true-d12938494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12938462e2-true-d12938494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938462e8-true-d12938535e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3618"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938462e8-true-d12938535e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12938462e8-true-d12938535e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e85-true-d12938628e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3617"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e85-true-d12938628e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12936815e85-true-d12938628e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938564e9-true-d12938688e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3616"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938564e9-true-d12938688e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12938564e9-true-d12938688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e90-true-d12938810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3615"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e90-true-d12938810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12936815e90-true-d12938810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938737e10-true-d12938902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3614"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938737e10-true-d12938902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12938737e10-true-d12938902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938737e30-true-d12938941e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3613"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938737e30-true-d12938941e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12938737e30-true-d12938941e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938737e34-true-d12938980e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3612"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938737e34-true-d12938980e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12938737e34-true-d12938980e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12938737e39-true-d12939041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3611"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12938737e39-true-d12939041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12938737e39-true-d12939041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939004e12-true-d12939109e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3610"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939004e12-true-d12939109e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12939004e12-true-d12939109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939004e35-true-d12939168e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3609"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939004e35-true-d12939168e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12939004e35-true-d12939168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e94-true-d12939265e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3608"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e94-true-d12939265e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12936815e94-true-d12939265e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939199e7-true-d12939340e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3607"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939199e7-true-d12939340e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12939199e7-true-d12939340e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939270e9-true-d12939379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3606"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939270e9-true-d12939379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12939270e9-true-d12939379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939270e10-true-d12939427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3605"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939270e10-true-d12939427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12939270e10-true-d12939427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939390e12-true-d12939495e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3604"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939390e12-true-d12939495e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12939390e12-true-d12939495e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939390e35-true-d12939554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3603"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939390e35-true-d12939554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12939390e35-true-d12939554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939199e11-true-d12939631e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3602"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939199e11-true-d12939631e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12939199e11-true-d12939631e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939585e16-true-d12939672e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3601"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939585e16-true-d12939672e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12939585e16-true-d12939672e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e98-true-d12939744e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3600"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e98-true-d12939744e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12936815e98-true-d12939744e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939683e15-true-d12939820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3599"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939683e15-true-d12939820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12939683e15-true-d12939820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939683e35-true-d12939875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3598"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939683e35-true-d12939875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12939683e35-true-d12939875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939683e39-true-d12939932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3597"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939683e39-true-d12939932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12939683e39-true-d12939932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12939683e42-true-d12939986e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3596"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12939683e42-true-d12939986e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12939683e42-true-d12939986e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e126-true-d12940055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3595"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e126-true-d12940055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12936815e126-true-d12940055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940065e13-true-d12940089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3594"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12940065e13-true-d12940089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12940065e13-true-d12940089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940110e13-true-d12940134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3593"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12940110e13-true-d12940134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12940110e13-true-d12940134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940155e13-true-d12940179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3592"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12940155e13-true-d12940179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12940155e13-true-d12940179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940200e13-true-d12940234e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3591"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12940200e13-true-d12940234e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12940200e13-true-d12940234e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12936815e130-true-d12940278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3590"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12936815e130-true-d12940278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12936815e130-true-d12940278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940266e2-true-d12940305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3589"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12940266e2-true-d12940305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12940266e2-true-d12940305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e16-true-d12941769e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3588"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e16-true-d12941769e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12940326e16-true-d12941769e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e65-true-d12941843e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3587"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e65-true-d12941843e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12940326e65-true-d12941843e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12941820e9-true-d12941887e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3586"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12941820e9-true-d12941887e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12941820e9-true-d12941887e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12941820e29-true-d12941936e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3585"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12941820e29-true-d12941936e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12941820e29-true-d12941936e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e69-true-d12941972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3584"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e69-true-d12941972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12940326e69-true-d12941972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12941960e2-true-d12941992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3583"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12941960e2-true-d12941992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12941960e2-true-d12941992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12941960e8-true-d12942033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3582"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12941960e8-true-d12942033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12941960e8-true-d12942033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e73-true-d12942126e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3581"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e73-true-d12942126e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12940326e73-true-d12942126e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942062e9-true-d12942186e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3580"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942062e9-true-d12942186e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12942062e9-true-d12942186e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e78-true-d12942308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3579"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e78-true-d12942308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12940326e78-true-d12942308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942235e10-true-d12942400e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3578"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942235e10-true-d12942400e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12942235e10-true-d12942400e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942235e30-true-d12942439e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3577"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942235e30-true-d12942439e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12942235e30-true-d12942439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942235e34-true-d12942478e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3576"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942235e34-true-d12942478e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12942235e34-true-d12942478e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942235e39-true-d12942539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3575"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942235e39-true-d12942539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12942235e39-true-d12942539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942502e12-true-d12942607e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3574"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942502e12-true-d12942607e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12942502e12-true-d12942607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942502e35-true-d12942666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3573"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942502e35-true-d12942666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12942502e35-true-d12942666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e82-true-d12942763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3572"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e82-true-d12942763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12940326e82-true-d12942763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942697e7-true-d12942838e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3571"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942697e7-true-d12942838e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12942697e7-true-d12942838e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942768e9-true-d12942877e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3570"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942768e9-true-d12942877e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12942768e9-true-d12942877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942768e10-true-d12942925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3569"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942768e10-true-d12942925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12942768e10-true-d12942925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942888e12-true-d12942993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3568"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942888e12-true-d12942993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12942888e12-true-d12942993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942888e35-true-d12943052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3567"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942888e35-true-d12943052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12942888e35-true-d12943052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12942697e11-true-d12943129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3566"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12942697e11-true-d12943129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12942697e11-true-d12943129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943083e16-true-d12943170e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3565"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12943083e16-true-d12943170e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12943083e16-true-d12943170e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e86-true-d12943242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3564"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e86-true-d12943242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12940326e86-true-d12943242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943181e15-true-d12943318e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3563"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12943181e15-true-d12943318e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12943181e15-true-d12943318e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943181e35-true-d12943373e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3562"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12943181e35-true-d12943373e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12943181e35-true-d12943373e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943181e39-true-d12943430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3561"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12943181e39-true-d12943430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12943181e39-true-d12943430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943181e42-true-d12943484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3560"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12943181e42-true-d12943484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12943181e42-true-d12943484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e114-true-d12943553e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3559"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e114-true-d12943553e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12940326e114-true-d12943553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943563e13-true-d12943587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3558"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12943563e13-true-d12943587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12943563e13-true-d12943587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943608e13-true-d12943632e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3557"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12943608e13-true-d12943632e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12943608e13-true-d12943632e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943653e13-true-d12943677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3556"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12943653e13-true-d12943677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12943653e13-true-d12943677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943698e13-true-d12943732e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3555"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12943698e13-true-d12943732e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12943698e13-true-d12943732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12940326e118-true-d12943776e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3554"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12940326e118-true-d12943776e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12940326e118-true-d12943776e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943764e2-true-d12943803e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3553"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12943764e2-true-d12943803e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12943764e2-true-d12943803e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e16-true-d12945327e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="3552"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e16-true-d12945327e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12943824e16-true-d12945327e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e100-true-d12945446e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3551"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e100-true-d12945446e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12943824e100-true-d12945446e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945423e9-true-d12945490e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3550"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945423e9-true-d12945490e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12945423e9-true-d12945490e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945423e29-true-d12945539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3549"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945423e29-true-d12945539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12945423e29-true-d12945539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e104-true-d12945575e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3548"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e104-true-d12945575e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12943824e104-true-d12945575e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945563e2-true-d12945595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3547"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945563e2-true-d12945595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12945563e2-true-d12945595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945563e8-true-d12945636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3546"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945563e8-true-d12945636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12945563e8-true-d12945636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e108-true-d12945729e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3545"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e108-true-d12945729e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12943824e108-true-d12945729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945665e9-true-d12945789e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3544"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945665e9-true-d12945789e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12945665e9-true-d12945789e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e113-true-d12945911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3543"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e113-true-d12945911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12943824e113-true-d12945911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945838e10-true-d12946003e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3542"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945838e10-true-d12946003e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12945838e10-true-d12946003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945838e30-true-d12946042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3541"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945838e30-true-d12946042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12945838e30-true-d12946042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945838e34-true-d12946081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3540"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945838e34-true-d12946081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12945838e34-true-d12946081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12945838e39-true-d12946142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3539"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12945838e39-true-d12946142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12945838e39-true-d12946142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946105e12-true-d12946210e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3538"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946105e12-true-d12946210e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12946105e12-true-d12946210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946105e35-true-d12946269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3537"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946105e35-true-d12946269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12946105e35-true-d12946269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e117-true-d12946366e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3536"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e117-true-d12946366e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12943824e117-true-d12946366e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946300e7-true-d12946441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3535"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946300e7-true-d12946441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12946300e7-true-d12946441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946371e9-true-d12946480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3534"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946371e9-true-d12946480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12946371e9-true-d12946480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946371e10-true-d12946528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3533"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946371e10-true-d12946528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12946371e10-true-d12946528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946491e12-true-d12946596e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3532"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946491e12-true-d12946596e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12946491e12-true-d12946596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946491e35-true-d12946655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3531"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946491e35-true-d12946655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12946491e35-true-d12946655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946300e11-true-d12946732e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3530"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946300e11-true-d12946732e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12946300e11-true-d12946732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946686e16-true-d12946773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3529"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946686e16-true-d12946773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12946686e16-true-d12946773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e121-true-d12946845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3528"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e121-true-d12946845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12943824e121-true-d12946845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946784e15-true-d12946921e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3527"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946784e15-true-d12946921e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12946784e15-true-d12946921e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946784e35-true-d12946976e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3526"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946784e35-true-d12946976e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12946784e35-true-d12946976e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946784e39-true-d12947033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3525"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946784e39-true-d12947033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12946784e39-true-d12947033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12946784e42-true-d12947087e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3524"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12946784e42-true-d12947087e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12946784e42-true-d12947087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e149-true-d12947156e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3523"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e149-true-d12947156e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12943824e149-true-d12947156e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947166e13-true-d12947190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3522"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12947166e13-true-d12947190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12947166e13-true-d12947190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947211e13-true-d12947235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3521"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12947211e13-true-d12947235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12947211e13-true-d12947235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947256e13-true-d12947280e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3520"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12947256e13-true-d12947280e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12947256e13-true-d12947280e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947301e13-true-d12947335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3519"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12947301e13-true-d12947335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12947301e13-true-d12947335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e153-true-d12947379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3518"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e153-true-d12947379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12943824e153-true-d12947379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947367e2-true-d12947406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3517"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12947367e2-true-d12947406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12947367e2-true-d12947406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e158-true-d12947437e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="3516"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e158-true-d12947437e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12943824e158-true-d12947437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12943824e162-true-d12947475e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="3515"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12943824e162-true-d12947475e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12943824e162-true-d12947475e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e16-true-d12948920e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3514"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e16-true-d12948920e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12947504e16-true-d12948920e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e43-true-d12948973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3513"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e43-true-d12948973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12947504e43-true-d12948973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12948950e9-true-d12949017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3512"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12948950e9-true-d12949017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12948950e9-true-d12949017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12948950e29-true-d12949066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3511"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12948950e29-true-d12949066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12948950e29-true-d12949066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e47-true-d12949102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3510"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e47-true-d12949102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12947504e47-true-d12949102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949090e2-true-d12949122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3509"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949090e2-true-d12949122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12949090e2-true-d12949122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949090e8-true-d12949163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3508"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949090e8-true-d12949163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12949090e8-true-d12949163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e52-true-d12949256e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3507"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e52-true-d12949256e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12947504e52-true-d12949256e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949192e9-true-d12949316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3506"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949192e9-true-d12949316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12949192e9-true-d12949316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e56-true-d12949438e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3505"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e56-true-d12949438e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12947504e56-true-d12949438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949365e10-true-d12949530e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3504"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949365e10-true-d12949530e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12949365e10-true-d12949530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949365e30-true-d12949569e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3503"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949365e30-true-d12949569e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12949365e30-true-d12949569e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949365e34-true-d12949608e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3502"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949365e34-true-d12949608e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12949365e34-true-d12949608e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949365e39-true-d12949669e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3501"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949365e39-true-d12949669e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12949365e39-true-d12949669e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949632e12-true-d12949737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3500"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949632e12-true-d12949737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12949632e12-true-d12949737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949632e35-true-d12949796e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3499"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949632e35-true-d12949796e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12949632e35-true-d12949796e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e60-true-d12949893e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3498"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e60-true-d12949893e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12947504e60-true-d12949893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949827e7-true-d12949968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3497"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949827e7-true-d12949968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12949827e7-true-d12949968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949898e9-true-d12950007e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3496"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949898e9-true-d12950007e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12949898e9-true-d12950007e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949898e10-true-d12950055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3495"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949898e10-true-d12950055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12949898e10-true-d12950055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950018e12-true-d12950123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3494"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950018e12-true-d12950123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12950018e12-true-d12950123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950018e35-true-d12950182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3493"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950018e35-true-d12950182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12950018e35-true-d12950182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12949827e11-true-d12950259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3492"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12949827e11-true-d12950259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12949827e11-true-d12950259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950213e16-true-d12950300e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3491"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950213e16-true-d12950300e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12950213e16-true-d12950300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e65-true-d12950372e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3490"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e65-true-d12950372e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12947504e65-true-d12950372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950311e15-true-d12950448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3489"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950311e15-true-d12950448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12950311e15-true-d12950448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950311e35-true-d12950503e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3488"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950311e35-true-d12950503e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12950311e35-true-d12950503e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950311e39-true-d12950560e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3487"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950311e39-true-d12950560e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12950311e39-true-d12950560e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950311e42-true-d12950614e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3486"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950311e42-true-d12950614e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12950311e42-true-d12950614e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e92-true-d12950683e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3485"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e92-true-d12950683e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12947504e92-true-d12950683e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950693e13-true-d12950717e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3484"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12950693e13-true-d12950717e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12950693e13-true-d12950717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950738e13-true-d12950762e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3483"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12950738e13-true-d12950762e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12950738e13-true-d12950762e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950783e13-true-d12950807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3482"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12950783e13-true-d12950807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12950783e13-true-d12950807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950828e13-true-d12950862e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3481"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12950828e13-true-d12950862e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12950828e13-true-d12950862e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12947504e97-true-d12950906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3480"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12947504e97-true-d12950906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12947504e97-true-d12950906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950894e2-true-d12950933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3479"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12950894e2-true-d12950933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12950894e2-true-d12950933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e16-true-d12952377e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="3478"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e16-true-d12952377e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12950954e16-true-d12952377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e53-true-d12952436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3477"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e53-true-d12952436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12950954e53-true-d12952436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952413e9-true-d12952480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3476"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952413e9-true-d12952480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12952413e9-true-d12952480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952413e29-true-d12952529e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3475"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952413e29-true-d12952529e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12952413e29-true-d12952529e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e58-true-d12952565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3474"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e58-true-d12952565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12950954e58-true-d12952565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952553e2-true-d12952585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3473"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952553e2-true-d12952585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12952553e2-true-d12952585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952553e8-true-d12952626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3472"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952553e8-true-d12952626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12952553e8-true-d12952626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e62-true-d12952719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3471"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e62-true-d12952719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12950954e62-true-d12952719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952655e9-true-d12952779e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3470"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952655e9-true-d12952779e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12952655e9-true-d12952779e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e66-true-d12952901e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3469"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e66-true-d12952901e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12950954e66-true-d12952901e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952828e10-true-d12952993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3468"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952828e10-true-d12952993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12952828e10-true-d12952993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952828e30-true-d12953032e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3467"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952828e30-true-d12953032e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12952828e30-true-d12953032e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952828e34-true-d12953071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3466"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952828e34-true-d12953071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12952828e34-true-d12953071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12952828e39-true-d12953132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3465"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12952828e39-true-d12953132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12952828e39-true-d12953132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953095e12-true-d12953200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3464"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953095e12-true-d12953200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12953095e12-true-d12953200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953095e35-true-d12953259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3463"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953095e35-true-d12953259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12953095e35-true-d12953259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e71-true-d12953356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3462"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e71-true-d12953356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12950954e71-true-d12953356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953290e7-true-d12953431e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3461"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953290e7-true-d12953431e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12953290e7-true-d12953431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953361e9-true-d12953470e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3460"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953361e9-true-d12953470e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12953361e9-true-d12953470e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953361e10-true-d12953518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3459"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953361e10-true-d12953518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12953361e10-true-d12953518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953481e12-true-d12953586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3458"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953481e12-true-d12953586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12953481e12-true-d12953586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953481e35-true-d12953645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3457"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953481e35-true-d12953645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12953481e35-true-d12953645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953290e11-true-d12953722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3456"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953290e11-true-d12953722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12953290e11-true-d12953722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953676e16-true-d12953763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3455"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953676e16-true-d12953763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12953676e16-true-d12953763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e75-true-d12953835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3454"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e75-true-d12953835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12950954e75-true-d12953835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953774e15-true-d12953911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3453"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953774e15-true-d12953911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12953774e15-true-d12953911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953774e35-true-d12953966e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3452"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953774e35-true-d12953966e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12953774e35-true-d12953966e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953774e39-true-d12954023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3451"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953774e39-true-d12954023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12953774e39-true-d12954023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12953774e42-true-d12954077e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3450"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12953774e42-true-d12954077e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12953774e42-true-d12954077e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e81-true-d12954137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3449"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e81-true-d12954137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12950954e81-true-d12954137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954147e13-true-d12954171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3448"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12954147e13-true-d12954171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12954147e13-true-d12954171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954192e13-true-d12954216e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3447"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12954192e13-true-d12954216e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12954192e13-true-d12954216e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954237e13-true-d12954261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3446"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12954237e13-true-d12954261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12954237e13-true-d12954261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954282e13-true-d12954316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3445"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12954282e13-true-d12954316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12954282e13-true-d12954316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12950954e86-true-d12954360e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3444"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12950954e86-true-d12954360e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12950954e86-true-d12954360e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954348e2-true-d12954387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3443"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12954348e2-true-d12954387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12954348e2-true-d12954387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e16-true-d12955888e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3442"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e16-true-d12955888e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12954417e16-true-d12955888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e87-true-d12955986e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3441"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e87-true-d12955986e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12954417e87-true-d12955986e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12955963e9-true-d12956030e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3440"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12955963e9-true-d12956030e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12955963e9-true-d12956030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12955963e29-true-d12956079e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3439"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12955963e29-true-d12956079e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12955963e29-true-d12956079e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e92-true-d12956115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3438"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e92-true-d12956115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12954417e92-true-d12956115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956103e2-true-d12956135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3437"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956103e2-true-d12956135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12956103e2-true-d12956135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956103e8-true-d12956176e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3436"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956103e8-true-d12956176e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12956103e8-true-d12956176e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e96-true-d12956269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3435"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e96-true-d12956269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12954417e96-true-d12956269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956205e9-true-d12956329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3434"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956205e9-true-d12956329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12956205e9-true-d12956329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e100-true-d12956451e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3433"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e100-true-d12956451e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12954417e100-true-d12956451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956378e10-true-d12956543e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3432"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956378e10-true-d12956543e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12956378e10-true-d12956543e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956378e30-true-d12956582e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3431"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956378e30-true-d12956582e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12956378e30-true-d12956582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956378e34-true-d12956621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3430"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956378e34-true-d12956621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12956378e34-true-d12956621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956378e39-true-d12956682e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3429"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956378e39-true-d12956682e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12956378e39-true-d12956682e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956645e12-true-d12956750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3428"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956645e12-true-d12956750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12956645e12-true-d12956750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956645e35-true-d12956809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3427"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956645e35-true-d12956809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12956645e35-true-d12956809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e105-true-d12956906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3426"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e105-true-d12956906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12954417e105-true-d12956906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956840e7-true-d12956981e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3425"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956840e7-true-d12956981e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12956840e7-true-d12956981e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956911e9-true-d12957020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3424"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956911e9-true-d12957020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12956911e9-true-d12957020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956911e10-true-d12957068e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3423"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956911e10-true-d12957068e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12956911e10-true-d12957068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957031e12-true-d12957136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3422"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957031e12-true-d12957136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12957031e12-true-d12957136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957031e35-true-d12957195e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3421"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957031e35-true-d12957195e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12957031e35-true-d12957195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12956840e11-true-d12957272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3420"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12956840e11-true-d12957272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12956840e11-true-d12957272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957226e16-true-d12957313e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3419"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957226e16-true-d12957313e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12957226e16-true-d12957313e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e109-true-d12957385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3418"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e109-true-d12957385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12954417e109-true-d12957385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957324e15-true-d12957461e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3417"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957324e15-true-d12957461e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12957324e15-true-d12957461e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957324e35-true-d12957516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3416"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957324e35-true-d12957516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12957324e35-true-d12957516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957324e39-true-d12957573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3415"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957324e39-true-d12957573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12957324e39-true-d12957573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957324e42-true-d12957627e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3414"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957324e42-true-d12957627e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12957324e42-true-d12957627e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e137-true-d12957696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3413"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e137-true-d12957696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12954417e137-true-d12957696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957706e13-true-d12957730e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3412"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12957706e13-true-d12957730e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12957706e13-true-d12957730e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957751e13-true-d12957775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3411"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12957751e13-true-d12957775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12957751e13-true-d12957775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957796e13-true-d12957820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3410"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12957796e13-true-d12957820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12957796e13-true-d12957820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957841e13-true-d12957875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3409"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12957841e13-true-d12957875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12957841e13-true-d12957875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12954417e141-true-d12957919e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3408"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12954417e141-true-d12957919e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12954417e141-true-d12957919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957907e2-true-d12957946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3407"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12957907e2-true-d12957946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12957907e2-true-d12957946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e16-true-d12959383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3406"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e16-true-d12959383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12957967e16-true-d12959383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e43-true-d12959436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3405"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e43-true-d12959436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12957967e43-true-d12959436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959413e9-true-d12959480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3404"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959413e9-true-d12959480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12959413e9-true-d12959480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959413e29-true-d12959529e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3403"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959413e29-true-d12959529e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12959413e29-true-d12959529e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e47-true-d12959565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3402"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e47-true-d12959565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12957967e47-true-d12959565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959553e2-true-d12959585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3401"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959553e2-true-d12959585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12959553e2-true-d12959585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959553e8-true-d12959626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3400"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959553e8-true-d12959626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12959553e8-true-d12959626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e52-true-d12959719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3399"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e52-true-d12959719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12957967e52-true-d12959719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959655e9-true-d12959779e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3398"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959655e9-true-d12959779e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12959655e9-true-d12959779e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e56-true-d12959901e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3397"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e56-true-d12959901e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12957967e56-true-d12959901e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959828e10-true-d12959993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3396"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959828e10-true-d12959993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12959828e10-true-d12959993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959828e30-true-d12960032e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3395"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959828e30-true-d12960032e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12959828e30-true-d12960032e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959828e34-true-d12960071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3394"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959828e34-true-d12960071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12959828e34-true-d12960071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12959828e39-true-d12960132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3393"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12959828e39-true-d12960132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12959828e39-true-d12960132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960095e12-true-d12960200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3392"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960095e12-true-d12960200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12960095e12-true-d12960200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960095e35-true-d12960259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3391"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960095e35-true-d12960259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12960095e35-true-d12960259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e60-true-d12960356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3390"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e60-true-d12960356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12957967e60-true-d12960356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960290e7-true-d12960431e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3389"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960290e7-true-d12960431e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12960290e7-true-d12960431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960361e9-true-d12960470e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3388"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960361e9-true-d12960470e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12960361e9-true-d12960470e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960361e10-true-d12960518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3387"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960361e10-true-d12960518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12960361e10-true-d12960518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960481e12-true-d12960586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3386"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960481e12-true-d12960586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12960481e12-true-d12960586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960481e35-true-d12960645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3385"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960481e35-true-d12960645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12960481e35-true-d12960645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960290e11-true-d12960722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3384"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960290e11-true-d12960722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12960290e11-true-d12960722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960676e16-true-d12960763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3383"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960676e16-true-d12960763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12960676e16-true-d12960763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e65-true-d12960835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3382"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e65-true-d12960835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12957967e65-true-d12960835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960774e15-true-d12960911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3381"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960774e15-true-d12960911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12960774e15-true-d12960911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960774e35-true-d12960966e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3380"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960774e35-true-d12960966e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12960774e35-true-d12960966e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960774e39-true-d12961023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3379"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960774e39-true-d12961023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12960774e39-true-d12961023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12960774e42-true-d12961077e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3378"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12960774e42-true-d12961077e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12960774e42-true-d12961077e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e92-true-d12961146e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3377"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e92-true-d12961146e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12957967e92-true-d12961146e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961156e13-true-d12961180e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3376"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12961156e13-true-d12961180e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12961156e13-true-d12961180e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961201e13-true-d12961225e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3375"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12961201e13-true-d12961225e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12961201e13-true-d12961225e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961246e13-true-d12961270e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3374"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12961246e13-true-d12961270e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12961246e13-true-d12961270e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961291e13-true-d12961325e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3373"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12961291e13-true-d12961325e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12961291e13-true-d12961325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12957967e97-true-d12961369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3372"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12957967e97-true-d12961369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12957967e97-true-d12961369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961357e2-true-d12961396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3371"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12961357e2-true-d12961396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12961357e2-true-d12961396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e16-true-d12962956e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3370"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e16-true-d12962956e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12961417e16-true-d12962956e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e95-true-d12963072e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3369"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e95-true-d12963072e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12961417e95-true-d12963072e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963049e9-true-d12963116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3368"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963049e9-true-d12963116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12963049e9-true-d12963116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963049e29-true-d12963165e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3367"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963049e29-true-d12963165e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12963049e29-true-d12963165e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e99-true-d12963201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3366"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e99-true-d12963201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12961417e99-true-d12963201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963189e2-true-d12963221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3365"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963189e2-true-d12963221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12963189e2-true-d12963221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963189e8-true-d12963262e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3364"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963189e8-true-d12963262e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12963189e8-true-d12963262e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e103-true-d12963339e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="3363"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e103-true-d12963339e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12961417e103-true-d12963339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963291e5-true-d12963395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="3362"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963291e5-true-d12963395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12963291e5-true-d12963395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963405e13-true-d12963422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="3361"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12963405e13-true-d12963422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12963405e13-true-d12963422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963437e13-true-d12963465e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="3360"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12963437e13-true-d12963465e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12963437e13-true-d12963465e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963291e24-true-d12963526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3359"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963291e24-true-d12963526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12963291e24-true-d12963526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963489e12-true-d12963594e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3358"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963489e12-true-d12963594e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12963489e12-true-d12963594e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963489e35-true-d12963653e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3357"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963489e35-true-d12963653e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12963489e35-true-d12963653e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e111-true-d12963748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3356"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e111-true-d12963748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12961417e111-true-d12963748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963684e9-true-d12963808e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3355"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963684e9-true-d12963808e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12963684e9-true-d12963808e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e115-true-d12963930e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3354"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e115-true-d12963930e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12961417e115-true-d12963930e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963857e10-true-d12964022e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3353"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963857e10-true-d12964022e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12963857e10-true-d12964022e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963857e30-true-d12964061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3352"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963857e30-true-d12964061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12963857e30-true-d12964061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963857e34-true-d12964100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3351"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963857e34-true-d12964100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12963857e34-true-d12964100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12963857e39-true-d12964161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3350"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12963857e39-true-d12964161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12963857e39-true-d12964161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964124e12-true-d12964229e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3349"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964124e12-true-d12964229e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12964124e12-true-d12964229e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964124e35-true-d12964288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3348"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964124e35-true-d12964288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12964124e35-true-d12964288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e119-true-d12964385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3347"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e119-true-d12964385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12961417e119-true-d12964385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964319e7-true-d12964460e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3346"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964319e7-true-d12964460e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12964319e7-true-d12964460e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964390e9-true-d12964499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3345"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964390e9-true-d12964499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12964390e9-true-d12964499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964390e10-true-d12964547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3344"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964390e10-true-d12964547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12964390e10-true-d12964547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964510e12-true-d12964615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3343"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964510e12-true-d12964615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12964510e12-true-d12964615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964510e35-true-d12964674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3342"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964510e35-true-d12964674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12964510e35-true-d12964674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964319e11-true-d12964751e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3341"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964319e11-true-d12964751e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12964319e11-true-d12964751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964705e16-true-d12964792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3340"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964705e16-true-d12964792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12964705e16-true-d12964792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e124-true-d12964864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3339"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e124-true-d12964864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12961417e124-true-d12964864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964803e15-true-d12964940e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3338"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964803e15-true-d12964940e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12964803e15-true-d12964940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964803e35-true-d12964995e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3337"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964803e35-true-d12964995e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12964803e35-true-d12964995e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964803e39-true-d12965052e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3336"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964803e39-true-d12965052e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12964803e39-true-d12965052e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12964803e42-true-d12965106e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3335"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12964803e42-true-d12965106e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12964803e42-true-d12965106e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e151-true-d12965175e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3334"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e151-true-d12965175e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12961417e151-true-d12965175e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965185e13-true-d12965209e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3333"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12965185e13-true-d12965209e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12965185e13-true-d12965209e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965230e13-true-d12965254e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3332"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12965230e13-true-d12965254e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12965230e13-true-d12965254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965275e13-true-d12965299e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3331"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12965275e13-true-d12965299e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12965275e13-true-d12965299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965320e13-true-d12965354e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3330"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12965320e13-true-d12965354e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12965320e13-true-d12965354e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12961417e156-true-d12965398e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3329"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12961417e156-true-d12965398e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12961417e156-true-d12965398e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965386e2-true-d12965425e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3328"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d12965386e2-true-d12965425e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12965386e2-true-d12965425e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e16-true-d12966952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3327"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e16-true-d12966952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12965446e16-true-d12966952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e71-true-d12967044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3326"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e71-true-d12967044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12965446e71-true-d12967044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967021e9-true-d12967088e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3325"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967021e9-true-d12967088e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12967021e9-true-d12967088e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967021e29-true-d12967137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3324"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967021e29-true-d12967137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12967021e29-true-d12967137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e76-true-d12967173e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3323"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e76-true-d12967173e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12965446e76-true-d12967173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967161e2-true-d12967193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3322"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967161e2-true-d12967193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12967161e2-true-d12967193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967161e8-true-d12967234e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3321"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967161e8-true-d12967234e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12967161e8-true-d12967234e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e80-true-d12967311e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="3320"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e80-true-d12967311e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d12965446e80-true-d12967311e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967263e5-true-d12967367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="3319"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967263e5-true-d12967367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d12967263e5-true-d12967367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967377e13-true-d12967394e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="3318"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d12967377e13-true-d12967394e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d12967377e13-true-d12967394e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967409e13-true-d12967437e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="3317"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d12967409e13-true-d12967437e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d12967409e13-true-d12967437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967263e24-true-d12967498e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3316"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967263e24-true-d12967498e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12967263e24-true-d12967498e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967461e12-true-d12967566e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3315"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967461e12-true-d12967566e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12967461e12-true-d12967566e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967461e35-true-d12967625e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3314"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967461e35-true-d12967625e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12967461e35-true-d12967625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e87-true-d12967720e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3313"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e87-true-d12967720e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12965446e87-true-d12967720e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967656e9-true-d12967780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3312"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967656e9-true-d12967780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12967656e9-true-d12967780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e92-true-d12967902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3311"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e92-true-d12967902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12965446e92-true-d12967902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967829e10-true-d12967994e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3310"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967829e10-true-d12967994e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12967829e10-true-d12967994e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967829e30-true-d12968033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3309"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967829e30-true-d12968033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12967829e30-true-d12968033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967829e34-true-d12968072e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3308"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967829e34-true-d12968072e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12967829e34-true-d12968072e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12967829e39-true-d12968133e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3307"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12967829e39-true-d12968133e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12967829e39-true-d12968133e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968096e12-true-d12968201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3306"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968096e12-true-d12968201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12968096e12-true-d12968201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968096e35-true-d12968260e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3305"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968096e35-true-d12968260e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12968096e35-true-d12968260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e96-true-d12968357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3304"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e96-true-d12968357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12965446e96-true-d12968357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968291e7-true-d12968432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3303"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968291e7-true-d12968432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12968291e7-true-d12968432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968362e9-true-d12968471e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3302"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968362e9-true-d12968471e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12968362e9-true-d12968471e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968362e10-true-d12968519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3301"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968362e10-true-d12968519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12968362e10-true-d12968519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968482e12-true-d12968587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3300"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968482e12-true-d12968587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12968482e12-true-d12968587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968482e35-true-d12968646e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3299"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968482e35-true-d12968646e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12968482e35-true-d12968646e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968291e11-true-d12968723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3298"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968291e11-true-d12968723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12968291e11-true-d12968723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968677e16-true-d12968764e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3297"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968677e16-true-d12968764e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12968677e16-true-d12968764e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e100-true-d12968836e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3296"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e100-true-d12968836e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12965446e100-true-d12968836e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968775e15-true-d12968912e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3295"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968775e15-true-d12968912e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12968775e15-true-d12968912e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968775e35-true-d12968967e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3294"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968775e35-true-d12968967e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12968775e35-true-d12968967e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968775e39-true-d12969024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3293"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968775e39-true-d12969024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12968775e39-true-d12969024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12968775e42-true-d12969078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3292"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12968775e42-true-d12969078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12968775e42-true-d12969078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e128-true-d12969147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3291"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e128-true-d12969147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12965446e128-true-d12969147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969157e13-true-d12969181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3290"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12969157e13-true-d12969181e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12969157e13-true-d12969181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969202e13-true-d12969226e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3289"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12969202e13-true-d12969226e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12969202e13-true-d12969226e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969247e13-true-d12969271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3288"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12969247e13-true-d12969271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12969247e13-true-d12969271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969292e13-true-d12969326e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3287"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12969292e13-true-d12969326e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12969292e13-true-d12969326e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12965446e132-true-d12969370e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3286"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12965446e132-true-d12969370e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12965446e132-true-d12969370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969358e2-true-d12969397e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3285"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d12969358e2-true-d12969397e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12969358e2-true-d12969397e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e149-true-d12969455e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3284"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e149-true-d12969455e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12928430e149-true-d12969455e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969465e13-true-d12969489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3283"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12969465e13-true-d12969489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12969465e13-true-d12969489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969510e13-true-d12969534e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3282"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12969510e13-true-d12969534e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12969510e13-true-d12969534e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969555e13-true-d12969579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3281"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12969555e13-true-d12969579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12969555e13-true-d12969579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969600e13-true-d12969634e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3280"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12969600e13-true-d12969634e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12969600e13-true-d12969634e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e153-true-d12969678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3279"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e153-true-d12969678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12928430e153-true-d12969678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969666e2-true-d12969705e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3278"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12969666e2-true-d12969705e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12969666e2-true-d12969705e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e158-true-d12969736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="3277"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e158-true-d12969736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12928430e158-true-d12969736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12928430e162-true-d12969774e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="3276"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12928430e162-true-d12969774e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12928430e162-true-d12969774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e16-true-d12971219e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3275"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e16-true-d12971219e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12969803e16-true-d12971219e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e43-true-d12971272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3274"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e43-true-d12971272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12969803e43-true-d12971272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971249e9-true-d12971316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3273"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971249e9-true-d12971316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12971249e9-true-d12971316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971249e29-true-d12971365e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3272"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971249e29-true-d12971365e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12971249e29-true-d12971365e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e47-true-d12971401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3271"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e47-true-d12971401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12969803e47-true-d12971401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971389e2-true-d12971421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3270"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971389e2-true-d12971421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12971389e2-true-d12971421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971389e8-true-d12971462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3269"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971389e8-true-d12971462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12971389e8-true-d12971462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e52-true-d12971555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3268"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e52-true-d12971555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12969803e52-true-d12971555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971491e9-true-d12971615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3267"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971491e9-true-d12971615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12971491e9-true-d12971615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e56-true-d12971737e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3266"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e56-true-d12971737e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12969803e56-true-d12971737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971664e10-true-d12971829e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3265"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971664e10-true-d12971829e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12971664e10-true-d12971829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971664e30-true-d12971868e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3264"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971664e30-true-d12971868e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12971664e30-true-d12971868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971664e34-true-d12971907e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3263"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971664e34-true-d12971907e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12971664e34-true-d12971907e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971664e39-true-d12971968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3262"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971664e39-true-d12971968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12971664e39-true-d12971968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971931e12-true-d12972036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3261"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971931e12-true-d12972036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12971931e12-true-d12972036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12971931e35-true-d12972095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3260"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12971931e35-true-d12972095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12971931e35-true-d12972095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e60-true-d12972192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3259"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e60-true-d12972192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12969803e60-true-d12972192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972126e7-true-d12972267e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3258"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972126e7-true-d12972267e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12972126e7-true-d12972267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972197e9-true-d12972306e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3257"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972197e9-true-d12972306e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12972197e9-true-d12972306e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972197e10-true-d12972354e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3256"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972197e10-true-d12972354e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12972197e10-true-d12972354e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972317e12-true-d12972422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3255"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972317e12-true-d12972422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12972317e12-true-d12972422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972317e35-true-d12972481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3254"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972317e35-true-d12972481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12972317e35-true-d12972481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972126e11-true-d12972558e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3253"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972126e11-true-d12972558e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12972126e11-true-d12972558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972512e16-true-d12972599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3252"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972512e16-true-d12972599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12972512e16-true-d12972599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e65-true-d12972671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3251"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e65-true-d12972671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12969803e65-true-d12972671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972610e15-true-d12972747e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3250"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972610e15-true-d12972747e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12972610e15-true-d12972747e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972610e35-true-d12972802e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3249"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972610e35-true-d12972802e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12972610e35-true-d12972802e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972610e39-true-d12972859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3248"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972610e39-true-d12972859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12972610e39-true-d12972859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12972610e42-true-d12972913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3247"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12972610e42-true-d12972913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12972610e42-true-d12972913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e69-true-d12978020e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="3246"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e69-true-d12978020e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d12969803e69-true-d12978020e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e16-true-d12979485e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3245"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e16-true-d12979485e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12978035e16-true-d12979485e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e77-true-d12979565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3244"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e77-true-d12979565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12978035e77-true-d12979565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979542e9-true-d12979609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3243"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979542e9-true-d12979609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12979542e9-true-d12979609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979542e29-true-d12979658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3242"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979542e29-true-d12979658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12979542e29-true-d12979658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e81-true-d12979694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3241"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e81-true-d12979694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12978035e81-true-d12979694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979682e2-true-d12979714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3240"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979682e2-true-d12979714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12979682e2-true-d12979714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979682e8-true-d12979755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3239"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979682e8-true-d12979755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12979682e8-true-d12979755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e85-true-d12979848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3238"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e85-true-d12979848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12978035e85-true-d12979848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979784e9-true-d12979908e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3237"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979784e9-true-d12979908e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12979784e9-true-d12979908e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e90-true-d12980030e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3236"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e90-true-d12980030e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12978035e90-true-d12980030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979957e10-true-d12980122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3235"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979957e10-true-d12980122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12979957e10-true-d12980122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979957e30-true-d12980161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3234"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979957e30-true-d12980161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12979957e30-true-d12980161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979957e34-true-d12980200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3233"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979957e34-true-d12980200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12979957e34-true-d12980200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12979957e39-true-d12980261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3232"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12979957e39-true-d12980261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12979957e39-true-d12980261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980224e12-true-d12980329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3231"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980224e12-true-d12980329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12980224e12-true-d12980329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980224e35-true-d12980388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3230"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980224e35-true-d12980388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12980224e35-true-d12980388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e94-true-d12980485e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3229"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e94-true-d12980485e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12978035e94-true-d12980485e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980419e7-true-d12980560e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3228"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980419e7-true-d12980560e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12980419e7-true-d12980560e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980490e9-true-d12980599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3227"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980490e9-true-d12980599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12980490e9-true-d12980599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980490e10-true-d12980647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3226"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980490e10-true-d12980647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12980490e10-true-d12980647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980610e12-true-d12980715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3225"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980610e12-true-d12980715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12980610e12-true-d12980715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980610e35-true-d12980774e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3224"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980610e35-true-d12980774e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12980610e35-true-d12980774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980419e11-true-d12980851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3223"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980419e11-true-d12980851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12980419e11-true-d12980851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980805e16-true-d12980892e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3222"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980805e16-true-d12980892e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12980805e16-true-d12980892e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e98-true-d12980964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3221"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e98-true-d12980964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12978035e98-true-d12980964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980903e15-true-d12981040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3220"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980903e15-true-d12981040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12980903e15-true-d12981040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980903e35-true-d12981095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3219"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980903e35-true-d12981095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12980903e35-true-d12981095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980903e39-true-d12981152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3218"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980903e39-true-d12981152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12980903e39-true-d12981152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12980903e42-true-d12981206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3217"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12980903e42-true-d12981206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12980903e42-true-d12981206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e126-true-d12981275e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3216"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e126-true-d12981275e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12978035e126-true-d12981275e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981285e13-true-d12981309e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3215"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12981285e13-true-d12981309e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12981285e13-true-d12981309e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981330e13-true-d12981354e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3214"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12981330e13-true-d12981354e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12981330e13-true-d12981354e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981375e13-true-d12981399e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3213"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12981375e13-true-d12981399e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12981375e13-true-d12981399e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981420e13-true-d12981454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3212"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12981420e13-true-d12981454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12981420e13-true-d12981454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12978035e130-true-d12981498e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3211"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12978035e130-true-d12981498e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12978035e130-true-d12981498e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981486e2-true-d12981525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3210"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d12981486e2-true-d12981525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12981486e2-true-d12981525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e16-true-d12982989e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3209"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e16-true-d12982989e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12981546e16-true-d12982989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e65-true-d12983063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3208"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e65-true-d12983063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12981546e65-true-d12983063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983040e9-true-d12983107e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3207"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983040e9-true-d12983107e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12983040e9-true-d12983107e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983040e29-true-d12983156e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3206"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983040e29-true-d12983156e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12983040e29-true-d12983156e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e69-true-d12983192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3205"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e69-true-d12983192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12981546e69-true-d12983192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983180e2-true-d12983212e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3204"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983180e2-true-d12983212e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12983180e2-true-d12983212e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983180e8-true-d12983253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3203"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983180e8-true-d12983253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12983180e8-true-d12983253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e73-true-d12983346e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3202"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e73-true-d12983346e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12981546e73-true-d12983346e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983282e9-true-d12983406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3201"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983282e9-true-d12983406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12983282e9-true-d12983406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e78-true-d12983528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3200"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e78-true-d12983528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12981546e78-true-d12983528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983455e10-true-d12983620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3199"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983455e10-true-d12983620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12983455e10-true-d12983620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983455e30-true-d12983659e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3198"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983455e30-true-d12983659e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12983455e30-true-d12983659e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983455e34-true-d12983698e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3197"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983455e34-true-d12983698e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12983455e34-true-d12983698e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983455e39-true-d12983759e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3196"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983455e39-true-d12983759e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12983455e39-true-d12983759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983722e12-true-d12983827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3195"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983722e12-true-d12983827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12983722e12-true-d12983827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983722e35-true-d12983886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3194"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983722e35-true-d12983886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12983722e35-true-d12983886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e82-true-d12983983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3193"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e82-true-d12983983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12981546e82-true-d12983983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983917e7-true-d12984058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3192"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983917e7-true-d12984058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12983917e7-true-d12984058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983988e9-true-d12984097e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3191"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983988e9-true-d12984097e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12983988e9-true-d12984097e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983988e10-true-d12984145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3190"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983988e10-true-d12984145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12983988e10-true-d12984145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984108e12-true-d12984213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3189"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984108e12-true-d12984213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12984108e12-true-d12984213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984108e35-true-d12984272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3188"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984108e35-true-d12984272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12984108e35-true-d12984272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12983917e11-true-d12984349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3187"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12983917e11-true-d12984349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12983917e11-true-d12984349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984303e16-true-d12984390e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3186"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984303e16-true-d12984390e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12984303e16-true-d12984390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e86-true-d12984462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3185"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e86-true-d12984462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12981546e86-true-d12984462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984401e15-true-d12984538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3184"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984401e15-true-d12984538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12984401e15-true-d12984538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984401e35-true-d12984593e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3183"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984401e35-true-d12984593e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12984401e35-true-d12984593e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984401e39-true-d12984650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3182"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984401e39-true-d12984650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12984401e39-true-d12984650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984401e42-true-d12984704e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3181"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984401e42-true-d12984704e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12984401e42-true-d12984704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e114-true-d12984773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3180"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e114-true-d12984773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12981546e114-true-d12984773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984783e13-true-d12984807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3179"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12984783e13-true-d12984807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12984783e13-true-d12984807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984828e13-true-d12984852e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3178"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12984828e13-true-d12984852e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12984828e13-true-d12984852e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984873e13-true-d12984897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3177"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12984873e13-true-d12984897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12984873e13-true-d12984897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984918e13-true-d12984952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3176"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12984918e13-true-d12984952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12984918e13-true-d12984952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12981546e118-true-d12984996e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3175"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12981546e118-true-d12984996e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12981546e118-true-d12984996e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12984984e2-true-d12985023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3174"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d12984984e2-true-d12985023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12984984e2-true-d12985023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e16-true-d12986547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="3173"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e16-true-d12986547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d12985044e16-true-d12986547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e100-true-d12986666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3172"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e100-true-d12986666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12985044e100-true-d12986666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12986643e9-true-d12986710e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3171"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12986643e9-true-d12986710e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12986643e9-true-d12986710e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12986643e29-true-d12986759e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3170"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12986643e29-true-d12986759e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12986643e29-true-d12986759e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e104-true-d12986795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3169"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e104-true-d12986795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12985044e104-true-d12986795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12986783e2-true-d12986815e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3168"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12986783e2-true-d12986815e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12986783e2-true-d12986815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12986783e8-true-d12986856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3167"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12986783e8-true-d12986856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12986783e8-true-d12986856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e108-true-d12986949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3166"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e108-true-d12986949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12985044e108-true-d12986949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12986885e9-true-d12987009e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3165"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12986885e9-true-d12987009e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12986885e9-true-d12987009e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e113-true-d12987131e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3164"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e113-true-d12987131e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12985044e113-true-d12987131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987058e10-true-d12987223e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3163"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987058e10-true-d12987223e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12987058e10-true-d12987223e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987058e30-true-d12987262e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3162"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987058e30-true-d12987262e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12987058e30-true-d12987262e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987058e34-true-d12987301e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3161"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987058e34-true-d12987301e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12987058e34-true-d12987301e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987058e39-true-d12987362e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3160"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987058e39-true-d12987362e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12987058e39-true-d12987362e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987325e12-true-d12987430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3159"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987325e12-true-d12987430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12987325e12-true-d12987430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987325e35-true-d12987489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3158"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987325e35-true-d12987489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12987325e35-true-d12987489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e117-true-d12987586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3157"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e117-true-d12987586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12985044e117-true-d12987586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987520e7-true-d12987661e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3156"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987520e7-true-d12987661e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12987520e7-true-d12987661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987591e9-true-d12987700e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3155"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987591e9-true-d12987700e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12987591e9-true-d12987700e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987591e10-true-d12987748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3154"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987591e10-true-d12987748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12987591e10-true-d12987748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987711e12-true-d12987816e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3153"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987711e12-true-d12987816e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12987711e12-true-d12987816e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987711e35-true-d12987875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3152"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987711e35-true-d12987875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12987711e35-true-d12987875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987520e11-true-d12987952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3151"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987520e11-true-d12987952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12987520e11-true-d12987952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12987906e16-true-d12987993e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3150"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12987906e16-true-d12987993e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12987906e16-true-d12987993e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e121-true-d12988065e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3149"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e121-true-d12988065e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12985044e121-true-d12988065e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988004e15-true-d12988141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3148"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12988004e15-true-d12988141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12988004e15-true-d12988141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988004e35-true-d12988196e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3147"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12988004e35-true-d12988196e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12988004e35-true-d12988196e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988004e39-true-d12988253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3146"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12988004e39-true-d12988253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12988004e39-true-d12988253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988004e42-true-d12988307e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3145"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12988004e42-true-d12988307e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12988004e42-true-d12988307e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e149-true-d12988376e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3144"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e149-true-d12988376e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12985044e149-true-d12988376e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988386e13-true-d12988410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3143"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12988386e13-true-d12988410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12988386e13-true-d12988410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988431e13-true-d12988455e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3142"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12988431e13-true-d12988455e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12988431e13-true-d12988455e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988476e13-true-d12988500e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3141"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12988476e13-true-d12988500e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12988476e13-true-d12988500e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988521e13-true-d12988555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3140"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12988521e13-true-d12988555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12988521e13-true-d12988555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e153-true-d12988599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3139"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e153-true-d12988599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12985044e153-true-d12988599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988587e2-true-d12988626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3138"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12988587e2-true-d12988626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12988587e2-true-d12988626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e158-true-d12988657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="3137"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e158-true-d12988657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d12985044e158-true-d12988657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12985044e162-true-d12988695e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="3136"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d12985044e162-true-d12988695e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d12985044e162-true-d12988695e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e16-true-d12990140e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3135"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e16-true-d12990140e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12988724e16-true-d12990140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e43-true-d12990193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3134"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e43-true-d12990193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12988724e43-true-d12990193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990170e9-true-d12990237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3133"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990170e9-true-d12990237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12990170e9-true-d12990237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990170e29-true-d12990286e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3132"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990170e29-true-d12990286e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12990170e29-true-d12990286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e47-true-d12990322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3131"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e47-true-d12990322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12988724e47-true-d12990322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990310e2-true-d12990342e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3130"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990310e2-true-d12990342e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12990310e2-true-d12990342e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990310e8-true-d12990383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3129"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990310e8-true-d12990383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12990310e8-true-d12990383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e52-true-d12990476e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3128"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e52-true-d12990476e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12988724e52-true-d12990476e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990412e9-true-d12990536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3127"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990412e9-true-d12990536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12990412e9-true-d12990536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e56-true-d12990658e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3126"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e56-true-d12990658e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12988724e56-true-d12990658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990585e10-true-d12990750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3125"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990585e10-true-d12990750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12990585e10-true-d12990750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990585e30-true-d12990789e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3124"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990585e30-true-d12990789e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12990585e30-true-d12990789e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990585e34-true-d12990828e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3123"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990585e34-true-d12990828e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12990585e34-true-d12990828e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990585e39-true-d12990889e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3122"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990585e39-true-d12990889e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12990585e39-true-d12990889e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990852e12-true-d12990957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3121"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990852e12-true-d12990957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12990852e12-true-d12990957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12990852e35-true-d12991016e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3120"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12990852e35-true-d12991016e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12990852e35-true-d12991016e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e60-true-d12991113e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3119"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e60-true-d12991113e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12988724e60-true-d12991113e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991047e7-true-d12991188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3118"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991047e7-true-d12991188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12991047e7-true-d12991188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991118e9-true-d12991227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3117"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991118e9-true-d12991227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12991118e9-true-d12991227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991118e10-true-d12991275e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3116"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991118e10-true-d12991275e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12991118e10-true-d12991275e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991238e12-true-d12991343e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3115"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991238e12-true-d12991343e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12991238e12-true-d12991343e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991238e35-true-d12991402e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3114"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991238e35-true-d12991402e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12991238e35-true-d12991402e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991047e11-true-d12991479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3113"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991047e11-true-d12991479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12991047e11-true-d12991479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991433e16-true-d12991520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3112"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991433e16-true-d12991520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12991433e16-true-d12991520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e65-true-d12991592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3111"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e65-true-d12991592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12988724e65-true-d12991592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991531e15-true-d12991668e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3110"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991531e15-true-d12991668e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12991531e15-true-d12991668e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991531e35-true-d12991723e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3109"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991531e35-true-d12991723e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12991531e35-true-d12991723e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991531e39-true-d12991780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3108"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991531e39-true-d12991780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12991531e39-true-d12991780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991531e42-true-d12991834e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3107"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12991531e42-true-d12991834e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12991531e42-true-d12991834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e92-true-d12991903e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3106"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e92-true-d12991903e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12988724e92-true-d12991903e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991913e13-true-d12991937e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3105"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12991913e13-true-d12991937e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12991913e13-true-d12991937e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12991958e13-true-d12991982e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3104"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12991958e13-true-d12991982e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12991958e13-true-d12991982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992003e13-true-d12992027e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3103"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12992003e13-true-d12992027e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12992003e13-true-d12992027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992048e13-true-d12992082e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3102"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12992048e13-true-d12992082e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12992048e13-true-d12992082e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12988724e97-true-d12992126e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3101"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12988724e97-true-d12992126e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12988724e97-true-d12992126e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992114e2-true-d12992153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3100"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12992114e2-true-d12992153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12992114e2-true-d12992153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e16-true-d12993597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="3099"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e16-true-d12993597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d12992174e16-true-d12993597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e53-true-d12993656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3098"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e53-true-d12993656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12992174e53-true-d12993656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12993633e9-true-d12993700e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3097"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12993633e9-true-d12993700e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12993633e9-true-d12993700e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12993633e29-true-d12993749e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3096"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12993633e29-true-d12993749e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12993633e29-true-d12993749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e58-true-d12993785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3095"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e58-true-d12993785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12992174e58-true-d12993785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12993773e2-true-d12993805e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3094"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12993773e2-true-d12993805e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12993773e2-true-d12993805e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12993773e8-true-d12993846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3093"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12993773e8-true-d12993846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12993773e8-true-d12993846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e62-true-d12993939e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3092"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e62-true-d12993939e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12992174e62-true-d12993939e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12993875e9-true-d12993999e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3091"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12993875e9-true-d12993999e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12993875e9-true-d12993999e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e66-true-d12994121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3090"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e66-true-d12994121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12992174e66-true-d12994121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994048e10-true-d12994213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3089"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994048e10-true-d12994213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12994048e10-true-d12994213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994048e30-true-d12994252e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3088"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994048e30-true-d12994252e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12994048e30-true-d12994252e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994048e34-true-d12994291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3087"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994048e34-true-d12994291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12994048e34-true-d12994291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994048e39-true-d12994352e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3086"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994048e39-true-d12994352e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12994048e39-true-d12994352e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994315e12-true-d12994420e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3085"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994315e12-true-d12994420e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12994315e12-true-d12994420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994315e35-true-d12994479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3084"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994315e35-true-d12994479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12994315e35-true-d12994479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e71-true-d12994576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3083"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e71-true-d12994576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12992174e71-true-d12994576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994510e7-true-d12994651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3082"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994510e7-true-d12994651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12994510e7-true-d12994651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994581e9-true-d12994690e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3081"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994581e9-true-d12994690e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12994581e9-true-d12994690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994581e10-true-d12994738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3080"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994581e10-true-d12994738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12994581e10-true-d12994738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994701e12-true-d12994806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3079"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994701e12-true-d12994806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12994701e12-true-d12994806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994701e35-true-d12994865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3078"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994701e35-true-d12994865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12994701e35-true-d12994865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994510e11-true-d12994942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3077"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994510e11-true-d12994942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12994510e11-true-d12994942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994896e16-true-d12994983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3076"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994896e16-true-d12994983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12994896e16-true-d12994983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e75-true-d12995055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3075"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e75-true-d12995055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12992174e75-true-d12995055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994994e15-true-d12995131e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3074"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994994e15-true-d12995131e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12994994e15-true-d12995131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994994e35-true-d12995186e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3073"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994994e35-true-d12995186e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12994994e35-true-d12995186e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994994e39-true-d12995243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3072"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994994e39-true-d12995243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12994994e39-true-d12995243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12994994e42-true-d12995297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3071"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12994994e42-true-d12995297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12994994e42-true-d12995297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e81-true-d12995357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3070"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e81-true-d12995357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12992174e81-true-d12995357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995367e13-true-d12995391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3069"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12995367e13-true-d12995391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12995367e13-true-d12995391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995412e13-true-d12995436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3068"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12995412e13-true-d12995436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12995412e13-true-d12995436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995457e13-true-d12995481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3067"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12995457e13-true-d12995481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12995457e13-true-d12995481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995502e13-true-d12995536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3066"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12995502e13-true-d12995536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12995502e13-true-d12995536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12992174e86-true-d12995580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3065"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12992174e86-true-d12995580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12992174e86-true-d12995580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995568e2-true-d12995607e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3064"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d12995568e2-true-d12995607e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12995568e2-true-d12995607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e16-true-d12997108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3063"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e16-true-d12997108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12995637e16-true-d12997108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e87-true-d12997206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3062"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e87-true-d12997206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12995637e87-true-d12997206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997183e9-true-d12997250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3061"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997183e9-true-d12997250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d12997183e9-true-d12997250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997183e29-true-d12997299e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3060"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997183e29-true-d12997299e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d12997183e29-true-d12997299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e92-true-d12997335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3059"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e92-true-d12997335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12995637e92-true-d12997335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997323e2-true-d12997355e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3058"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997323e2-true-d12997355e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d12997323e2-true-d12997355e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997323e8-true-d12997396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3057"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997323e8-true-d12997396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12997323e8-true-d12997396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e96-true-d12997489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3056"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e96-true-d12997489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12995637e96-true-d12997489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997425e9-true-d12997549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3055"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997425e9-true-d12997549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12997425e9-true-d12997549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e100-true-d12997671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3054"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e100-true-d12997671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12995637e100-true-d12997671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997598e10-true-d12997763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3053"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997598e10-true-d12997763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d12997598e10-true-d12997763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997598e30-true-d12997802e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3052"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997598e30-true-d12997802e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12997598e30-true-d12997802e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997598e34-true-d12997841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3051"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997598e34-true-d12997841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12997598e34-true-d12997841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997598e39-true-d12997902e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3050"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997598e39-true-d12997902e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12997598e39-true-d12997902e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997865e12-true-d12997970e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3049"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997865e12-true-d12997970e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12997865e12-true-d12997970e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12997865e35-true-d12998029e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3048"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12997865e35-true-d12998029e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12997865e35-true-d12998029e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e105-true-d12998126e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3047"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e105-true-d12998126e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12995637e105-true-d12998126e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998060e7-true-d12998201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3046"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998060e7-true-d12998201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d12998060e7-true-d12998201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998131e9-true-d12998240e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3045"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998131e9-true-d12998240e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12998131e9-true-d12998240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998131e10-true-d12998288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3044"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998131e10-true-d12998288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d12998131e10-true-d12998288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998251e12-true-d12998356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3043"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998251e12-true-d12998356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d12998251e12-true-d12998356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998251e35-true-d12998415e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3042"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998251e35-true-d12998415e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d12998251e35-true-d12998415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998060e11-true-d12998492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3041"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998060e11-true-d12998492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d12998060e11-true-d12998492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998446e16-true-d12998533e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3040"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998446e16-true-d12998533e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d12998446e16-true-d12998533e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e109-true-d12998605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3039"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e109-true-d12998605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12995637e109-true-d12998605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998544e15-true-d12998681e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3038"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998544e15-true-d12998681e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d12998544e15-true-d12998681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998544e35-true-d12998736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3037"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998544e35-true-d12998736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d12998544e35-true-d12998736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998544e39-true-d12998793e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3036"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998544e39-true-d12998793e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d12998544e39-true-d12998793e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998544e42-true-d12998847e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="3035"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12998544e42-true-d12998847e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d12998544e42-true-d12998847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e137-true-d12998916e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="3034"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e137-true-d12998916e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12995637e137-true-d12998916e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998926e13-true-d12998950e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3033"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d12998926e13-true-d12998950e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12998926e13-true-d12998950e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12998971e13-true-d12998995e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3032"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d12998971e13-true-d12998995e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12998971e13-true-d12998995e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999016e13-true-d12999040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="3031"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d12999016e13-true-d12999040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d12999016e13-true-d12999040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999061e13-true-d12999095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="3030"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d12999061e13-true-d12999095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d12999061e13-true-d12999095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12995637e141-true-d12999139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="3029"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12995637e141-true-d12999139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12995637e141-true-d12999139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999127e2-true-d12999166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="3028"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d12999127e2-true-d12999166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d12999127e2-true-d12999166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e16-true-d13000603e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="3027"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e16-true-d13000603e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d12999187e16-true-d13000603e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e43-true-d13000656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="3026"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e43-true-d13000656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d12999187e43-true-d13000656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13000633e9-true-d13000700e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="3025"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13000633e9-true-d13000700e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13000633e9-true-d13000700e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13000633e29-true-d13000749e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="3024"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13000633e29-true-d13000749e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13000633e29-true-d13000749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e47-true-d13000785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="3023"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e47-true-d13000785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d12999187e47-true-d13000785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13000773e2-true-d13000805e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="3022"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13000773e2-true-d13000805e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13000773e2-true-d13000805e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13000773e8-true-d13000846e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3021"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13000773e8-true-d13000846e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13000773e8-true-d13000846e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e52-true-d13000939e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="3020"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e52-true-d13000939e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d12999187e52-true-d13000939e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13000875e9-true-d13000999e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3019"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13000875e9-true-d13000999e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13000875e9-true-d13000999e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e56-true-d13001121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="3018"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e56-true-d13001121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d12999187e56-true-d13001121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001048e10-true-d13001213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="3017"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001048e10-true-d13001213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13001048e10-true-d13001213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001048e30-true-d13001252e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3016"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001048e30-true-d13001252e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13001048e30-true-d13001252e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001048e34-true-d13001291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3015"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001048e34-true-d13001291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13001048e34-true-d13001291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001048e39-true-d13001352e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3014"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001048e39-true-d13001352e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13001048e39-true-d13001352e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001315e12-true-d13001420e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3013"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001315e12-true-d13001420e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13001315e12-true-d13001420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001315e35-true-d13001479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3012"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001315e35-true-d13001479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13001315e35-true-d13001479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e60-true-d13001576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="3011"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e60-true-d13001576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d12999187e60-true-d13001576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001510e7-true-d13001651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="3010"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001510e7-true-d13001651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13001510e7-true-d13001651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001581e9-true-d13001690e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="3009"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001581e9-true-d13001690e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13001581e9-true-d13001690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001581e10-true-d13001738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="3008"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001581e10-true-d13001738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13001581e10-true-d13001738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001701e12-true-d13001806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="3007"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001701e12-true-d13001806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13001701e12-true-d13001806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001701e35-true-d13001865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="3006"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001701e35-true-d13001865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13001701e35-true-d13001865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001510e11-true-d13001942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="3005"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001510e11-true-d13001942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13001510e11-true-d13001942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001896e16-true-d13001983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="3004"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001896e16-true-d13001983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13001896e16-true-d13001983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e65-true-d13002055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="3003"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e65-true-d13002055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d12999187e65-true-d13002055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001994e15-true-d13002131e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="3002"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001994e15-true-d13002131e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13001994e15-true-d13002131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001994e35-true-d13002186e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="3001"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001994e35-true-d13002186e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13001994e35-true-d13002186e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001994e39-true-d13002243e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="3000"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001994e39-true-d13002243e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13001994e39-true-d13002243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13001994e42-true-d13002297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2999"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13001994e42-true-d13002297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13001994e42-true-d13002297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e92-true-d13002366e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2998"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e92-true-d13002366e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12999187e92-true-d13002366e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002376e13-true-d13002400e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2997"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13002376e13-true-d13002400e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13002376e13-true-d13002400e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002421e13-true-d13002445e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2996"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13002421e13-true-d13002445e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13002421e13-true-d13002445e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002466e13-true-d13002490e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2995"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13002466e13-true-d13002490e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13002466e13-true-d13002490e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002511e13-true-d13002545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2994"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13002511e13-true-d13002545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13002511e13-true-d13002545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12999187e97-true-d13002589e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2993"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d12999187e97-true-d13002589e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12999187e97-true-d13002589e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002577e2-true-d13002616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2992"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13002577e2-true-d13002616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13002577e2-true-d13002616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e16-true-d13004176e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2991"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e16-true-d13004176e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13002637e16-true-d13004176e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e95-true-d13004292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2990"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e95-true-d13004292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13002637e95-true-d13004292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004269e9-true-d13004336e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2989"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004269e9-true-d13004336e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13004269e9-true-d13004336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004269e29-true-d13004385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2988"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004269e29-true-d13004385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13004269e29-true-d13004385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e99-true-d13004421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2987"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e99-true-d13004421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13002637e99-true-d13004421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004409e2-true-d13004441e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2986"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004409e2-true-d13004441e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13004409e2-true-d13004441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004409e8-true-d13004482e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2985"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004409e8-true-d13004482e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13004409e8-true-d13004482e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e103-true-d13004559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="2984"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e103-true-d13004559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13002637e103-true-d13004559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004511e5-true-d13004615e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="2983"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004511e5-true-d13004615e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13004511e5-true-d13004615e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004625e13-true-d13004642e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="2982"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13004625e13-true-d13004642e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13004625e13-true-d13004642e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004657e13-true-d13004685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="2981"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13004657e13-true-d13004685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13004657e13-true-d13004685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004511e24-true-d13004746e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2980"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004511e24-true-d13004746e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13004511e24-true-d13004746e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004709e12-true-d13004814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2979"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004709e12-true-d13004814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13004709e12-true-d13004814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004709e35-true-d13004873e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2978"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004709e35-true-d13004873e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13004709e35-true-d13004873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e111-true-d13004968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2977"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e111-true-d13004968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13002637e111-true-d13004968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13004904e9-true-d13005028e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2976"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13004904e9-true-d13005028e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13004904e9-true-d13005028e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e115-true-d13005150e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2975"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e115-true-d13005150e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13002637e115-true-d13005150e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005077e10-true-d13005242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2974"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005077e10-true-d13005242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13005077e10-true-d13005242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005077e30-true-d13005281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2973"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005077e30-true-d13005281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13005077e30-true-d13005281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005077e34-true-d13005320e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2972"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005077e34-true-d13005320e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13005077e34-true-d13005320e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005077e39-true-d13005381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2971"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005077e39-true-d13005381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13005077e39-true-d13005381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005344e12-true-d13005449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2970"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005344e12-true-d13005449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13005344e12-true-d13005449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005344e35-true-d13005508e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2969"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005344e35-true-d13005508e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13005344e35-true-d13005508e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e119-true-d13005605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2968"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e119-true-d13005605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13002637e119-true-d13005605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005539e7-true-d13005680e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2967"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005539e7-true-d13005680e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13005539e7-true-d13005680e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005610e9-true-d13005719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2966"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005610e9-true-d13005719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13005610e9-true-d13005719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005610e10-true-d13005767e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2965"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005610e10-true-d13005767e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13005610e10-true-d13005767e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005730e12-true-d13005835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2964"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005730e12-true-d13005835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13005730e12-true-d13005835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005730e35-true-d13005894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2963"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005730e35-true-d13005894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13005730e35-true-d13005894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005539e11-true-d13005971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2962"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005539e11-true-d13005971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13005539e11-true-d13005971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13005925e16-true-d13006012e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2961"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13005925e16-true-d13006012e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13005925e16-true-d13006012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e124-true-d13006084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2960"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e124-true-d13006084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13002637e124-true-d13006084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006023e15-true-d13006160e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2959"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13006023e15-true-d13006160e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13006023e15-true-d13006160e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006023e35-true-d13006215e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2958"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13006023e35-true-d13006215e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13006023e35-true-d13006215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006023e39-true-d13006272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2957"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13006023e39-true-d13006272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13006023e39-true-d13006272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006023e42-true-d13006326e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2956"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13006023e42-true-d13006326e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13006023e42-true-d13006326e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e151-true-d13006395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2955"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e151-true-d13006395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13002637e151-true-d13006395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006405e13-true-d13006429e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2954"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13006405e13-true-d13006429e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13006405e13-true-d13006429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006450e13-true-d13006474e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2953"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13006450e13-true-d13006474e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13006450e13-true-d13006474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006495e13-true-d13006519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2952"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13006495e13-true-d13006519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13006495e13-true-d13006519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006540e13-true-d13006574e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2951"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13006540e13-true-d13006574e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13006540e13-true-d13006574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13002637e156-true-d13006618e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2950"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13002637e156-true-d13006618e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13002637e156-true-d13006618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006606e2-true-d13006645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2949"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13006606e2-true-d13006645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13006606e2-true-d13006645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e16-true-d13008172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2948"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e16-true-d13008172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13006666e16-true-d13008172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e71-true-d13008264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2947"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e71-true-d13008264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13006666e71-true-d13008264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008241e9-true-d13008308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2946"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008241e9-true-d13008308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13008241e9-true-d13008308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008241e29-true-d13008357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2945"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008241e29-true-d13008357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13008241e29-true-d13008357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e76-true-d13008393e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2944"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e76-true-d13008393e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13006666e76-true-d13008393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008381e2-true-d13008413e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2943"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008381e2-true-d13008413e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13008381e2-true-d13008413e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008381e8-true-d13008454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2942"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008381e8-true-d13008454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13008381e8-true-d13008454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e80-true-d13008531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="2941"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e80-true-d13008531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13006666e80-true-d13008531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008483e5-true-d13008587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="2940"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008483e5-true-d13008587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13008483e5-true-d13008587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008597e13-true-d13008614e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="2939"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13008597e13-true-d13008614e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13008597e13-true-d13008614e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008629e13-true-d13008657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="2938"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13008629e13-true-d13008657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13008629e13-true-d13008657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008483e24-true-d13008718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2937"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008483e24-true-d13008718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13008483e24-true-d13008718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008681e12-true-d13008786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2936"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008681e12-true-d13008786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13008681e12-true-d13008786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008681e35-true-d13008845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2935"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008681e35-true-d13008845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13008681e35-true-d13008845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e87-true-d13008940e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2934"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e87-true-d13008940e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13006666e87-true-d13008940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13008876e9-true-d13009000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2933"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13008876e9-true-d13009000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13008876e9-true-d13009000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e92-true-d13009122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2932"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e92-true-d13009122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13006666e92-true-d13009122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009049e10-true-d13009214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2931"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009049e10-true-d13009214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13009049e10-true-d13009214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009049e30-true-d13009253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2930"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009049e30-true-d13009253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13009049e30-true-d13009253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009049e34-true-d13009292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2929"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009049e34-true-d13009292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13009049e34-true-d13009292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009049e39-true-d13009353e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2928"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009049e39-true-d13009353e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13009049e39-true-d13009353e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009316e12-true-d13009421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2927"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009316e12-true-d13009421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13009316e12-true-d13009421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009316e35-true-d13009480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2926"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009316e35-true-d13009480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13009316e35-true-d13009480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e96-true-d13009577e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2925"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e96-true-d13009577e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13006666e96-true-d13009577e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009511e7-true-d13009652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2924"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009511e7-true-d13009652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13009511e7-true-d13009652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009582e9-true-d13009691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2923"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009582e9-true-d13009691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13009582e9-true-d13009691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009582e10-true-d13009739e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2922"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009582e10-true-d13009739e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13009582e10-true-d13009739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009702e12-true-d13009807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2921"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009702e12-true-d13009807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13009702e12-true-d13009807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009702e35-true-d13009866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2920"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009702e35-true-d13009866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13009702e35-true-d13009866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009511e11-true-d13009943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2919"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009511e11-true-d13009943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13009511e11-true-d13009943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009897e16-true-d13009984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2918"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009897e16-true-d13009984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13009897e16-true-d13009984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e100-true-d13010056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2917"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e100-true-d13010056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13006666e100-true-d13010056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009995e15-true-d13010132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2916"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009995e15-true-d13010132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13009995e15-true-d13010132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009995e35-true-d13010187e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2915"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009995e35-true-d13010187e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13009995e35-true-d13010187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009995e39-true-d13010244e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2914"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009995e39-true-d13010244e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13009995e39-true-d13010244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13009995e42-true-d13010298e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2913"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13009995e42-true-d13010298e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13009995e42-true-d13010298e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e128-true-d13010367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2912"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e128-true-d13010367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13006666e128-true-d13010367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010377e13-true-d13010401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2911"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13010377e13-true-d13010401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13010377e13-true-d13010401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010422e13-true-d13010446e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2910"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13010422e13-true-d13010446e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13010422e13-true-d13010446e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010467e13-true-d13010491e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2909"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13010467e13-true-d13010491e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13010467e13-true-d13010491e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010512e13-true-d13010546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2908"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13010512e13-true-d13010546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13010512e13-true-d13010546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13006666e132-true-d13010590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2907"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13006666e132-true-d13010590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13006666e132-true-d13010590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010578e2-true-d13010617e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2906"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13010578e2-true-d13010617e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13010578e2-true-d13010617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e92-true-d13010675e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2905"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e92-true-d13010675e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d12969803e92-true-d13010675e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010685e13-true-d13010709e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2904"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13010685e13-true-d13010709e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13010685e13-true-d13010709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010730e13-true-d13010754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2903"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13010730e13-true-d13010754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13010730e13-true-d13010754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010775e13-true-d13010799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2902"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13010775e13-true-d13010799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13010775e13-true-d13010799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010820e13-true-d13010854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2901"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13010820e13-true-d13010854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13010820e13-true-d13010854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d12969803e97-true-d13010898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2900"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d12969803e97-true-d13010898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d12969803e97-true-d13010898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010886e2-true-d13010925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2899"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13010886e2-true-d13010925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13010886e2-true-d13010925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e16-true-d13012369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="2898"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e16-true-d13012369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d13010946e16-true-d13012369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e53-true-d13012428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2897"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e53-true-d13012428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13010946e53-true-d13012428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012405e9-true-d13012472e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2896"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012405e9-true-d13012472e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13012405e9-true-d13012472e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012405e29-true-d13012521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2895"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012405e29-true-d13012521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13012405e29-true-d13012521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e58-true-d13012557e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2894"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e58-true-d13012557e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13010946e58-true-d13012557e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012545e2-true-d13012577e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2893"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012545e2-true-d13012577e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13012545e2-true-d13012577e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012545e8-true-d13012618e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2892"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012545e8-true-d13012618e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13012545e8-true-d13012618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e62-true-d13012711e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2891"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e62-true-d13012711e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13010946e62-true-d13012711e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012647e9-true-d13012771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2890"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012647e9-true-d13012771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13012647e9-true-d13012771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e66-true-d13012893e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2889"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e66-true-d13012893e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13010946e66-true-d13012893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012820e10-true-d13012985e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2888"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012820e10-true-d13012985e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13012820e10-true-d13012985e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012820e30-true-d13013024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2887"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012820e30-true-d13013024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13012820e30-true-d13013024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012820e34-true-d13013063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2886"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012820e34-true-d13013063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13012820e34-true-d13013063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13012820e39-true-d13013124e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2885"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13012820e39-true-d13013124e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13012820e39-true-d13013124e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013087e12-true-d13013192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2884"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013087e12-true-d13013192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13013087e12-true-d13013192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013087e35-true-d13013251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2883"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013087e35-true-d13013251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13013087e35-true-d13013251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e71-true-d13013348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2882"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e71-true-d13013348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13010946e71-true-d13013348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013282e7-true-d13013423e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2881"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013282e7-true-d13013423e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13013282e7-true-d13013423e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013353e9-true-d13013462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2880"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013353e9-true-d13013462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13013353e9-true-d13013462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013353e10-true-d13013510e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2879"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013353e10-true-d13013510e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13013353e10-true-d13013510e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013473e12-true-d13013578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2878"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013473e12-true-d13013578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13013473e12-true-d13013578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013473e35-true-d13013637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2877"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013473e35-true-d13013637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13013473e35-true-d13013637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013282e11-true-d13013714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2876"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013282e11-true-d13013714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13013282e11-true-d13013714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013668e16-true-d13013755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2875"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013668e16-true-d13013755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13013668e16-true-d13013755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e75-true-d13013827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2874"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e75-true-d13013827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13010946e75-true-d13013827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013766e15-true-d13013903e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2873"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013766e15-true-d13013903e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13013766e15-true-d13013903e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013766e35-true-d13013958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2872"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013766e35-true-d13013958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13013766e35-true-d13013958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013766e39-true-d13014015e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2871"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013766e39-true-d13014015e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13013766e39-true-d13014015e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13013766e42-true-d13014069e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2870"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13013766e42-true-d13014069e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13013766e42-true-d13014069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e81-true-d13014129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2869"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e81-true-d13014129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13010946e81-true-d13014129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13014139e13-true-d13014163e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2868"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13014139e13-true-d13014163e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13014139e13-true-d13014163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13014184e13-true-d13014208e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2867"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13014184e13-true-d13014208e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13014184e13-true-d13014208e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13014229e13-true-d13014253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2866"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13014229e13-true-d13014253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13014229e13-true-d13014253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13014274e13-true-d13014308e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2865"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13014274e13-true-d13014308e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13014274e13-true-d13014308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e86-true-d13014352e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2864"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e86-true-d13014352e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13010946e86-true-d13014352e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13014340e2-true-d13014379e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2863"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13014340e2-true-d13014379e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13014340e2-true-d13014379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13010946e92-true-d13019484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="2862"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13010946e92-true-d13019484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d13010946e92-true-d13019484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e16-true-d13020949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2861"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e16-true-d13020949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13019499e16-true-d13020949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e77-true-d13021029e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2860"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e77-true-d13021029e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13019499e77-true-d13021029e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021006e9-true-d13021073e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2859"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021006e9-true-d13021073e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13021006e9-true-d13021073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021006e29-true-d13021122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2858"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021006e29-true-d13021122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13021006e29-true-d13021122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e81-true-d13021158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2857"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e81-true-d13021158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13019499e81-true-d13021158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021146e2-true-d13021178e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2856"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021146e2-true-d13021178e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13021146e2-true-d13021178e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021146e8-true-d13021219e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2855"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021146e8-true-d13021219e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13021146e8-true-d13021219e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e85-true-d13021312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2854"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e85-true-d13021312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13019499e85-true-d13021312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021248e9-true-d13021372e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2853"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021248e9-true-d13021372e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13021248e9-true-d13021372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e90-true-d13021494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2852"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e90-true-d13021494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13019499e90-true-d13021494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021421e10-true-d13021586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2851"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021421e10-true-d13021586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13021421e10-true-d13021586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021421e30-true-d13021625e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2850"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021421e30-true-d13021625e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13021421e30-true-d13021625e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021421e34-true-d13021664e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2849"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021421e34-true-d13021664e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13021421e34-true-d13021664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021421e39-true-d13021725e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2848"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021421e39-true-d13021725e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13021421e39-true-d13021725e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021688e12-true-d13021793e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2847"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021688e12-true-d13021793e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13021688e12-true-d13021793e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021688e35-true-d13021852e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2846"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021688e35-true-d13021852e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13021688e35-true-d13021852e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e94-true-d13021949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2845"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e94-true-d13021949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13019499e94-true-d13021949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021883e7-true-d13022024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2844"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021883e7-true-d13022024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13021883e7-true-d13022024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021954e9-true-d13022063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2843"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021954e9-true-d13022063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13021954e9-true-d13022063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021954e10-true-d13022111e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2842"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021954e10-true-d13022111e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13021954e10-true-d13022111e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022074e12-true-d13022179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2841"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022074e12-true-d13022179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13022074e12-true-d13022179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022074e35-true-d13022238e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2840"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022074e35-true-d13022238e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13022074e35-true-d13022238e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13021883e11-true-d13022315e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2839"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13021883e11-true-d13022315e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13021883e11-true-d13022315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022269e16-true-d13022356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2838"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022269e16-true-d13022356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13022269e16-true-d13022356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e98-true-d13022428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2837"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e98-true-d13022428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13019499e98-true-d13022428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022367e15-true-d13022504e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2836"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022367e15-true-d13022504e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13022367e15-true-d13022504e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022367e35-true-d13022559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2835"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022367e35-true-d13022559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13022367e35-true-d13022559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022367e39-true-d13022616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2834"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022367e39-true-d13022616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13022367e39-true-d13022616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022367e42-true-d13022670e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2833"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022367e42-true-d13022670e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13022367e42-true-d13022670e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e126-true-d13022739e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2832"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e126-true-d13022739e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13019499e126-true-d13022739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022749e13-true-d13022773e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2831"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13022749e13-true-d13022773e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13022749e13-true-d13022773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022794e13-true-d13022818e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2830"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13022794e13-true-d13022818e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13022794e13-true-d13022818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022839e13-true-d13022863e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2829"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13022839e13-true-d13022863e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13022839e13-true-d13022863e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022884e13-true-d13022918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2828"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13022884e13-true-d13022918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13022884e13-true-d13022918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13019499e130-true-d13022962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2827"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13019499e130-true-d13022962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13019499e130-true-d13022962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13022950e2-true-d13022989e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2826"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13022950e2-true-d13022989e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13022950e2-true-d13022989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e16-true-d13024453e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2825"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e16-true-d13024453e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13023010e16-true-d13024453e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e65-true-d13024527e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2824"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e65-true-d13024527e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13023010e65-true-d13024527e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024504e9-true-d13024571e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2823"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024504e9-true-d13024571e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13024504e9-true-d13024571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024504e29-true-d13024620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2822"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024504e29-true-d13024620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13024504e29-true-d13024620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e69-true-d13024656e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2821"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e69-true-d13024656e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13023010e69-true-d13024656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024644e2-true-d13024676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2820"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024644e2-true-d13024676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13024644e2-true-d13024676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024644e8-true-d13024717e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2819"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024644e8-true-d13024717e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13024644e8-true-d13024717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e73-true-d13024810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2818"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e73-true-d13024810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13023010e73-true-d13024810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024746e9-true-d13024870e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2817"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024746e9-true-d13024870e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13024746e9-true-d13024870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e78-true-d13024992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2816"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e78-true-d13024992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13023010e78-true-d13024992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024919e10-true-d13025084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2815"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024919e10-true-d13025084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13024919e10-true-d13025084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024919e30-true-d13025123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2814"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024919e30-true-d13025123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13024919e30-true-d13025123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024919e34-true-d13025162e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2813"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024919e34-true-d13025162e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13024919e34-true-d13025162e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13024919e39-true-d13025223e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2812"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13024919e39-true-d13025223e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13024919e39-true-d13025223e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025186e12-true-d13025291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2811"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025186e12-true-d13025291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13025186e12-true-d13025291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025186e35-true-d13025350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2810"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025186e35-true-d13025350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13025186e35-true-d13025350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e82-true-d13025447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2809"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e82-true-d13025447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13023010e82-true-d13025447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025381e7-true-d13025522e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2808"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025381e7-true-d13025522e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13025381e7-true-d13025522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025452e9-true-d13025561e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2807"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025452e9-true-d13025561e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13025452e9-true-d13025561e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025452e10-true-d13025609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2806"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025452e10-true-d13025609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13025452e10-true-d13025609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025572e12-true-d13025677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2805"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025572e12-true-d13025677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13025572e12-true-d13025677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025572e35-true-d13025736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2804"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025572e35-true-d13025736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13025572e35-true-d13025736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025381e11-true-d13025813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2803"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025381e11-true-d13025813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13025381e11-true-d13025813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025767e16-true-d13025854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2802"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025767e16-true-d13025854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13025767e16-true-d13025854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e86-true-d13025926e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2801"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e86-true-d13025926e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13023010e86-true-d13025926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025865e15-true-d13026002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2800"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025865e15-true-d13026002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13025865e15-true-d13026002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025865e35-true-d13026057e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2799"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025865e35-true-d13026057e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13025865e35-true-d13026057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025865e39-true-d13026114e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2798"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025865e39-true-d13026114e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13025865e39-true-d13026114e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13025865e42-true-d13026168e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2797"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13025865e42-true-d13026168e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13025865e42-true-d13026168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e114-true-d13026237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2796"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e114-true-d13026237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13023010e114-true-d13026237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026247e13-true-d13026271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2795"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13026247e13-true-d13026271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13026247e13-true-d13026271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026292e13-true-d13026316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2794"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13026292e13-true-d13026316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13026292e13-true-d13026316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026337e13-true-d13026361e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2793"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13026337e13-true-d13026361e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13026337e13-true-d13026361e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026382e13-true-d13026416e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2792"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13026382e13-true-d13026416e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13026382e13-true-d13026416e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13023010e118-true-d13026460e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2791"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13023010e118-true-d13026460e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13023010e118-true-d13026460e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026448e2-true-d13026487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2790"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13026448e2-true-d13026487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13026448e2-true-d13026487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e16-true-d13028011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="2789"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e16-true-d13028011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d13026508e16-true-d13028011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e100-true-d13028130e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2788"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e100-true-d13028130e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13026508e100-true-d13028130e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028107e9-true-d13028174e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2787"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028107e9-true-d13028174e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13028107e9-true-d13028174e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028107e29-true-d13028223e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2786"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028107e29-true-d13028223e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13028107e29-true-d13028223e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e104-true-d13028259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2785"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e104-true-d13028259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13026508e104-true-d13028259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028247e2-true-d13028279e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2784"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028247e2-true-d13028279e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13028247e2-true-d13028279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028247e8-true-d13028320e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2783"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028247e8-true-d13028320e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13028247e8-true-d13028320e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e108-true-d13028413e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2782"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e108-true-d13028413e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13026508e108-true-d13028413e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028349e9-true-d13028473e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2781"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028349e9-true-d13028473e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13028349e9-true-d13028473e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e113-true-d13028595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2780"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e113-true-d13028595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13026508e113-true-d13028595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028522e10-true-d13028687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2779"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028522e10-true-d13028687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13028522e10-true-d13028687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028522e30-true-d13028726e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2778"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028522e30-true-d13028726e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13028522e30-true-d13028726e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028522e34-true-d13028765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2777"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028522e34-true-d13028765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13028522e34-true-d13028765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028522e39-true-d13028826e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2776"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028522e39-true-d13028826e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13028522e39-true-d13028826e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028789e12-true-d13028894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2775"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028789e12-true-d13028894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13028789e12-true-d13028894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028789e35-true-d13028953e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2774"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028789e35-true-d13028953e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13028789e35-true-d13028953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e117-true-d13029050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2773"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e117-true-d13029050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13026508e117-true-d13029050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028984e7-true-d13029125e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2772"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028984e7-true-d13029125e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13028984e7-true-d13029125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029055e9-true-d13029164e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2771"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029055e9-true-d13029164e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13029055e9-true-d13029164e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029055e10-true-d13029212e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2770"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029055e10-true-d13029212e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13029055e10-true-d13029212e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029175e12-true-d13029280e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2769"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029175e12-true-d13029280e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13029175e12-true-d13029280e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029175e35-true-d13029339e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2768"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029175e35-true-d13029339e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13029175e35-true-d13029339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13028984e11-true-d13029416e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2767"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13028984e11-true-d13029416e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13028984e11-true-d13029416e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029370e16-true-d13029457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2766"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029370e16-true-d13029457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13029370e16-true-d13029457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e121-true-d13029529e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2765"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e121-true-d13029529e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13026508e121-true-d13029529e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029468e15-true-d13029605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2764"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029468e15-true-d13029605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13029468e15-true-d13029605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029468e35-true-d13029660e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2763"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029468e35-true-d13029660e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13029468e35-true-d13029660e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029468e39-true-d13029717e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2762"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029468e39-true-d13029717e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13029468e39-true-d13029717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029468e42-true-d13029771e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2761"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13029468e42-true-d13029771e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13029468e42-true-d13029771e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e149-true-d13029840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2760"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e149-true-d13029840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13026508e149-true-d13029840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029850e13-true-d13029874e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2759"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13029850e13-true-d13029874e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13029850e13-true-d13029874e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029895e13-true-d13029919e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2758"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13029895e13-true-d13029919e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13029895e13-true-d13029919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029940e13-true-d13029964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2757"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13029940e13-true-d13029964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13029940e13-true-d13029964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13029985e13-true-d13030019e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2756"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13029985e13-true-d13030019e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13029985e13-true-d13030019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e153-true-d13030063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2755"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e153-true-d13030063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13026508e153-true-d13030063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030051e2-true-d13030090e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2754"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13030051e2-true-d13030090e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13030051e2-true-d13030090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e158-true-d13030121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="2753"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e158-true-d13030121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d13026508e158-true-d13030121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13026508e162-true-d13030159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="2752"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13026508e162-true-d13030159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d13026508e162-true-d13030159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e16-true-d13031604e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2751"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e16-true-d13031604e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13030188e16-true-d13031604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e43-true-d13031657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2750"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e43-true-d13031657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13030188e43-true-d13031657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13031634e9-true-d13031701e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2749"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13031634e9-true-d13031701e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13031634e9-true-d13031701e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13031634e29-true-d13031750e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2748"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13031634e29-true-d13031750e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13031634e29-true-d13031750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e47-true-d13031786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2747"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e47-true-d13031786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13030188e47-true-d13031786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13031774e2-true-d13031806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2746"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13031774e2-true-d13031806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13031774e2-true-d13031806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13031774e8-true-d13031847e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2745"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13031774e8-true-d13031847e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13031774e8-true-d13031847e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e52-true-d13031940e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2744"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e52-true-d13031940e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13030188e52-true-d13031940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13031876e9-true-d13032000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2743"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13031876e9-true-d13032000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13031876e9-true-d13032000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e56-true-d13032122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2742"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e56-true-d13032122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13030188e56-true-d13032122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032049e10-true-d13032214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2741"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032049e10-true-d13032214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13032049e10-true-d13032214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032049e30-true-d13032253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2740"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032049e30-true-d13032253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13032049e30-true-d13032253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032049e34-true-d13032292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2739"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032049e34-true-d13032292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13032049e34-true-d13032292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032049e39-true-d13032353e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2738"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032049e39-true-d13032353e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13032049e39-true-d13032353e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032316e12-true-d13032421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2737"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032316e12-true-d13032421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13032316e12-true-d13032421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032316e35-true-d13032480e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2736"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032316e35-true-d13032480e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13032316e35-true-d13032480e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e60-true-d13032577e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2735"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e60-true-d13032577e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13030188e60-true-d13032577e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032511e7-true-d13032652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2734"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032511e7-true-d13032652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13032511e7-true-d13032652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032582e9-true-d13032691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2733"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032582e9-true-d13032691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13032582e9-true-d13032691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032582e10-true-d13032739e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2732"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032582e10-true-d13032739e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13032582e10-true-d13032739e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032702e12-true-d13032807e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2731"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032702e12-true-d13032807e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13032702e12-true-d13032807e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032702e35-true-d13032866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2730"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032702e35-true-d13032866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13032702e35-true-d13032866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032511e11-true-d13032943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2729"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032511e11-true-d13032943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13032511e11-true-d13032943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032897e16-true-d13032984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2728"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032897e16-true-d13032984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13032897e16-true-d13032984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e65-true-d13033056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2727"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e65-true-d13033056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13030188e65-true-d13033056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032995e15-true-d13033132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2726"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032995e15-true-d13033132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13032995e15-true-d13033132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032995e35-true-d13033187e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2725"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032995e35-true-d13033187e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13032995e35-true-d13033187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032995e39-true-d13033244e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2724"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032995e39-true-d13033244e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13032995e39-true-d13033244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13032995e42-true-d13033298e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2723"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13032995e42-true-d13033298e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13032995e42-true-d13033298e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e92-true-d13033367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2722"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e92-true-d13033367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13030188e92-true-d13033367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033377e13-true-d13033401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2721"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13033377e13-true-d13033401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13033377e13-true-d13033401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033422e13-true-d13033446e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2720"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13033422e13-true-d13033446e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13033422e13-true-d13033446e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033467e13-true-d13033491e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2719"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13033467e13-true-d13033491e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13033467e13-true-d13033491e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033512e13-true-d13033546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2718"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13033512e13-true-d13033546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13033512e13-true-d13033546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13030188e97-true-d13033590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2717"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13030188e97-true-d13033590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13030188e97-true-d13033590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033578e2-true-d13033617e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2716"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13033578e2-true-d13033617e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13033578e2-true-d13033617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e16-true-d13035061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="2715"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e16-true-d13035061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d13033638e16-true-d13035061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e53-true-d13035120e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2714"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e53-true-d13035120e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13033638e53-true-d13035120e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035097e9-true-d13035164e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2713"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035097e9-true-d13035164e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13035097e9-true-d13035164e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035097e29-true-d13035213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2712"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035097e29-true-d13035213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13035097e29-true-d13035213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e58-true-d13035249e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2711"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e58-true-d13035249e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13033638e58-true-d13035249e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035237e2-true-d13035269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2710"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035237e2-true-d13035269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13035237e2-true-d13035269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035237e8-true-d13035310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2709"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035237e8-true-d13035310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13035237e8-true-d13035310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e62-true-d13035403e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2708"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e62-true-d13035403e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13033638e62-true-d13035403e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035339e9-true-d13035463e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2707"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035339e9-true-d13035463e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13035339e9-true-d13035463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e66-true-d13035585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2706"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e66-true-d13035585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13033638e66-true-d13035585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035512e10-true-d13035677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2705"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035512e10-true-d13035677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13035512e10-true-d13035677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035512e30-true-d13035716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2704"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035512e30-true-d13035716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13035512e30-true-d13035716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035512e34-true-d13035755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2703"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035512e34-true-d13035755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13035512e34-true-d13035755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035512e39-true-d13035816e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2702"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035512e39-true-d13035816e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13035512e39-true-d13035816e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035779e12-true-d13035884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2701"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035779e12-true-d13035884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13035779e12-true-d13035884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035779e35-true-d13035943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2700"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035779e35-true-d13035943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13035779e35-true-d13035943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e71-true-d13036040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2699"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e71-true-d13036040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13033638e71-true-d13036040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035974e7-true-d13036115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2698"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035974e7-true-d13036115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13035974e7-true-d13036115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036045e9-true-d13036154e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2697"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036045e9-true-d13036154e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13036045e9-true-d13036154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036045e10-true-d13036202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2696"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036045e10-true-d13036202e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13036045e10-true-d13036202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036165e12-true-d13036270e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2695"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036165e12-true-d13036270e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13036165e12-true-d13036270e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036165e35-true-d13036329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2694"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036165e35-true-d13036329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13036165e35-true-d13036329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13035974e11-true-d13036406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2693"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13035974e11-true-d13036406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13035974e11-true-d13036406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036360e16-true-d13036447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2692"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036360e16-true-d13036447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13036360e16-true-d13036447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e75-true-d13036519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2691"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e75-true-d13036519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13033638e75-true-d13036519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036458e15-true-d13036595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2690"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036458e15-true-d13036595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13036458e15-true-d13036595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036458e35-true-d13036650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2689"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036458e35-true-d13036650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13036458e35-true-d13036650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036458e39-true-d13036707e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2688"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036458e39-true-d13036707e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13036458e39-true-d13036707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036458e42-true-d13036761e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2687"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13036458e42-true-d13036761e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13036458e42-true-d13036761e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e81-true-d13036821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2686"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e81-true-d13036821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13033638e81-true-d13036821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036831e13-true-d13036855e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2685"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13036831e13-true-d13036855e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13036831e13-true-d13036855e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036876e13-true-d13036900e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2684"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13036876e13-true-d13036900e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13036876e13-true-d13036900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036921e13-true-d13036945e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2683"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13036921e13-true-d13036945e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13036921e13-true-d13036945e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13036966e13-true-d13037000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2682"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13036966e13-true-d13037000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13036966e13-true-d13037000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13033638e86-true-d13037044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2681"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13033638e86-true-d13037044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13033638e86-true-d13037044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037032e2-true-d13037071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2680"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13037032e2-true-d13037071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13037032e2-true-d13037071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e16-true-d13038572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2679"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e16-true-d13038572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13037101e16-true-d13038572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e87-true-d13038670e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2678"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e87-true-d13038670e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13037101e87-true-d13038670e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13038647e9-true-d13038714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2677"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13038647e9-true-d13038714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13038647e9-true-d13038714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13038647e29-true-d13038763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2676"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13038647e29-true-d13038763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13038647e29-true-d13038763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e92-true-d13038799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2675"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e92-true-d13038799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13037101e92-true-d13038799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13038787e2-true-d13038819e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2674"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13038787e2-true-d13038819e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13038787e2-true-d13038819e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13038787e8-true-d13038860e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2673"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13038787e8-true-d13038860e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13038787e8-true-d13038860e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e96-true-d13038953e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2672"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e96-true-d13038953e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13037101e96-true-d13038953e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13038889e9-true-d13039013e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2671"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13038889e9-true-d13039013e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13038889e9-true-d13039013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e100-true-d13039135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2670"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e100-true-d13039135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13037101e100-true-d13039135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039062e10-true-d13039227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2669"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039062e10-true-d13039227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13039062e10-true-d13039227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039062e30-true-d13039266e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2668"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039062e30-true-d13039266e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13039062e30-true-d13039266e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039062e34-true-d13039305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2667"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039062e34-true-d13039305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13039062e34-true-d13039305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039062e39-true-d13039366e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2666"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039062e39-true-d13039366e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13039062e39-true-d13039366e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039329e12-true-d13039434e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2665"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039329e12-true-d13039434e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13039329e12-true-d13039434e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039329e35-true-d13039493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2664"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039329e35-true-d13039493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13039329e35-true-d13039493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e105-true-d13039590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2663"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e105-true-d13039590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13037101e105-true-d13039590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039524e7-true-d13039665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2662"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039524e7-true-d13039665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13039524e7-true-d13039665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039595e9-true-d13039704e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2661"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039595e9-true-d13039704e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13039595e9-true-d13039704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039595e10-true-d13039752e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2660"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039595e10-true-d13039752e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13039595e10-true-d13039752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039715e12-true-d13039820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2659"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039715e12-true-d13039820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13039715e12-true-d13039820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039715e35-true-d13039879e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2658"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039715e35-true-d13039879e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13039715e35-true-d13039879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039524e11-true-d13039956e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2657"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039524e11-true-d13039956e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13039524e11-true-d13039956e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13039910e16-true-d13039997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2656"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13039910e16-true-d13039997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13039910e16-true-d13039997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e109-true-d13040069e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2655"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e109-true-d13040069e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13037101e109-true-d13040069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040008e15-true-d13040145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2654"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13040008e15-true-d13040145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13040008e15-true-d13040145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040008e35-true-d13040200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2653"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13040008e35-true-d13040200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13040008e35-true-d13040200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040008e39-true-d13040257e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2652"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13040008e39-true-d13040257e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13040008e39-true-d13040257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040008e42-true-d13040311e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2651"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13040008e42-true-d13040311e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13040008e42-true-d13040311e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e137-true-d13040380e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2650"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e137-true-d13040380e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13037101e137-true-d13040380e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040390e13-true-d13040414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2649"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13040390e13-true-d13040414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13040390e13-true-d13040414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040435e13-true-d13040459e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2648"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13040435e13-true-d13040459e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13040435e13-true-d13040459e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040480e13-true-d13040504e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2647"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13040480e13-true-d13040504e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13040480e13-true-d13040504e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040525e13-true-d13040559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2646"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13040525e13-true-d13040559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13040525e13-true-d13040559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13037101e141-true-d13040603e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2645"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13037101e141-true-d13040603e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13037101e141-true-d13040603e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040591e2-true-d13040630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2644"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13040591e2-true-d13040630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13040591e2-true-d13040630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e16-true-d13042067e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2643"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e16-true-d13042067e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13040651e16-true-d13042067e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e43-true-d13042120e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2642"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e43-true-d13042120e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13040651e43-true-d13042120e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042097e9-true-d13042164e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2641"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042097e9-true-d13042164e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13042097e9-true-d13042164e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042097e29-true-d13042213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2640"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042097e29-true-d13042213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13042097e29-true-d13042213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e47-true-d13042249e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2639"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e47-true-d13042249e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13040651e47-true-d13042249e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042237e2-true-d13042269e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2638"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042237e2-true-d13042269e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13042237e2-true-d13042269e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042237e8-true-d13042310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2637"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042237e8-true-d13042310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13042237e8-true-d13042310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e52-true-d13042403e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2636"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e52-true-d13042403e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13040651e52-true-d13042403e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042339e9-true-d13042463e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2635"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042339e9-true-d13042463e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13042339e9-true-d13042463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e56-true-d13042585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2634"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e56-true-d13042585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13040651e56-true-d13042585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042512e10-true-d13042677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2633"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042512e10-true-d13042677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13042512e10-true-d13042677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042512e30-true-d13042716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2632"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042512e30-true-d13042716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13042512e30-true-d13042716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042512e34-true-d13042755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2631"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042512e34-true-d13042755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13042512e34-true-d13042755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042512e39-true-d13042816e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2630"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042512e39-true-d13042816e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13042512e39-true-d13042816e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042779e12-true-d13042884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2629"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042779e12-true-d13042884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13042779e12-true-d13042884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042779e35-true-d13042943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2628"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042779e35-true-d13042943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13042779e35-true-d13042943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e60-true-d13043040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2627"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e60-true-d13043040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13040651e60-true-d13043040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042974e7-true-d13043115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2626"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042974e7-true-d13043115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13042974e7-true-d13043115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043045e9-true-d13043154e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2625"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043045e9-true-d13043154e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13043045e9-true-d13043154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043045e10-true-d13043202e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2624"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043045e10-true-d13043202e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13043045e10-true-d13043202e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043165e12-true-d13043270e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2623"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043165e12-true-d13043270e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13043165e12-true-d13043270e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043165e35-true-d13043329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2622"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043165e35-true-d13043329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13043165e35-true-d13043329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13042974e11-true-d13043406e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2621"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13042974e11-true-d13043406e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13042974e11-true-d13043406e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043360e16-true-d13043447e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2620"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043360e16-true-d13043447e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13043360e16-true-d13043447e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e65-true-d13043519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2619"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e65-true-d13043519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13040651e65-true-d13043519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043458e15-true-d13043595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2618"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043458e15-true-d13043595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13043458e15-true-d13043595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043458e35-true-d13043650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2617"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043458e35-true-d13043650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13043458e35-true-d13043650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043458e39-true-d13043707e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2616"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043458e39-true-d13043707e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13043458e39-true-d13043707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043458e42-true-d13043761e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2615"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13043458e42-true-d13043761e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13043458e42-true-d13043761e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e92-true-d13043830e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2614"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e92-true-d13043830e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13040651e92-true-d13043830e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043840e13-true-d13043864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2613"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13043840e13-true-d13043864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13043840e13-true-d13043864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043885e13-true-d13043909e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2612"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13043885e13-true-d13043909e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13043885e13-true-d13043909e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043930e13-true-d13043954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2611"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13043930e13-true-d13043954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13043930e13-true-d13043954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13043975e13-true-d13044009e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2610"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13043975e13-true-d13044009e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13043975e13-true-d13044009e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13040651e97-true-d13044053e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2609"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13040651e97-true-d13044053e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13040651e97-true-d13044053e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044041e2-true-d13044080e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2608"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13044041e2-true-d13044080e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13044041e2-true-d13044080e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e16-true-d13045640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2607"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e16-true-d13045640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13044101e16-true-d13045640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e95-true-d13045756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2606"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e95-true-d13045756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13044101e95-true-d13045756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13045733e9-true-d13045800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2605"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13045733e9-true-d13045800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13045733e9-true-d13045800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13045733e29-true-d13045849e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2604"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13045733e29-true-d13045849e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13045733e29-true-d13045849e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e99-true-d13045885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2603"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e99-true-d13045885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13044101e99-true-d13045885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13045873e2-true-d13045905e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2602"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13045873e2-true-d13045905e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13045873e2-true-d13045905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13045873e8-true-d13045946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2601"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13045873e8-true-d13045946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13045873e8-true-d13045946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e103-true-d13046023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="2600"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e103-true-d13046023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13044101e103-true-d13046023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13045975e5-true-d13046079e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="2599"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13045975e5-true-d13046079e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13045975e5-true-d13046079e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046089e13-true-d13046106e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="2598"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13046089e13-true-d13046106e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13046089e13-true-d13046106e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046121e13-true-d13046149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="2597"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13046121e13-true-d13046149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13046121e13-true-d13046149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13045975e24-true-d13046210e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2596"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13045975e24-true-d13046210e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13045975e24-true-d13046210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046173e12-true-d13046278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2595"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046173e12-true-d13046278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13046173e12-true-d13046278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046173e35-true-d13046337e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2594"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046173e35-true-d13046337e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13046173e35-true-d13046337e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e111-true-d13046432e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2593"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e111-true-d13046432e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13044101e111-true-d13046432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046368e9-true-d13046492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2592"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046368e9-true-d13046492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13046368e9-true-d13046492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e115-true-d13046614e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2591"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e115-true-d13046614e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13044101e115-true-d13046614e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046541e10-true-d13046706e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2590"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046541e10-true-d13046706e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13046541e10-true-d13046706e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046541e30-true-d13046745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2589"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046541e30-true-d13046745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13046541e30-true-d13046745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046541e34-true-d13046784e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2588"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046541e34-true-d13046784e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13046541e34-true-d13046784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046541e39-true-d13046845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2587"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046541e39-true-d13046845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13046541e39-true-d13046845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046808e12-true-d13046913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2586"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046808e12-true-d13046913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13046808e12-true-d13046913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13046808e35-true-d13046972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2585"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13046808e35-true-d13046972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13046808e35-true-d13046972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e119-true-d13047069e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2584"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e119-true-d13047069e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13044101e119-true-d13047069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047003e7-true-d13047144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2583"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047003e7-true-d13047144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13047003e7-true-d13047144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047074e9-true-d13047183e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2582"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047074e9-true-d13047183e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13047074e9-true-d13047183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047074e10-true-d13047231e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2581"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047074e10-true-d13047231e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13047074e10-true-d13047231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047194e12-true-d13047299e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2580"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047194e12-true-d13047299e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13047194e12-true-d13047299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047194e35-true-d13047358e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2579"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047194e35-true-d13047358e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13047194e35-true-d13047358e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047003e11-true-d13047435e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2578"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047003e11-true-d13047435e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13047003e11-true-d13047435e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047389e16-true-d13047476e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2577"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047389e16-true-d13047476e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13047389e16-true-d13047476e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e124-true-d13047548e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2576"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e124-true-d13047548e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13044101e124-true-d13047548e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047487e15-true-d13047624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2575"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047487e15-true-d13047624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13047487e15-true-d13047624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047487e35-true-d13047679e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2574"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047487e35-true-d13047679e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13047487e35-true-d13047679e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047487e39-true-d13047736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2573"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047487e39-true-d13047736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13047487e39-true-d13047736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047487e42-true-d13047790e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2572"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13047487e42-true-d13047790e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13047487e42-true-d13047790e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e151-true-d13047859e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2571"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e151-true-d13047859e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13044101e151-true-d13047859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047869e13-true-d13047893e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2570"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13047869e13-true-d13047893e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13047869e13-true-d13047893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047914e13-true-d13047938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2569"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13047914e13-true-d13047938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13047914e13-true-d13047938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13047959e13-true-d13047983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2568"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13047959e13-true-d13047983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13047959e13-true-d13047983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048004e13-true-d13048038e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2567"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13048004e13-true-d13048038e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13048004e13-true-d13048038e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13044101e156-true-d13048082e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2566"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13044101e156-true-d13048082e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13044101e156-true-d13048082e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048070e2-true-d13048109e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2565"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13048070e2-true-d13048109e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13048070e2-true-d13048109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e16-true-d13049636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2564"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e16-true-d13049636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13048130e16-true-d13049636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e71-true-d13049728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2563"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e71-true-d13049728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13048130e71-true-d13049728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13049705e9-true-d13049772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2562"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13049705e9-true-d13049772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13049705e9-true-d13049772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13049705e29-true-d13049821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2561"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13049705e29-true-d13049821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13049705e29-true-d13049821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e76-true-d13049857e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2560"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e76-true-d13049857e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13048130e76-true-d13049857e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13049845e2-true-d13049877e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2559"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13049845e2-true-d13049877e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13049845e2-true-d13049877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13049845e8-true-d13049918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2558"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13049845e8-true-d13049918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13049845e8-true-d13049918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e80-true-d13049995e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="2557"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e80-true-d13049995e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13048130e80-true-d13049995e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13049947e5-true-d13050051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="2556"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13049947e5-true-d13050051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13049947e5-true-d13050051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050061e13-true-d13050078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="2555"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13050061e13-true-d13050078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13050061e13-true-d13050078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050093e13-true-d13050121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="2554"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13050093e13-true-d13050121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13050093e13-true-d13050121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13049947e24-true-d13050182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2553"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13049947e24-true-d13050182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13049947e24-true-d13050182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050145e12-true-d13050250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2552"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050145e12-true-d13050250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13050145e12-true-d13050250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050145e35-true-d13050309e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2551"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050145e35-true-d13050309e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13050145e35-true-d13050309e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e87-true-d13050404e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2550"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e87-true-d13050404e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13048130e87-true-d13050404e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050340e9-true-d13050464e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2549"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050340e9-true-d13050464e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13050340e9-true-d13050464e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e92-true-d13050586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2548"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e92-true-d13050586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13048130e92-true-d13050586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050513e10-true-d13050678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2547"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050513e10-true-d13050678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13050513e10-true-d13050678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050513e30-true-d13050717e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2546"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050513e30-true-d13050717e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13050513e30-true-d13050717e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050513e34-true-d13050756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2545"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050513e34-true-d13050756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13050513e34-true-d13050756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050513e39-true-d13050817e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2544"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050513e39-true-d13050817e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13050513e39-true-d13050817e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050780e12-true-d13050885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2543"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050780e12-true-d13050885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13050780e12-true-d13050885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050780e35-true-d13050944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2542"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050780e35-true-d13050944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13050780e35-true-d13050944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e96-true-d13051041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2541"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e96-true-d13051041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13048130e96-true-d13051041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050975e7-true-d13051116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2540"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050975e7-true-d13051116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13050975e7-true-d13051116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051046e9-true-d13051155e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2539"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051046e9-true-d13051155e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13051046e9-true-d13051155e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051046e10-true-d13051203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2538"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051046e10-true-d13051203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13051046e10-true-d13051203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051166e12-true-d13051271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2537"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051166e12-true-d13051271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13051166e12-true-d13051271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051166e35-true-d13051330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2536"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051166e35-true-d13051330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13051166e35-true-d13051330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13050975e11-true-d13051407e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2535"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13050975e11-true-d13051407e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13050975e11-true-d13051407e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051361e16-true-d13051448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2534"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051361e16-true-d13051448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13051361e16-true-d13051448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e100-true-d13051520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2533"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e100-true-d13051520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13048130e100-true-d13051520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051459e15-true-d13051596e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2532"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051459e15-true-d13051596e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13051459e15-true-d13051596e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051459e35-true-d13051651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2531"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051459e35-true-d13051651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13051459e35-true-d13051651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051459e39-true-d13051708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2530"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051459e39-true-d13051708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13051459e39-true-d13051708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051459e42-true-d13051762e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2529"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13051459e42-true-d13051762e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13051459e42-true-d13051762e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e128-true-d13051831e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2528"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e128-true-d13051831e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13048130e128-true-d13051831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051841e13-true-d13051865e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2527"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13051841e13-true-d13051865e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13051841e13-true-d13051865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051886e13-true-d13051910e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2526"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13051886e13-true-d13051910e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13051886e13-true-d13051910e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051931e13-true-d13051955e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2525"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13051931e13-true-d13051955e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13051931e13-true-d13051955e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13051976e13-true-d13052010e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2524"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13051976e13-true-d13052010e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13051976e13-true-d13052010e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13048130e132-true-d13052054e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2523"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13048130e132-true-d13052054e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13048130e132-true-d13052054e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052042e2-true-d13052081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2522"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13052042e2-true-d13052081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13052042e2-true-d13052081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e16-true-d13053573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2521"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e16-true-d13053573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13052102e16-true-d13053573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e87-true-d13053671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2520"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e87-true-d13053671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13052102e87-true-d13053671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13053648e9-true-d13053715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2519"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13053648e9-true-d13053715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13053648e9-true-d13053715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13053648e29-true-d13053764e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2518"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13053648e29-true-d13053764e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13053648e29-true-d13053764e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e92-true-d13053800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2517"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e92-true-d13053800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13052102e92-true-d13053800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13053788e2-true-d13053820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2516"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13053788e2-true-d13053820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13053788e2-true-d13053820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13053788e8-true-d13053861e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2515"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13053788e8-true-d13053861e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13053788e8-true-d13053861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e96-true-d13053954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2514"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e96-true-d13053954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13052102e96-true-d13053954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13053890e9-true-d13054014e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2513"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13053890e9-true-d13054014e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13053890e9-true-d13054014e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e100-true-d13054136e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2512"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e100-true-d13054136e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13052102e100-true-d13054136e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054063e10-true-d13054228e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2511"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054063e10-true-d13054228e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13054063e10-true-d13054228e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054063e30-true-d13054267e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2510"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054063e30-true-d13054267e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13054063e30-true-d13054267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054063e34-true-d13054306e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2509"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054063e34-true-d13054306e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13054063e34-true-d13054306e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054063e39-true-d13054367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2508"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054063e39-true-d13054367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13054063e39-true-d13054367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054330e12-true-d13054435e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2507"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054330e12-true-d13054435e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13054330e12-true-d13054435e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054330e35-true-d13054494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2506"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054330e35-true-d13054494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13054330e35-true-d13054494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e105-true-d13054591e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2505"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e105-true-d13054591e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13052102e105-true-d13054591e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054525e7-true-d13054666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2504"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054525e7-true-d13054666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13054525e7-true-d13054666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054596e9-true-d13054705e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2503"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054596e9-true-d13054705e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13054596e9-true-d13054705e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054596e10-true-d13054753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2502"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054596e10-true-d13054753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13054596e10-true-d13054753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054716e12-true-d13054821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2501"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054716e12-true-d13054821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13054716e12-true-d13054821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054716e35-true-d13054880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2500"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054716e35-true-d13054880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13054716e35-true-d13054880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054525e11-true-d13054957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2499"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054525e11-true-d13054957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13054525e11-true-d13054957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13054911e16-true-d13054998e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2498"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13054911e16-true-d13054998e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13054911e16-true-d13054998e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e109-true-d13055070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2497"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e109-true-d13055070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13052102e109-true-d13055070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13055009e15-true-d13055146e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2496"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13055009e15-true-d13055146e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13055009e15-true-d13055146e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13055009e35-true-d13055201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2495"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13055009e35-true-d13055201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13055009e35-true-d13055201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13055009e39-true-d13055258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2494"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13055009e39-true-d13055258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13055009e39-true-d13055258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13055009e42-true-d13055312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2493"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13055009e42-true-d13055312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13055009e42-true-d13055312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e113-true-d13060419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="2492"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e113-true-d13060419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d13052102e113-true-d13060419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e16-true-d13061884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2491"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e16-true-d13061884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13060434e16-true-d13061884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e77-true-d13061964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2490"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e77-true-d13061964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13060434e77-true-d13061964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13061941e9-true-d13062008e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2489"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13061941e9-true-d13062008e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13061941e9-true-d13062008e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13061941e29-true-d13062057e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2488"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13061941e29-true-d13062057e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13061941e29-true-d13062057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e81-true-d13062093e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2487"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e81-true-d13062093e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13060434e81-true-d13062093e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062081e2-true-d13062113e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2486"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062081e2-true-d13062113e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13062081e2-true-d13062113e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062081e8-true-d13062154e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2485"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062081e8-true-d13062154e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13062081e8-true-d13062154e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e85-true-d13062247e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2484"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e85-true-d13062247e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13060434e85-true-d13062247e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062183e9-true-d13062307e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2483"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062183e9-true-d13062307e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13062183e9-true-d13062307e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e90-true-d13062429e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2482"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e90-true-d13062429e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13060434e90-true-d13062429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062356e10-true-d13062521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2481"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062356e10-true-d13062521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13062356e10-true-d13062521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062356e30-true-d13062560e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2480"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062356e30-true-d13062560e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13062356e30-true-d13062560e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062356e34-true-d13062599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2479"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062356e34-true-d13062599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13062356e34-true-d13062599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062356e39-true-d13062660e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2478"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062356e39-true-d13062660e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13062356e39-true-d13062660e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062623e12-true-d13062728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2477"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062623e12-true-d13062728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13062623e12-true-d13062728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062623e35-true-d13062787e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2476"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062623e35-true-d13062787e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13062623e35-true-d13062787e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e94-true-d13062884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2475"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e94-true-d13062884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13060434e94-true-d13062884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062818e7-true-d13062959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2474"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062818e7-true-d13062959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13062818e7-true-d13062959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062889e9-true-d13062998e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2473"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062889e9-true-d13062998e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13062889e9-true-d13062998e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062889e10-true-d13063046e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2472"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062889e10-true-d13063046e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13062889e10-true-d13063046e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063009e12-true-d13063114e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2471"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063009e12-true-d13063114e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13063009e12-true-d13063114e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063009e35-true-d13063173e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2470"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063009e35-true-d13063173e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13063009e35-true-d13063173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13062818e11-true-d13063250e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2469"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13062818e11-true-d13063250e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13062818e11-true-d13063250e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063204e16-true-d13063291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2468"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063204e16-true-d13063291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13063204e16-true-d13063291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e98-true-d13063363e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2467"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e98-true-d13063363e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13060434e98-true-d13063363e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063302e15-true-d13063439e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2466"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063302e15-true-d13063439e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13063302e15-true-d13063439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063302e35-true-d13063494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2465"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063302e35-true-d13063494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13063302e35-true-d13063494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063302e39-true-d13063551e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2464"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063302e39-true-d13063551e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13063302e39-true-d13063551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063302e42-true-d13063605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2463"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063302e42-true-d13063605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13063302e42-true-d13063605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e126-true-d13063674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2462"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e126-true-d13063674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13060434e126-true-d13063674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063684e13-true-d13063708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2461"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13063684e13-true-d13063708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13063684e13-true-d13063708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063729e13-true-d13063753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2460"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13063729e13-true-d13063753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13063729e13-true-d13063753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063774e13-true-d13063798e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2459"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13063774e13-true-d13063798e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13063774e13-true-d13063798e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063819e13-true-d13063853e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2458"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13063819e13-true-d13063853e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13063819e13-true-d13063853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13060434e130-true-d13063897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2457"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13060434e130-true-d13063897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13060434e130-true-d13063897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063885e2-true-d13063924e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2456"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13063885e2-true-d13063924e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13063885e2-true-d13063924e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e16-true-d13065388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2455"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e16-true-d13065388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13063945e16-true-d13065388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e65-true-d13065462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2454"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e65-true-d13065462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13063945e65-true-d13065462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065439e9-true-d13065506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2453"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065439e9-true-d13065506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13065439e9-true-d13065506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065439e29-true-d13065555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2452"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065439e29-true-d13065555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13065439e29-true-d13065555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e69-true-d13065591e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2451"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e69-true-d13065591e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13063945e69-true-d13065591e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065579e2-true-d13065611e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2450"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065579e2-true-d13065611e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13065579e2-true-d13065611e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065579e8-true-d13065652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2449"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065579e8-true-d13065652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13065579e8-true-d13065652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e73-true-d13065745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2448"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e73-true-d13065745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13063945e73-true-d13065745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065681e9-true-d13065805e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2447"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065681e9-true-d13065805e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13065681e9-true-d13065805e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e78-true-d13065927e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2446"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e78-true-d13065927e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13063945e78-true-d13065927e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065854e10-true-d13066019e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2445"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065854e10-true-d13066019e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13065854e10-true-d13066019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065854e30-true-d13066058e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2444"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065854e30-true-d13066058e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13065854e30-true-d13066058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065854e34-true-d13066097e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2443"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065854e34-true-d13066097e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13065854e34-true-d13066097e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13065854e39-true-d13066158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2442"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13065854e39-true-d13066158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13065854e39-true-d13066158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066121e12-true-d13066226e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2441"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066121e12-true-d13066226e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13066121e12-true-d13066226e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066121e35-true-d13066285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2440"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066121e35-true-d13066285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13066121e35-true-d13066285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e82-true-d13066382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2439"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e82-true-d13066382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13063945e82-true-d13066382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066316e7-true-d13066457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2438"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066316e7-true-d13066457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13066316e7-true-d13066457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066387e9-true-d13066496e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2437"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066387e9-true-d13066496e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13066387e9-true-d13066496e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066387e10-true-d13066544e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2436"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066387e10-true-d13066544e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13066387e10-true-d13066544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066507e12-true-d13066612e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2435"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066507e12-true-d13066612e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13066507e12-true-d13066612e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066507e35-true-d13066671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2434"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066507e35-true-d13066671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13066507e35-true-d13066671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066316e11-true-d13066748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2433"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066316e11-true-d13066748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13066316e11-true-d13066748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066702e16-true-d13066789e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2432"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066702e16-true-d13066789e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13066702e16-true-d13066789e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e86-true-d13066861e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2431"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e86-true-d13066861e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13063945e86-true-d13066861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066800e15-true-d13066937e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2430"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066800e15-true-d13066937e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13066800e15-true-d13066937e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066800e35-true-d13066992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2429"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066800e35-true-d13066992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13066800e35-true-d13066992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066800e39-true-d13067049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2428"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066800e39-true-d13067049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13066800e39-true-d13067049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13066800e42-true-d13067103e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2427"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13066800e42-true-d13067103e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13066800e42-true-d13067103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e114-true-d13067172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2426"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e114-true-d13067172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13063945e114-true-d13067172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067182e13-true-d13067206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2425"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13067182e13-true-d13067206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13067182e13-true-d13067206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067227e13-true-d13067251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2424"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13067227e13-true-d13067251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13067227e13-true-d13067251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067272e13-true-d13067296e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2423"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13067272e13-true-d13067296e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13067272e13-true-d13067296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067317e13-true-d13067351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2422"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13067317e13-true-d13067351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13067317e13-true-d13067351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13063945e118-true-d13067395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2421"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13063945e118-true-d13067395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13063945e118-true-d13067395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067383e2-true-d13067422e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2420"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13067383e2-true-d13067422e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13067383e2-true-d13067422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e16-true-d13068946e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="2419"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e16-true-d13068946e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d13067443e16-true-d13068946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e100-true-d13069065e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2418"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e100-true-d13069065e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13067443e100-true-d13069065e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069042e9-true-d13069109e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2417"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069042e9-true-d13069109e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13069042e9-true-d13069109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069042e29-true-d13069158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2416"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069042e29-true-d13069158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13069042e29-true-d13069158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e104-true-d13069194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2415"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e104-true-d13069194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13067443e104-true-d13069194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069182e2-true-d13069214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2414"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069182e2-true-d13069214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13069182e2-true-d13069214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069182e8-true-d13069255e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2413"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069182e8-true-d13069255e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13069182e8-true-d13069255e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e108-true-d13069348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2412"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e108-true-d13069348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13067443e108-true-d13069348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069284e9-true-d13069408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2411"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069284e9-true-d13069408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13069284e9-true-d13069408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e113-true-d13069530e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2410"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e113-true-d13069530e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13067443e113-true-d13069530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069457e10-true-d13069622e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2409"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069457e10-true-d13069622e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13069457e10-true-d13069622e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069457e30-true-d13069661e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2408"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069457e30-true-d13069661e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13069457e30-true-d13069661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069457e34-true-d13069700e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2407"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069457e34-true-d13069700e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13069457e34-true-d13069700e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069457e39-true-d13069761e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2406"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069457e39-true-d13069761e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13069457e39-true-d13069761e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069724e12-true-d13069829e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2405"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069724e12-true-d13069829e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13069724e12-true-d13069829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069724e35-true-d13069888e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2404"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069724e35-true-d13069888e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13069724e35-true-d13069888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e117-true-d13069985e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2403"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e117-true-d13069985e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13067443e117-true-d13069985e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069919e7-true-d13070060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2402"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069919e7-true-d13070060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13069919e7-true-d13070060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069990e9-true-d13070099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2401"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069990e9-true-d13070099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13069990e9-true-d13070099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069990e10-true-d13070147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2400"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069990e10-true-d13070147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13069990e10-true-d13070147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070110e12-true-d13070215e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2399"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070110e12-true-d13070215e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13070110e12-true-d13070215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070110e35-true-d13070274e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2398"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070110e35-true-d13070274e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13070110e35-true-d13070274e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13069919e11-true-d13070351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2397"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13069919e11-true-d13070351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13069919e11-true-d13070351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070305e16-true-d13070392e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2396"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070305e16-true-d13070392e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13070305e16-true-d13070392e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e121-true-d13070464e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2395"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e121-true-d13070464e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13067443e121-true-d13070464e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070403e15-true-d13070540e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2394"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070403e15-true-d13070540e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13070403e15-true-d13070540e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070403e35-true-d13070595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2393"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070403e35-true-d13070595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13070403e35-true-d13070595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070403e39-true-d13070652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2392"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070403e39-true-d13070652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13070403e39-true-d13070652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070403e42-true-d13070706e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2391"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070403e42-true-d13070706e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13070403e42-true-d13070706e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e149-true-d13070775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2390"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e149-true-d13070775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13067443e149-true-d13070775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070785e13-true-d13070809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2389"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13070785e13-true-d13070809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13070785e13-true-d13070809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070830e13-true-d13070854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2388"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13070830e13-true-d13070854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13070830e13-true-d13070854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070875e13-true-d13070899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2387"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13070875e13-true-d13070899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13070875e13-true-d13070899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070920e13-true-d13070954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2386"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13070920e13-true-d13070954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13070920e13-true-d13070954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e153-true-d13070998e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2385"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e153-true-d13070998e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13067443e153-true-d13070998e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13070986e2-true-d13071025e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2384"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13070986e2-true-d13071025e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13070986e2-true-d13071025e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e158-true-d13071056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="2383"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e158-true-d13071056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d13067443e158-true-d13071056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13067443e162-true-d13071094e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="2382"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13067443e162-true-d13071094e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d13067443e162-true-d13071094e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e16-true-d13072539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2381"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e16-true-d13072539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13071123e16-true-d13072539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e43-true-d13072592e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2380"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e43-true-d13072592e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13071123e43-true-d13072592e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072569e9-true-d13072636e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2379"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072569e9-true-d13072636e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13072569e9-true-d13072636e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072569e29-true-d13072685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2378"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072569e29-true-d13072685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13072569e29-true-d13072685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e47-true-d13072721e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2377"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e47-true-d13072721e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13071123e47-true-d13072721e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072709e2-true-d13072741e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2376"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072709e2-true-d13072741e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13072709e2-true-d13072741e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072709e8-true-d13072782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2375"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072709e8-true-d13072782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13072709e8-true-d13072782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e52-true-d13072875e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2374"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e52-true-d13072875e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13071123e52-true-d13072875e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072811e9-true-d13072935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2373"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072811e9-true-d13072935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13072811e9-true-d13072935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e56-true-d13073057e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2372"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e56-true-d13073057e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13071123e56-true-d13073057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072984e10-true-d13073149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2371"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072984e10-true-d13073149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13072984e10-true-d13073149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072984e30-true-d13073188e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2370"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072984e30-true-d13073188e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13072984e30-true-d13073188e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072984e34-true-d13073227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2369"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072984e34-true-d13073227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13072984e34-true-d13073227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13072984e39-true-d13073288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2368"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13072984e39-true-d13073288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13072984e39-true-d13073288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073251e12-true-d13073356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2367"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073251e12-true-d13073356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13073251e12-true-d13073356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073251e35-true-d13073415e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2366"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073251e35-true-d13073415e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13073251e35-true-d13073415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e60-true-d13073512e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2365"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e60-true-d13073512e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13071123e60-true-d13073512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073446e7-true-d13073587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2364"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073446e7-true-d13073587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13073446e7-true-d13073587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073517e9-true-d13073626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2363"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073517e9-true-d13073626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13073517e9-true-d13073626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073517e10-true-d13073674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2362"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073517e10-true-d13073674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13073517e10-true-d13073674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073637e12-true-d13073742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2361"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073637e12-true-d13073742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13073637e12-true-d13073742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073637e35-true-d13073801e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2360"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073637e35-true-d13073801e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13073637e35-true-d13073801e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073446e11-true-d13073878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2359"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073446e11-true-d13073878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13073446e11-true-d13073878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073832e16-true-d13073919e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2358"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073832e16-true-d13073919e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13073832e16-true-d13073919e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e65-true-d13073991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2357"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e65-true-d13073991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13071123e65-true-d13073991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073930e15-true-d13074067e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2356"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073930e15-true-d13074067e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13073930e15-true-d13074067e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073930e35-true-d13074122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2355"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073930e35-true-d13074122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13073930e35-true-d13074122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073930e39-true-d13074179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2354"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073930e39-true-d13074179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13073930e39-true-d13074179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13073930e42-true-d13074233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2353"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13073930e42-true-d13074233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13073930e42-true-d13074233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e92-true-d13074302e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2352"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e92-true-d13074302e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13071123e92-true-d13074302e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074312e13-true-d13074336e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2351"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13074312e13-true-d13074336e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13074312e13-true-d13074336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074357e13-true-d13074381e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2350"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13074357e13-true-d13074381e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13074357e13-true-d13074381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074402e13-true-d13074426e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2349"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13074402e13-true-d13074426e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13074402e13-true-d13074426e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074447e13-true-d13074481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2348"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13074447e13-true-d13074481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13074447e13-true-d13074481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13071123e97-true-d13074525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2347"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13071123e97-true-d13074525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13071123e97-true-d13074525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074513e2-true-d13074552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2346"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13074513e2-true-d13074552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13074513e2-true-d13074552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e16-true-d13075996e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="2345"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e16-true-d13075996e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d13074573e16-true-d13075996e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e53-true-d13076055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2344"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e53-true-d13076055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13074573e53-true-d13076055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076032e9-true-d13076099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2343"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076032e9-true-d13076099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13076032e9-true-d13076099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076032e29-true-d13076148e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2342"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076032e29-true-d13076148e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13076032e29-true-d13076148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e58-true-d13076184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2341"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e58-true-d13076184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13074573e58-true-d13076184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076172e2-true-d13076204e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2340"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076172e2-true-d13076204e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13076172e2-true-d13076204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076172e8-true-d13076245e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2339"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076172e8-true-d13076245e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13076172e8-true-d13076245e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e62-true-d13076338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2338"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e62-true-d13076338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13074573e62-true-d13076338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076274e9-true-d13076398e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2337"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076274e9-true-d13076398e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13076274e9-true-d13076398e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e66-true-d13076520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2336"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e66-true-d13076520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13074573e66-true-d13076520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076447e10-true-d13076612e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2335"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076447e10-true-d13076612e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13076447e10-true-d13076612e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076447e30-true-d13076651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2334"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076447e30-true-d13076651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13076447e30-true-d13076651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076447e34-true-d13076690e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2333"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076447e34-true-d13076690e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13076447e34-true-d13076690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076447e39-true-d13076751e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2332"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076447e39-true-d13076751e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13076447e39-true-d13076751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076714e12-true-d13076819e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2331"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076714e12-true-d13076819e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13076714e12-true-d13076819e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076714e35-true-d13076878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2330"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076714e35-true-d13076878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13076714e35-true-d13076878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e71-true-d13076975e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2329"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e71-true-d13076975e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13074573e71-true-d13076975e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076909e7-true-d13077050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2328"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076909e7-true-d13077050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13076909e7-true-d13077050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076980e9-true-d13077089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2327"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076980e9-true-d13077089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13076980e9-true-d13077089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076980e10-true-d13077137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2326"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076980e10-true-d13077137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13076980e10-true-d13077137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077100e12-true-d13077205e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2325"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077100e12-true-d13077205e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13077100e12-true-d13077205e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077100e35-true-d13077264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2324"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077100e35-true-d13077264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13077100e35-true-d13077264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13076909e11-true-d13077341e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2323"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13076909e11-true-d13077341e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13076909e11-true-d13077341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077295e16-true-d13077382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2322"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077295e16-true-d13077382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13077295e16-true-d13077382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e75-true-d13077454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2321"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e75-true-d13077454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13074573e75-true-d13077454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077393e15-true-d13077530e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2320"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077393e15-true-d13077530e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13077393e15-true-d13077530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077393e35-true-d13077585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2319"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077393e35-true-d13077585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13077393e35-true-d13077585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077393e39-true-d13077642e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2318"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077393e39-true-d13077642e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13077393e39-true-d13077642e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077393e42-true-d13077696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2317"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077393e42-true-d13077696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13077393e42-true-d13077696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e81-true-d13077756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2316"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e81-true-d13077756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13074573e81-true-d13077756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077766e13-true-d13077790e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2315"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13077766e13-true-d13077790e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13077766e13-true-d13077790e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077811e13-true-d13077835e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2314"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13077811e13-true-d13077835e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13077811e13-true-d13077835e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077856e13-true-d13077880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2313"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13077856e13-true-d13077880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13077856e13-true-d13077880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077901e13-true-d13077935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2312"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13077901e13-true-d13077935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13077901e13-true-d13077935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13074573e86-true-d13077979e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2311"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13074573e86-true-d13077979e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13074573e86-true-d13077979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13077967e2-true-d13078006e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2310"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13077967e2-true-d13078006e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13077967e2-true-d13078006e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e16-true-d13079507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2309"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e16-true-d13079507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13078036e16-true-d13079507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e87-true-d13079605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2308"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e87-true-d13079605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13078036e87-true-d13079605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079582e9-true-d13079649e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2307"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079582e9-true-d13079649e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13079582e9-true-d13079649e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079582e29-true-d13079698e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2306"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079582e29-true-d13079698e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13079582e29-true-d13079698e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e92-true-d13079734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2305"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e92-true-d13079734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13078036e92-true-d13079734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079722e2-true-d13079754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2304"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079722e2-true-d13079754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13079722e2-true-d13079754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079722e8-true-d13079795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2303"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079722e8-true-d13079795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13079722e8-true-d13079795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e96-true-d13079888e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2302"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e96-true-d13079888e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13078036e96-true-d13079888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079824e9-true-d13079948e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2301"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079824e9-true-d13079948e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13079824e9-true-d13079948e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e100-true-d13080070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2300"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e100-true-d13080070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13078036e100-true-d13080070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079997e10-true-d13080162e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2299"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079997e10-true-d13080162e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13079997e10-true-d13080162e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079997e30-true-d13080201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2298"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079997e30-true-d13080201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13079997e30-true-d13080201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079997e34-true-d13080240e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2297"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079997e34-true-d13080240e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13079997e34-true-d13080240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13079997e39-true-d13080301e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2296"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13079997e39-true-d13080301e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13079997e39-true-d13080301e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080264e12-true-d13080369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2295"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080264e12-true-d13080369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13080264e12-true-d13080369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080264e35-true-d13080428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2294"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080264e35-true-d13080428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13080264e35-true-d13080428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e105-true-d13080525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2293"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e105-true-d13080525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13078036e105-true-d13080525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080459e7-true-d13080600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2292"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080459e7-true-d13080600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13080459e7-true-d13080600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080530e9-true-d13080639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2291"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080530e9-true-d13080639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13080530e9-true-d13080639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080530e10-true-d13080687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2290"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080530e10-true-d13080687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13080530e10-true-d13080687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080650e12-true-d13080755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2289"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080650e12-true-d13080755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13080650e12-true-d13080755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080650e35-true-d13080814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2288"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080650e35-true-d13080814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13080650e35-true-d13080814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080459e11-true-d13080891e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2287"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080459e11-true-d13080891e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13080459e11-true-d13080891e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080845e16-true-d13080932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2286"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080845e16-true-d13080932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13080845e16-true-d13080932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e109-true-d13081004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2285"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e109-true-d13081004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13078036e109-true-d13081004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080943e15-true-d13081080e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2284"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080943e15-true-d13081080e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13080943e15-true-d13081080e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080943e35-true-d13081135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2283"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080943e35-true-d13081135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13080943e35-true-d13081135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080943e39-true-d13081192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2282"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080943e39-true-d13081192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13080943e39-true-d13081192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13080943e42-true-d13081246e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2281"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13080943e42-true-d13081246e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13080943e42-true-d13081246e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e137-true-d13081315e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2280"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e137-true-d13081315e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13078036e137-true-d13081315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081325e13-true-d13081349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2279"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13081325e13-true-d13081349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13081325e13-true-d13081349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081370e13-true-d13081394e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2278"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13081370e13-true-d13081394e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13081370e13-true-d13081394e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081415e13-true-d13081439e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2277"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13081415e13-true-d13081439e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13081415e13-true-d13081439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081460e13-true-d13081494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2276"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13081460e13-true-d13081494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13081460e13-true-d13081494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13078036e141-true-d13081538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2275"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13078036e141-true-d13081538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13078036e141-true-d13081538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081526e2-true-d13081565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2274"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13081526e2-true-d13081565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13081526e2-true-d13081565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e16-true-d13083002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2273"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e16-true-d13083002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13081586e16-true-d13083002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e43-true-d13083055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2272"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e43-true-d13083055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13081586e43-true-d13083055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083032e9-true-d13083099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2271"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083032e9-true-d13083099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13083032e9-true-d13083099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083032e29-true-d13083148e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2270"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083032e29-true-d13083148e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13083032e29-true-d13083148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e47-true-d13083184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2269"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e47-true-d13083184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13081586e47-true-d13083184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083172e2-true-d13083204e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2268"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083172e2-true-d13083204e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13083172e2-true-d13083204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083172e8-true-d13083245e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2267"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083172e8-true-d13083245e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13083172e8-true-d13083245e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e52-true-d13083338e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2266"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e52-true-d13083338e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13081586e52-true-d13083338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083274e9-true-d13083398e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2265"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083274e9-true-d13083398e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13083274e9-true-d13083398e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e56-true-d13083520e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2264"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e56-true-d13083520e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13081586e56-true-d13083520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083447e10-true-d13083612e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2263"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083447e10-true-d13083612e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13083447e10-true-d13083612e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083447e30-true-d13083651e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2262"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083447e30-true-d13083651e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13083447e30-true-d13083651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083447e34-true-d13083690e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2261"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083447e34-true-d13083690e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13083447e34-true-d13083690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083447e39-true-d13083751e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2260"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083447e39-true-d13083751e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13083447e39-true-d13083751e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083714e12-true-d13083819e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2259"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083714e12-true-d13083819e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13083714e12-true-d13083819e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083714e35-true-d13083878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2258"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083714e35-true-d13083878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13083714e35-true-d13083878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e60-true-d13083975e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2257"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e60-true-d13083975e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13081586e60-true-d13083975e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083909e7-true-d13084050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2256"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083909e7-true-d13084050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13083909e7-true-d13084050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083980e9-true-d13084089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2255"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083980e9-true-d13084089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13083980e9-true-d13084089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083980e10-true-d13084137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2254"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083980e10-true-d13084137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13083980e10-true-d13084137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084100e12-true-d13084205e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2253"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084100e12-true-d13084205e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13084100e12-true-d13084205e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084100e35-true-d13084264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2252"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084100e35-true-d13084264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13084100e35-true-d13084264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13083909e11-true-d13084341e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2251"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13083909e11-true-d13084341e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13083909e11-true-d13084341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084295e16-true-d13084382e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2250"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084295e16-true-d13084382e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13084295e16-true-d13084382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e65-true-d13084454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2249"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e65-true-d13084454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13081586e65-true-d13084454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084393e15-true-d13084530e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2248"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084393e15-true-d13084530e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13084393e15-true-d13084530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084393e35-true-d13084585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2247"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084393e35-true-d13084585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13084393e35-true-d13084585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084393e39-true-d13084642e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2246"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084393e39-true-d13084642e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13084393e39-true-d13084642e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084393e42-true-d13084696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2245"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084393e42-true-d13084696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13084393e42-true-d13084696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e92-true-d13084765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2244"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e92-true-d13084765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13081586e92-true-d13084765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084775e13-true-d13084799e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2243"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13084775e13-true-d13084799e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13084775e13-true-d13084799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084820e13-true-d13084844e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2242"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13084820e13-true-d13084844e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13084820e13-true-d13084844e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084865e13-true-d13084889e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2241"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13084865e13-true-d13084889e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13084865e13-true-d13084889e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084910e13-true-d13084944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2240"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13084910e13-true-d13084944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13084910e13-true-d13084944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13081586e97-true-d13084988e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2239"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13081586e97-true-d13084988e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13081586e97-true-d13084988e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13084976e2-true-d13085015e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2238"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13084976e2-true-d13085015e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13084976e2-true-d13085015e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e16-true-d13086575e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2237"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e16-true-d13086575e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13085036e16-true-d13086575e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e95-true-d13086691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2236"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e95-true-d13086691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13085036e95-true-d13086691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13086668e9-true-d13086735e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2235"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13086668e9-true-d13086735e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13086668e9-true-d13086735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13086668e29-true-d13086784e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2234"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13086668e29-true-d13086784e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13086668e29-true-d13086784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e99-true-d13086820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2233"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e99-true-d13086820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13085036e99-true-d13086820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13086808e2-true-d13086840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2232"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13086808e2-true-d13086840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13086808e2-true-d13086840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13086808e8-true-d13086881e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2231"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13086808e8-true-d13086881e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13086808e8-true-d13086881e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e103-true-d13086958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="2230"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e103-true-d13086958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13085036e103-true-d13086958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13086910e5-true-d13087014e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="2229"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13086910e5-true-d13087014e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13086910e5-true-d13087014e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087024e13-true-d13087041e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="2228"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13087024e13-true-d13087041e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13087024e13-true-d13087041e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087056e13-true-d13087084e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="2227"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13087056e13-true-d13087084e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13087056e13-true-d13087084e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13086910e24-true-d13087145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2226"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13086910e24-true-d13087145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13086910e24-true-d13087145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087108e12-true-d13087213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2225"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087108e12-true-d13087213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13087108e12-true-d13087213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087108e35-true-d13087272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2224"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087108e35-true-d13087272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13087108e35-true-d13087272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e111-true-d13087367e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2223"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e111-true-d13087367e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13085036e111-true-d13087367e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087303e9-true-d13087427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2222"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087303e9-true-d13087427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13087303e9-true-d13087427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e115-true-d13087549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2221"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e115-true-d13087549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13085036e115-true-d13087549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087476e10-true-d13087641e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2220"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087476e10-true-d13087641e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13087476e10-true-d13087641e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087476e30-true-d13087680e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2219"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087476e30-true-d13087680e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13087476e30-true-d13087680e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087476e34-true-d13087719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2218"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087476e34-true-d13087719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13087476e34-true-d13087719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087476e39-true-d13087780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2217"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087476e39-true-d13087780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13087476e39-true-d13087780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087743e12-true-d13087848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2216"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087743e12-true-d13087848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13087743e12-true-d13087848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087743e35-true-d13087907e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2215"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087743e35-true-d13087907e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13087743e35-true-d13087907e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e119-true-d13088004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2214"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e119-true-d13088004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13085036e119-true-d13088004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087938e7-true-d13088079e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2213"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087938e7-true-d13088079e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13087938e7-true-d13088079e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088009e9-true-d13088118e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2212"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088009e9-true-d13088118e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13088009e9-true-d13088118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088009e10-true-d13088166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2211"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088009e10-true-d13088166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13088009e10-true-d13088166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088129e12-true-d13088234e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2210"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088129e12-true-d13088234e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13088129e12-true-d13088234e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088129e35-true-d13088293e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2209"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088129e35-true-d13088293e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13088129e35-true-d13088293e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13087938e11-true-d13088370e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2208"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13087938e11-true-d13088370e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13087938e11-true-d13088370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088324e16-true-d13088411e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2207"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088324e16-true-d13088411e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13088324e16-true-d13088411e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e124-true-d13088483e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2206"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e124-true-d13088483e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13085036e124-true-d13088483e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088422e15-true-d13088559e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2205"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088422e15-true-d13088559e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13088422e15-true-d13088559e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088422e35-true-d13088614e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2204"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088422e35-true-d13088614e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13088422e35-true-d13088614e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088422e39-true-d13088671e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2203"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088422e39-true-d13088671e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13088422e39-true-d13088671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088422e42-true-d13088725e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2202"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13088422e42-true-d13088725e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13088422e42-true-d13088725e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e151-true-d13088794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2201"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e151-true-d13088794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13085036e151-true-d13088794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088804e13-true-d13088828e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2200"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13088804e13-true-d13088828e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13088804e13-true-d13088828e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088849e13-true-d13088873e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2199"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13088849e13-true-d13088873e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13088849e13-true-d13088873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088894e13-true-d13088918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2198"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13088894e13-true-d13088918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13088894e13-true-d13088918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13088939e13-true-d13088973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2197"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13088939e13-true-d13088973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13088939e13-true-d13088973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13085036e156-true-d13089017e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2196"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13085036e156-true-d13089017e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13085036e156-true-d13089017e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089005e2-true-d13089044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2195"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13089005e2-true-d13089044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13089005e2-true-d13089044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e16-true-d13090571e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2194"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e16-true-d13090571e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13089065e16-true-d13090571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e71-true-d13090663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2193"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e71-true-d13090663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13089065e71-true-d13090663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13090640e9-true-d13090707e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2192"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13090640e9-true-d13090707e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13090640e9-true-d13090707e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13090640e29-true-d13090756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2191"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13090640e29-true-d13090756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13090640e29-true-d13090756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e76-true-d13090792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2190"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e76-true-d13090792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13089065e76-true-d13090792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13090780e2-true-d13090812e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2189"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13090780e2-true-d13090812e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13090780e2-true-d13090812e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13090780e8-true-d13090853e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2188"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13090780e8-true-d13090853e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13090780e8-true-d13090853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e80-true-d13090930e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="2187"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e80-true-d13090930e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13089065e80-true-d13090930e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13090882e5-true-d13090986e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="2186"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13090882e5-true-d13090986e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13090882e5-true-d13090986e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13090996e13-true-d13091013e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="2185"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13090996e13-true-d13091013e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13090996e13-true-d13091013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091028e13-true-d13091056e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="2184"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13091028e13-true-d13091056e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13091028e13-true-d13091056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13090882e24-true-d13091117e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2183"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13090882e24-true-d13091117e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13090882e24-true-d13091117e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091080e12-true-d13091185e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2182"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091080e12-true-d13091185e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13091080e12-true-d13091185e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091080e35-true-d13091244e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2181"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091080e35-true-d13091244e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13091080e35-true-d13091244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e87-true-d13091339e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2180"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e87-true-d13091339e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13089065e87-true-d13091339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091275e9-true-d13091399e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2179"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091275e9-true-d13091399e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13091275e9-true-d13091399e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e92-true-d13091521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2178"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e92-true-d13091521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13089065e92-true-d13091521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091448e10-true-d13091613e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2177"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091448e10-true-d13091613e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13091448e10-true-d13091613e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091448e30-true-d13091652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2176"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091448e30-true-d13091652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13091448e30-true-d13091652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091448e34-true-d13091691e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2175"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091448e34-true-d13091691e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13091448e34-true-d13091691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091448e39-true-d13091752e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2174"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091448e39-true-d13091752e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13091448e39-true-d13091752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091715e12-true-d13091820e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2173"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091715e12-true-d13091820e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13091715e12-true-d13091820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091715e35-true-d13091879e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2172"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091715e35-true-d13091879e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13091715e35-true-d13091879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e96-true-d13091976e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2171"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e96-true-d13091976e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13089065e96-true-d13091976e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091910e7-true-d13092051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2170"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091910e7-true-d13092051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13091910e7-true-d13092051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091981e9-true-d13092090e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2169"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091981e9-true-d13092090e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13091981e9-true-d13092090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091981e10-true-d13092138e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2168"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091981e10-true-d13092138e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13091981e10-true-d13092138e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092101e12-true-d13092206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2167"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092101e12-true-d13092206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13092101e12-true-d13092206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092101e35-true-d13092265e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2166"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092101e35-true-d13092265e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13092101e35-true-d13092265e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13091910e11-true-d13092342e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2165"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13091910e11-true-d13092342e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13091910e11-true-d13092342e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092296e16-true-d13092383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2164"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092296e16-true-d13092383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13092296e16-true-d13092383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e100-true-d13092455e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2163"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e100-true-d13092455e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13089065e100-true-d13092455e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092394e15-true-d13092531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2162"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092394e15-true-d13092531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13092394e15-true-d13092531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092394e35-true-d13092586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2161"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092394e35-true-d13092586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13092394e35-true-d13092586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092394e39-true-d13092643e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2160"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092394e39-true-d13092643e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13092394e39-true-d13092643e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092394e42-true-d13092697e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2159"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092394e42-true-d13092697e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13092394e42-true-d13092697e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e128-true-d13092766e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2158"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e128-true-d13092766e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13089065e128-true-d13092766e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092776e13-true-d13092800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2157"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13092776e13-true-d13092800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13092776e13-true-d13092800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092821e13-true-d13092845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2156"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13092821e13-true-d13092845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13092821e13-true-d13092845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092866e13-true-d13092890e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2155"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13092866e13-true-d13092890e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13092866e13-true-d13092890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092911e13-true-d13092945e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2154"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13092911e13-true-d13092945e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13092911e13-true-d13092945e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13089065e132-true-d13092989e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2153"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13089065e132-true-d13092989e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13089065e132-true-d13092989e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13092977e2-true-d13093016e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2152"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13092977e2-true-d13093016e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13092977e2-true-d13093016e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e137-true-d13093074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2151"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e137-true-d13093074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13052102e137-true-d13093074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093084e13-true-d13093108e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2150"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13093084e13-true-d13093108e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13093084e13-true-d13093108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093129e13-true-d13093153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2149"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13093129e13-true-d13093153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13093129e13-true-d13093153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093174e13-true-d13093198e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2148"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13093174e13-true-d13093198e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13093174e13-true-d13093198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093219e13-true-d13093253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2147"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13093219e13-true-d13093253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13093219e13-true-d13093253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13052102e141-true-d13093297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2146"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13052102e141-true-d13093297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13052102e141-true-d13093297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093285e2-true-d13093324e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2145"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13093285e2-true-d13093324e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13093285e2-true-d13093324e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e16-true-d13094761e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2144"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e16-true-d13094761e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13093345e16-true-d13094761e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e43-true-d13094814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2143"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e43-true-d13094814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13093345e43-true-d13094814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13094791e9-true-d13094858e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2142"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13094791e9-true-d13094858e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13094791e9-true-d13094858e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13094791e29-true-d13094907e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2141"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13094791e29-true-d13094907e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13094791e29-true-d13094907e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e47-true-d13094943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2140"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e47-true-d13094943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13093345e47-true-d13094943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13094931e2-true-d13094963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2139"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13094931e2-true-d13094963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13094931e2-true-d13094963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13094931e8-true-d13095004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2138"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13094931e8-true-d13095004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13094931e8-true-d13095004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e52-true-d13095097e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2137"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e52-true-d13095097e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13093345e52-true-d13095097e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095033e9-true-d13095157e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2136"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095033e9-true-d13095157e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13095033e9-true-d13095157e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e56-true-d13095279e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2135"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e56-true-d13095279e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13093345e56-true-d13095279e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095206e10-true-d13095371e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2134"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095206e10-true-d13095371e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13095206e10-true-d13095371e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095206e30-true-d13095410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2133"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095206e30-true-d13095410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13095206e30-true-d13095410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095206e34-true-d13095449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2132"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095206e34-true-d13095449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13095206e34-true-d13095449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095206e39-true-d13095510e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2131"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095206e39-true-d13095510e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13095206e39-true-d13095510e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095473e12-true-d13095578e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2130"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095473e12-true-d13095578e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13095473e12-true-d13095578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095473e35-true-d13095637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2129"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095473e35-true-d13095637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13095473e35-true-d13095637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e60-true-d13095734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2128"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e60-true-d13095734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13093345e60-true-d13095734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095668e7-true-d13095809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2127"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095668e7-true-d13095809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13095668e7-true-d13095809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095739e9-true-d13095848e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2126"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095739e9-true-d13095848e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13095739e9-true-d13095848e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095739e10-true-d13095896e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2125"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095739e10-true-d13095896e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13095739e10-true-d13095896e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095859e12-true-d13095964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2124"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095859e12-true-d13095964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13095859e12-true-d13095964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095859e35-true-d13096023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2123"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095859e35-true-d13096023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13095859e35-true-d13096023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13095668e11-true-d13096100e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2122"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13095668e11-true-d13096100e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13095668e11-true-d13096100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13096054e16-true-d13096141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2121"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13096054e16-true-d13096141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13096054e16-true-d13096141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e65-true-d13096213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2120"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e65-true-d13096213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13093345e65-true-d13096213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13096152e15-true-d13096289e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2119"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13096152e15-true-d13096289e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13096152e15-true-d13096289e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13096152e35-true-d13096344e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2118"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13096152e35-true-d13096344e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13096152e35-true-d13096344e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13096152e39-true-d13096401e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2117"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13096152e39-true-d13096401e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13096152e39-true-d13096401e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13096152e42-true-d13096455e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2116"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13096152e42-true-d13096455e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13096152e42-true-d13096455e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e69-true-d13101562e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="2115"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e69-true-d13101562e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d13093345e69-true-d13101562e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e16-true-d13103027e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2114"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e16-true-d13103027e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13101577e16-true-d13103027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e77-true-d13103107e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2113"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e77-true-d13103107e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13101577e77-true-d13103107e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103084e9-true-d13103151e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2112"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103084e9-true-d13103151e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13103084e9-true-d13103151e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103084e29-true-d13103200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2111"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103084e29-true-d13103200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13103084e29-true-d13103200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e81-true-d13103236e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2110"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e81-true-d13103236e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13101577e81-true-d13103236e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103224e2-true-d13103256e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2109"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103224e2-true-d13103256e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13103224e2-true-d13103256e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103224e8-true-d13103297e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2108"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103224e8-true-d13103297e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13103224e8-true-d13103297e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e85-true-d13103390e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2107"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e85-true-d13103390e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13101577e85-true-d13103390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103326e9-true-d13103450e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2106"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103326e9-true-d13103450e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13103326e9-true-d13103450e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e90-true-d13103572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2105"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e90-true-d13103572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13101577e90-true-d13103572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103499e10-true-d13103664e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2104"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103499e10-true-d13103664e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13103499e10-true-d13103664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103499e30-true-d13103703e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2103"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103499e30-true-d13103703e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13103499e30-true-d13103703e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103499e34-true-d13103742e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2102"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103499e34-true-d13103742e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13103499e34-true-d13103742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103499e39-true-d13103803e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2101"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103499e39-true-d13103803e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13103499e39-true-d13103803e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103766e12-true-d13103871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2100"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103766e12-true-d13103871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13103766e12-true-d13103871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103766e35-true-d13103930e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2099"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103766e35-true-d13103930e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13103766e35-true-d13103930e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e94-true-d13104027e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2098"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e94-true-d13104027e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13101577e94-true-d13104027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103961e7-true-d13104102e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2097"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103961e7-true-d13104102e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13103961e7-true-d13104102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104032e9-true-d13104141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2096"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104032e9-true-d13104141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13104032e9-true-d13104141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104032e10-true-d13104189e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2095"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104032e10-true-d13104189e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13104032e10-true-d13104189e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104152e12-true-d13104257e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2094"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104152e12-true-d13104257e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13104152e12-true-d13104257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104152e35-true-d13104316e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2093"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104152e35-true-d13104316e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13104152e35-true-d13104316e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13103961e11-true-d13104393e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2092"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13103961e11-true-d13104393e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13103961e11-true-d13104393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104347e16-true-d13104434e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2091"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104347e16-true-d13104434e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13104347e16-true-d13104434e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e98-true-d13104506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2090"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e98-true-d13104506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13101577e98-true-d13104506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104445e15-true-d13104582e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2089"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104445e15-true-d13104582e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13104445e15-true-d13104582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104445e35-true-d13104637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2088"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104445e35-true-d13104637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13104445e35-true-d13104637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104445e39-true-d13104694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2087"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104445e39-true-d13104694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13104445e39-true-d13104694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104445e42-true-d13104748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2086"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13104445e42-true-d13104748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13104445e42-true-d13104748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e126-true-d13104817e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2085"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e126-true-d13104817e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13101577e126-true-d13104817e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104827e13-true-d13104851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2084"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13104827e13-true-d13104851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13104827e13-true-d13104851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104872e13-true-d13104896e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2083"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13104872e13-true-d13104896e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13104872e13-true-d13104896e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104917e13-true-d13104941e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2082"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13104917e13-true-d13104941e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13104917e13-true-d13104941e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13104962e13-true-d13104996e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2081"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13104962e13-true-d13104996e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13104962e13-true-d13104996e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13101577e130-true-d13105040e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2080"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13101577e130-true-d13105040e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13101577e130-true-d13105040e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105028e2-true-d13105067e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2079"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13105028e2-true-d13105067e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13105028e2-true-d13105067e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e16-true-d13106531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2078"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e16-true-d13106531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13105088e16-true-d13106531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e65-true-d13106605e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2077"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e65-true-d13106605e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13105088e65-true-d13106605e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106582e9-true-d13106649e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2076"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106582e9-true-d13106649e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13106582e9-true-d13106649e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106582e29-true-d13106698e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2075"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106582e29-true-d13106698e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13106582e29-true-d13106698e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e69-true-d13106734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2074"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e69-true-d13106734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13105088e69-true-d13106734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106722e2-true-d13106754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2073"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106722e2-true-d13106754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13106722e2-true-d13106754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106722e8-true-d13106795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2072"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106722e8-true-d13106795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13106722e8-true-d13106795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e73-true-d13106888e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2071"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e73-true-d13106888e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13105088e73-true-d13106888e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106824e9-true-d13106948e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2070"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106824e9-true-d13106948e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13106824e9-true-d13106948e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e78-true-d13107070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2069"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e78-true-d13107070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13105088e78-true-d13107070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106997e10-true-d13107162e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2068"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106997e10-true-d13107162e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13106997e10-true-d13107162e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106997e30-true-d13107201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2067"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106997e30-true-d13107201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13106997e30-true-d13107201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106997e34-true-d13107240e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2066"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106997e34-true-d13107240e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13106997e34-true-d13107240e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13106997e39-true-d13107301e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2065"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13106997e39-true-d13107301e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13106997e39-true-d13107301e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107264e12-true-d13107369e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2064"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107264e12-true-d13107369e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13107264e12-true-d13107369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107264e35-true-d13107428e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2063"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107264e35-true-d13107428e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13107264e35-true-d13107428e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e82-true-d13107525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2062"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e82-true-d13107525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13105088e82-true-d13107525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107459e7-true-d13107600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2061"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107459e7-true-d13107600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13107459e7-true-d13107600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107530e9-true-d13107639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2060"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107530e9-true-d13107639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13107530e9-true-d13107639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107530e10-true-d13107687e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2059"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107530e10-true-d13107687e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13107530e10-true-d13107687e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107650e12-true-d13107755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2058"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107650e12-true-d13107755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13107650e12-true-d13107755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107650e35-true-d13107814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2057"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107650e35-true-d13107814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13107650e35-true-d13107814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107459e11-true-d13107891e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2056"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107459e11-true-d13107891e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13107459e11-true-d13107891e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107845e16-true-d13107932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2055"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107845e16-true-d13107932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13107845e16-true-d13107932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e86-true-d13108004e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2054"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e86-true-d13108004e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13105088e86-true-d13108004e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107943e15-true-d13108080e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2053"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107943e15-true-d13108080e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13107943e15-true-d13108080e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107943e35-true-d13108135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2052"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107943e35-true-d13108135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13107943e35-true-d13108135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107943e39-true-d13108192e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2051"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107943e39-true-d13108192e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13107943e39-true-d13108192e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13107943e42-true-d13108246e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2050"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13107943e42-true-d13108246e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13107943e42-true-d13108246e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e114-true-d13108315e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2049"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e114-true-d13108315e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13105088e114-true-d13108315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108325e13-true-d13108349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2048"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13108325e13-true-d13108349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13108325e13-true-d13108349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108370e13-true-d13108394e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2047"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13108370e13-true-d13108394e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13108370e13-true-d13108394e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108415e13-true-d13108439e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2046"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13108415e13-true-d13108439e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13108415e13-true-d13108439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108460e13-true-d13108494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2045"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13108460e13-true-d13108494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13108460e13-true-d13108494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13105088e118-true-d13108538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2044"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13105088e118-true-d13108538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13105088e118-true-d13108538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108526e2-true-d13108565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2043"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13108526e2-true-d13108565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13108526e2-true-d13108565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e16-true-d13110089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="2042"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e16-true-d13110089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d13108586e16-true-d13110089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e100-true-d13110208e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2041"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e100-true-d13110208e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13108586e100-true-d13110208e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110185e9-true-d13110252e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2040"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110185e9-true-d13110252e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13110185e9-true-d13110252e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110185e29-true-d13110301e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2039"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110185e29-true-d13110301e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13110185e29-true-d13110301e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e104-true-d13110337e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2038"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e104-true-d13110337e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13108586e104-true-d13110337e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110325e2-true-d13110357e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="2037"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110325e2-true-d13110357e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13110325e2-true-d13110357e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110325e8-true-d13110398e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2036"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110325e8-true-d13110398e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13110325e8-true-d13110398e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e108-true-d13110491e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="2035"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e108-true-d13110491e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13108586e108-true-d13110491e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110427e9-true-d13110551e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2034"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110427e9-true-d13110551e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13110427e9-true-d13110551e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e113-true-d13110673e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="2033"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e113-true-d13110673e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13108586e113-true-d13110673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110600e10-true-d13110765e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="2032"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110600e10-true-d13110765e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13110600e10-true-d13110765e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110600e30-true-d13110804e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2031"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110600e30-true-d13110804e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13110600e30-true-d13110804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110600e34-true-d13110843e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2030"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110600e34-true-d13110843e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13110600e34-true-d13110843e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110600e39-true-d13110904e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2029"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110600e39-true-d13110904e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13110600e39-true-d13110904e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110867e12-true-d13110972e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2028"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110867e12-true-d13110972e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13110867e12-true-d13110972e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13110867e35-true-d13111031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2027"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13110867e35-true-d13111031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13110867e35-true-d13111031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e117-true-d13111128e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="2026"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e117-true-d13111128e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13108586e117-true-d13111128e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111062e7-true-d13111203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="2025"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111062e7-true-d13111203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13111062e7-true-d13111203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111133e9-true-d13111242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="2024"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111133e9-true-d13111242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13111133e9-true-d13111242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111133e10-true-d13111290e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="2023"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111133e10-true-d13111290e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13111133e10-true-d13111290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111253e12-true-d13111358e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="2022"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111253e12-true-d13111358e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13111253e12-true-d13111358e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111253e35-true-d13111417e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="2021"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111253e35-true-d13111417e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13111253e35-true-d13111417e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111062e11-true-d13111494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="2020"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111062e11-true-d13111494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13111062e11-true-d13111494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111448e16-true-d13111535e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="2019"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111448e16-true-d13111535e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13111448e16-true-d13111535e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e121-true-d13111607e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="2018"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e121-true-d13111607e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13108586e121-true-d13111607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111546e15-true-d13111683e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="2017"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111546e15-true-d13111683e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13111546e15-true-d13111683e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111546e35-true-d13111738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="2016"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111546e35-true-d13111738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13111546e35-true-d13111738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111546e39-true-d13111795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="2015"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111546e39-true-d13111795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13111546e39-true-d13111795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111546e42-true-d13111849e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="2014"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13111546e42-true-d13111849e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13111546e42-true-d13111849e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e149-true-d13111918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="2013"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e149-true-d13111918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13108586e149-true-d13111918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111928e13-true-d13111952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2012"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13111928e13-true-d13111952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13111928e13-true-d13111952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13111973e13-true-d13111997e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2011"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13111973e13-true-d13111997e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13111973e13-true-d13111997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112018e13-true-d13112042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="2010"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13112018e13-true-d13112042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13112018e13-true-d13112042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112063e13-true-d13112097e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="2009"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13112063e13-true-d13112097e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13112063e13-true-d13112097e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e153-true-d13112141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="2008"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e153-true-d13112141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13108586e153-true-d13112141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112129e2-true-d13112168e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="2007"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13112129e2-true-d13112168e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13112129e2-true-d13112168e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e158-true-d13112199e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="2006"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e158-true-d13112199e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d13108586e158-true-d13112199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13108586e162-true-d13112237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="2005"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13108586e162-true-d13112237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d13108586e162-true-d13112237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e16-true-d13113682e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="2004"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e16-true-d13113682e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13112266e16-true-d13113682e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e43-true-d13113735e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="2003"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e43-true-d13113735e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13112266e43-true-d13113735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13113712e9-true-d13113779e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="2002"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13113712e9-true-d13113779e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13113712e9-true-d13113779e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13113712e29-true-d13113828e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="2001"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13113712e29-true-d13113828e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13113712e29-true-d13113828e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e47-true-d13113864e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="2000"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e47-true-d13113864e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13112266e47-true-d13113864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13113852e2-true-d13113884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1999"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13113852e2-true-d13113884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13113852e2-true-d13113884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13113852e8-true-d13113925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1998"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13113852e8-true-d13113925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13113852e8-true-d13113925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e52-true-d13114018e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1997"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e52-true-d13114018e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13112266e52-true-d13114018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13113954e9-true-d13114078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1996"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13113954e9-true-d13114078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13113954e9-true-d13114078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e56-true-d13114200e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1995"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e56-true-d13114200e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13112266e56-true-d13114200e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114127e10-true-d13114292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1994"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114127e10-true-d13114292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13114127e10-true-d13114292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114127e30-true-d13114331e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1993"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114127e30-true-d13114331e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13114127e30-true-d13114331e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114127e34-true-d13114370e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1992"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114127e34-true-d13114370e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13114127e34-true-d13114370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114127e39-true-d13114431e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1991"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114127e39-true-d13114431e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13114127e39-true-d13114431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114394e12-true-d13114499e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1990"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114394e12-true-d13114499e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13114394e12-true-d13114499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114394e35-true-d13114558e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1989"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114394e35-true-d13114558e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13114394e35-true-d13114558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e60-true-d13114655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1988"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e60-true-d13114655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13112266e60-true-d13114655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114589e7-true-d13114730e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1987"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114589e7-true-d13114730e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13114589e7-true-d13114730e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114660e9-true-d13114769e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1986"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114660e9-true-d13114769e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13114660e9-true-d13114769e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114660e10-true-d13114817e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1985"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114660e10-true-d13114817e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13114660e10-true-d13114817e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114780e12-true-d13114885e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1984"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114780e12-true-d13114885e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13114780e12-true-d13114885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114780e35-true-d13114944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1983"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114780e35-true-d13114944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13114780e35-true-d13114944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114589e11-true-d13115021e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1982"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114589e11-true-d13115021e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13114589e11-true-d13115021e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13114975e16-true-d13115062e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1981"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13114975e16-true-d13115062e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13114975e16-true-d13115062e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e65-true-d13115134e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1980"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e65-true-d13115134e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13112266e65-true-d13115134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115073e15-true-d13115210e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1979"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13115073e15-true-d13115210e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13115073e15-true-d13115210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115073e35-true-d13115265e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1978"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13115073e35-true-d13115265e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13115073e35-true-d13115265e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115073e39-true-d13115322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1977"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13115073e39-true-d13115322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13115073e39-true-d13115322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115073e42-true-d13115376e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1976"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13115073e42-true-d13115376e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13115073e42-true-d13115376e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e92-true-d13115445e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1975"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e92-true-d13115445e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13112266e92-true-d13115445e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115455e13-true-d13115479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1974"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13115455e13-true-d13115479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13115455e13-true-d13115479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115500e13-true-d13115524e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1973"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13115500e13-true-d13115524e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13115500e13-true-d13115524e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115545e13-true-d13115569e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1972"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13115545e13-true-d13115569e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13115545e13-true-d13115569e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115590e13-true-d13115624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1971"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13115590e13-true-d13115624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13115590e13-true-d13115624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13112266e97-true-d13115668e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1970"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13112266e97-true-d13115668e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13112266e97-true-d13115668e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115656e2-true-d13115695e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1969"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13115656e2-true-d13115695e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13115656e2-true-d13115695e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e16-true-d13117139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="1968"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e16-true-d13117139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d13115716e16-true-d13117139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e53-true-d13117198e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1967"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e53-true-d13117198e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13115716e53-true-d13117198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117175e9-true-d13117242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1966"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117175e9-true-d13117242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13117175e9-true-d13117242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117175e29-true-d13117291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1965"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117175e29-true-d13117291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13117175e29-true-d13117291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e58-true-d13117327e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1964"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e58-true-d13117327e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13115716e58-true-d13117327e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117315e2-true-d13117347e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1963"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117315e2-true-d13117347e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13117315e2-true-d13117347e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117315e8-true-d13117388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1962"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117315e8-true-d13117388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13117315e8-true-d13117388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e62-true-d13117481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1961"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e62-true-d13117481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13115716e62-true-d13117481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117417e9-true-d13117541e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1960"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117417e9-true-d13117541e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13117417e9-true-d13117541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e66-true-d13117663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1959"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e66-true-d13117663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13115716e66-true-d13117663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117590e10-true-d13117755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1958"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117590e10-true-d13117755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13117590e10-true-d13117755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117590e30-true-d13117794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1957"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117590e30-true-d13117794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13117590e30-true-d13117794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117590e34-true-d13117833e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1956"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117590e34-true-d13117833e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13117590e34-true-d13117833e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117590e39-true-d13117894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1955"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117590e39-true-d13117894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13117590e39-true-d13117894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117857e12-true-d13117962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1954"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117857e12-true-d13117962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13117857e12-true-d13117962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13117857e35-true-d13118021e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1953"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13117857e35-true-d13118021e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13117857e35-true-d13118021e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e71-true-d13118118e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1952"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e71-true-d13118118e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13115716e71-true-d13118118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118052e7-true-d13118193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1951"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118052e7-true-d13118193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13118052e7-true-d13118193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118123e9-true-d13118232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1950"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118123e9-true-d13118232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13118123e9-true-d13118232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118123e10-true-d13118280e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1949"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118123e10-true-d13118280e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13118123e10-true-d13118280e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118243e12-true-d13118348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1948"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118243e12-true-d13118348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13118243e12-true-d13118348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118243e35-true-d13118407e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1947"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118243e35-true-d13118407e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13118243e35-true-d13118407e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118052e11-true-d13118484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1946"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118052e11-true-d13118484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13118052e11-true-d13118484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118438e16-true-d13118525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1945"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118438e16-true-d13118525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13118438e16-true-d13118525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e75-true-d13118597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1944"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e75-true-d13118597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13115716e75-true-d13118597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118536e15-true-d13118673e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1943"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118536e15-true-d13118673e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13118536e15-true-d13118673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118536e35-true-d13118728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1942"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118536e35-true-d13118728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13118536e35-true-d13118728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118536e39-true-d13118785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1941"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118536e39-true-d13118785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13118536e39-true-d13118785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118536e42-true-d13118839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1940"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13118536e42-true-d13118839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13118536e42-true-d13118839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e81-true-d13118899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1939"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e81-true-d13118899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13115716e81-true-d13118899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118909e13-true-d13118933e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1938"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13118909e13-true-d13118933e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13118909e13-true-d13118933e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118954e13-true-d13118978e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1937"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13118954e13-true-d13118978e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13118954e13-true-d13118978e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13118999e13-true-d13119023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1936"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13118999e13-true-d13119023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13118999e13-true-d13119023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119044e13-true-d13119078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1935"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13119044e13-true-d13119078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13119044e13-true-d13119078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13115716e86-true-d13119122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1934"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13115716e86-true-d13119122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13115716e86-true-d13119122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119110e2-true-d13119149e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1933"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13119110e2-true-d13119149e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13119110e2-true-d13119149e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e16-true-d13120650e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1932"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e16-true-d13120650e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13119179e16-true-d13120650e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e87-true-d13120748e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1931"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e87-true-d13120748e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13119179e87-true-d13120748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13120725e9-true-d13120792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1930"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13120725e9-true-d13120792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13120725e9-true-d13120792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13120725e29-true-d13120841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1929"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13120725e29-true-d13120841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13120725e29-true-d13120841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e92-true-d13120877e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1928"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e92-true-d13120877e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13119179e92-true-d13120877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13120865e2-true-d13120897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1927"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13120865e2-true-d13120897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13120865e2-true-d13120897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13120865e8-true-d13120938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1926"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13120865e8-true-d13120938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13120865e8-true-d13120938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e96-true-d13121031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1925"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e96-true-d13121031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13119179e96-true-d13121031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13120967e9-true-d13121091e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1924"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13120967e9-true-d13121091e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13120967e9-true-d13121091e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e100-true-d13121213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1923"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e100-true-d13121213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13119179e100-true-d13121213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121140e10-true-d13121305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1922"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121140e10-true-d13121305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13121140e10-true-d13121305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121140e30-true-d13121344e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1921"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121140e30-true-d13121344e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13121140e30-true-d13121344e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121140e34-true-d13121383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1920"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121140e34-true-d13121383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13121140e34-true-d13121383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121140e39-true-d13121444e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1919"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121140e39-true-d13121444e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13121140e39-true-d13121444e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121407e12-true-d13121512e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1918"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121407e12-true-d13121512e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13121407e12-true-d13121512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121407e35-true-d13121571e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1917"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121407e35-true-d13121571e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13121407e35-true-d13121571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e105-true-d13121668e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1916"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e105-true-d13121668e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13119179e105-true-d13121668e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121602e7-true-d13121743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1915"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121602e7-true-d13121743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13121602e7-true-d13121743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121673e9-true-d13121782e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1914"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121673e9-true-d13121782e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13121673e9-true-d13121782e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121673e10-true-d13121830e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1913"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121673e10-true-d13121830e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13121673e10-true-d13121830e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121793e12-true-d13121898e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1912"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121793e12-true-d13121898e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13121793e12-true-d13121898e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121793e35-true-d13121957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1911"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121793e35-true-d13121957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13121793e35-true-d13121957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121602e11-true-d13122034e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1910"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121602e11-true-d13122034e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13121602e11-true-d13122034e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13121988e16-true-d13122075e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1909"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13121988e16-true-d13122075e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13121988e16-true-d13122075e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e109-true-d13122147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1908"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e109-true-d13122147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13119179e109-true-d13122147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122086e15-true-d13122223e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1907"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13122086e15-true-d13122223e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13122086e15-true-d13122223e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122086e35-true-d13122278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1906"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13122086e35-true-d13122278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13122086e35-true-d13122278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122086e39-true-d13122335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1905"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13122086e39-true-d13122335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13122086e39-true-d13122335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122086e42-true-d13122389e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1904"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13122086e42-true-d13122389e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13122086e42-true-d13122389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e137-true-d13122458e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1903"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e137-true-d13122458e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13119179e137-true-d13122458e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122468e13-true-d13122492e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1902"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13122468e13-true-d13122492e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13122468e13-true-d13122492e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122513e13-true-d13122537e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1901"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13122513e13-true-d13122537e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13122513e13-true-d13122537e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122558e13-true-d13122582e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1900"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13122558e13-true-d13122582e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13122558e13-true-d13122582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122603e13-true-d13122637e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1899"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13122603e13-true-d13122637e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13122603e13-true-d13122637e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13119179e141-true-d13122681e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1898"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13119179e141-true-d13122681e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13119179e141-true-d13122681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122669e2-true-d13122708e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1897"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13122669e2-true-d13122708e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13122669e2-true-d13122708e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e16-true-d13124145e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1896"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e16-true-d13124145e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13122729e16-true-d13124145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e43-true-d13124198e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1895"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e43-true-d13124198e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13122729e43-true-d13124198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124175e9-true-d13124242e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1894"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124175e9-true-d13124242e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13124175e9-true-d13124242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124175e29-true-d13124291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1893"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124175e29-true-d13124291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13124175e29-true-d13124291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e47-true-d13124327e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1892"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e47-true-d13124327e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13122729e47-true-d13124327e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124315e2-true-d13124347e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1891"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124315e2-true-d13124347e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13124315e2-true-d13124347e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124315e8-true-d13124388e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1890"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124315e8-true-d13124388e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13124315e8-true-d13124388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e52-true-d13124481e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1889"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e52-true-d13124481e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13122729e52-true-d13124481e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124417e9-true-d13124541e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1888"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124417e9-true-d13124541e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13124417e9-true-d13124541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e56-true-d13124663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1887"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e56-true-d13124663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13122729e56-true-d13124663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124590e10-true-d13124755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1886"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124590e10-true-d13124755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13124590e10-true-d13124755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124590e30-true-d13124794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1885"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124590e30-true-d13124794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13124590e30-true-d13124794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124590e34-true-d13124833e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1884"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124590e34-true-d13124833e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13124590e34-true-d13124833e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124590e39-true-d13124894e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1883"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124590e39-true-d13124894e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13124590e39-true-d13124894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124857e12-true-d13124962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1882"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124857e12-true-d13124962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13124857e12-true-d13124962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13124857e35-true-d13125021e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1881"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13124857e35-true-d13125021e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13124857e35-true-d13125021e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e60-true-d13125118e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1880"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e60-true-d13125118e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13122729e60-true-d13125118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125052e7-true-d13125193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1879"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125052e7-true-d13125193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13125052e7-true-d13125193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125123e9-true-d13125232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1878"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125123e9-true-d13125232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13125123e9-true-d13125232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125123e10-true-d13125280e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1877"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125123e10-true-d13125280e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13125123e10-true-d13125280e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125243e12-true-d13125348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1876"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125243e12-true-d13125348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13125243e12-true-d13125348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125243e35-true-d13125407e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1875"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125243e35-true-d13125407e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13125243e35-true-d13125407e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125052e11-true-d13125484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1874"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125052e11-true-d13125484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13125052e11-true-d13125484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125438e16-true-d13125525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1873"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125438e16-true-d13125525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13125438e16-true-d13125525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e65-true-d13125597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1872"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e65-true-d13125597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13122729e65-true-d13125597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125536e15-true-d13125673e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1871"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125536e15-true-d13125673e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13125536e15-true-d13125673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125536e35-true-d13125728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1870"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125536e35-true-d13125728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13125536e35-true-d13125728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125536e39-true-d13125785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1869"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125536e39-true-d13125785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13125536e39-true-d13125785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125536e42-true-d13125839e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1868"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13125536e42-true-d13125839e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13125536e42-true-d13125839e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e92-true-d13125908e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1867"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e92-true-d13125908e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13122729e92-true-d13125908e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125918e13-true-d13125942e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1866"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13125918e13-true-d13125942e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13125918e13-true-d13125942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13125963e13-true-d13125987e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1865"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13125963e13-true-d13125987e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13125963e13-true-d13125987e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126008e13-true-d13126032e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1864"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13126008e13-true-d13126032e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13126008e13-true-d13126032e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126053e13-true-d13126087e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1863"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13126053e13-true-d13126087e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13126053e13-true-d13126087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13122729e97-true-d13126131e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1862"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13122729e97-true-d13126131e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13122729e97-true-d13126131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126119e2-true-d13126158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1861"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13126119e2-true-d13126158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13126119e2-true-d13126158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e16-true-d13127718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1860"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e16-true-d13127718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13126179e16-true-d13127718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e95-true-d13127834e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1859"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e95-true-d13127834e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13126179e95-true-d13127834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13127811e9-true-d13127878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1858"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13127811e9-true-d13127878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13127811e9-true-d13127878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13127811e29-true-d13127927e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1857"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13127811e29-true-d13127927e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13127811e29-true-d13127927e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e99-true-d13127963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1856"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e99-true-d13127963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13126179e99-true-d13127963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13127951e2-true-d13127983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1855"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13127951e2-true-d13127983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13127951e2-true-d13127983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13127951e8-true-d13128024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1854"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13127951e8-true-d13128024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13127951e8-true-d13128024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e103-true-d13128101e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1853"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e103-true-d13128101e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13126179e103-true-d13128101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128053e5-true-d13128157e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1852"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128053e5-true-d13128157e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13128053e5-true-d13128157e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128167e13-true-d13128184e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1851"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13128167e13-true-d13128184e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13128167e13-true-d13128184e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128199e13-true-d13128227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1850"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13128199e13-true-d13128227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13128199e13-true-d13128227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128053e24-true-d13128288e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1849"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128053e24-true-d13128288e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13128053e24-true-d13128288e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128251e12-true-d13128356e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1848"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128251e12-true-d13128356e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13128251e12-true-d13128356e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128251e35-true-d13128415e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1847"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128251e35-true-d13128415e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13128251e35-true-d13128415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e111-true-d13128510e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1846"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e111-true-d13128510e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13126179e111-true-d13128510e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128446e9-true-d13128570e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1845"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128446e9-true-d13128570e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13128446e9-true-d13128570e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e115-true-d13128692e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1844"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e115-true-d13128692e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13126179e115-true-d13128692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128619e10-true-d13128784e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1843"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128619e10-true-d13128784e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13128619e10-true-d13128784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128619e30-true-d13128823e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1842"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128619e30-true-d13128823e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13128619e30-true-d13128823e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128619e34-true-d13128862e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1841"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128619e34-true-d13128862e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13128619e34-true-d13128862e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128619e39-true-d13128923e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1840"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128619e39-true-d13128923e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13128619e39-true-d13128923e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128886e12-true-d13128991e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1839"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128886e12-true-d13128991e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13128886e12-true-d13128991e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13128886e35-true-d13129050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1838"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13128886e35-true-d13129050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13128886e35-true-d13129050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e119-true-d13129147e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1837"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e119-true-d13129147e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13126179e119-true-d13129147e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129081e7-true-d13129222e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1836"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129081e7-true-d13129222e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13129081e7-true-d13129222e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129152e9-true-d13129261e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1835"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129152e9-true-d13129261e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13129152e9-true-d13129261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129152e10-true-d13129309e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1834"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129152e10-true-d13129309e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13129152e10-true-d13129309e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129272e12-true-d13129377e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1833"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129272e12-true-d13129377e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13129272e12-true-d13129377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129272e35-true-d13129436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1832"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129272e35-true-d13129436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13129272e35-true-d13129436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129081e11-true-d13129513e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1831"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129081e11-true-d13129513e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13129081e11-true-d13129513e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129467e16-true-d13129554e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1830"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129467e16-true-d13129554e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13129467e16-true-d13129554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e124-true-d13129626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1829"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e124-true-d13129626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13126179e124-true-d13129626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129565e15-true-d13129702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1828"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129565e15-true-d13129702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13129565e15-true-d13129702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129565e35-true-d13129757e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1827"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129565e35-true-d13129757e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13129565e35-true-d13129757e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129565e39-true-d13129814e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1826"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129565e39-true-d13129814e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13129565e39-true-d13129814e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129565e42-true-d13129868e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1825"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13129565e42-true-d13129868e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13129565e42-true-d13129868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e151-true-d13129937e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1824"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e151-true-d13129937e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13126179e151-true-d13129937e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129947e13-true-d13129971e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1823"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13129947e13-true-d13129971e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13129947e13-true-d13129971e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13129992e13-true-d13130016e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1822"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13129992e13-true-d13130016e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13129992e13-true-d13130016e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130037e13-true-d13130061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1821"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13130037e13-true-d13130061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13130037e13-true-d13130061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130082e13-true-d13130116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1820"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13130082e13-true-d13130116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13130082e13-true-d13130116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13126179e156-true-d13130160e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1819"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13126179e156-true-d13130160e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13126179e156-true-d13130160e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130148e2-true-d13130187e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1818"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13130148e2-true-d13130187e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13130148e2-true-d13130187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e16-true-d13131714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1817"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e16-true-d13131714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13130208e16-true-d13131714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e71-true-d13131806e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1816"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e71-true-d13131806e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13130208e71-true-d13131806e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13131783e9-true-d13131850e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1815"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13131783e9-true-d13131850e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13131783e9-true-d13131850e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13131783e29-true-d13131899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1814"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13131783e29-true-d13131899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13131783e29-true-d13131899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e76-true-d13131935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1813"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e76-true-d13131935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13130208e76-true-d13131935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13131923e2-true-d13131955e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1812"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13131923e2-true-d13131955e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13131923e2-true-d13131955e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13131923e8-true-d13131996e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1811"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13131923e8-true-d13131996e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13131923e8-true-d13131996e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e80-true-d13132073e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1810"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e80-true-d13132073e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13130208e80-true-d13132073e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132025e5-true-d13132129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1809"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132025e5-true-d13132129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13132025e5-true-d13132129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132139e13-true-d13132156e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1808"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13132139e13-true-d13132156e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13132139e13-true-d13132156e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132171e13-true-d13132199e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1807"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13132171e13-true-d13132199e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13132171e13-true-d13132199e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132025e24-true-d13132260e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1806"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132025e24-true-d13132260e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13132025e24-true-d13132260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132223e12-true-d13132328e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1805"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132223e12-true-d13132328e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13132223e12-true-d13132328e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132223e35-true-d13132387e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1804"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132223e35-true-d13132387e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13132223e35-true-d13132387e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e87-true-d13132482e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1803"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e87-true-d13132482e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13130208e87-true-d13132482e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132418e9-true-d13132542e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1802"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132418e9-true-d13132542e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13132418e9-true-d13132542e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e92-true-d13132664e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1801"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e92-true-d13132664e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13130208e92-true-d13132664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132591e10-true-d13132756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1800"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132591e10-true-d13132756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13132591e10-true-d13132756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132591e30-true-d13132795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1799"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132591e30-true-d13132795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13132591e30-true-d13132795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132591e34-true-d13132834e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1798"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132591e34-true-d13132834e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13132591e34-true-d13132834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132591e39-true-d13132895e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1797"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132591e39-true-d13132895e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13132591e39-true-d13132895e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132858e12-true-d13132963e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1796"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132858e12-true-d13132963e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13132858e12-true-d13132963e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13132858e35-true-d13133022e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1795"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13132858e35-true-d13133022e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13132858e35-true-d13133022e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e96-true-d13133119e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1794"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e96-true-d13133119e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13130208e96-true-d13133119e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133053e7-true-d13133194e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1793"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133053e7-true-d13133194e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13133053e7-true-d13133194e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133124e9-true-d13133233e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1792"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133124e9-true-d13133233e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13133124e9-true-d13133233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133124e10-true-d13133281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1791"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133124e10-true-d13133281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13133124e10-true-d13133281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133244e12-true-d13133349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1790"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133244e12-true-d13133349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13133244e12-true-d13133349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133244e35-true-d13133408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1789"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133244e35-true-d13133408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13133244e35-true-d13133408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133053e11-true-d13133485e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1788"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133053e11-true-d13133485e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13133053e11-true-d13133485e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133439e16-true-d13133526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1787"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133439e16-true-d13133526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13133439e16-true-d13133526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e100-true-d13133598e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1786"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e100-true-d13133598e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13130208e100-true-d13133598e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133537e15-true-d13133674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1785"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133537e15-true-d13133674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13133537e15-true-d13133674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133537e35-true-d13133729e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1784"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133537e35-true-d13133729e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13133537e35-true-d13133729e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133537e39-true-d13133786e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1783"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133537e39-true-d13133786e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13133537e39-true-d13133786e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133537e42-true-d13133840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1782"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13133537e42-true-d13133840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13133537e42-true-d13133840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e128-true-d13133909e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1781"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e128-true-d13133909e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13130208e128-true-d13133909e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133919e13-true-d13133943e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1780"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13133919e13-true-d13133943e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13133919e13-true-d13133943e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13133964e13-true-d13133988e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1779"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13133964e13-true-d13133988e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13133964e13-true-d13133988e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134009e13-true-d13134033e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1778"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13134009e13-true-d13134033e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13134009e13-true-d13134033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134054e13-true-d13134088e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1777"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13134054e13-true-d13134088e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13134054e13-true-d13134088e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13130208e132-true-d13134132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1776"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13130208e132-true-d13134132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13130208e132-true-d13134132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134120e2-true-d13134159e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1775"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13134120e2-true-d13134159e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13134120e2-true-d13134159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e92-true-d13134217e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1774"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e92-true-d13134217e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13093345e92-true-d13134217e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134227e13-true-d13134251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1773"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13134227e13-true-d13134251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13134227e13-true-d13134251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134272e13-true-d13134296e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1772"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13134272e13-true-d13134296e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13134272e13-true-d13134296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134317e13-true-d13134341e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1771"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13134317e13-true-d13134341e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13134317e13-true-d13134341e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134362e13-true-d13134396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1770"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13134362e13-true-d13134396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13134362e13-true-d13134396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13093345e97-true-d13134440e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1769"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13093345e97-true-d13134440e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13093345e97-true-d13134440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134428e2-true-d13134467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1768"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13134428e2-true-d13134467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13134428e2-true-d13134467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e16-true-d13136027e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1767"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e16-true-d13136027e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13134488e16-true-d13136027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e95-true-d13136143e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1766"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e95-true-d13136143e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13134488e95-true-d13136143e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136120e9-true-d13136187e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1765"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136120e9-true-d13136187e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13136120e9-true-d13136187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136120e29-true-d13136236e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1764"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136120e29-true-d13136236e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13136120e29-true-d13136236e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e99-true-d13136272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1763"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e99-true-d13136272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13134488e99-true-d13136272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136260e2-true-d13136292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1762"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136260e2-true-d13136292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13136260e2-true-d13136292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136260e8-true-d13136333e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1761"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136260e8-true-d13136333e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13136260e8-true-d13136333e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e103-true-d13136410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1760"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e103-true-d13136410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13134488e103-true-d13136410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136362e5-true-d13136466e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1759"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136362e5-true-d13136466e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13136362e5-true-d13136466e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136476e13-true-d13136493e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1758"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13136476e13-true-d13136493e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13136476e13-true-d13136493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136508e13-true-d13136536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1757"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13136508e13-true-d13136536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13136508e13-true-d13136536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136362e24-true-d13136597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1756"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136362e24-true-d13136597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13136362e24-true-d13136597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136560e12-true-d13136665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1755"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136560e12-true-d13136665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13136560e12-true-d13136665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136560e35-true-d13136724e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1754"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136560e35-true-d13136724e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13136560e35-true-d13136724e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e111-true-d13136819e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1753"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e111-true-d13136819e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13134488e111-true-d13136819e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136755e9-true-d13136879e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1752"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136755e9-true-d13136879e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13136755e9-true-d13136879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e115-true-d13137001e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1751"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e115-true-d13137001e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13134488e115-true-d13137001e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136928e10-true-d13137093e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1750"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136928e10-true-d13137093e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13136928e10-true-d13137093e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136928e30-true-d13137132e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1749"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136928e30-true-d13137132e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13136928e30-true-d13137132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136928e34-true-d13137171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1748"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136928e34-true-d13137171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13136928e34-true-d13137171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13136928e39-true-d13137232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1747"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13136928e39-true-d13137232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13136928e39-true-d13137232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137195e12-true-d13137300e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1746"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137195e12-true-d13137300e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13137195e12-true-d13137300e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137195e35-true-d13137359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1745"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137195e35-true-d13137359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13137195e35-true-d13137359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e119-true-d13137456e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1744"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e119-true-d13137456e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13134488e119-true-d13137456e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137390e7-true-d13137531e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1743"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137390e7-true-d13137531e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13137390e7-true-d13137531e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137461e9-true-d13137570e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1742"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137461e9-true-d13137570e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13137461e9-true-d13137570e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137461e10-true-d13137618e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1741"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137461e10-true-d13137618e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13137461e10-true-d13137618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137581e12-true-d13137686e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1740"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137581e12-true-d13137686e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13137581e12-true-d13137686e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137581e35-true-d13137745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1739"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137581e35-true-d13137745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13137581e35-true-d13137745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137390e11-true-d13137822e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1738"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137390e11-true-d13137822e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13137390e11-true-d13137822e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137776e16-true-d13137863e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1737"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137776e16-true-d13137863e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13137776e16-true-d13137863e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e124-true-d13137935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1736"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e124-true-d13137935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13134488e124-true-d13137935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137874e15-true-d13138011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1735"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137874e15-true-d13138011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13137874e15-true-d13138011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137874e35-true-d13138066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1734"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137874e35-true-d13138066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13137874e35-true-d13138066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137874e39-true-d13138123e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1733"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137874e39-true-d13138123e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13137874e39-true-d13138123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13137874e42-true-d13138177e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1732"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13137874e42-true-d13138177e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13137874e42-true-d13138177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e128-true-d13143284e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="1731"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e128-true-d13143284e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d13134488e128-true-d13143284e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e16-true-d13144749e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1730"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e16-true-d13144749e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13143299e16-true-d13144749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e77-true-d13144829e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1729"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e77-true-d13144829e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13143299e77-true-d13144829e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13144806e9-true-d13144873e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1728"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13144806e9-true-d13144873e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13144806e9-true-d13144873e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13144806e29-true-d13144922e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1727"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13144806e29-true-d13144922e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13144806e29-true-d13144922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e81-true-d13144958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1726"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e81-true-d13144958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13143299e81-true-d13144958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13144946e2-true-d13144978e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1725"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13144946e2-true-d13144978e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13144946e2-true-d13144978e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13144946e8-true-d13145019e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1724"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13144946e8-true-d13145019e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13144946e8-true-d13145019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e85-true-d13145112e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1723"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e85-true-d13145112e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13143299e85-true-d13145112e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145048e9-true-d13145172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1722"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145048e9-true-d13145172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13145048e9-true-d13145172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e90-true-d13145294e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1721"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e90-true-d13145294e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13143299e90-true-d13145294e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145221e10-true-d13145386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1720"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145221e10-true-d13145386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13145221e10-true-d13145386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145221e30-true-d13145425e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1719"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145221e30-true-d13145425e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13145221e30-true-d13145425e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145221e34-true-d13145464e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1718"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145221e34-true-d13145464e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13145221e34-true-d13145464e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145221e39-true-d13145525e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1717"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145221e39-true-d13145525e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13145221e39-true-d13145525e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145488e12-true-d13145593e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1716"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145488e12-true-d13145593e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13145488e12-true-d13145593e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145488e35-true-d13145652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1715"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145488e35-true-d13145652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13145488e35-true-d13145652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e94-true-d13145749e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1714"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e94-true-d13145749e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13143299e94-true-d13145749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145683e7-true-d13145824e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1713"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145683e7-true-d13145824e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13145683e7-true-d13145824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145754e9-true-d13145863e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1712"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145754e9-true-d13145863e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13145754e9-true-d13145863e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145754e10-true-d13145911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1711"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145754e10-true-d13145911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13145754e10-true-d13145911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145874e12-true-d13145979e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1710"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145874e12-true-d13145979e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13145874e12-true-d13145979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145874e35-true-d13146038e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1709"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145874e35-true-d13146038e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13145874e35-true-d13146038e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13145683e11-true-d13146115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1708"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13145683e11-true-d13146115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13145683e11-true-d13146115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146069e16-true-d13146156e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1707"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13146069e16-true-d13146156e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13146069e16-true-d13146156e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e98-true-d13146228e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1706"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e98-true-d13146228e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13143299e98-true-d13146228e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146167e15-true-d13146304e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1705"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13146167e15-true-d13146304e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13146167e15-true-d13146304e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146167e35-true-d13146359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1704"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13146167e35-true-d13146359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13146167e35-true-d13146359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146167e39-true-d13146416e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1703"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13146167e39-true-d13146416e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13146167e39-true-d13146416e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146167e42-true-d13146470e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1702"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13146167e42-true-d13146470e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13146167e42-true-d13146470e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e126-true-d13146539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1701"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e126-true-d13146539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13143299e126-true-d13146539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146549e13-true-d13146573e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1700"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13146549e13-true-d13146573e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13146549e13-true-d13146573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146594e13-true-d13146618e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1699"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13146594e13-true-d13146618e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13146594e13-true-d13146618e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146639e13-true-d13146663e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1698"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13146639e13-true-d13146663e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13146639e13-true-d13146663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146684e13-true-d13146718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1697"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13146684e13-true-d13146718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13146684e13-true-d13146718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13143299e130-true-d13146762e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1696"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13143299e130-true-d13146762e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13143299e130-true-d13146762e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146750e2-true-d13146789e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1695"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13146750e2-true-d13146789e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13146750e2-true-d13146789e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e16-true-d13148253e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1694"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e16-true-d13148253e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13146810e16-true-d13148253e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e65-true-d13148327e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1693"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e65-true-d13148327e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13146810e65-true-d13148327e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148304e9-true-d13148371e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1692"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148304e9-true-d13148371e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13148304e9-true-d13148371e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148304e29-true-d13148420e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1691"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148304e29-true-d13148420e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13148304e29-true-d13148420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e69-true-d13148456e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1690"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e69-true-d13148456e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13146810e69-true-d13148456e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148444e2-true-d13148476e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1689"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148444e2-true-d13148476e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13148444e2-true-d13148476e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148444e8-true-d13148517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1688"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148444e8-true-d13148517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13148444e8-true-d13148517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e73-true-d13148610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1687"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e73-true-d13148610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13146810e73-true-d13148610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148546e9-true-d13148670e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1686"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148546e9-true-d13148670e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13148546e9-true-d13148670e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e78-true-d13148792e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1685"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e78-true-d13148792e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13146810e78-true-d13148792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148719e10-true-d13148884e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1684"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148719e10-true-d13148884e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13148719e10-true-d13148884e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148719e30-true-d13148923e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1683"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148719e30-true-d13148923e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13148719e30-true-d13148923e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148719e34-true-d13148962e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1682"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148719e34-true-d13148962e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13148719e34-true-d13148962e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148719e39-true-d13149023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1681"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148719e39-true-d13149023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13148719e39-true-d13149023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148986e12-true-d13149091e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1680"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148986e12-true-d13149091e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13148986e12-true-d13149091e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13148986e35-true-d13149150e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1679"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13148986e35-true-d13149150e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13148986e35-true-d13149150e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e82-true-d13149247e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1678"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e82-true-d13149247e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13146810e82-true-d13149247e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149181e7-true-d13149322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1677"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149181e7-true-d13149322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13149181e7-true-d13149322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149252e9-true-d13149361e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1676"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149252e9-true-d13149361e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13149252e9-true-d13149361e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149252e10-true-d13149409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1675"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149252e10-true-d13149409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13149252e10-true-d13149409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149372e12-true-d13149477e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1674"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149372e12-true-d13149477e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13149372e12-true-d13149477e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149372e35-true-d13149536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1673"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149372e35-true-d13149536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13149372e35-true-d13149536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149181e11-true-d13149613e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1672"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149181e11-true-d13149613e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13149181e11-true-d13149613e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149567e16-true-d13149654e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1671"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149567e16-true-d13149654e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13149567e16-true-d13149654e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e86-true-d13149726e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1670"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e86-true-d13149726e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13146810e86-true-d13149726e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149665e15-true-d13149802e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1669"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149665e15-true-d13149802e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13149665e15-true-d13149802e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149665e35-true-d13149857e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1668"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149665e35-true-d13149857e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13149665e35-true-d13149857e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149665e39-true-d13149914e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1667"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149665e39-true-d13149914e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13149665e39-true-d13149914e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13149665e42-true-d13149968e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1666"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13149665e42-true-d13149968e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13149665e42-true-d13149968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e114-true-d13150037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1665"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e114-true-d13150037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13146810e114-true-d13150037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150047e13-true-d13150071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1664"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13150047e13-true-d13150071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13150047e13-true-d13150071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150092e13-true-d13150116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1663"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13150092e13-true-d13150116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13150092e13-true-d13150116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150137e13-true-d13150161e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1662"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13150137e13-true-d13150161e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13150137e13-true-d13150161e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150182e13-true-d13150216e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1661"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13150182e13-true-d13150216e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13150182e13-true-d13150216e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13146810e118-true-d13150260e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1660"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13146810e118-true-d13150260e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13146810e118-true-d13150260e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150248e2-true-d13150287e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1659"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13150248e2-true-d13150287e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13150248e2-true-d13150287e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e16-true-d13151811e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="1658"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e16-true-d13151811e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d13150308e16-true-d13151811e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e100-true-d13151930e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1657"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e100-true-d13151930e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13150308e100-true-d13151930e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13151907e9-true-d13151974e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1656"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13151907e9-true-d13151974e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13151907e9-true-d13151974e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13151907e29-true-d13152023e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1655"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13151907e29-true-d13152023e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13151907e29-true-d13152023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e104-true-d13152059e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1654"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e104-true-d13152059e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13150308e104-true-d13152059e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152047e2-true-d13152079e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1653"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152047e2-true-d13152079e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13152047e2-true-d13152079e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152047e8-true-d13152120e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1652"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152047e8-true-d13152120e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13152047e8-true-d13152120e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e108-true-d13152213e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1651"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e108-true-d13152213e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13150308e108-true-d13152213e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152149e9-true-d13152273e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1650"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152149e9-true-d13152273e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13152149e9-true-d13152273e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e113-true-d13152395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1649"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e113-true-d13152395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13150308e113-true-d13152395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152322e10-true-d13152487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1648"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152322e10-true-d13152487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13152322e10-true-d13152487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152322e30-true-d13152526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1647"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152322e30-true-d13152526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13152322e30-true-d13152526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152322e34-true-d13152565e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1646"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152322e34-true-d13152565e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13152322e34-true-d13152565e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152322e39-true-d13152626e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1645"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152322e39-true-d13152626e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13152322e39-true-d13152626e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152589e12-true-d13152694e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1644"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152589e12-true-d13152694e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13152589e12-true-d13152694e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152589e35-true-d13152753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1643"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152589e35-true-d13152753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13152589e35-true-d13152753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e117-true-d13152850e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1642"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e117-true-d13152850e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13150308e117-true-d13152850e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152784e7-true-d13152925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1641"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152784e7-true-d13152925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13152784e7-true-d13152925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152855e9-true-d13152964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1640"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152855e9-true-d13152964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13152855e9-true-d13152964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152855e10-true-d13153012e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1639"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152855e10-true-d13153012e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13152855e10-true-d13153012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152975e12-true-d13153080e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1638"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152975e12-true-d13153080e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13152975e12-true-d13153080e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152975e35-true-d13153139e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1637"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152975e35-true-d13153139e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13152975e35-true-d13153139e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13152784e11-true-d13153216e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1636"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13152784e11-true-d13153216e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13152784e11-true-d13153216e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153170e16-true-d13153257e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1635"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13153170e16-true-d13153257e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13153170e16-true-d13153257e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e121-true-d13153329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1634"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e121-true-d13153329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13150308e121-true-d13153329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153268e15-true-d13153405e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1633"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13153268e15-true-d13153405e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13153268e15-true-d13153405e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153268e35-true-d13153460e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1632"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13153268e35-true-d13153460e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13153268e35-true-d13153460e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153268e39-true-d13153517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1631"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13153268e39-true-d13153517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13153268e39-true-d13153517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153268e42-true-d13153571e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1630"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13153268e42-true-d13153571e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13153268e42-true-d13153571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e149-true-d13153640e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1629"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e149-true-d13153640e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13150308e149-true-d13153640e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153650e13-true-d13153674e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1628"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13153650e13-true-d13153674e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13153650e13-true-d13153674e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153695e13-true-d13153719e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1627"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13153695e13-true-d13153719e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13153695e13-true-d13153719e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153740e13-true-d13153764e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1626"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13153740e13-true-d13153764e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13153740e13-true-d13153764e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153785e13-true-d13153819e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1625"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13153785e13-true-d13153819e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13153785e13-true-d13153819e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e153-true-d13153863e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1624"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e153-true-d13153863e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13150308e153-true-d13153863e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153851e2-true-d13153890e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1623"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13153851e2-true-d13153890e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13153851e2-true-d13153890e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e158-true-d13153921e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="1622"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e158-true-d13153921e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d13150308e158-true-d13153921e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13150308e162-true-d13153959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="1621"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13150308e162-true-d13153959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d13150308e162-true-d13153959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e16-true-d13155404e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1620"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e16-true-d13155404e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13153988e16-true-d13155404e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e43-true-d13155457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1619"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e43-true-d13155457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13153988e43-true-d13155457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155434e9-true-d13155501e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1618"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155434e9-true-d13155501e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13155434e9-true-d13155501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155434e29-true-d13155550e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1617"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155434e29-true-d13155550e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13155434e29-true-d13155550e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e47-true-d13155586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1616"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e47-true-d13155586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13153988e47-true-d13155586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155574e2-true-d13155606e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1615"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155574e2-true-d13155606e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13155574e2-true-d13155606e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155574e8-true-d13155647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1614"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155574e8-true-d13155647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13155574e8-true-d13155647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e52-true-d13155740e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1613"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e52-true-d13155740e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13153988e52-true-d13155740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155676e9-true-d13155800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1612"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155676e9-true-d13155800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13155676e9-true-d13155800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e56-true-d13155922e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1611"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e56-true-d13155922e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13153988e56-true-d13155922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155849e10-true-d13156014e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1610"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155849e10-true-d13156014e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13155849e10-true-d13156014e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155849e30-true-d13156053e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1609"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155849e30-true-d13156053e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13155849e30-true-d13156053e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155849e34-true-d13156092e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1608"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155849e34-true-d13156092e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13155849e34-true-d13156092e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13155849e39-true-d13156153e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1607"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13155849e39-true-d13156153e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13155849e39-true-d13156153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156116e12-true-d13156221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1606"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156116e12-true-d13156221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13156116e12-true-d13156221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156116e35-true-d13156280e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1605"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156116e35-true-d13156280e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13156116e35-true-d13156280e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e60-true-d13156377e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1604"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e60-true-d13156377e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13153988e60-true-d13156377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156311e7-true-d13156452e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1603"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156311e7-true-d13156452e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13156311e7-true-d13156452e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156382e9-true-d13156491e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1602"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156382e9-true-d13156491e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13156382e9-true-d13156491e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156382e10-true-d13156539e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1601"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156382e10-true-d13156539e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13156382e10-true-d13156539e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156502e12-true-d13156607e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1600"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156502e12-true-d13156607e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13156502e12-true-d13156607e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156502e35-true-d13156666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1599"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156502e35-true-d13156666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13156502e35-true-d13156666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156311e11-true-d13156743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1598"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156311e11-true-d13156743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13156311e11-true-d13156743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156697e16-true-d13156784e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1597"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156697e16-true-d13156784e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13156697e16-true-d13156784e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e65-true-d13156856e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1596"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e65-true-d13156856e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13153988e65-true-d13156856e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156795e15-true-d13156932e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1595"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156795e15-true-d13156932e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13156795e15-true-d13156932e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156795e35-true-d13156987e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1594"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156795e35-true-d13156987e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13156795e35-true-d13156987e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156795e39-true-d13157044e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1593"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156795e39-true-d13157044e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13156795e39-true-d13157044e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13156795e42-true-d13157098e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1592"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13156795e42-true-d13157098e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13156795e42-true-d13157098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e92-true-d13157167e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1591"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e92-true-d13157167e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13153988e92-true-d13157167e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157177e13-true-d13157201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1590"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13157177e13-true-d13157201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13157177e13-true-d13157201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157222e13-true-d13157246e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1589"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13157222e13-true-d13157246e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13157222e13-true-d13157246e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157267e13-true-d13157291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1588"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13157267e13-true-d13157291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13157267e13-true-d13157291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157312e13-true-d13157346e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1587"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13157312e13-true-d13157346e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13157312e13-true-d13157346e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13153988e97-true-d13157390e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1586"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13153988e97-true-d13157390e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13153988e97-true-d13157390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157378e2-true-d13157417e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1585"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13157378e2-true-d13157417e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13157378e2-true-d13157417e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e16-true-d13158861e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="1584"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e16-true-d13158861e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d13157438e16-true-d13158861e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e53-true-d13158920e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1583"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e53-true-d13158920e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13157438e53-true-d13158920e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13158897e9-true-d13158964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1582"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13158897e9-true-d13158964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13158897e9-true-d13158964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13158897e29-true-d13159013e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1581"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13158897e29-true-d13159013e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13158897e29-true-d13159013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e58-true-d13159049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1580"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e58-true-d13159049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13157438e58-true-d13159049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159037e2-true-d13159069e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1579"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159037e2-true-d13159069e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13159037e2-true-d13159069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159037e8-true-d13159110e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1578"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159037e8-true-d13159110e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13159037e8-true-d13159110e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e62-true-d13159203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1577"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e62-true-d13159203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13157438e62-true-d13159203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159139e9-true-d13159263e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1576"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159139e9-true-d13159263e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13159139e9-true-d13159263e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e66-true-d13159385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1575"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e66-true-d13159385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13157438e66-true-d13159385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159312e10-true-d13159477e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1574"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159312e10-true-d13159477e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13159312e10-true-d13159477e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159312e30-true-d13159516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1573"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159312e30-true-d13159516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13159312e30-true-d13159516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159312e34-true-d13159555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1572"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159312e34-true-d13159555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13159312e34-true-d13159555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159312e39-true-d13159616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1571"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159312e39-true-d13159616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13159312e39-true-d13159616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159579e12-true-d13159684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1570"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159579e12-true-d13159684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13159579e12-true-d13159684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159579e35-true-d13159743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1569"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159579e35-true-d13159743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13159579e35-true-d13159743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e71-true-d13159840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1568"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e71-true-d13159840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13157438e71-true-d13159840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159774e7-true-d13159915e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1567"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159774e7-true-d13159915e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13159774e7-true-d13159915e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159845e9-true-d13159954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1566"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159845e9-true-d13159954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13159845e9-true-d13159954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159845e10-true-d13160002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1565"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159845e10-true-d13160002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13159845e10-true-d13160002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159965e12-true-d13160070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1564"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159965e12-true-d13160070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13159965e12-true-d13160070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159965e35-true-d13160129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1563"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159965e35-true-d13160129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13159965e35-true-d13160129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13159774e11-true-d13160206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1562"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13159774e11-true-d13160206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13159774e11-true-d13160206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160160e16-true-d13160247e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1561"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13160160e16-true-d13160247e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13160160e16-true-d13160247e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e75-true-d13160319e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1560"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e75-true-d13160319e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13157438e75-true-d13160319e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160258e15-true-d13160395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1559"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13160258e15-true-d13160395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13160258e15-true-d13160395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160258e35-true-d13160450e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1558"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13160258e35-true-d13160450e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13160258e35-true-d13160450e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160258e39-true-d13160507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1557"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13160258e39-true-d13160507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13160258e39-true-d13160507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160258e42-true-d13160561e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1556"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13160258e42-true-d13160561e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13160258e42-true-d13160561e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e81-true-d13160621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1555"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e81-true-d13160621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13157438e81-true-d13160621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160631e13-true-d13160655e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1554"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13160631e13-true-d13160655e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13160631e13-true-d13160655e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160676e13-true-d13160700e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1553"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13160676e13-true-d13160700e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13160676e13-true-d13160700e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160721e13-true-d13160745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1552"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13160721e13-true-d13160745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13160721e13-true-d13160745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160766e13-true-d13160800e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1551"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13160766e13-true-d13160800e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13160766e13-true-d13160800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13157438e86-true-d13160844e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1550"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13157438e86-true-d13160844e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13157438e86-true-d13160844e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160832e2-true-d13160871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1549"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13160832e2-true-d13160871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13160832e2-true-d13160871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e16-true-d13162372e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1548"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e16-true-d13162372e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13160901e16-true-d13162372e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e87-true-d13162470e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1547"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e87-true-d13162470e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13160901e87-true-d13162470e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162447e9-true-d13162514e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1546"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162447e9-true-d13162514e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13162447e9-true-d13162514e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162447e29-true-d13162563e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1545"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162447e29-true-d13162563e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13162447e29-true-d13162563e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e92-true-d13162599e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1544"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e92-true-d13162599e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13160901e92-true-d13162599e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162587e2-true-d13162619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1543"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162587e2-true-d13162619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13162587e2-true-d13162619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162587e8-true-d13162660e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1542"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162587e8-true-d13162660e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13162587e8-true-d13162660e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e96-true-d13162753e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1541"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e96-true-d13162753e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13160901e96-true-d13162753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162689e9-true-d13162813e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1540"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162689e9-true-d13162813e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13162689e9-true-d13162813e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e100-true-d13162935e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1539"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e100-true-d13162935e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13160901e100-true-d13162935e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162862e10-true-d13163027e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1538"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162862e10-true-d13163027e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13162862e10-true-d13163027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162862e30-true-d13163066e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1537"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162862e30-true-d13163066e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13162862e30-true-d13163066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162862e34-true-d13163105e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1536"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162862e34-true-d13163105e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13162862e34-true-d13163105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13162862e39-true-d13163166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1535"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13162862e39-true-d13163166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13162862e39-true-d13163166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163129e12-true-d13163234e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1534"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163129e12-true-d13163234e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13163129e12-true-d13163234e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163129e35-true-d13163293e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1533"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163129e35-true-d13163293e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13163129e35-true-d13163293e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e105-true-d13163390e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1532"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e105-true-d13163390e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13160901e105-true-d13163390e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163324e7-true-d13163465e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1531"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163324e7-true-d13163465e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13163324e7-true-d13163465e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163395e9-true-d13163504e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1530"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163395e9-true-d13163504e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13163395e9-true-d13163504e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163395e10-true-d13163552e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1529"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163395e10-true-d13163552e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13163395e10-true-d13163552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163515e12-true-d13163620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1528"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163515e12-true-d13163620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13163515e12-true-d13163620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163515e35-true-d13163679e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1527"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163515e35-true-d13163679e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13163515e35-true-d13163679e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163324e11-true-d13163756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1526"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163324e11-true-d13163756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13163324e11-true-d13163756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163710e16-true-d13163797e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1525"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163710e16-true-d13163797e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13163710e16-true-d13163797e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e109-true-d13163869e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1524"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e109-true-d13163869e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13160901e109-true-d13163869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163808e15-true-d13163945e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1523"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163808e15-true-d13163945e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13163808e15-true-d13163945e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163808e35-true-d13164000e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1522"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163808e35-true-d13164000e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13163808e35-true-d13164000e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163808e39-true-d13164057e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1521"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163808e39-true-d13164057e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13163808e39-true-d13164057e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13163808e42-true-d13164111e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1520"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13163808e42-true-d13164111e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13163808e42-true-d13164111e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e137-true-d13164180e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1519"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e137-true-d13164180e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13160901e137-true-d13164180e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164190e13-true-d13164214e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1518"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13164190e13-true-d13164214e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13164190e13-true-d13164214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164235e13-true-d13164259e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1517"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13164235e13-true-d13164259e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13164235e13-true-d13164259e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164280e13-true-d13164304e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1516"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13164280e13-true-d13164304e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13164280e13-true-d13164304e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164325e13-true-d13164359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1515"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13164325e13-true-d13164359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13164325e13-true-d13164359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13160901e141-true-d13164403e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1514"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13160901e141-true-d13164403e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13160901e141-true-d13164403e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164391e2-true-d13164430e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1513"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13164391e2-true-d13164430e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13164391e2-true-d13164430e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e16-true-d13165867e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1512"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e16-true-d13165867e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13164451e16-true-d13165867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e43-true-d13165920e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1511"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e43-true-d13165920e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13164451e43-true-d13165920e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13165897e9-true-d13165964e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1510"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13165897e9-true-d13165964e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13165897e9-true-d13165964e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13165897e29-true-d13166013e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1509"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13165897e29-true-d13166013e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13165897e29-true-d13166013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e47-true-d13166049e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1508"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e47-true-d13166049e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13164451e47-true-d13166049e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166037e2-true-d13166069e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1507"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166037e2-true-d13166069e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13166037e2-true-d13166069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166037e8-true-d13166110e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1506"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166037e8-true-d13166110e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13166037e8-true-d13166110e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e52-true-d13166203e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1505"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e52-true-d13166203e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13164451e52-true-d13166203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166139e9-true-d13166263e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1504"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166139e9-true-d13166263e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13166139e9-true-d13166263e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e56-true-d13166385e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1503"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e56-true-d13166385e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13164451e56-true-d13166385e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166312e10-true-d13166477e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1502"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166312e10-true-d13166477e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13166312e10-true-d13166477e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166312e30-true-d13166516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1501"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166312e30-true-d13166516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13166312e30-true-d13166516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166312e34-true-d13166555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1500"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166312e34-true-d13166555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13166312e34-true-d13166555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166312e39-true-d13166616e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1499"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166312e39-true-d13166616e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13166312e39-true-d13166616e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166579e12-true-d13166684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1498"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166579e12-true-d13166684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13166579e12-true-d13166684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166579e35-true-d13166743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1497"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166579e35-true-d13166743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13166579e35-true-d13166743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e60-true-d13166840e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1496"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e60-true-d13166840e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13164451e60-true-d13166840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166774e7-true-d13166915e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1495"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166774e7-true-d13166915e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13166774e7-true-d13166915e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166845e9-true-d13166954e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1494"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166845e9-true-d13166954e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13166845e9-true-d13166954e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166845e10-true-d13167002e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1493"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166845e10-true-d13167002e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13166845e10-true-d13167002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166965e12-true-d13167070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1492"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166965e12-true-d13167070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13166965e12-true-d13167070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166965e35-true-d13167129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1491"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166965e35-true-d13167129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13166965e35-true-d13167129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13166774e11-true-d13167206e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1490"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13166774e11-true-d13167206e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13166774e11-true-d13167206e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167160e16-true-d13167247e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1489"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13167160e16-true-d13167247e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13167160e16-true-d13167247e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e65-true-d13167319e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1488"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e65-true-d13167319e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13164451e65-true-d13167319e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167258e15-true-d13167395e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1487"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13167258e15-true-d13167395e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13167258e15-true-d13167395e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167258e35-true-d13167450e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1486"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13167258e35-true-d13167450e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13167258e35-true-d13167450e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167258e39-true-d13167507e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1485"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13167258e39-true-d13167507e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13167258e39-true-d13167507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167258e42-true-d13167561e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1484"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13167258e42-true-d13167561e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13167258e42-true-d13167561e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e92-true-d13167630e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1483"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e92-true-d13167630e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13164451e92-true-d13167630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167640e13-true-d13167664e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1482"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13167640e13-true-d13167664e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13167640e13-true-d13167664e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167685e13-true-d13167709e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1481"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13167685e13-true-d13167709e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13167685e13-true-d13167709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167730e13-true-d13167754e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1480"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13167730e13-true-d13167754e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13167730e13-true-d13167754e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167775e13-true-d13167809e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1479"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13167775e13-true-d13167809e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13167775e13-true-d13167809e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13164451e97-true-d13167853e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1478"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13164451e97-true-d13167853e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13164451e97-true-d13167853e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167841e2-true-d13167880e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1477"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13167841e2-true-d13167880e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13167841e2-true-d13167880e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e16-true-d13169440e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1476"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e16-true-d13169440e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13167901e16-true-d13169440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e95-true-d13169556e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1475"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e95-true-d13169556e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13167901e95-true-d13169556e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169533e9-true-d13169600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1474"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169533e9-true-d13169600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13169533e9-true-d13169600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169533e29-true-d13169649e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1473"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169533e29-true-d13169649e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13169533e29-true-d13169649e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e99-true-d13169685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1472"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e99-true-d13169685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13167901e99-true-d13169685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169673e2-true-d13169705e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1471"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169673e2-true-d13169705e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13169673e2-true-d13169705e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169673e8-true-d13169746e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1470"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169673e8-true-d13169746e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13169673e8-true-d13169746e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e103-true-d13169823e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1469"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e103-true-d13169823e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13167901e103-true-d13169823e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169775e5-true-d13169879e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1468"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169775e5-true-d13169879e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13169775e5-true-d13169879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169889e13-true-d13169906e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1467"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13169889e13-true-d13169906e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13169889e13-true-d13169906e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169921e13-true-d13169949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1466"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13169921e13-true-d13169949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13169921e13-true-d13169949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169775e24-true-d13170010e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1465"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169775e24-true-d13170010e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13169775e24-true-d13170010e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169973e12-true-d13170078e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1464"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169973e12-true-d13170078e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13169973e12-true-d13170078e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13169973e35-true-d13170137e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1463"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13169973e35-true-d13170137e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13169973e35-true-d13170137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e111-true-d13170232e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1462"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e111-true-d13170232e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13167901e111-true-d13170232e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170168e9-true-d13170292e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1461"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170168e9-true-d13170292e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13170168e9-true-d13170292e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e115-true-d13170414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1460"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e115-true-d13170414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13167901e115-true-d13170414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170341e10-true-d13170506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1459"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170341e10-true-d13170506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13170341e10-true-d13170506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170341e30-true-d13170545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1458"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170341e30-true-d13170545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13170341e30-true-d13170545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170341e34-true-d13170584e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1457"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170341e34-true-d13170584e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13170341e34-true-d13170584e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170341e39-true-d13170645e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1456"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170341e39-true-d13170645e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13170341e39-true-d13170645e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170608e12-true-d13170713e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1455"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170608e12-true-d13170713e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13170608e12-true-d13170713e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170608e35-true-d13170772e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1454"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170608e35-true-d13170772e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13170608e35-true-d13170772e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e119-true-d13170869e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1453"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e119-true-d13170869e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13167901e119-true-d13170869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170803e7-true-d13170944e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1452"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170803e7-true-d13170944e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13170803e7-true-d13170944e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170874e9-true-d13170983e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1451"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170874e9-true-d13170983e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13170874e9-true-d13170983e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170874e10-true-d13171031e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1450"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170874e10-true-d13171031e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13170874e10-true-d13171031e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170994e12-true-d13171099e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1449"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170994e12-true-d13171099e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13170994e12-true-d13171099e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170994e35-true-d13171158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1448"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170994e35-true-d13171158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13170994e35-true-d13171158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13170803e11-true-d13171235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1447"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13170803e11-true-d13171235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13170803e11-true-d13171235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171189e16-true-d13171276e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1446"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13171189e16-true-d13171276e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13171189e16-true-d13171276e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e124-true-d13171348e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1445"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e124-true-d13171348e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13167901e124-true-d13171348e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171287e15-true-d13171424e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1444"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13171287e15-true-d13171424e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13171287e15-true-d13171424e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171287e35-true-d13171479e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1443"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13171287e35-true-d13171479e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13171287e35-true-d13171479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171287e39-true-d13171536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1442"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13171287e39-true-d13171536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13171287e39-true-d13171536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171287e42-true-d13171590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1441"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13171287e42-true-d13171590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13171287e42-true-d13171590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e151-true-d13171659e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1440"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e151-true-d13171659e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13167901e151-true-d13171659e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171669e13-true-d13171693e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1439"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13171669e13-true-d13171693e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13171669e13-true-d13171693e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171714e13-true-d13171738e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1438"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13171714e13-true-d13171738e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13171714e13-true-d13171738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171759e13-true-d13171783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1437"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13171759e13-true-d13171783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13171759e13-true-d13171783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171804e13-true-d13171838e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1436"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13171804e13-true-d13171838e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13171804e13-true-d13171838e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13167901e156-true-d13171882e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1435"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13167901e156-true-d13171882e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13167901e156-true-d13171882e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171870e2-true-d13171909e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1434"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13171870e2-true-d13171909e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13171870e2-true-d13171909e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e16-true-d13173436e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1433"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e16-true-d13173436e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13171930e16-true-d13173436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e71-true-d13173528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1432"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e71-true-d13173528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13171930e71-true-d13173528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173505e9-true-d13173572e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1431"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173505e9-true-d13173572e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13173505e9-true-d13173572e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173505e29-true-d13173621e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1430"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173505e29-true-d13173621e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13173505e29-true-d13173621e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e76-true-d13173657e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1429"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e76-true-d13173657e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13171930e76-true-d13173657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173645e2-true-d13173677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1428"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173645e2-true-d13173677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13173645e2-true-d13173677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173645e8-true-d13173718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1427"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173645e8-true-d13173718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13173645e8-true-d13173718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e80-true-d13173795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1426"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e80-true-d13173795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13171930e80-true-d13173795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173747e5-true-d13173851e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1425"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173747e5-true-d13173851e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13173747e5-true-d13173851e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173861e13-true-d13173878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1424"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13173861e13-true-d13173878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13173861e13-true-d13173878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173893e13-true-d13173921e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1423"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13173893e13-true-d13173921e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13173893e13-true-d13173921e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173747e24-true-d13173982e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1422"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173747e24-true-d13173982e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13173747e24-true-d13173982e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173945e12-true-d13174050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1421"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173945e12-true-d13174050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13173945e12-true-d13174050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13173945e35-true-d13174109e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1420"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13173945e35-true-d13174109e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13173945e35-true-d13174109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e87-true-d13174204e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1419"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e87-true-d13174204e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13171930e87-true-d13174204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174140e9-true-d13174264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1418"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174140e9-true-d13174264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13174140e9-true-d13174264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e92-true-d13174386e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1417"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e92-true-d13174386e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13171930e92-true-d13174386e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174313e10-true-d13174478e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1416"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174313e10-true-d13174478e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13174313e10-true-d13174478e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174313e30-true-d13174517e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1415"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174313e30-true-d13174517e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13174313e30-true-d13174517e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174313e34-true-d13174556e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1414"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174313e34-true-d13174556e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13174313e34-true-d13174556e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174313e39-true-d13174617e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1413"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174313e39-true-d13174617e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13174313e39-true-d13174617e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174580e12-true-d13174685e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1412"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174580e12-true-d13174685e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13174580e12-true-d13174685e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174580e35-true-d13174744e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1411"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174580e35-true-d13174744e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13174580e35-true-d13174744e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e96-true-d13174841e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1410"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e96-true-d13174841e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13171930e96-true-d13174841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174775e7-true-d13174916e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1409"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174775e7-true-d13174916e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13174775e7-true-d13174916e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174846e9-true-d13174955e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1408"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174846e9-true-d13174955e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13174846e9-true-d13174955e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174846e10-true-d13175003e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1407"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174846e10-true-d13175003e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13174846e10-true-d13175003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174966e12-true-d13175071e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1406"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174966e12-true-d13175071e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13174966e12-true-d13175071e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174966e35-true-d13175130e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1405"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174966e35-true-d13175130e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13174966e35-true-d13175130e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13174775e11-true-d13175207e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1404"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13174775e11-true-d13175207e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13174775e11-true-d13175207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175161e16-true-d13175248e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1403"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13175161e16-true-d13175248e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13175161e16-true-d13175248e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e100-true-d13175320e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1402"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e100-true-d13175320e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13171930e100-true-d13175320e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175259e15-true-d13175396e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1401"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13175259e15-true-d13175396e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13175259e15-true-d13175396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175259e35-true-d13175451e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1400"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13175259e35-true-d13175451e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13175259e35-true-d13175451e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175259e39-true-d13175508e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1399"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13175259e39-true-d13175508e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13175259e39-true-d13175508e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175259e42-true-d13175562e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1398"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13175259e42-true-d13175562e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13175259e42-true-d13175562e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e128-true-d13175631e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1397"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e128-true-d13175631e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13171930e128-true-d13175631e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175641e13-true-d13175665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1396"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13175641e13-true-d13175665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13175641e13-true-d13175665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175686e13-true-d13175710e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1395"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13175686e13-true-d13175710e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13175686e13-true-d13175710e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175731e13-true-d13175755e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1394"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13175731e13-true-d13175755e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13175731e13-true-d13175755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175776e13-true-d13175810e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1393"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13175776e13-true-d13175810e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13175776e13-true-d13175810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13171930e132-true-d13175854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1392"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13171930e132-true-d13175854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13171930e132-true-d13175854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175842e2-true-d13175881e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1391"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13175842e2-true-d13175881e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13175842e2-true-d13175881e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e151-true-d13175939e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1390"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e151-true-d13175939e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13134488e151-true-d13175939e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175949e13-true-d13175973e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1389"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13175949e13-true-d13175973e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13175949e13-true-d13175973e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13175994e13-true-d13176018e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1388"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13175994e13-true-d13176018e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13175994e13-true-d13176018e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176039e13-true-d13176063e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1387"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13176039e13-true-d13176063e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13176039e13-true-d13176063e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176084e13-true-d13176118e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1386"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13176084e13-true-d13176118e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13176084e13-true-d13176118e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13134488e156-true-d13176162e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1385"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13134488e156-true-d13176162e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13134488e156-true-d13176162e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176150e2-true-d13176189e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1384"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13176150e2-true-d13176189e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13176150e2-true-d13176189e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e16-true-d13177716e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1383"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e16-true-d13177716e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13176210e16-true-d13177716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e71-true-d13177808e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1382"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e71-true-d13177808e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13176210e71-true-d13177808e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13177785e9-true-d13177852e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1381"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13177785e9-true-d13177852e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13177785e9-true-d13177852e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13177785e29-true-d13177901e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1380"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13177785e29-true-d13177901e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13177785e29-true-d13177901e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e76-true-d13177937e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1379"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e76-true-d13177937e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13176210e76-true-d13177937e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13177925e2-true-d13177957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1378"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13177925e2-true-d13177957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13177925e2-true-d13177957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13177925e8-true-d13177998e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1377"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13177925e8-true-d13177998e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13177925e8-true-d13177998e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e80-true-d13178075e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1376"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e80-true-d13178075e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13176210e80-true-d13178075e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178027e5-true-d13178131e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1375"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178027e5-true-d13178131e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13178027e5-true-d13178131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178141e13-true-d13178158e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1374"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13178141e13-true-d13178158e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13178141e13-true-d13178158e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178173e13-true-d13178201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1373"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13178173e13-true-d13178201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13178173e13-true-d13178201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178027e24-true-d13178262e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1372"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178027e24-true-d13178262e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13178027e24-true-d13178262e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178225e12-true-d13178330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1371"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178225e12-true-d13178330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13178225e12-true-d13178330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178225e35-true-d13178389e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1370"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178225e35-true-d13178389e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13178225e35-true-d13178389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e87-true-d13178484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1369"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e87-true-d13178484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13176210e87-true-d13178484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178420e9-true-d13178544e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1368"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178420e9-true-d13178544e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13178420e9-true-d13178544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e92-true-d13178666e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1367"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e92-true-d13178666e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13176210e92-true-d13178666e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178593e10-true-d13178758e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1366"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178593e10-true-d13178758e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13178593e10-true-d13178758e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178593e30-true-d13178797e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1365"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178593e30-true-d13178797e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13178593e30-true-d13178797e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178593e34-true-d13178836e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1364"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178593e34-true-d13178836e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13178593e34-true-d13178836e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178593e39-true-d13178897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1363"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178593e39-true-d13178897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13178593e39-true-d13178897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178860e12-true-d13178965e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1362"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178860e12-true-d13178965e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13178860e12-true-d13178965e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13178860e35-true-d13179024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1361"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13178860e35-true-d13179024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13178860e35-true-d13179024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e96-true-d13179121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1360"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e96-true-d13179121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13176210e96-true-d13179121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179055e7-true-d13179196e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1359"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179055e7-true-d13179196e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13179055e7-true-d13179196e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179126e9-true-d13179235e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1358"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179126e9-true-d13179235e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13179126e9-true-d13179235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179126e10-true-d13179283e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1357"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179126e10-true-d13179283e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13179126e10-true-d13179283e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179246e12-true-d13179351e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1356"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179246e12-true-d13179351e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13179246e12-true-d13179351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179246e35-true-d13179410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1355"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179246e35-true-d13179410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13179246e35-true-d13179410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179055e11-true-d13179487e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1354"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179055e11-true-d13179487e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13179055e11-true-d13179487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179441e16-true-d13179528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1353"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179441e16-true-d13179528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13179441e16-true-d13179528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e100-true-d13179600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1352"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e100-true-d13179600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13176210e100-true-d13179600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179539e15-true-d13179676e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1351"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179539e15-true-d13179676e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13179539e15-true-d13179676e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179539e35-true-d13179731e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1350"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179539e35-true-d13179731e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13179539e35-true-d13179731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179539e39-true-d13179788e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1349"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179539e39-true-d13179788e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13179539e39-true-d13179788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13179539e42-true-d13179842e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1348"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13179539e42-true-d13179842e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13179539e42-true-d13179842e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e105-true-d13184949e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/*[not(self::hl7:sequenceNumber | self::hl7:seperatableInd | self::hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | self::hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | self::hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | self::hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | self::hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | self::hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | self::hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | self::hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | self::hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])]"
                 priority="1347"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e105-true-d13184949e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:sequenceNumber | hl7:seperatableInd | hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']] (rule-reference: d13176210e105-true-d13184949e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e16-true-d13186414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1346"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e16-true-d13186414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13184964e16-true-d13186414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e77-true-d13186494e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1345"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e77-true-d13186494e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13184964e77-true-d13186494e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186471e9-true-d13186538e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1344"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186471e9-true-d13186538e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13186471e9-true-d13186538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186471e29-true-d13186587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1343"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186471e29-true-d13186587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13186471e29-true-d13186587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e81-true-d13186623e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1342"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e81-true-d13186623e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13184964e81-true-d13186623e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186611e2-true-d13186643e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1341"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186611e2-true-d13186643e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13186611e2-true-d13186643e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186611e8-true-d13186684e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1340"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186611e8-true-d13186684e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13186611e8-true-d13186684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e85-true-d13186777e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1339"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e85-true-d13186777e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13184964e85-true-d13186777e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186713e9-true-d13186837e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1338"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186713e9-true-d13186837e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13186713e9-true-d13186837e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e90-true-d13186959e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1337"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e90-true-d13186959e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13184964e90-true-d13186959e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186886e10-true-d13187051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1336"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186886e10-true-d13187051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13186886e10-true-d13187051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186886e30-true-d13187090e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1335"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186886e30-true-d13187090e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13186886e30-true-d13187090e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186886e34-true-d13187129e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1334"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186886e34-true-d13187129e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13186886e34-true-d13187129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13186886e39-true-d13187190e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1333"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13186886e39-true-d13187190e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13186886e39-true-d13187190e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187153e12-true-d13187258e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1332"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187153e12-true-d13187258e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13187153e12-true-d13187258e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187153e35-true-d13187317e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1331"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187153e35-true-d13187317e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13187153e35-true-d13187317e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e94-true-d13187414e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1330"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e94-true-d13187414e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13184964e94-true-d13187414e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187348e7-true-d13187489e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1329"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187348e7-true-d13187489e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13187348e7-true-d13187489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187419e9-true-d13187528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1328"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187419e9-true-d13187528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13187419e9-true-d13187528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187419e10-true-d13187576e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1327"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187419e10-true-d13187576e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13187419e10-true-d13187576e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187539e12-true-d13187644e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1326"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187539e12-true-d13187644e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13187539e12-true-d13187644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187539e35-true-d13187703e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1325"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187539e35-true-d13187703e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13187539e35-true-d13187703e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187348e11-true-d13187780e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1324"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187348e11-true-d13187780e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13187348e11-true-d13187780e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187734e16-true-d13187821e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1323"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187734e16-true-d13187821e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13187734e16-true-d13187821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e98-true-d13187893e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1322"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e98-true-d13187893e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13184964e98-true-d13187893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187832e15-true-d13187969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1321"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187832e15-true-d13187969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13187832e15-true-d13187969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187832e35-true-d13188024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1320"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187832e35-true-d13188024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13187832e35-true-d13188024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187832e39-true-d13188081e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1319"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187832e39-true-d13188081e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13187832e39-true-d13188081e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13187832e42-true-d13188135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1318"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13187832e42-true-d13188135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13187832e42-true-d13188135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e126-true-d13188204e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1317"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e126-true-d13188204e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13184964e126-true-d13188204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188214e13-true-d13188238e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1316"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13188214e13-true-d13188238e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13188214e13-true-d13188238e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188259e13-true-d13188283e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1315"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13188259e13-true-d13188283e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13188259e13-true-d13188283e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188304e13-true-d13188328e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1314"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13188304e13-true-d13188328e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13188304e13-true-d13188328e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188349e13-true-d13188383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1313"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13188349e13-true-d13188383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13188349e13-true-d13188383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13184964e130-true-d13188427e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1312"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13184964e130-true-d13188427e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13184964e130-true-d13188427e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188415e2-true-d13188454e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1311"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct)/d13188415e2-true-d13188454e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13188415e2-true-d13188454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e16-true-d13189918e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1310"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e16-true-d13189918e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13188475e16-true-d13189918e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e65-true-d13189992e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1309"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e65-true-d13189992e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13188475e65-true-d13189992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13189969e9-true-d13190036e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1308"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13189969e9-true-d13190036e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13189969e9-true-d13190036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13189969e29-true-d13190085e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1307"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13189969e29-true-d13190085e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13189969e29-true-d13190085e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e69-true-d13190121e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1306"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e69-true-d13190121e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13188475e69-true-d13190121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190109e2-true-d13190141e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1305"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190109e2-true-d13190141e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13190109e2-true-d13190141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190109e8-true-d13190182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1304"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190109e8-true-d13190182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13190109e8-true-d13190182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e73-true-d13190275e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1303"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e73-true-d13190275e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13188475e73-true-d13190275e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190211e9-true-d13190335e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1302"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190211e9-true-d13190335e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13190211e9-true-d13190335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e78-true-d13190457e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1301"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e78-true-d13190457e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13188475e78-true-d13190457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190384e10-true-d13190549e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1300"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190384e10-true-d13190549e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13190384e10-true-d13190549e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190384e30-true-d13190588e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1299"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190384e30-true-d13190588e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13190384e30-true-d13190588e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190384e34-true-d13190627e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1298"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190384e34-true-d13190627e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13190384e34-true-d13190627e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190384e39-true-d13190688e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1297"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190384e39-true-d13190688e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13190384e39-true-d13190688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190651e12-true-d13190756e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1296"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190651e12-true-d13190756e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13190651e12-true-d13190756e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190651e35-true-d13190815e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1295"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190651e35-true-d13190815e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13190651e35-true-d13190815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e82-true-d13190912e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1294"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e82-true-d13190912e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13188475e82-true-d13190912e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190846e7-true-d13190987e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1293"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190846e7-true-d13190987e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13190846e7-true-d13190987e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190917e9-true-d13191026e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1292"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190917e9-true-d13191026e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13190917e9-true-d13191026e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190917e10-true-d13191074e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1291"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190917e10-true-d13191074e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13190917e10-true-d13191074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191037e12-true-d13191142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1290"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191037e12-true-d13191142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13191037e12-true-d13191142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191037e35-true-d13191201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1289"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191037e35-true-d13191201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13191037e35-true-d13191201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13190846e11-true-d13191278e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1288"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13190846e11-true-d13191278e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13190846e11-true-d13191278e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191232e16-true-d13191319e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1287"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191232e16-true-d13191319e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13191232e16-true-d13191319e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e86-true-d13191391e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1286"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e86-true-d13191391e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13188475e86-true-d13191391e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191330e15-true-d13191467e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1285"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191330e15-true-d13191467e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13191330e15-true-d13191467e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191330e35-true-d13191522e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1284"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191330e35-true-d13191522e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13191330e35-true-d13191522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191330e39-true-d13191579e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1283"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191330e39-true-d13191579e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13191330e39-true-d13191579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191330e42-true-d13191633e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1282"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191330e42-true-d13191633e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13191330e42-true-d13191633e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e114-true-d13191702e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1281"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e114-true-d13191702e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13188475e114-true-d13191702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191712e13-true-d13191736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1280"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13191712e13-true-d13191736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13191712e13-true-d13191736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191757e13-true-d13191781e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1279"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13191757e13-true-d13191781e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13191757e13-true-d13191781e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191802e13-true-d13191826e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1278"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13191802e13-true-d13191826e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13191802e13-true-d13191826e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191847e13-true-d13191881e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1277"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13191847e13-true-d13191881e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13191847e13-true-d13191881e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13188475e118-true-d13191925e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1276"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13188475e118-true-d13191925e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13188475e118-true-d13191925e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191913e2-true-d13191952e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1275"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter)/d13191913e2-true-d13191952e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13191913e2-true-d13191952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e16-true-d13193476e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:derivationExpr | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:languageCode | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange])]"
                 priority="1274"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e16-true-d13193476e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] | hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:derivationExpr | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:languageCode | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange] (rule-reference: d13191973e16-true-d13193476e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e100-true-d13193595e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1273"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e100-true-d13193595e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13191973e100-true-d13193595e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193572e9-true-d13193639e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1272"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193572e9-true-d13193639e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13193572e9-true-d13193639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193572e29-true-d13193688e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1271"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193572e29-true-d13193688e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13193572e29-true-d13193688e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e104-true-d13193724e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1270"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e104-true-d13193724e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13191973e104-true-d13193724e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193712e2-true-d13193744e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1269"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193712e2-true-d13193744e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13193712e2-true-d13193744e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193712e8-true-d13193785e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1268"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193712e8-true-d13193785e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13193712e8-true-d13193785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e108-true-d13193878e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1267"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e108-true-d13193878e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13191973e108-true-d13193878e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193814e9-true-d13193938e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1266"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193814e9-true-d13193938e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13193814e9-true-d13193938e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e113-true-d13194060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1265"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e113-true-d13194060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13191973e113-true-d13194060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193987e10-true-d13194152e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1264"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193987e10-true-d13194152e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13193987e10-true-d13194152e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193987e30-true-d13194191e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1263"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193987e30-true-d13194191e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13193987e30-true-d13194191e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193987e34-true-d13194230e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1262"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193987e34-true-d13194230e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13193987e34-true-d13194230e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13193987e39-true-d13194291e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1261"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13193987e39-true-d13194291e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13193987e39-true-d13194291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194254e12-true-d13194359e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1260"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194254e12-true-d13194359e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13194254e12-true-d13194359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194254e35-true-d13194418e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1259"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194254e35-true-d13194418e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13194254e35-true-d13194418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e117-true-d13194515e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1258"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e117-true-d13194515e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13191973e117-true-d13194515e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194449e7-true-d13194590e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1257"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194449e7-true-d13194590e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13194449e7-true-d13194590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194520e9-true-d13194629e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1256"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194520e9-true-d13194629e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13194520e9-true-d13194629e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194520e10-true-d13194677e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1255"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194520e10-true-d13194677e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13194520e10-true-d13194677e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194640e12-true-d13194745e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1254"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194640e12-true-d13194745e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13194640e12-true-d13194745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194640e35-true-d13194804e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1253"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194640e35-true-d13194804e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13194640e35-true-d13194804e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194449e11-true-d13194881e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1252"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194449e11-true-d13194881e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13194449e11-true-d13194881e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194835e16-true-d13194922e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1251"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194835e16-true-d13194922e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13194835e16-true-d13194922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e121-true-d13194994e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1250"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e121-true-d13194994e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13191973e121-true-d13194994e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194933e15-true-d13195070e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1249"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194933e15-true-d13195070e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13194933e15-true-d13195070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194933e35-true-d13195125e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1248"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194933e35-true-d13195125e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13194933e35-true-d13195125e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194933e39-true-d13195182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1247"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194933e39-true-d13195182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13194933e39-true-d13195182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13194933e42-true-d13195236e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1246"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13194933e42-true-d13195236e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13194933e42-true-d13195236e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e149-true-d13195305e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1245"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e149-true-d13195305e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13191973e149-true-d13195305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195315e13-true-d13195339e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1244"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13195315e13-true-d13195339e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13195315e13-true-d13195339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195360e13-true-d13195384e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1243"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13195360e13-true-d13195384e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13195360e13-true-d13195384e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195405e13-true-d13195429e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1242"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13195405e13-true-d13195429e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13195405e13-true-d13195429e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195450e13-true-d13195484e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1241"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13195450e13-true-d13195484e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13195450e13-true-d13195484e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e153-true-d13195528e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1240"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e153-true-d13195528e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13191973e153-true-d13195528e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195516e2-true-d13195555e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1239"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13195516e2-true-d13195555e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13195516e2-true-d13195555e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e158-true-d13195586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/*[not(self::hl7:observationRange)]"
                 priority="1238"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e158-true-d13195586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:observationRange (rule-reference: d13191973e158-true-d13195586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13191973e162-true-d13195624e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value | self::hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor])]"
                 priority="1237"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation)/d13191973e162-true-d13195624e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value | hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] (rule-reference: d13191973e162-true-d13195624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e16-true-d13197069e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | self::hl7:id | self::hl7:languageCode | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1236"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e16-true-d13197069e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] | hl7:id | hl7:languageCode | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13195653e16-true-d13197069e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e43-true-d13197122e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1235"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e43-true-d13197122e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13195653e43-true-d13197122e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197099e9-true-d13197166e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1234"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197099e9-true-d13197166e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13197099e9-true-d13197166e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197099e29-true-d13197215e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1233"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197099e29-true-d13197215e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13197099e29-true-d13197215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e47-true-d13197251e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1232"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e47-true-d13197251e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13195653e47-true-d13197251e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197239e2-true-d13197271e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1231"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197239e2-true-d13197271e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13197239e2-true-d13197271e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197239e8-true-d13197312e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1230"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197239e8-true-d13197312e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13197239e8-true-d13197312e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e52-true-d13197405e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1229"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e52-true-d13197405e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13195653e52-true-d13197405e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197341e9-true-d13197465e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1228"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197341e9-true-d13197465e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13197341e9-true-d13197465e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e56-true-d13197587e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1227"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e56-true-d13197587e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13195653e56-true-d13197587e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197514e10-true-d13197679e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1226"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197514e10-true-d13197679e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13197514e10-true-d13197679e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197514e30-true-d13197718e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1225"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197514e30-true-d13197718e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13197514e30-true-d13197718e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197514e34-true-d13197757e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1224"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197514e34-true-d13197757e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13197514e34-true-d13197757e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197514e39-true-d13197818e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1223"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197514e39-true-d13197818e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13197514e39-true-d13197818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197781e12-true-d13197886e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1222"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197781e12-true-d13197886e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13197781e12-true-d13197886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197781e35-true-d13197945e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1221"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197781e35-true-d13197945e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13197781e35-true-d13197945e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e60-true-d13198042e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1220"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e60-true-d13198042e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13195653e60-true-d13198042e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197976e7-true-d13198117e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1219"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197976e7-true-d13198117e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13197976e7-true-d13198117e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198047e9-true-d13198156e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1218"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198047e9-true-d13198156e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13198047e9-true-d13198156e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198047e10-true-d13198204e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1217"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198047e10-true-d13198204e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13198047e10-true-d13198204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198167e12-true-d13198272e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1216"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198167e12-true-d13198272e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13198167e12-true-d13198272e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198167e35-true-d13198331e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1215"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198167e35-true-d13198331e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13198167e35-true-d13198331e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13197976e11-true-d13198408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1214"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13197976e11-true-d13198408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13197976e11-true-d13198408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198362e16-true-d13198449e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1213"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198362e16-true-d13198449e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13198362e16-true-d13198449e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e65-true-d13198521e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1212"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e65-true-d13198521e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13195653e65-true-d13198521e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198460e15-true-d13198597e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1211"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198460e15-true-d13198597e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13198460e15-true-d13198597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198460e35-true-d13198652e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1210"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198460e35-true-d13198652e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13198460e35-true-d13198652e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198460e39-true-d13198709e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1209"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198460e39-true-d13198709e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13198460e39-true-d13198709e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198460e42-true-d13198763e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1208"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13198460e42-true-d13198763e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13198460e42-true-d13198763e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e92-true-d13198832e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1207"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e92-true-d13198832e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13195653e92-true-d13198832e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198842e13-true-d13198866e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1206"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13198842e13-true-d13198866e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13198842e13-true-d13198866e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198887e13-true-d13198911e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1205"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13198887e13-true-d13198911e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13198887e13-true-d13198911e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198932e13-true-d13198956e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1204"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13198932e13-true-d13198956e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13198932e13-true-d13198956e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13198977e13-true-d13199011e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1203"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13198977e13-true-d13199011e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13198977e13-true-d13199011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13195653e97-true-d13199055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1202"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13195653e97-true-d13199055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13195653e97-true-d13199055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199043e2-true-d13199082e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1201"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia)/d13199043e2-true-d13199082e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13199043e2-true-d13199082e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e16-true-d13200526e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion] | self::hl7:component)]"
                 priority="1200"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e16-true-d13200526e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] | hl7:component (rule-reference: d13199103e16-true-d13200526e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e53-true-d13200585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1199"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e53-true-d13200585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13199103e53-true-d13200585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200562e9-true-d13200629e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1198"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200562e9-true-d13200629e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13200562e9-true-d13200629e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200562e29-true-d13200678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1197"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200562e29-true-d13200678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13200562e29-true-d13200678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e58-true-d13200714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1196"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e58-true-d13200714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13199103e58-true-d13200714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200702e2-true-d13200734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1195"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200702e2-true-d13200734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13200702e2-true-d13200734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200702e8-true-d13200775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1194"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200702e8-true-d13200775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13200702e8-true-d13200775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e62-true-d13200868e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1193"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e62-true-d13200868e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13199103e62-true-d13200868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200804e9-true-d13200928e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1192"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200804e9-true-d13200928e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13200804e9-true-d13200928e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e66-true-d13201050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1191"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e66-true-d13201050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13199103e66-true-d13201050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200977e10-true-d13201142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1190"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200977e10-true-d13201142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13200977e10-true-d13201142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200977e30-true-d13201181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1189"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200977e30-true-d13201181e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13200977e30-true-d13201181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200977e34-true-d13201220e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1188"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200977e34-true-d13201220e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13200977e34-true-d13201220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13200977e39-true-d13201281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1187"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13200977e39-true-d13201281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13200977e39-true-d13201281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201244e12-true-d13201349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1186"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201244e12-true-d13201349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13201244e12-true-d13201349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201244e35-true-d13201408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1185"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201244e35-true-d13201408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13201244e35-true-d13201408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e71-true-d13201505e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1184"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e71-true-d13201505e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13199103e71-true-d13201505e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201439e7-true-d13201580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1183"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201439e7-true-d13201580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13201439e7-true-d13201580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201510e9-true-d13201619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1182"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201510e9-true-d13201619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13201510e9-true-d13201619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201510e10-true-d13201667e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1181"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201510e10-true-d13201667e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13201510e10-true-d13201667e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201630e12-true-d13201735e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1180"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201630e12-true-d13201735e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13201630e12-true-d13201735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201630e35-true-d13201794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1179"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201630e35-true-d13201794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13201630e35-true-d13201794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201439e11-true-d13201871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1178"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201439e11-true-d13201871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13201439e11-true-d13201871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201825e16-true-d13201912e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1177"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201825e16-true-d13201912e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13201825e16-true-d13201912e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e75-true-d13201984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1176"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e75-true-d13201984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13199103e75-true-d13201984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201923e15-true-d13202060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1175"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201923e15-true-d13202060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13201923e15-true-d13202060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201923e35-true-d13202115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1174"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201923e35-true-d13202115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13201923e35-true-d13202115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201923e39-true-d13202172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1173"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201923e39-true-d13202172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13201923e39-true-d13202172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13201923e42-true-d13202226e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1172"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13201923e42-true-d13202226e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13201923e42-true-d13202226e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e81-true-d13202286e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1171"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e81-true-d13202286e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13199103e81-true-d13202286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202296e13-true-d13202320e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1170"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13202296e13-true-d13202320e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13202296e13-true-d13202320e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202341e13-true-d13202365e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1169"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13202341e13-true-d13202365e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13202341e13-true-d13202365e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202386e13-true-d13202410e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1168"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13202386e13-true-d13202410e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13202386e13-true-d13202410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202431e13-true-d13202465e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1167"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13202431e13-true-d13202465e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13202431e13-true-d13202465e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13199103e86-true-d13202509e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1166"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13199103e86-true-d13202509e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13199103e86-true-d13202509e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202497e2-true-d13202536e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1165"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer)/d13202497e2-true-d13202536e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13202497e2-true-d13202536e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e16-true-d13204037e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:languageCode | self::hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1164"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e16-true-d13204037e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:languageCode | hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13202566e16-true-d13204037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e87-true-d13204135e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1163"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e87-true-d13204135e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13202566e87-true-d13204135e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204112e9-true-d13204179e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1162"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204112e9-true-d13204179e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13204112e9-true-d13204179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204112e29-true-d13204228e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1161"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204112e29-true-d13204228e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13204112e29-true-d13204228e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e92-true-d13204264e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1160"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e92-true-d13204264e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13202566e92-true-d13204264e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204252e2-true-d13204284e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1159"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204252e2-true-d13204284e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13204252e2-true-d13204284e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204252e8-true-d13204325e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1158"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204252e8-true-d13204325e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13204252e8-true-d13204325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e96-true-d13204418e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1157"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e96-true-d13204418e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13202566e96-true-d13204418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204354e9-true-d13204478e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1156"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204354e9-true-d13204478e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13204354e9-true-d13204478e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e100-true-d13204600e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1155"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e100-true-d13204600e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13202566e100-true-d13204600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204527e10-true-d13204692e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1154"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204527e10-true-d13204692e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13204527e10-true-d13204692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204527e30-true-d13204731e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1153"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204527e30-true-d13204731e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13204527e30-true-d13204731e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204527e34-true-d13204770e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1152"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204527e34-true-d13204770e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13204527e34-true-d13204770e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204527e39-true-d13204831e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1151"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204527e39-true-d13204831e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13204527e39-true-d13204831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204794e12-true-d13204899e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1150"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204794e12-true-d13204899e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13204794e12-true-d13204899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204794e35-true-d13204958e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1149"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204794e35-true-d13204958e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13204794e35-true-d13204958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e105-true-d13205055e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1148"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e105-true-d13205055e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13202566e105-true-d13205055e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204989e7-true-d13205130e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1147"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204989e7-true-d13205130e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13204989e7-true-d13205130e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205060e9-true-d13205169e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1146"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205060e9-true-d13205169e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13205060e9-true-d13205169e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205060e10-true-d13205217e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1145"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205060e10-true-d13205217e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13205060e10-true-d13205217e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205180e12-true-d13205285e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1144"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205180e12-true-d13205285e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13205180e12-true-d13205285e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205180e35-true-d13205344e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1143"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205180e35-true-d13205344e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13205180e35-true-d13205344e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13204989e11-true-d13205421e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1142"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13204989e11-true-d13205421e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13204989e11-true-d13205421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205375e16-true-d13205462e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1141"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205375e16-true-d13205462e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13205375e16-true-d13205462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e109-true-d13205534e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1140"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e109-true-d13205534e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13202566e109-true-d13205534e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205473e15-true-d13205610e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1139"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205473e15-true-d13205610e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13205473e15-true-d13205610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205473e35-true-d13205665e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1138"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205473e35-true-d13205665e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13205473e35-true-d13205665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205473e39-true-d13205722e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1137"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205473e39-true-d13205722e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13205473e39-true-d13205722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205473e42-true-d13205776e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1136"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13205473e42-true-d13205776e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13205473e42-true-d13205776e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e137-true-d13205845e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1135"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e137-true-d13205845e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13202566e137-true-d13205845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205855e13-true-d13205879e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1134"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13205855e13-true-d13205879e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13205855e13-true-d13205879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205900e13-true-d13205924e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1133"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13205900e13-true-d13205924e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13205900e13-true-d13205924e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205945e13-true-d13205969e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1132"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13205945e13-true-d13205969e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13205945e13-true-d13205969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13205990e13-true-d13206024e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1131"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13205990e13-true-d13206024e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13205990e13-true-d13206024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13202566e141-true-d13206068e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1130"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13202566e141-true-d13206068e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13202566e141-true-d13206068e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206056e2-true-d13206095e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1129"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure)/d13206056e2-true-d13206095e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13206056e2-true-d13206095e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e16-true-d13207532e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | self::hl7:id | self::hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:value | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1128"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e16-true-d13207532e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] | hl7:id | hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:value | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13206116e16-true-d13207532e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e43-true-d13207585e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1127"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e43-true-d13207585e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13206116e43-true-d13207585e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207562e9-true-d13207629e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1126"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207562e9-true-d13207629e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13207562e9-true-d13207629e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207562e29-true-d13207678e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1125"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207562e29-true-d13207678e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13207562e29-true-d13207678e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e47-true-d13207714e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1124"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e47-true-d13207714e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13206116e47-true-d13207714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207702e2-true-d13207734e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1123"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207702e2-true-d13207734e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13207702e2-true-d13207734e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207702e8-true-d13207775e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1122"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207702e8-true-d13207775e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13207702e8-true-d13207775e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e52-true-d13207868e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1121"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e52-true-d13207868e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13206116e52-true-d13207868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207804e9-true-d13207928e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1120"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207804e9-true-d13207928e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13207804e9-true-d13207928e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e56-true-d13208050e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1119"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e56-true-d13208050e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13206116e56-true-d13208050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207977e10-true-d13208142e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1118"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207977e10-true-d13208142e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13207977e10-true-d13208142e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207977e30-true-d13208181e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1117"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207977e30-true-d13208181e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13207977e30-true-d13208181e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207977e34-true-d13208220e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1116"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207977e34-true-d13208220e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13207977e34-true-d13208220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13207977e39-true-d13208281e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1115"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13207977e39-true-d13208281e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13207977e39-true-d13208281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208244e12-true-d13208349e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1114"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208244e12-true-d13208349e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13208244e12-true-d13208349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208244e35-true-d13208408e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1113"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208244e35-true-d13208408e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13208244e35-true-d13208408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e60-true-d13208505e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1112"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e60-true-d13208505e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13206116e60-true-d13208505e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208439e7-true-d13208580e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1111"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208439e7-true-d13208580e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13208439e7-true-d13208580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208510e9-true-d13208619e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1110"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208510e9-true-d13208619e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13208510e9-true-d13208619e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208510e10-true-d13208667e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1109"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208510e10-true-d13208667e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13208510e10-true-d13208667e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208630e12-true-d13208735e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1108"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208630e12-true-d13208735e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13208630e12-true-d13208735e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208630e35-true-d13208794e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1107"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208630e35-true-d13208794e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13208630e35-true-d13208794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208439e11-true-d13208871e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1106"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208439e11-true-d13208871e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13208439e11-true-d13208871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208825e16-true-d13208912e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1105"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208825e16-true-d13208912e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13208825e16-true-d13208912e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e65-true-d13208984e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1104"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e65-true-d13208984e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13206116e65-true-d13208984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208923e15-true-d13209060e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1103"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208923e15-true-d13209060e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13208923e15-true-d13209060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208923e35-true-d13209115e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1102"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208923e35-true-d13209115e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13208923e35-true-d13209115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208923e39-true-d13209172e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1101"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208923e39-true-d13209172e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13208923e39-true-d13209172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13208923e42-true-d13209226e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1100"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13208923e42-true-d13209226e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13208923e42-true-d13209226e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e92-true-d13209295e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1099"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e92-true-d13209295e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13206116e92-true-d13209295e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209305e13-true-d13209329e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1098"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13209305e13-true-d13209329e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13209305e13-true-d13209329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209350e13-true-d13209374e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1097"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13209350e13-true-d13209374e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13209350e13-true-d13209374e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209395e13-true-d13209419e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1096"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13209395e13-true-d13209419e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13209395e13-true-d13209419e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209440e13-true-d13209474e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1095"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13209440e13-true-d13209474e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13209440e13-true-d13209474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13206116e97-true-d13209518e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1094"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13206116e97-true-d13209518e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13206116e97-true-d13209518e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209506e2-true-d13209545e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1093"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest)/d13209506e2-true-d13209545e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13209506e2-true-d13209545e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e16-true-d13211105e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | self::hl7:id | self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | self::hl7:doseQuantity | self::hl7:rateQuantity | self::hl7:maxDoseQuantity | self::hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1092"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e16-true-d13211105e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] | hl7:id | hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor] | hl7:doseQuantity | hl7:rateQuantity | hl7:maxDoseQuantity | hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13209566e16-true-d13211105e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e95-true-d13211221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1091"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e95-true-d13211221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13209566e95-true-d13211221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211198e9-true-d13211265e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1090"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211198e9-true-d13211265e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13211198e9-true-d13211265e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211198e29-true-d13211314e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1089"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211198e29-true-d13211314e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13211198e29-true-d13211314e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e99-true-d13211350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1088"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e99-true-d13211350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13209566e99-true-d13211350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211338e2-true-d13211370e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1087"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211338e2-true-d13211370e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13211338e2-true-d13211370e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211338e8-true-d13211411e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1086"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211338e8-true-d13211411e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13211338e8-true-d13211411e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e103-true-d13211488e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1085"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e103-true-d13211488e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13209566e103-true-d13211488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211440e5-true-d13211544e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1084"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211440e5-true-d13211544e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13211440e5-true-d13211544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211554e13-true-d13211571e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1083"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13211554e13-true-d13211571e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13211554e13-true-d13211571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211586e13-true-d13211614e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1082"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13211586e13-true-d13211614e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13211586e13-true-d13211614e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211440e24-true-d13211675e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1081"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211440e24-true-d13211675e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13211440e24-true-d13211675e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211638e12-true-d13211743e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1080"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211638e12-true-d13211743e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13211638e12-true-d13211743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211638e35-true-d13211802e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1079"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211638e35-true-d13211802e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13211638e35-true-d13211802e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e111-true-d13211897e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1078"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e111-true-d13211897e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13209566e111-true-d13211897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13211833e9-true-d13211957e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1077"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13211833e9-true-d13211957e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13211833e9-true-d13211957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e115-true-d13212079e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1076"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e115-true-d13212079e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13209566e115-true-d13212079e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212006e10-true-d13212171e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1075"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212006e10-true-d13212171e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13212006e10-true-d13212171e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212006e30-true-d13212210e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1074"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212006e30-true-d13212210e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13212006e30-true-d13212210e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212006e34-true-d13212249e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1073"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212006e34-true-d13212249e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13212006e34-true-d13212249e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212006e39-true-d13212310e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1072"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212006e39-true-d13212310e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13212006e39-true-d13212310e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212273e12-true-d13212378e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1071"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212273e12-true-d13212378e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13212273e12-true-d13212378e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212273e35-true-d13212437e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1070"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212273e35-true-d13212437e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13212273e35-true-d13212437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e119-true-d13212534e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1069"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e119-true-d13212534e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13209566e119-true-d13212534e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212468e7-true-d13212609e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1068"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212468e7-true-d13212609e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13212468e7-true-d13212609e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212539e9-true-d13212648e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1067"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212539e9-true-d13212648e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13212539e9-true-d13212648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212539e10-true-d13212696e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1066"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212539e10-true-d13212696e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13212539e10-true-d13212696e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212659e12-true-d13212764e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1065"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212659e12-true-d13212764e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13212659e12-true-d13212764e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212659e35-true-d13212823e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1064"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212659e35-true-d13212823e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13212659e35-true-d13212823e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212468e11-true-d13212900e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1063"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212468e11-true-d13212900e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13212468e11-true-d13212900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212854e16-true-d13212941e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1062"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212854e16-true-d13212941e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13212854e16-true-d13212941e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e124-true-d13213013e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1061"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e124-true-d13213013e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13209566e124-true-d13213013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212952e15-true-d13213089e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1060"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212952e15-true-d13213089e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13212952e15-true-d13213089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212952e35-true-d13213144e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1059"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212952e35-true-d13213144e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13212952e35-true-d13213144e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212952e39-true-d13213201e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1058"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212952e39-true-d13213201e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13212952e39-true-d13213201e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13212952e42-true-d13213255e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1057"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13212952e42-true-d13213255e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13212952e42-true-d13213255e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e151-true-d13213324e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1056"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e151-true-d13213324e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13209566e151-true-d13213324e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213334e13-true-d13213358e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1055"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13213334e13-true-d13213358e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13213334e13-true-d13213358e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213379e13-true-d13213403e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1054"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13213379e13-true-d13213403e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13213379e13-true-d13213403e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213424e13-true-d13213448e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1053"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13213424e13-true-d13213448e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13213424e13-true-d13213448e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213469e13-true-d13213503e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1052"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13213469e13-true-d13213503e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13213469e13-true-d13213503e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13209566e156-true-d13213547e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1051"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13209566e156-true-d13213547e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13209566e156-true-d13213547e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213535e2-true-d13213574e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1050"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration)/d13213535e2-true-d13213574e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13213535e2-true-d13213574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e16-true-d13215101e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/*[not(self::hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:repeatNumber | self::hl7:independentInd | self::hl7:quantity | self::hl7:expectedUseTime | self::hl7:subject[hl7:relatedSubject[@classCode]] | self::hl7:specimen[hl7:specimenRole] | self::hl7:product[hl7:manufacturedProduct] | self::hl7:performer[hl7:assignedEntity] | self::hl7:author[hl7:assignedAuthor] | self::hl7:informant | self::hl7:participant[@typeCode][hl7:participantRole] | self::hl7:entryRelationship[@typeCode] | self::hl7:reference[@typeCode] | self::hl7:precondition[hl7:criterion])]"
                 priority="1049"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e16-true-d13215101e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] | hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:repeatNumber | hl7:independentInd | hl7:quantity | hl7:expectedUseTime | hl7:subject[hl7:relatedSubject[@classCode]] | hl7:specimen[hl7:specimenRole] | hl7:product[hl7:manufacturedProduct] | hl7:performer[hl7:assignedEntity] | hl7:author[hl7:assignedAuthor] | hl7:informant | hl7:participant[@typeCode][hl7:participantRole] | hl7:entryRelationship[@typeCode] | hl7:reference[@typeCode] | hl7:precondition[hl7:criterion] (rule-reference: d13213595e16-true-d13215101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e71-true-d13215193e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/*[not(self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:relatedSubject[@classCode])]"
                 priority="1048"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e71-true-d13215193e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:relatedSubject[@classCode] (rule-reference: d13213595e71-true-d13215193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215170e9-true-d13215237e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:subject)]"
                 priority="1047"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215170e9-true-d13215237e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:subject (rule-reference: d13215170e9-true-d13215237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215170e29-true-d13215286e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/*[not(self::hl7:name | self::hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:birthTime)]"
                 priority="1046"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215170e29-true-d13215286e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name | hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:birthTime (rule-reference: d13215170e29-true-d13215286e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e76-true-d13215322e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/*[not(self::hl7:specimenRole)]"
                 priority="1045"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e76-true-d13215322e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:specimenRole (rule-reference: d13213595e76-true-d13215322e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215310e2-true-d13215342e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/*[not(self::hl7:id | self::hl7:specimenPlayingEntity)]"
                 priority="1044"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215310e2-true-d13215342e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:specimenPlayingEntity (rule-reference: d13215310e2-true-d13215342e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215310e8-true-d13215383e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1043"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215310e8-true-d13215383e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13215310e8-true-d13215383e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e80-true-d13215460e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/*[not(self::hl7:manufacturedProduct)]"
                 priority="1042"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e80-true-d13215460e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:manufacturedProduct (rule-reference: d13213595e80-true-d13215460e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215412e5-true-d13215516e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/*[not(self::hl7:id | self::hl7:manufacturedLabeledDrug | self::hl7:manufacturedMaterial | self::hl7:manufacturerOrganization)]"
                 priority="1041"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215412e5-true-d13215516e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial | hl7:manufacturerOrganization (rule-reference: d13215412e5-true-d13215516e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215526e13-true-d13215543e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/*[not(self::hl7:code | self::hl7:name)]"
                 priority="1040"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug)/d13215526e13-true-d13215543e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code | hl7:name (rule-reference: d13215526e13-true-d13215543e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215558e13-true-d13215586e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:name | self::hl7:lotNumberText)]"
                 priority="1039"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial)/d13215558e13-true-d13215586e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:name | hl7:lotNumberText (rule-reference: d13215558e13-true-d13215586e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215412e24-true-d13215647e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1038"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215412e24-true-d13215647e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13215412e24-true-d13215647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215610e12-true-d13215715e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1037"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215610e12-true-d13215715e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13215610e12-true-d13215715e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215610e35-true-d13215774e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1036"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215610e35-true-d13215774e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13215610e35-true-d13215774e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e87-true-d13215869e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/*[not(self::hl7:time | self::hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:assignedEntity)]"
                 priority="1035"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e87-true-d13215869e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:assignedEntity (rule-reference: d13213595e87-true-d13215869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215805e9-true-d13215929e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1034"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215805e9-true-d13215929e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13215805e9-true-d13215929e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e92-true-d13216051e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/*[not(self::hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:time | self::hl7:assignedAuthor)]"
                 priority="1033"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e92-true-d13216051e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:time | hl7:assignedAuthor (rule-reference: d13213595e92-true-d13216051e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215978e10-true-d13216143e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:assignedAuthoringDevice | self::hl7:representedOrganization)]"
                 priority="1032"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215978e10-true-d13216143e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:assignedAuthoringDevice | hl7:representedOrganization (rule-reference: d13215978e10-true-d13216143e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215978e30-true-d13216182e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1031"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215978e30-true-d13216182e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13215978e30-true-d13216182e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215978e34-true-d13216221e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1030"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215978e34-true-d13216221e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13215978e34-true-d13216221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13215978e39-true-d13216282e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1029"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13215978e39-true-d13216282e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13215978e39-true-d13216282e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216245e12-true-d13216350e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1028"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216245e12-true-d13216350e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13216245e12-true-d13216350e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216245e35-true-d13216409e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1027"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216245e35-true-d13216409e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13216245e35-true-d13216409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e96-true-d13216506e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/*[not(self::hl7:assignedEntity | self::hl7:relatedEntity[@classCode])]"
                 priority="1026"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e96-true-d13216506e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:assignedEntity | hl7:relatedEntity[@classCode] (rule-reference: d13213595e96-true-d13216506e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216440e7-true-d13216581e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:assignedPerson | self::hl7:representedOrganization)]"
                 priority="1025"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216440e7-true-d13216581e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:assignedPerson | hl7:representedOrganization (rule-reference: d13216440e7-true-d13216581e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216511e9-true-d13216620e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson/*[not(self::hl7:name)]"
                 priority="1024"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216511e9-true-d13216620e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13216511e9-true-d13216620e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216511e10-true-d13216668e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode | self::hl7:asOrganizationPartOf)]"
                 priority="1023"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216511e10-true-d13216668e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode | hl7:asOrganizationPartOf (rule-reference: d13216511e10-true-d13216668e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216631e12-true-d13216736e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | self::hl7:effectiveTime | self::hl7:wholeOrganization)]"
                 priority="1022"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216631e12-true-d13216736e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] | hl7:effectiveTime | hl7:wholeOrganization (rule-reference: d13216631e12-true-d13216736e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216631e35-true-d13216795e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization/*[not(self::hl7:id | self::hl7:name | self::hl7:telecom | self::hl7:addr | self::hl7:standardIndustryClassCode)]"
                 priority="1021"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216631e35-true-d13216795e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:name | hl7:telecom | hl7:addr | hl7:standardIndustryClassCode (rule-reference: d13216631e35-true-d13216795e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216440e11-true-d13216872e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/*[not(self::hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:effectiveTime | self::hl7:relatedPerson)]"
                 priority="1020"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216440e11-true-d13216872e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:addr | hl7:telecom | hl7:effectiveTime | hl7:relatedPerson (rule-reference: d13216440e11-true-d13216872e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216826e16-true-d13216913e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson/*[not(self::hl7:name)]"
                 priority="1019"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216826e16-true-d13216913e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:name (rule-reference: d13216826e16-true-d13216913e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e100-true-d13216985e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/*[not(self::hl7:time | self::hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:participantRole)]"
                 priority="1018"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e100-true-d13216985e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:time | hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:participantRole (rule-reference: d13213595e100-true-d13216985e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216924e15-true-d13217061e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | self::hl7:addr | self::hl7:telecom | self::hl7:playingDevice | self::hl7:playingEntity | self::hl7:scopingEntity)]"
                 priority="1017"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216924e15-true-d13217061e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] | hl7:addr | hl7:telecom | hl7:playingDevice | hl7:playingEntity | hl7:scopingEntity (rule-reference: d13216924e15-true-d13217061e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216924e35-true-d13217116e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:manufacturerModelName | self::hl7:softwareName)]"
                 priority="1016"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216924e35-true-d13217116e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:manufacturerModelName | hl7:softwareName (rule-reference: d13216924e35-true-d13217116e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216924e39-true-d13217173e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/*[not(self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:quantity | self::hl7:name | self::hl7:desc)]"
                 priority="1015"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216924e39-true-d13217173e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:quantity | hl7:name | hl7:desc (rule-reference: d13216924e39-true-d13217173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13216924e42-true-d13217227e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/*[not(self::hl7:id | self::hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | self::hl7:desc)]"
                 priority="1014"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13216924e42-true-d13217227e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] | hl7:desc (rule-reference: d13216924e42-true-d13217227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e128-true-d13217296e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1013"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e128-true-d13217296e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13213595e128-true-d13217296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217306e13-true-d13217330e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1012"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13217306e13-true-d13217330e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13217306e13-true-d13217330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217351e13-true-d13217375e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1011"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13217351e13-true-d13217375e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13217351e13-true-d13217375e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217396e13-true-d13217420e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1010"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13217396e13-true-d13217420e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13217396e13-true-d13217420e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217441e13-true-d13217475e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1009"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13217441e13-true-d13217475e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13217441e13-true-d13217475e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13213595e132-true-d13217519e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1008"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13213595e132-true-d13217519e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13213595e132-true-d13217519e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217507e2-true-d13217546e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1007"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13217507e2-true-d13217546e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13217507e2-true-d13217546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e128-true-d13217604e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/*[not(self::hl7:seperatableInd | self::hl7:externalAct | self::hl7:externalObservation | self::hl7:externalProcedure | self::hl7:externalDocument)]"
                 priority="1006"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e128-true-d13217604e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:seperatableInd | hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument (rule-reference: d13176210e128-true-d13217604e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217614e13-true-d13217638e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1005"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct)/d13217614e13-true-d13217638e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13217614e13-true-d13217638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217659e13-true-d13217683e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1004"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation)/d13217659e13-true-d13217683e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13217659e13-true-d13217683e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217704e13-true-d13217728e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text)]"
                 priority="1003"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure)/d13217704e13-true-d13217728e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text (rule-reference: d13217704e13-true-d13217728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217749e13-true-d13217783e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/*[not(self::hl7:id | self::hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | self::hl7:text | self::hl7:setId | self::hl7:versionNumber)]"
                 priority="1002"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument)/d13217749e13-true-d13217783e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:id | hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] | hl7:text | hl7:setId | hl7:versionNumber (rule-reference: d13217749e13-true-d13217783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13176210e132-true-d13217827e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/*[not(self::hl7:criterion)]"
                 priority="1001"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13176210e132-true-d13217827e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:criterion (rule-reference: d13176210e132-true-d13217827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

	  <!--RULE d13217815e2-true-d13217854e0-->
   <xsl:template match="//hl7:ClinicalDocument[hl7:templateId[@root = '2.16.840.1.113883.10.12.1']]/hl7:component[@contextConductionInd][hl7:structuredBody]/hl7:structuredBody[hl7:component[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode][@typeCode]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/*[not(self::hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | self::hl7:text | self::hl7:value)]"
                 priority="1000"
                 mode="M11">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply)/d13217815e2-true-d13217854e0: dieses Element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' ist nicht definiert oder nicht mit diesem Inhalt definiert. Dies kann templateId, code oder id betreffen. Erwartet:  hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] | hl7:text | hl7:value (rule-reference: d13217815e2-true-d13217854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M11"/>
   <xsl:template match="@*|node()" priority="-2" mode="M11">
      <xsl:apply-templates select="*" mode="M11"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.201-2005-09-07T000000CDA Section-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Section</svrl:text>

	  <!--RULE d19e500-false-d2013e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1040"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:confidentialityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16926-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:confidentialityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16926-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:confidentialityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16926-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:languageCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:languageCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:languageCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE d19e506-false-d2595e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1039"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE d19e511-false-d2612e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1038"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE d19e513-false-d2626e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1037"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE d19e521-false-d2648e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1036"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE d19e523-false-d2659e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1035"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE d19e525-false-d2673e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:confidentialityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16926-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1034"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16926-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16926-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16926 HL7 BasicConfidentialityKind (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE d19e532-false-d2698e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:languageCode"
                 priority="1033"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1032"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1031"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1030"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1029"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1028"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1027"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]"
                 priority="1026"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1025"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1024"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1023"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1022"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1021"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1020"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1019"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1018"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1017"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1016"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1015"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant"
                 priority="1014"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity"
                 priority="1013"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1012"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1011"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1010"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1009"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1008"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1007"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1006"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1005"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M73">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1003"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1002"
                 mode="M73">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:component[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]"
                 priority="1000"
                 mode="M73">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.201-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASection): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M73"/>
   <xsl:template match="@*|node()" priority="-2" mode="M73">
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.301-2005-09-07T000000CDA Act-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Act</svrl:text>

	  <!--RULE d19e733-false-d10328e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]"
                 priority="1083"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19599-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19599-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19599' x_ActClassDocumentEntryAct (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19458-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19458-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19458' x_DocumentActMood (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.301']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.301']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.301']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.301']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.301'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:languageCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:languageCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:languageCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e751-false-d10930e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.301']"
                 priority="1082"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.301')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.301')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Der Wert von root MUSS '2.16.840.1.113883.10.12.301' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e756-false-d10945e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:id"
                 priority="1081"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e759-false-d10957e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1080"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e764-false-d10974e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:text"
                 priority="1079"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e766-false-d10988e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1078"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e773-false-d11010e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:effectiveTime"
                 priority="1077"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e775-false-d11024e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1076"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16866 ActPriority (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE d19e782-false-d11049e0-->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:languageCode"
                 priority="1075"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1074"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1073"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1072"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1070"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]"
                 priority="1068"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1067"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1066"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1065"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant"
                 priority="1045"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M74">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:entryRelationship[@typeCode]"
                 priority="1023"
                 mode="M74">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.301-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAct): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]"
                 priority="1021"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1020"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1019"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1018"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1017"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1016"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1015"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1014"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1013"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1012"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1011"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1010"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1009"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1008"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1007"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1006"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1005"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1004"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1003"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]"
                 priority="1002"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1001"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]]/hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1000"
                 mode="M74">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M74"/>
   <xsl:template match="@*|node()" priority="-2" mode="M74">
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.302-2005-09-07T000000CDA Encounter-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Encounter</svrl:text>

	  <!--RULE d19e869-false-d20065e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]"
                 priority="1082"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENC')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENC')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Der Wert von classCode MUSS 'ENC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19459-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19459-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19459' x_DocumentEncounterMood (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.302']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.302']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.302']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.302']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.302'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE d19e880-false-d20638e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.302']"
                 priority="1081"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.302')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.302')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Der Wert von root MUSS '2.16.840.1.113883.10.12.302' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE d19e885-false-d20653e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:id"
                 priority="1080"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE d19e887-false-d20667e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1079"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.13955-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.13955 ActEncounterCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE d19e895-false-d20689e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:text"
                 priority="1078"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE d19e897-false-d20703e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1077"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE d19e904-false-d20725e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:effectiveTime"
                 priority="1076"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE d19e906-false-d20739e0-->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1075"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16866 ActPriority (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1074"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1073"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1072"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1070"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]"
                 priority="1068"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1067"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1066"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1065"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant"
                 priority="1045"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M75">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:entryRelationship[@typeCode]"
                 priority="1023"
                 mode="M75">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.302-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAEncounter): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]"
                 priority="1021"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1020"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1019"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1018"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1017"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1016"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1015"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1014"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1013"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1012"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1011"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1010"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1009"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1008"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1007"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1006"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1005"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1004"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1003"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]"
                 priority="1002"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1001"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]]/hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1000"
                 mode="M75">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M75"/>
   <xsl:template match="@*|node()" priority="-2" mode="M75">
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.303-2005-09-07T000000CDA Observation-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Observation</svrl:text>

	  <!--RULE d19e993-false-d29764e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1095"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:derivationExpr) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:derivationExpr) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:derivationExpr kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:repeatNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:repeatNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:repeatNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:languageCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:languageCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:languageCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1006-false-d30395e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1094"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1011-false-d30410e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1093"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1014-false-d30424e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1092"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16226 ObservationType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1021-false-d30446e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:derivationExpr"
                 priority="1091"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1023-false-d30457e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1090"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1025-false-d30471e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1089"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1032-false-d30493e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:effectiveTime"
                 priority="1088"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1034-false-d30507e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1087"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16866 ActPriority (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1042-false-d30529e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:repeatNumber"
                 priority="1086"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_INT: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_INT: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_INT: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_INT: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_INT: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_INT: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_INT: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_INT: low/@value must be lower than or equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_INT: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_INT: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1044-false-d30543e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:languageCode"
                 priority="1085"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1051-false-d30558e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1084"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1053-false-d30569e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1083"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.78 ObservationInterpretation (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1060-false-d30594e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1082"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.14079 ObservationMethod (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1067-false-d30617e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor]"
                 priority="1081"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.1052'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1080"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1079"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1078"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1077"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1076"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1075"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]"
                 priority="1074"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1073"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1072"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]"
                 priority="1070"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1068"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1067"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1066"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1065"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1064"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]"
                 priority="1063"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1062"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1061"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1059"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1058"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1057"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1056"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1055"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1053"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1052"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant"
                 priority="1051"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity"
                 priority="1050"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1049"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1048"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1047"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1046"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1045"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1044"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1043"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1042"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1041"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1040"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1039"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1038"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1037"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1036"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1035"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1034"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1033"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1031"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1030"
                 mode="M76">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode]"
                 priority="1029"
                 mode="M76">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]"
                 priority="1027"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1026"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1025"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1024"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1023"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1022"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1021"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1020"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1019"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1018"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1017"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1016"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1015"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1014"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1013"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1012"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1011"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1010"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1009"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]"
                 priority="1008"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1007"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1006"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1135-false-d38281e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]"
                 priority="1005"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('REFV')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('REFV')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Wert von typeCode MUSS 'REFV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:observationRange) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:observationRange) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:observationRange ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:observationRange) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:observationRange) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:observationRange kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1139-false-d38302e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange"
                 priority="1004"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Element hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1145-false-d38350e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1003"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1150-false-d38367e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:text"
                 priority="1002"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1152-false-d38378e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:value"
                 priority="1001"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE d19e1155-false-d38389e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1000"
                 mode="M76">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.303-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservation): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.78 ObservationInterpretation (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M76"/>
   <xsl:template match="@*|node()" priority="-2" mode="M76">
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.304-2005-09-07T000000CDA ObservationMedia-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA ObservationMedia</svrl:text>

	  <!--RULE d19e1182-false-d39765e0-->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]"
                 priority="1079"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.304']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.304']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.304']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.304']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.304'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:languageCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:languageCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:languageCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:value ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE d19e1188-false-d40300e0-->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.304']"
                 priority="1078"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.304')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.304')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Der Wert von root MUSS '2.16.840.1.113883.10.12.304' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE d19e1193-false-d40315e0-->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:id"
                 priority="1077"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE d19e1195-false-d40329e0-->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:languageCode"
                 priority="1076"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE d19e1203-false-d40344e0-->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:value"
                 priority="1075"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1074"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1073"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1072"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1070"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]"
                 priority="1068"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1067"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1066"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1065"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant"
                 priority="1045"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M77">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:entryRelationship[@typeCode]"
                 priority="1023"
                 mode="M77">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.304-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationMedia): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]"
                 priority="1021"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1020"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1019"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1018"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1017"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1016"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1015"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1014"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1013"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1012"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1011"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1010"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1009"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1008"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1007"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1006"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1005"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1004"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1003"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]"
                 priority="1002"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1001"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]]/hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1000"
                 mode="M77">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M77"/>
   <xsl:template match="@*|node()" priority="-2" mode="M77">
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.305-2005-09-07T000000CDA Organizer-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Organizer</svrl:text>

	  <!--RULE d19e1285-false-d49356e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]"
                 priority="1080"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19598-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19598-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19598' x_ActClassDocumentEntryOrganizer (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE d19e1296-false-d49913e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.305']"
                 priority="1079"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.305')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.305')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Der Wert von root MUSS '2.16.840.1.113883.10.12.305' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE d19e1301-false-d49928e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:id"
                 priority="1078"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE d19e1303-false-d49940e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1077"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE d19e1309-false-d49960e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1076"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE d19e1316-false-d49982e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:effectiveTime"
                 priority="1075"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1074"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1073"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1072"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1070"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]"
                 priority="1068"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1067"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1066"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1065"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant"
                 priority="1045"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M78">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]"
                 priority="1023"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1022"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1021"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1020"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1019"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1018"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1017"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1016"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1015"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1014"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1013"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1012"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1011"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1010"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1009"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1008"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1007"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1006"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1005"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]"
                 priority="1004"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1003"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1002"
                 mode="M78">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:component"
                 priority="1001"
                 mode="M78">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('COMP') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('COMP') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Der Wert von typeCode MUSS 'COMP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.305-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganizer): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M78"/>
   <xsl:template match="@*|node()" priority="-2" mode="M78">
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.306-2005-09-07T000000CDA Procedure-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Procedure</svrl:text>

	  <!--RULE d19e1390-false-d59958e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]"
                 priority="1086"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19460-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19460-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19460' x_DocumentProcedureMood (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.306']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.306']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.306']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.306']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.306'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:languageCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:languageCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:languageCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1403-false-d60558e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.306']"
                 priority="1085"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.306')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.306')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Wert von root MUSS '2.16.840.1.113883.10.12.306' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1408-false-d60573e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:id"
                 priority="1084"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1411-false-d60585e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1083"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1416-false-d60602e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:text"
                 priority="1082"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1418-false-d60616e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1081"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1425-false-d60638e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:effectiveTime"
                 priority="1080"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1427-false-d60652e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1079"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16866 ActPriority (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1434-false-d60677e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:languageCode"
                 priority="1078"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1442-false-d60693e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:methodCode[@codeSystem = '2.16.840.1.113883.5.1065' or @nullFlavor]"
                 priority="1077"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1065')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1065')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.1065'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1447-false-d60711e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor]"
                 priority="1076"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.1052'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE d19e1452-false-d60729e0-->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor]"
                 priority="1075"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.1052'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1074"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1073"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1072"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1070"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]"
                 priority="1068"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1067"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1066"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1065"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant"
                 priority="1045"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M79">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:entryRelationship[@typeCode]"
                 priority="1023"
                 mode="M79">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.306-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAProcedure): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]"
                 priority="1021"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1020"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1019"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1018"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1017"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1016"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1015"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1014"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1013"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1012"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1011"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1010"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1009"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1008"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1007"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1006"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1005"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1004"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1003"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]"
                 priority="1002"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1001"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]]/hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1000"
                 mode="M79">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M79"/>
   <xsl:template match="@*|node()" priority="-2" mode="M79">
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.307-2005-09-07T000000CDA RegionOfInterest-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA RegionOfInterest</svrl:text>

	  <!--RULE d19e1537-false-d69747e0-->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]"
                 priority="1079"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROIOVL')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROIOVL')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Der Wert von classCode MUSS 'ROIOVL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.307']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.307']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.307']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.307']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.307'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:value ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE d19e1543-false-d70285e0-->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.307']"
                 priority="1078"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.307')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.307')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Der Wert von root MUSS '2.16.840.1.113883.10.12.307' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE d19e1548-false-d70300e0-->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:id"
                 priority="1077"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE d19e1550-false-d70314e0-->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:code[@code = doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1076"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16117-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16117 ROIOverlayShape (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE d19e1558-false-d70336e0-->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:value"
                 priority="1075"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1074"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1073"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1072"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1070"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]"
                 priority="1068"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1067"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1066"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1065"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant"
                 priority="1045"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M80">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:entryRelationship[@typeCode]"
                 priority="1023"
                 mode="M80">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.307-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARegionOfInterest): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]"
                 priority="1021"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1020"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1019"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1018"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1017"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1016"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1015"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1014"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1013"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1012"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1011"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1010"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1009"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1008"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1007"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1006"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1005"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1004"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1003"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]"
                 priority="1002"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1001"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]]/hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1000"
                 mode="M80">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M80"/>
   <xsl:template match="@*|node()" priority="-2" mode="M80">
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.308-2005-09-07T000000CDA SubstanceAdministration-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA SubstanceAdministration</svrl:text>

	  <!--RULE d19e1640-false-d79394e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]"
                 priority="1103"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SBADM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SBADM')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Wert von classCode MUSS 'SBADM' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19461-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19461-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19461' x_DocumentSubstanceMood (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.308']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.308']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.308']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.308']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.308'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:repeatNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:repeatNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:repeatNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:doseQuantity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:doseQuantity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:doseQuantity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:rateQuantity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:rateQuantity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:rateQuantity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:maxDoseQuantity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:maxDoseQuantity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:maxDoseQuantity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1653-false-d80048e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.308']"
                 priority="1102"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.308')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.308')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Wert von root MUSS '2.16.840.1.113883.10.12.308' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1658-false-d80063e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:id"
                 priority="1101"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1661-false-d80077e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1100"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19708-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19708 ActSubstanceAdministrationCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1668-false-d80099e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:text"
                 priority="1099"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1670-false-d80113e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1098"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1677-false-d80135e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:effectiveTime"
                 priority="1097"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SXCM_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SXCM_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SXCM_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1679-false-d80149e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1096"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16866 ActPriority (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1686-false-d80171e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:repeatNumber"
                 priority="1095"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_INT: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_INT: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_INT: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_INT: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_INT: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_INT: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_INT: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_INT: low/@value must be lower than or equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_INT: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_INT: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1689-false-d80185e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:routeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1094"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14581-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.14581 RouteOfAdministration (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1696-false-d80208e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:approachSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor]"
                 priority="1093"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.1052'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1701-false-d80225e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:doseQuantity"
                 priority="1092"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_PQ: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_PQ: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:* except hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and hl7:* except hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_PQ: co-occurence violation. Cannot have @value and other child elements except translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_PQ: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_PQ: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_PQ: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_PQ: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_PQ: low/@value must be lower than or equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_PQ: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_PQ: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_PQ: units in low and high should be equal or comparable</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation and hl7:* except hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation and hl7:* except hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_PQ: co-occurence violation. Cannot have translation and other child elements except translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value) or matches(string(hl7:low/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value) or matches(string(hl7:low/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): value/low @value ist keine gültige PQ Zahl<xsl:text/>
                  <xsl:value-of select="hl7:low/@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high/@value) or matches(string(hl7:high/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high/@value) or matches(string(hl7:high/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): value/high @value ist keine gültige PQ Zahl<xsl:text/>
                  <xsl:value-of select="hl7:high/@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center/@value) or matches(string(hl7:center/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center/@value) or matches(string(hl7:center/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): value/center @value ist keine gültige PQ Zahl<xsl:text/>
                  <xsl:value-of select="hl7:center/@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1703-false-d80245e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:rateQuantity"
                 priority="1091"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_PQ: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_PQ: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:* except hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and hl7:* except hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_PQ: co-occurence violation. Cannot have @value and other child elements except translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_PQ: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_PQ: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_PQ: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_PQ: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_PQ: low/@value must be lower than or equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_PQ: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_PQ: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_PQ: units in low and high should be equal or comparable</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation and hl7:* except hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation and hl7:* except hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_PQ: co-occurence violation. Cannot have translation and other child elements except translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value) or matches(string(hl7:low/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value) or matches(string(hl7:low/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): value/low @value ist keine gültige PQ Zahl<xsl:text/>
                  <xsl:value-of select="hl7:low/@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high/@value) or matches(string(hl7:high/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high/@value) or matches(string(hl7:high/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): value/high @value ist keine gültige PQ Zahl<xsl:text/>
                  <xsl:value-of select="hl7:high/@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center/@value) or matches(string(hl7:center/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center/@value) or matches(string(hl7:center/@value), '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): value/center @value ist keine gültige PQ Zahl<xsl:text/>
                  <xsl:value-of select="hl7:center/@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1705-false-d80265e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:maxDoseQuantity"
                 priority="1090"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or hl7:numerator[not(@nullFlavor)] or hl7:denominator[not(@nullFlavor)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or hl7:numerator[not(@nullFlavor)] or hl7:denominator[not(@nullFlavor)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_RTO_PQ_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-RTO_PQ_PQ: numerator or denominator required</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:numerator[@updateMode] or hl7:denominator[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:numerator[@updateMode] or hl7:denominator[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_RTO_PQ_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-RTO_PQ_PQ: no updateMode on numerator or denominator</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_RTO_PQ_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-RTO_PQ_PQ: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:denominator/@value='0')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:denominator/@value='0')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_RTO_PQ_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-RTO_PQ_PQ: The denominator must not be zero.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='RTO_PQ_PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='RTO_PQ_PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:RTO_PQ_PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE d19e1707-false-d80279e0-->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:administrationUnitCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1089"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14570-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.14570 AdministrableDrugForm (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1088"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1087"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1086"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1085"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1084"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1083"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]"
                 priority="1082"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1081"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1080"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1079"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]"
                 priority="1078"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('CSM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('CSM')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Wert von typeCode MUSS 'CSM' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct"
                 priority="1077"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('MANU') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('MANU') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Der Wert von classCode MUSS 'MANU' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Auswahl (hl7:manufacturedLabeledDrug  oder  hl7:manufacturedMaterial) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Auswahl (hl7:manufacturedLabeledDrug  oder  hl7:manufacturedMaterial) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Element hl7:manufacturerOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug"
                 priority="1076"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('MMAT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('MMAT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Der Wert von classCode MUSS 'MMAT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('KIND') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('KIND') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Der Wert von determinerCode MUSS 'KIND' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:name) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:name) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Element hl7:name kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/hl7:code"
                 priority="1075"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/hl7:name"
                 priority="1074"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.1-EN: entity name shall not be null and have elements or text</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.2-EN: entity name shall not have both elements and text (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.3-EN: entity name that is not null shall not be empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-3-EN: empty name particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="substring(normalize-space(.),1,1)='&#34;'">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-EN: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-EN: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-EN: enxp elements SHALL have distinct values in @qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:EN" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial"
                 priority="1073"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('MMAT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('MMAT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Der Wert von classCode MUSS 'MMAT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('KIND') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('KIND') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Der Wert von determinerCode MUSS 'KIND' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:name) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:name) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Element hl7:name kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:lotNumberText) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:lotNumberText) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Element hl7:lotNumberText kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1072"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16041 MaterialEntityClassType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/hl7:name"
                 priority="1071"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.1-EN: entity name shall not be null and have elements or text</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.2-EN: entity name shall not have both elements and text (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.3-EN: entity name that is not null shall not be empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-3-EN: empty name particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="substring(normalize-space(.),1,1)='&#34;'">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-EN: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-EN: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-EN: enxp elements SHALL have distinct values in @qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:EN" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/hl7:lotNumberText"
                 priority="1070"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization"
                 priority="1069"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf"
                 priority="1068"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1067"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1066"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:consumable[@typeCode = 'CSM'][hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1065"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant"
                 priority="1045"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M81">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:entryRelationship[@typeCode]"
                 priority="1023"
                 mode="M81">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.308-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubstanceAdministration): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]"
                 priority="1021"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1020"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1019"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1018"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1017"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1016"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1015"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1014"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1013"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1012"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1011"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1010"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1009"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1008"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1007"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1006"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1005"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1004"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1003"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]"
                 priority="1002"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1001"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]]/hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1000"
                 mode="M81">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M81"/>
   <xsl:template match="@*|node()" priority="-2" mode="M81">
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.10.12.309-2005-09-07T000000CDA Supply-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Supply</svrl:text>

	  <!--RULE d19e1802-false-d89891e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]"
                 priority="1100"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPLY')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPLY')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Wert von classCode MUSS 'SPLY' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19461-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19461-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19461' x_DocumentSubstanceMood (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.309']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.309']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.309']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.309']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.309'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:repeatNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:repeatNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:repeatNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:independentInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:independentInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:independentInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:quantity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:quantity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:quantity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:expectedUseTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:expectedUseTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:expectedUseTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:product[hl7:manufacturedProduct]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:product[hl7:manufacturedProduct]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:product[hl7:manufacturedProduct] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1813-false-d90508e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.309']"
                 priority="1099"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.309')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.309')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Wert von root MUSS '2.16.840.1.113883.10.12.309' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1818-false-d90523e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:id"
                 priority="1098"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1820-false-d90535e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1097"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1826-false-d90552e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:text"
                 priority="1096"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1828-false-d90566e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1095"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1835-false-d90588e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:effectiveTime"
                 priority="1094"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SXCM_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SXCM_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SXCM_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1837-false-d90602e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1093"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16866 ActPriority (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1844-false-d90624e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:repeatNumber"
                 priority="1092"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_INT: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_INT: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_INT: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_INT: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_INT: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_INT: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_INT: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_INT: low/@value must be lower than or equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_INT: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_INT: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1846-false-d90635e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:independentInd"
                 priority="1091"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='BL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='BL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:BL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1849-false-d90646e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:quantity"
                 priority="1090"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE d19e1851-false-d90663e0-->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:expectedUseTime"
                 priority="1089"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1088"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1087"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1086"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1085"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1084"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1083"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]"
                 priority="1082"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1081"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1080"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1079"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]"
                 priority="1078"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRD') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRD') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Wert von typeCode MUSS 'PRD' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct"
                 priority="1077"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('MANU') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('MANU') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Der Wert von classCode MUSS 'MANU' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:manufacturedLabeledDrug | hl7:manufacturedMaterial)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Auswahl (hl7:manufacturedLabeledDrug  oder  hl7:manufacturedMaterial) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Auswahl (hl7:manufacturedLabeledDrug  oder  hl7:manufacturedMaterial) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.312-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAManufacturedProduct): Element hl7:manufacturerOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug"
                 priority="1076"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('MMAT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('MMAT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Der Wert von classCode MUSS 'MMAT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('KIND') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('KIND') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Der Wert von determinerCode MUSS 'KIND' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:name) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:name) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Element hl7:name kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/hl7:code"
                 priority="1075"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedLabeledDrug/hl7:name"
                 priority="1074"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.1-EN: entity name shall not be null and have elements or text</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.2-EN: entity name shall not have both elements and text (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.3-EN: entity name that is not null shall not be empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-3-EN: empty name particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="substring(normalize-space(.),1,1)='&#34;'">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-EN: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-EN: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-EN: enxp elements SHALL have distinct values in @qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.310-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDALabeledDrug): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:EN" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial"
                 priority="1073"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('MMAT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('MMAT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Der Wert von classCode MUSS 'MMAT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('KIND') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('KIND') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Der Wert von determinerCode MUSS 'KIND' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:name) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:name) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Element hl7:name kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:lotNumberText) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:lotNumberText) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Element hl7:lotNumberText kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1072"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16041-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16041 MaterialEntityClassType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/hl7:name"
                 priority="1071"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and (* or string-length(normalize-space(string-join(text(),'')))&gt;0))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.1-EN: entity name shall not be null and have elements or text</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(* and string-length(normalize-space(string-join(text(),'')))&gt;0)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.2-EN: entity name shall not have both elements and text (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or * or string-length(normalize-space(string-join(text(),'')))&gt;0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1.3-EN: entity name that is not null shall not be empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-3-EN: empty name particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="substring(normalize-space(.),1,1)='&#34;'">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-EN: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-EN: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:*) or hl7:*[count(tokenize(@qualifier,'\s'))=count(distinct-values(tokenize(@qualifier,'\s')))]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_EN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-EN: enxp elements SHALL have distinct values in @qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='EN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:EN" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturedMaterial/hl7:lotNumberText"
                 priority="1070"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.311-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAMaterial): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization"
                 priority="1069"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf"
                 priority="1068"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1067"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1066"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:product[hl7:manufacturedProduct]/hl7:manufacturedProduct/hl7:manufacturerOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1065"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]"
                 priority="1064"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1063"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1062"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1061"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1059"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1058"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]"
                 priority="1057"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1056"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1055"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1053"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1052"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1051"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1050"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1049"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1048"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1047"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1046"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant"
                 priority="1045"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity"
                 priority="1044"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1043"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1042"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1041"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1040"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1039"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1038"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1037"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1036"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1035"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1034"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1033"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1031"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1030"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1029"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1028"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1027"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1026"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1025"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1024"
                 mode="M82">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:entryRelationship[@typeCode]"
                 priority="1023"
                 mode="M82">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.309-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASupply): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]"
                 priority="1021"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1020"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1019"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1018"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1017"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1016"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1015"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1014"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1013"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1012"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1011"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1010"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1009"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1008"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1007"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1006"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1005"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1004"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1003"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]"
                 priority="1002"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1001"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]]/hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1000"
                 mode="M82">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M82"/>
   <xsl:template match="@*|node()" priority="-2" mode="M82">
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300Template Messwertkategorie-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Template Messwertkategorie</svrl:text>

	  <!--RULE d19e2680-false-d98890e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1007"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE d19e2684-false-d98959e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE d19e2689-false-d98975e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE d19e2694-false-d98990e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE d19e2696-false-d99004e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE d19e2702-false-d99026e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE d19e2704-false-d99037e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE d19e2706-false-d99048e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M83">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.10-2018-04-18T111300.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TemplateMesswertkategorie): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M83"/>
   <xsl:template match="@*|node()" priority="-2" mode="M83">
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551Dok3 Niere-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 Niere</svrl:text>

	  <!--RULE d19e2735-false-d99108e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1009"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE d19e2739-false-d99202e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']"
                 priority="1008"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.11' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE d19e2744-false-d99218e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1007"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE d19e2749-false-d99234e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1006"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE d19e2754-false-d99249e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1005"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE d19e2757-false-d99263e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE d19e2762-false-d99285e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1003"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE d19e2764-false-d99296e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1002"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1001"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.3' Harnstoff (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1000"
                 mode="M84">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.4' Kreatinin (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.11-2018-04-18T111551.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M84"/>
   <xsl:template match="@*|node()" priority="-2" mode="M84">
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636Leber Pankreas-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Leber Pankreas</svrl:text>

	  <!--RULE d19e2808-false-d99418e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE d19e2812-false-d99503e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12']"
                 priority="1007"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.12')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.12')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.12' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE d19e2817-false-d99519e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE d19e2822-false-d99535e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE d19e2827-false-d99550e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE d19e2830-false-d99564e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Der Elementinhalt MUSS einer von '2.16.840.1.113883.3.1937.99.61.45.11.2 LeberPankreas (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE d19e2835-false-d99586e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE d19e2837-false-d99597e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.12'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1000"
                 mode="M85">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.2-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.2' LeberPankreas (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.12-2018-04-18T111636.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(LeberPankreas): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M85"/>
   <xsl:template match="@*|node()" priority="-2" mode="M85">
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058Messwert: Leber Pankreas-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: Leber Pankreas</svrl:text>

	  <!--RULE d19e2924-false-d99857e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1006"
                 mode="M86">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE d19e2933-false-d99944e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']"
                 priority="1005"
                 mode="M86">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.13')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.13')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.13' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE d19e2938-false-d99960e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1004"
                 mode="M86">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE d19e2943-false-d99976e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1003"
                 mode="M86">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE d19e2949-false-d99991e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1002"
                 mode="M86">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE d19e2951-false-d100005e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1001"
                 mode="M86">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Elementinhalt MUSS einer von '2.16.840.1.113883.3.1937.99.61.45.11.6 Moegliche Messwerte (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE d19e2956-false-d100027e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M86">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-04-19T095058.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M86"/>
   <xsl:template match="@*|node()" priority="-2" mode="M86">
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412Messwert: Leber Pankreas-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: Leber Pankreas</svrl:text>

	  <!--RULE d19e2874-false-d99672e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1006"
                 mode="M87">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or (string-length(@moodCode) &gt; 0 and not(matches(@moodCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or (string-length(@moodCode) &gt; 0 and not(matches(@moodCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Attribute @moodCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE d19e2880-false-d99745e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13']"
                 priority="1005"
                 mode="M87">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.13')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.13')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.13' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE d19e2885-false-d99761e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1004"
                 mode="M87">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE d19e2890-false-d99777e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1003"
                 mode="M87">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE d19e2896-false-d99792e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1002"
                 mode="M87">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE d19e2898-false-d99803e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1001"
                 mode="M87">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE d19e2900-false-d99814e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.13'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M87">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.13-2018-05-04T123412.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertLeberPankreas): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M87"/>
   <xsl:template match="@*|node()" priority="-2" mode="M87">
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001Messwerte: Pankreas Leber-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwerte: Pankreas Leber</svrl:text>

	  <!--RULE d19e3039-false-d100267e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1007"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:value[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:value[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE d19e3048-false-d100361e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']"
                 priority="1006"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.15')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.15')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.15' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE d19e3053-false-d100377e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1005"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE d19e3058-false-d100393e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1004"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE d19e3064-false-d100408e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1003"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE d19e3066-false-d100419e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1002"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE d19e3068-false-d100430e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1001"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE d19e3070-false-d100444e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1000"
                 mode="M88">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-04-23T124001.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Elementinhalt MUSS einer von '2.16.840.1.113883.3.1937.99.61.45.11.6 Moegliche Messwerte (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M88"/>
   <xsl:template match="@*|node()" priority="-2" mode="M88">
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851Messwerte: Pankreas Leber-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwerte: Pankreas Leber</svrl:text>

	  <!--RULE d19e2987-false-d100070e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1007"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or (string-length(@moodCode) &gt; 0 and not(matches(@moodCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or (string-length(@moodCode) &gt; 0 and not(matches(@moodCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Attribute @moodCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE d19e2993-false-d100150e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15']"
                 priority="1006"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.15')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.15')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.15' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE d19e2998-false-d100166e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1005"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE d19e3003-false-d100182e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1004"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE d19e3009-false-d100197e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1003"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE d19e3011-false-d100208e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1002"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE d19e3013-false-d100219e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1001"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE d19e3015-false-d100230e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.15'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M89">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.15-2018-05-04T121851.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertePankreasLeber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M89"/>
   <xsl:template match="@*|node()" priority="-2" mode="M89">
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523Niere (Werte aus Gesamt-ValueSet)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Niere (Werte aus Gesamt-ValueSet)</svrl:text>

	  <!--RULE d19e3524-false-d109423e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1009"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3528-false-d109519e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']"
                 priority="1008"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.21')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.21')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.21' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3533-false-d109535e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']"
                 priority="1007"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.11' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3538-false-d109551e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3543-false-d109567e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3549-false-d109582e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3551-false-d109596e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3556-false-d109618e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE d19e3558-false-d109629e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1000"
                 mode="M90">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.3' Harnstoff (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-04-24T111523.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M90"/>
   <xsl:template match="@*|node()" priority="-2" mode="M90">
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341Niere (Werte aus Gesamt-ValueSet)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Niere (Werte aus Gesamt-ValueSet)</svrl:text>

	  <!--RULE d19e3460-false-d109171e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1009"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3464-false-d109259e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21']"
                 priority="1008"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.21')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.21')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.21' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3469-false-d109275e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']"
                 priority="1007"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.11' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3474-false-d109291e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3479-false-d109307e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3485-false-d109322e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3487-false-d109333e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1003"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3489-false-d109344e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3491-false-d109355e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE d19e3493-false-d109366e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.21'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M91">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.21-2018-05-14T103341.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Niere2): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M91"/>
   <xsl:template match="@*|node()" priority="-2" mode="M91">
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307Dok1 Moegliche Messwerte-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok1 Moegliche Messwerte</svrl:text>

	  <!--RULE d19e3592-false-d109704e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1009"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:statusCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3598-false-d109795e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22']"
                 priority="1008"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.22')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.22')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.22' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3603-false-d109811e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1007"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3608-false-d109827e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1006"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3614-false-d109842e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1005"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3616-false-d109853e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1004"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3618-false-d109864e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1003"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3620-false-d109875e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode"
                 priority="1002"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3622-false-d109886e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:effectiveTime"
                 priority="1001"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE d19e3624-false-d109897e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M92">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.22-2018-04-25T113307.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MoeglicheMesswerte): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M92"/>
   <xsl:template match="@*|node()" priority="-2" mode="M92">
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745Dok1 Messwerte-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok1 Messwerte</svrl:text>

	  <!--RULE d19e3646-false-d109944e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1006"
                 mode="M93">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Element hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.22'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE d19e3650-false-d110015e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']"
                 priority="1005"
                 mode="M93">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.23' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE d19e3655-false-d110031e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1004"
                 mode="M93">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE d19e3660-false-d110046e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1003"
                 mode="M93">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE d19e3662-false-d110057e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M93">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE d19e3665-false-d110068e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M93">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE d19e3667-false-d110079e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:effectiveTime"
                 priority="1000"
                 mode="M93">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{14,14}')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or matches(@value, '^[0-9]{14,14}')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS.DATETIME.MIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS.DATETIME.MIN: null or date precision of time stamp shall be at least YYYYMMDDhhmmss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.23-2018-04-25T121745.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS.DATETIME.MIN, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M93"/>
   <xsl:template match="@*|node()" priority="-2" mode="M93">
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014Dok2 Messwerte-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok2 Messwerte</svrl:text>

	  <!--RULE d19e3775-false-d112881e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1007"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Element hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE d19e3779-false-d112967e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25']"
                 priority="1006"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.25')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.25')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.25' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE d19e3784-false-d112983e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']"
                 priority="1005"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.23' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE d19e3789-false-d112999e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1004"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE d19e3794-false-d113014e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1003"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE d19e3797-false-d113025e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE d19e3799-false-d113036e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE d19e3801-false-d113047e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.25'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:effectiveTime"
                 priority="1000"
                 mode="M94">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{14,14}')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or matches(@value, '^[0-9]{14,14}')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS.DATETIME.MIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS.DATETIME.MIN: null or date precision of time stamp shall be at least YYYYMMDDhhmmss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.25-2018-04-27T091014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAuswahl): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS.DATETIME.MIN, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M94"/>
   <xsl:template match="@*|node()" priority="-2" mode="M94">
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139Dok2 Messwertauswahl-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok2 Messwertauswahl</svrl:text>

	  <!--RULE d19e3827-false-d113122e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1005"
                 mode="M95">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>

	  <!--RULE d19e3836-false-d113226e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']"
                 priority="1004"
                 mode="M95">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.26')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.26')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.26' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>

	  <!--RULE d19e3841-false-d113242e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1003"
                 mode="M95">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>

	  <!--RULE d19e3846-false-d113258e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1002"
                 mode="M95">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>

	  <!--RULE d19e3852-false-d113276e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1001"
                 mode="M95">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16226 ObservationType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>

	  <!--RULE d19e3857-false-d113301e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1000"
                 mode="M95">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.26-2018-04-27T103139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M95"/>
   <xsl:template match="@*|node()" priority="-2" mode="M95">
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101Dok3 Messwerte-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 Messwerte</svrl:text>

	  <!--RULE d19e3970-false-d12253489e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1007"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

	  <!--RULE d19e3974-false-d12254316e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']"
                 priority="1006"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.28')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.28')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.28' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

	  <!--RULE d19e3979-false-d12254332e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']"
                 priority="1005"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.23' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

	  <!--RULE d19e3984-false-d12254348e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1004"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

	  <!--RULE d19e3989-false-d12254363e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1003"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

	  <!--RULE d19e3992-false-d12254374e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

	  <!--RULE d19e3994-false-d12254385e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

	  <!--RULE d19e3996-false-d12254396e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:effectiveTime"
                 priority="1000"
                 mode="M96">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{14,14}')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or matches(@value, '^[0-9]{14,14}')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS.DATETIME.MIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS.DATETIME.MIN: null or date precision of time stamp shall be at least YYYYMMDDhhmmss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.28-2018-04-27T155101.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte3): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS.DATETIME.MIN, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M96"/>
   <xsl:template match="@*|node()" priority="-2" mode="M96">
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941Dok3 Pankreas Leber-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 Pankreas Leber</svrl:text>

	  <!--RULE d19e4035-false-d12255275e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1006"
                 mode="M97">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Element hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

	  <!--RULE d19e4039-false-d12255389e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29']"
                 priority="1005"
                 mode="M97">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.29')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.29')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.29' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

	  <!--RULE d19e4044-false-d12255405e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']"
                 priority="1004"
                 mode="M97">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.23' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

	  <!--RULE d19e4049-false-d12255421e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1003"
                 mode="M97">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

	  <!--RULE d19e4054-false-d12255436e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1002"
                 mode="M97">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

	  <!--RULE d19e4057-false-d12255447e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1001"
                 mode="M97">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

	  <!--RULE d19e4059-false-d12255458e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.29'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1000"
                 mode="M97">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.29-2018-04-27T162941.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(pankreasleber): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M97"/>
   <xsl:template match="@*|node()" priority="-2" mode="M97">
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525Messwert: ASAT-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: ASAT</svrl:text>

	  <!--RULE d19e4137-false-d12255563e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4146-false-d12255664e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30']"
                 priority="1007"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.30')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.30')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.30' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4151-false-d12255680e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4156-false-d12255696e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4162-false-d12255711e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4164-false-d12255722e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1003"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4166-false-d12255733e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4168-false-d12255747e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

	  <!--RULE d19e4173-false-d12255769e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.30'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M98">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.30-2018-04-27T164525.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertASAT): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M98"/>
   <xsl:template match="@*|node()" priority="-2" mode="M98">
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648Messwert: ALAT-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: ALAT</svrl:text>

	  <!--RULE d19e4197-false-d12255812e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4206-false-d12255913e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31']"
                 priority="1007"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.31')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.31')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.31' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4211-false-d12255929e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4216-false-d12255945e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4222-false-d12255960e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4224-false-d12255971e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1003"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4226-false-d12255982e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4228-false-d12255996e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

	  <!--RULE d19e4233-false-d12256018e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.31'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M99">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.31-2018-04-27T164648.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertALAT): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M99"/>
   <xsl:template match="@*|node()" priority="-2" mode="M99">
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837Messwert: Alkalische Phosphatase-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: Alkalische Phosphatase</svrl:text>

	  <!--RULE d19e4257-false-d12256061e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4266-false-d12256165e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32']"
                 priority="1007"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.32')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.32')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.32' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4271-false-d12256181e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4276-false-d12256197e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4282-false-d12256212e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4284-false-d12256226e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16226 ObservationType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4289-false-d12256248e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4291-false-d12256262e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE d19e4296-false-d12256284e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.32'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.32-2018-04-27T164837.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertAlkalischePhosphatase): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M100"/>
   <xsl:template match="@*|node()" priority="-2" mode="M100">
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956Messwert: Gamma Glutamyl-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: Gamma Glutamyl</svrl:text>

	  <!--RULE d19e4320-false-d12256327e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4329-false-d12256431e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33']"
                 priority="1007"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.33')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.33')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.33' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4334-false-d12256447e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4339-false-d12256463e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4345-false-d12256478e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4347-false-d12256492e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16226 ObservationType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4352-false-d12256514e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4354-false-d12256528e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

	  <!--RULE d19e4359-false-d12256550e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.33'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.33-2018-04-27T164956.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertGammaGlutamyl): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M101"/>
   <xsl:template match="@*|node()" priority="-2" mode="M101">
      <xsl:apply-templates select="*" mode="M101"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952Dok3 kleines Blutbild-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 kleines Blutbild</svrl:text>

	  <!--RULE d19e4407-false-d12256630e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1012"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE d19e4411-false-d12256748e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35']"
                 priority="1011"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.35')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.35')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.35' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE d19e4416-false-d12256764e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1010"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE d19e4421-false-d12256780e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1009"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE d19e4426-false-d12256795e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1008"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE d19e4429-false-d12256806e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1007"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE d19e4431-false-d12256817e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1006"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE d19e4433-false-d12256828e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1005"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1004"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1003"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1002"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1001"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.35'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1000"
                 mode="M102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.35-2018-05-02T174952.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3KleinesBlutbild): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M102"/>
   <xsl:template match="@*|node()" priority="-2" mode="M102">
      <xsl:apply-templates select="*" mode="M102"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135Dok3 Sepsis-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 Sepsis</svrl:text>

	  <!--RULE d19e4493-false-d12257001e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4497-false-d12257078e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36']"
                 priority="1007"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.36')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.36')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.36' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4502-false-d12257094e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4507-false-d12257110e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4512-false-d12257125e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4515-false-d12257136e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1003"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4517-false-d12257147e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4519-false-d12257158e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

	  <!--RULE d19e4521-false-d12257169e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.36'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.36-2018-05-02T175135.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sepsis): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M103"/>
   <xsl:template match="@*|node()" priority="-2" mode="M103">
      <xsl:apply-templates select="*" mode="M103"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241Dok3 Sonstiges-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 Sonstiges</svrl:text>

	  <!--RULE d19e4548-false-d12258230e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1009"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE d19e4552-false-d12258650e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37']"
                 priority="1008"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.37')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.37')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.37' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE d19e4557-false-d12258666e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1007"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE d19e4562-false-d12258682e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1006"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE d19e4567-false-d12258697e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1005"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE d19e4570-false-d12258711e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE d19e4575-false-d12258733e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1003"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE d19e4577-false-d12258744e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1002"
                 mode="M104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.37'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1001"
                 mode="M104">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.37-2018-05-02T175241.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3Sonstiges): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M104"/>
   <xsl:template match="@*|node()" priority="-2" mode="M104">
      <xsl:apply-templates select="*" mode="M104"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439Dok3 unbekannt-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 unbekannt</svrl:text>

	  <!--RULE d19e4611-false-d12263270e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1009"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4615-false-d12263351e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38']"
                 priority="1008"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.38')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.38')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.38' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4620-false-d12263367e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1007"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4625-false-d12263383e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1006"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4630-false-d12263398e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1005"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4633-false-d12263409e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1004"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4635-false-d12263420e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1003"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4637-false-d12263431e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1002"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4639-false-d12263442e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1001"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

	  <!--RULE d19e4646-false-d12263460e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.38'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.38-2018-05-02T175439.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3unbekannt): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M105"/>
   <xsl:template match="@*|node()" priority="-2" mode="M105">
      <xsl:apply-templates select="*" mode="M105"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811Dok3 kleines Blutbild ?-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok3 kleines Blutbild ?</svrl:text>

	  <!--RULE d19e4675-false-d12295155e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1069"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE d19e4679-false-d12305892e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39']"
                 priority="1068"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.39')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.39')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.39' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE d19e4684-false-d12305908e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1067"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE d19e4689-false-d12305924e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1066"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE d19e4694-false-d12305939e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1065"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE d19e4697-false-d12305950e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1064"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE d19e4699-false-d12305961e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1063"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE d19e4701-false-d12305972e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1062"
                 mode="M106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1061"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1059"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1057"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1055"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1053"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1051"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1049"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1047"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1045"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1043"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1041"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1039"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1037"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1035"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1033"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1031"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1029"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1027"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1025"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1023"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1021"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1019"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1017"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1015"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1013"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1011"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1009"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1007"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1005"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1003"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.39'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1001"
                 mode="M106">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.39-2018-05-02T175811.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok3kleinesBlutbild2): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M106"/>
   <xsl:template match="@*|node()" priority="-2" mode="M106">
      <xsl:apply-templates select="*" mode="M106"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423Dok4 Messwerte-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok4 Messwerte</svrl:text>

	  <!--RULE d19e5185-false-d12450240e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1007"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:entry[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:entry[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Element hl7:entry[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

	  <!--RULE d19e5189-false-d12450326e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41']"
                 priority="1006"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.41')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.41')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.41' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

	  <!--RULE d19e5194-false-d12450342e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']"
                 priority="1005"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.23' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

	  <!--RULE d19e5199-false-d12450358e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1004"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

	  <!--RULE d19e5204-false-d12450376e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

	  <!--RULE d19e5210-false-d12450398e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

	  <!--RULE d19e5212-false-d12450409e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

	  <!--RULE d19e5214-false-d12450420e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.41'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:effectiveTime"
                 priority="1000"
                 mode="M107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{14,14}')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or matches(@value, '^[0-9]{14,14}')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS.DATETIME.MIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS.DATETIME.MIN: null or date precision of time stamp shall be at least YYYYMMDDhhmmss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.41-2018-05-03T102423.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Messwerte4): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS.DATETIME.MIN, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M107"/>
   <xsl:template match="@*|node()" priority="-2" mode="M107">
      <xsl:apply-templates select="*" mode="M107"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627Dok4 Messwerte-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok4 Messwerte</svrl:text>

	  <!--RULE d19e5242-false-d12450482e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value[not(@nullFlavor)]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:value[not(@nullFlavor)]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:value[not(@nullFlavor)] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value[not(@nullFlavor)]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:value[not(@nullFlavor)]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Element hl7:value[not(@nullFlavor)] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5251-false-d12450589e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42']"
                 priority="1007"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.42')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.42')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.42' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5256-false-d12450605e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26']"
                 priority="1006"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.26')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.26')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.26' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5261-false-d12450621e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1005"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5267-false-d12450637e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1004"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5272-false-d12450655e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Elementinhalt MUSS einer von '2.16.840.1.113883.3.1937.99.61.45.11.6 Moegliche Messwerte (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5276-false-d12450681e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.6-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]/hl7:originalText"
                 priority="1002"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5279-false-d12450695e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

	  <!--RULE d19e5284-false-d12450717e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.42'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.26'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value[not(@nullFlavor)]"
                 priority="1000"
                 mode="M108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.42-2018-05-03T102627.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAuswahl4): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M108"/>
   <xsl:template match="@*|node()" priority="-2" mode="M108">
      <xsl:apply-templates select="*" mode="M108"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335Dok4 Messwert Organizer-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Dok4 Messwert Organizer</svrl:text>

	  <!--RULE d19e5310-false-d12450764e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]"
                 priority="1006"
                 mode="M109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19598-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19598-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19598' x_ActClassDocumentEntryOrganizer (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.305']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.305'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>

	  <!--RULE d19e5319-false-d12450857e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43']"
                 priority="1005"
                 mode="M109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.43')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.43')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.43' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>

	  <!--RULE d19e5324-false-d12450873e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.305']"
                 priority="1004"
                 mode="M109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.305')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.305')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Der Wert von root MUSS '2.16.840.1.113883.10.12.305' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>

	  <!--RULE d19e5329-false-d12450888e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:id"
                 priority="1003"
                 mode="M109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>

	  <!--RULE d19e5332-false-d12450899e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:code"
                 priority="1002"
                 mode="M109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>

	  <!--RULE d19e5334-false-d12450913e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>

	  <!--RULE d19e5339-false-d12450935e0-->
   <xsl:template match="*[hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]]/hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.43'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]/hl7:effectiveTime"
                 priority="1000"
                 mode="M109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.43-2018-05-03T103335.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(Dok4MesswertOrganizer): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M109"/>
   <xsl:template match="@*|node()" priority="-2" mode="M109">
      <xsl:apply-templates select="*" mode="M109"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053ASIC Messwerte-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Messwerte</svrl:text>

	  <!--RULE d19e5603-false-d13218041e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5607-false-d13218203e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46']"
                 priority="1007"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.46')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.46')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.46' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5612-false-d13218219e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28']"
                 priority="1006"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.28')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.28')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.28' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5617-false-d13218235e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23']"
                 priority="1005"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.23')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.23' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5622-false-d13218251e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1004"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5628-false-d13218266e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1003"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5630-false-d13218277e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5632-false-d13218288e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

	  <!--RULE d19e5634-false-d13218299e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.46'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.28'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.23'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:effectiveTime"
                 priority="1000"
                 mode="M110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{14,14}')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or matches(@value, '^[0-9]{14,14}')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS.DATETIME.MIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS.DATETIME.MIN: null or date precision of time stamp shall be at least YYYYMMDDhhmmss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(*)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.46-2018-05-08T162053.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMesswerte): <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> with datatype TS.DATETIME.MIN, SHOULD NOT have child elements.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M110"/>
   <xsl:template match="@*|node()" priority="-2" mode="M110">
      <xsl:apply-templates select="*" mode="M110"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226ASIC Beatmungsparameter-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Beatmungsparameter</svrl:text>

	  <!--RULE d19e5671-false-d13218480e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1010"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5675-false-d13218585e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47']"
                 priority="1009"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.47')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.47')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.47' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5680-false-d13218601e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']"
                 priority="1008"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.11' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5685-false-d13218617e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1007"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5690-false-d13218633e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1006"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5696-false-d13218648e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1005"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5698-false-d13218662e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5703-false-d13218684e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1003"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE d19e5705-false-d13218695e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1002"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1001"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.3' Harnstoff (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.47'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1000"
                 mode="M111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.4' Kreatinin (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.47-2018-05-08T162226.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBeatmungsparameter): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M111"/>
   <xsl:template match="@*|node()" priority="-2" mode="M111">
      <xsl:apply-templates select="*" mode="M111"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614ASIC Blutgasanalyse-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Blutgasanalyse</svrl:text>

	  <!--RULE d19e5751-false-d13218828e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1010"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5755-false-d13218933e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48']"
                 priority="1009"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.48')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.48')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.48' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5760-false-d13218949e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']"
                 priority="1008"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.11' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5765-false-d13218965e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1007"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5770-false-d13218981e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1006"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5776-false-d13218996e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1005"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5778-false-d13219010e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5783-false-d13219032e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1003"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE d19e5785-false-d13219043e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1002"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1001"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.3' Harnstoff (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.48'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1000"
                 mode="M112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.4' Kreatinin (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.48-2018-05-08T162614.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICBlutgasanalyse): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M112"/>
   <xsl:template match="@*|node()" priority="-2" mode="M112">
      <xsl:apply-templates select="*" mode="M112"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657ASIC Sauerstoffsättigung-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Sauerstoffsättigung</svrl:text>

	  <!--RULE d19e5831-false-d13219176e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1010"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5835-false-d13219281e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49']"
                 priority="1009"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.49')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.49')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.49' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5840-false-d13219297e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11']"
                 priority="1008"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.11')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.11' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5845-false-d13219313e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1007"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5850-false-d13219329e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1006"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5856-false-d13219344e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1005"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5858-false-d13219358e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5863-false-d13219380e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1003"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE d19e5865-false-d13219391e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1002"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1001"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.3-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.3' Harnstoff (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.49'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.11'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]"
                 priority="1000"
                 mode="M113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.3.1937.99.61.45.11.4-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.3.1937.99.61.45.11.4' Kreatinin (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextConductionInd) = ('true') or not(@contextConductionInd)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.49-2018-05-08T162657.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICSauerstoffsaettigung): Der Wert von contextConductionInd MUSS 'true' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M113"/>
   <xsl:template match="@*|node()" priority="-2" mode="M113">
      <xsl:apply-templates select="*" mode="M113"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427CDA Section t-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Section t</svrl:text>

	  <!--RULE d19e5907-false-d13220518e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]"
                 priority="1007"
                 mode="M114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[not(@root = '2.16.840.1.113883.10.12.201')]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[not(@root = '2.16.840.1.113883.10.12.201')]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Element hl7:templateId[not(@root = '2.16.840.1.113883.10.12.201')] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[not(@root = '2.16.840.1.113883.10.12.201')]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[not(@root = '2.16.840.1.113883.10.12.201')]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Element hl7:templateId[not(@root = '2.16.840.1.113883.10.12.201')] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>

	  <!--RULE d19e5911-false-d13220919e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']"
                 priority="1006"
                 mode="M114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.5')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.5')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.5' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>

	  <!--RULE d19e5916-false-d13220934e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]/hl7:templateId[not(@root = '2.16.840.1.113883.10.12.201')]"
                 priority="1005"
                 mode="M114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@root)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Attribut @root DARF NICHT vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>

	  <!--RULE d19e5921-false-d13220955e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>

	  <!--RULE d19e5926-false-d13220977e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]/hl7:title"
                 priority="1003"
                 mode="M114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>

	  <!--RULE d19e5929-false-d13220988e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]/hl7:text"
                 priority="1002"
                 mode="M114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.5']]/hl7:entry[@typeCode]"
                 priority="1001"
                 mode="M114">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.5-2018-04-16T114427.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASectionT): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M114"/>
   <xsl:template match="@*|node()" priority="-2" mode="M114">
      <xsl:apply-templates select="*" mode="M114"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904ASIC weitere Vitaldaten-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC weitere Vitaldaten</svrl:text>

	  <!--RULE d19e5964-false-d13226533e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1009"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE d19e5968-false-d13226953e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50']"
                 priority="1008"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.50')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.50')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.50' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE d19e5973-false-d13226969e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1007"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE d19e5978-false-d13226985e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1006"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE d19e5983-false-d13227000e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1005"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE d19e5986-false-d13227014e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1004"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE d19e5991-false-d13227036e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1003"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE d19e5993-false-d13227047e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1002"
                 mode="M115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.50'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1001"
                 mode="M115">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19446-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19446' x_ActRelationshipEntry (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.50-2018-05-08T162904.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICweitereVitaldaten): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M115"/>
   <xsl:template match="@*|node()" priority="-2" mode="M115">
      <xsl:apply-templates select="*" mode="M115"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443ASIC Einschlusskriterien-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Einschlusskriterien</svrl:text>

	  <!--RULE d19e6027-false-d13231572e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6031-false-d13231652e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51']"
                 priority="1007"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.51')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.51')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.51' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6036-false-d13231668e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6041-false-d13231684e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6046-false-d13231699e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6049-false-d13231713e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6054-false-d13231735e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6056-false-d13231746e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

	  <!--RULE d19e6058-false-d13231757e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.51'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.51-2018-05-08T164443.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICEinschlusskriterien): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M116"/>
   <xsl:template match="@*|node()" priority="-2" mode="M116">
      <xsl:apply-templates select="*" mode="M116"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612ASIC Ausschlusskriterien-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Ausschlusskriterien</svrl:text>

	  <!--RULE d19e6087-false-d13231802e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6091-false-d13231882e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52']"
                 priority="1007"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.52')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.52')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.52' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6096-false-d13231898e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6101-false-d13231914e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6106-false-d13231929e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6109-false-d13231943e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6114-false-d13231965e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6116-false-d13231976e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

	  <!--RULE d19e6118-false-d13231987e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.52'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.52-2018-05-08T164612.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICAusschlusskriterien): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M117"/>
   <xsl:template match="@*|node()" priority="-2" mode="M117">
      <xsl:apply-templates select="*" mode="M117"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717ASIC radiologische Befunde-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC radiologische Befunde</svrl:text>

	  <!--RULE d19e6147-false-d13232032e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6151-false-d13232112e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53']"
                 priority="1007"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.53')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.53')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.53' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6156-false-d13232128e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6161-false-d13232144e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6166-false-d13232159e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6169-false-d13232173e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6174-false-d13232195e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6176-false-d13232206e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

	  <!--RULE d19e6178-false-d13232217e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.53'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.53-2018-05-08T164717.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICradiologischeBefunde): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M118"/>
   <xsl:template match="@*|node()" priority="-2" mode="M118">
      <xsl:apply-templates select="*" mode="M118"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801ASIC Lungenoedem-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Lungenoedem</svrl:text>

	  <!--RULE d19e6207-false-d13232262e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6211-false-d13232342e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54']"
                 priority="1007"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.54')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.54')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.54' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6216-false-d13232358e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6221-false-d13232374e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6226-false-d13232389e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6229-false-d13232403e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6234-false-d13232425e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6236-false-d13232436e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

	  <!--RULE d19e6238-false-d13232447e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.54'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.54-2018-05-08T164801.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICLungenoedem): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M119"/>
   <xsl:template match="@*|node()" priority="-2" mode="M119">
      <xsl:apply-templates select="*" mode="M119"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919ASIC adjunktiv/supportive Maßnahmen-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC adjunktiv/supportive Maßnahmen</svrl:text>

	  <!--RULE d19e6267-false-d13232492e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6271-false-d13232572e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']"
                 priority="1007"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.55')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.55')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.55' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6276-false-d13232588e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6281-false-d13232604e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6286-false-d13232619e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6289-false-d13232633e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6294-false-d13232655e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6296-false-d13232666e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

	  <!--RULE d19e6298-false-d13232677e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.55-2018-05-08T164919.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M120"/>
   <xsl:template match="@*|node()" priority="-2" mode="M120">
      <xsl:apply-templates select="*" mode="M120"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137ASIC ECMO-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC ECMO</svrl:text>

	  <!--RULE d19e6327-false-d13232722e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6331-false-d13232802e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56']"
                 priority="1007"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.56')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.56')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.56' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6336-false-d13232818e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6341-false-d13232834e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6346-false-d13232849e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6349-false-d13232863e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6354-false-d13232885e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6356-false-d13232896e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

	  <!--RULE d19e6358-false-d13232907e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.56'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.56-2018-05-08T165137.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICECMO): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M121"/>
   <xsl:template match="@*|node()" priority="-2" mode="M121">
      <xsl:apply-templates select="*" mode="M121"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214ASIC Medikamente-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Medikamente</svrl:text>

	  <!--RULE d19e6387-false-d13232952e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6391-false-d13233032e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57']"
                 priority="1007"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.57')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.57')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.57' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6396-false-d13233048e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6401-false-d13233064e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6406-false-d13233079e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6409-false-d13233093e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6414-false-d13233115e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6416-false-d13233126e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

	  <!--RULE d19e6418-false-d13233137e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.57'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.57-2018-05-08T165214.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICMedikamente): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M122"/>
   <xsl:template match="@*|node()" priority="-2" mode="M122">
      <xsl:apply-templates select="*" mode="M122"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326ASIC Patienten-Bewegungsdaten-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Patienten-Bewegungsdaten</svrl:text>

	  <!--RULE d19e6447-false-d13233182e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6451-false-d13233262e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58']"
                 priority="1007"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.58')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.58')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.58' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6456-false-d13233278e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6461-false-d13233294e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6466-false-d13233309e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6469-false-d13233323e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6474-false-d13233345e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6476-false-d13233356e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

	  <!--RULE d19e6478-false-d13233367e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.58'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.58-2018-05-08T165326.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICPatientenBewegungsdaten): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M123"/>
   <xsl:template match="@*|node()" priority="-2" mode="M123">
      <xsl:apply-templates select="*" mode="M123"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413ASIC Outcome Parameter-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Outcome Parameter</svrl:text>

	  <!--RULE d19e6507-false-d13233412e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6511-false-d13233492e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59']"
                 priority="1007"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.59')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.59')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.59' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6516-false-d13233508e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6521-false-d13233524e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6526-false-d13233539e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6529-false-d13233553e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10871-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10871 DocumentSectionType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6534-false-d13233575e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6536-false-d13233586e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

	  <!--RULE d19e6538-false-d13233597e0-->
   <xsl:template match="*[hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.59'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.59-2018-05-08T165413.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICOutcomeParameter): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M124"/>
   <xsl:template match="@*|node()" priority="-2" mode="M124">
      <xsl:apply-templates select="*" mode="M124"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351CDA Observation t-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CDA Observation t</svrl:text>

	  <!--RULE d19e6565-false-d13234975e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1096"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:derivationExpr) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:derivationExpr) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:derivationExpr kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:repeatNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:repeatNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:repeatNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:languageCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:languageCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:languageCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:subject[hl7:relatedSubject[@classCode]]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:subject[hl7:relatedSubject[@classCode]] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6576-false-d13235617e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6']"
                 priority="1095"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.6')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.6')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.6' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6581-false-d13235633e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1094"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6587-false-d13235648e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1093"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6589-false-d13235662e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1092"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16226 ObservationType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6594-false-d13235684e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:derivationExpr"
                 priority="1091"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6596-false-d13235695e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1090"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6598-false-d13235709e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1089"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6603-false-d13235731e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:effectiveTime"
                 priority="1088"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TS: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/> "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_TS: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_TS: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_TS: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_TS: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_TS: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_TS: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_TS: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value = hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value = hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-IVL_TS: low/@value must not be equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_TS: low/@value must be before high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_TS: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_TS: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:low/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/low "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:center/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/center "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theTS" select="hl7:high/@value"/>
      <xsl:variable name="theBC" select="if (starts-with($theTS,'-')) then '-' else ()"/>
      <xsl:variable name="theTZ" select="replace($theTS,'-?[^+-]+([+-].*)?$','$1')"/>
      <xsl:variable name="theTZh"
                    select="if (string-length($theTZ)&gt;0) then substring($theTZ,1,3) else ()"/>
      <xsl:variable name="theTZm"
                    select="if (string-length($theTZ)&gt;3) then substring($theTZ,4) else ()"/>
      <xsl:variable name="theBaseTS" select="replace($theTS,'^-?([^+-]+)([+-].*)?','$1')"/>
      <xsl:variable name="theCentury"
                    select="if (substring($theBaseTS,1,2) castable as xs:integer) then substring($theBaseTS,1,2) else ()"/>
      <xsl:variable name="theYear"
                    select="if (substring($theBaseTS,3,2) castable as xs:integer) then substring($theBaseTS,3,2) else ()"/>
      <xsl:variable name="theMonth"
                    select="if (substring($theBaseTS,5,2) castable as xs:integer) then substring($theBaseTS,5,2) else ()"/>
      <xsl:variable name="theDay"
                    select="if (substring($theBaseTS,7,2) castable as xs:integer) then substring($theBaseTS,7,2) else ()"/>
      <xsl:variable name="theHour"
                    select="if (substring($theBaseTS,9,2) castable as xs:integer) then substring($theBaseTS,9,2) else ()"/>
      <xsl:variable name="theMinute"
                    select="if (substring($theBaseTS,11,2) castable as xs:integer) then substring($theBaseTS,11,2) else ()"/>
      <xsl:variable name="theSecond"
                    select="if (substring($theBaseTS,13,2) castable as xs:integer) then substring($theBaseTS,13,2) else ()"/>
      <xsl:variable name="theSubSecond"
                    select="if (substring($theBaseTS,16) castable as xs:integer) then substring($theBaseTS,15) else ()"/>
      <xsl:variable name="cCentury"
                    select="if (empty($theCentury)) then '00' else $theCentury"/>
      <xsl:variable name="cYear" select="if (empty($theYear)) then '00' else $theYear"/>
      <xsl:variable name="cMonth" select="if (empty($theMonth)) then '01' else $theMonth"/>
      <xsl:variable name="cDay" select="if (empty($theDay)) then '01' else $theDay"/>
      <xsl:variable name="cHour" select="if (empty($theHour)) then '00' else $theHour"/>
      <xsl:variable name="cMinute"
                    select="if (empty($theMinute)) then '00' else $theMinute"/>
      <xsl:variable name="cSecond"
                    select="if (empty($theSecond)) then '00' else $theSecond"/>
      <xsl:variable name="cTZ" select="string-join(($theTZh,$theTZm),':')"/>
      <xsl:variable name="theTSString"
                    select="string-join(($theBC,$theCentury,$theYear,$theMonth,$theDay,$theHour,$theMinute,$theSecond,$theSubSecond,$theTZ),'')"/>
      <xsl:variable name="theDateTime"
                    select="concat($theBC,$cCentury,$cYear,'-',$cMonth,'-',$cDay,'T',$cHour,':',$cMinute,':',$cSecond,$theSubSecond,$cTZ)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($theTS) or ($theTS=$theTSString and $theDateTime castable as xs:dateTime)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_TS</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-IVL_TS: <xsl:text/>
                  <xsl:value-of select="local-name()"/>
                  <xsl:text/>/high "<xsl:text/>
                  <xsl:value-of select="$theTS"/>
                  <xsl:text/>" is not a valid timestamp.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_TS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6606-false-d13235745e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:priorityCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1087"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16866-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16866 ActPriority (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6611-false-d13235767e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:repeatNumber"
                 priority="1086"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @operator) or @operator = 'I'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @operator) or @operator = 'I'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_SXCM_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-SXCM_INT: not operator if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(descendant-or-self::*[@nullFlavor and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-IVL_INT: null violation. Cannot have @nullFlavor and @value or other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and hl7:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@value and hl7:*)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-IVL_INT: co-occurence violation. Cannot have @value and other child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value and (hl7:low|hl7:center|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-2-IVL_INT: co-occurence violation. Cannot have @value and child elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:center and (hl7:low|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:center and (hl7:low|hl7:high|hl7:width))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-3-IVL_INT: co-occurence violation. Cannot have center and other elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width and hl7:low and hl7:high)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width and hl7:low and hl7:high)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-4-IVL_INT: co-occurence violation. Cannot have width and have both low and high elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:*[@updateMode])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:*[@updateMode])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-IVL_INT: no updateMode on IVL attributes</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width[@unit][not(@value)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width[@unit][not(@value)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQR: width element: no unit without value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:width/hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-PQR: width element: no translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low/@value and hl7:high/@value) or hl7:low/number(@value) &lt;= hl7:high/number(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-IVL_INT: low/@value must be lower than or equal to high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:low[@nullFlavor='PINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:low[@nullFlavor='PINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-1-IVL_INT: low must be lower than or equal to high. Found low boundary PINF (Positive Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:high[@nullFlavor='NINF'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:high[@nullFlavor='NINF'])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_IVL_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-2-IVL_INT: low must be lower than or equal to high. Found high boundary NINF (Negative Infinity)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='IVL_INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:IVL_INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6613-false-d13235781e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:languageCode"
                 priority="1085"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6618-false-d13235796e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1084"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6620-false-d13235807e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1083"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.78 ObservationInterpretation (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6625-false-d13235832e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:methodCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1082"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.14079-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.14079 ObservationMethod (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6631-false-d13235855e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:targetSiteCode[@codeSystem = '2.16.840.1.113883.5.1052' or @nullFlavor]"
                 priority="1081"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.1052')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.1052'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]"
                 priority="1080"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SBJ') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SBJ') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von typeCode MUSS 'SBJ' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedSubject[@classCode]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedSubject[@classCode]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:relatedSubject[@classCode] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1079"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]"
                 priority="1078"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19368-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19368' x_DocumentSubject (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:subject) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:subject) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:subject kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1077"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject"
                 priority="1076"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:birthTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:birthTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Element hl7:birthTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:subject[hl7:relatedSubject[@classCode]]/hl7:relatedSubject[@classCode]/hl7:subject/hl7:administrativeGenderCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1075"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.1-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.320-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASubjectBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.1 AdministrativeGender (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]"
                 priority="1074"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('SPC') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('SPC') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von typeCode MUSS 'SPC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole"
                 priority="1073"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('SPEC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('SPEC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'SPEC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:specimenPlayingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:specimenPlayingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:specimenPlayingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity"
                 priority="1072"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:specimen[hl7:specimenRole]/hl7:specimenRole/hl7:specimenPlayingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1071"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.322-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDASpecimen): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]"
                 priority="1070"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von typeCode MUSS 'PRF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:modeCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1069"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16543-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16543 ParticipationMode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity"
                 priority="1068"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.323-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerformerBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:id"
                 priority="1067"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1066"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:addr"
                 priority="1065"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (count(*)&gt;0 and not(text()[string-length(normalize-space())&gt;0])) or (count(*)=0 and text()[string-length(normalize-space())&gt;0])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-AD: address shall be null or text only or element only (no mixed content)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-AD: no useablePeriod if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:useablePeriod][@updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-AD: updateMode shall not be used on address elements</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week), mo (month) or a (year) are allowed</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="*[not(@nullFlavor or self::hl7:useablePeriod)][normalize-space(.)='']">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-AD: empty address particles should not be present.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="value" select="string-join((.//@use|.//text()),'')"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-AD: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[string-join((.//@use|.//text()),'')=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[string-join((.//@use|.//text()),'')=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_AD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-AD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:performer[hl7:assignedEntity]/hl7:assignedEntity/hl7:telecom"
                 priority="1064"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@nullFlavor or @value">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-URL: elements of type URL SHALL have a @value attribute.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @value=iri-to-uri(@value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
                  <xsl:value-of select="iri-to-uri(@value)"/>
                  <xsl:text/>'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="use" select="@use"/>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-URL: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@use=$use][@value=$value])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@use=$use][@value=$value])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_URL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-URL: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:useablePeriod)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:useablePeriod)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_TEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-TEL: not null and useablePeriod</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]"
                 priority="1063"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('AUT') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('AUT') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von typeCode MUSS 'AUT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedAuthor) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:functionCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1062"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor"
                 priority="1061"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedPerson | hl7:assignedAuthoringDevice)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Auswahl (hl7:assignedPerson  oder  hl7:assignedAuthoringDevice) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1060"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.318-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1059"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice"
                 priority="1058"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:assignedAuthoringDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1057"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1056"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1055"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1054"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1053"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:author[hl7:assignedAuthor]/hl7:assignedAuthor/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1052"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant"
                 priority="1051"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('INF') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('INF') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von typeCode MUSS 'INF' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity | hl7:relatedEntity[@classCode])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.319-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAinformantBody): Auswahl (hl7:assignedEntity  oder  hl7:relatedEntity[@classCode]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity"
                 priority="1050"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ASSIGNED') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ASSIGNED') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Wert von classCode MUSS 'ASSIGNED' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:id ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:assignedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:assignedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:representedOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:representedOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1049"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.153-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAAssignedEntity): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1048"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1047"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:asOrganizationPartOf) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:asOrganizationPartOf) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:asOrganizationPartOf kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf"
                 priority="1046"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PART') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PART') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'PART' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:wholeOrganization) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:wholeOrganization) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:wholeOrganization kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1045"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1044"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15999-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15999 RoleStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:assignedEntity/hl7:representedOrganization/hl7:asOrganizationPartOf/hl7:wholeOrganization"
                 priority="1043"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ORG') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ORG') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von classCode MUSS 'ORG' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:standardIndustryClassCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:standardIndustryClassCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.151-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAOrganization): Element hl7:standardIndustryClassCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]"
                 priority="1042"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@classCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@classCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Attribut @classCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@classCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@classCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19316-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Wert von classCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19316' RoleClassMutualRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:effectiveTime) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:effectiveTime) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:effectiveTime kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:relatedPerson) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:relatedPerson) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Element hl7:relatedPerson kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:code[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1041"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.19563-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.316-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDARelatedEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.19563 PersonalRelationshipRoleType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:informant/hl7:relatedEntity[@classCode]/hl7:relatedPerson"
                 priority="1040"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PSN') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PSN') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von classCode MUSS 'PSN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.152-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPerson): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]"
                 priority="1039"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.10901-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.10901' ParticipationType (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@contextControlCode) = ('OP') or not(@contextControlCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@contextControlCode) = ('OP') or not(@contextControlCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von contextControlCode MUSS 'OP' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@contextControlCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:time) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:time) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:time kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:participantRole) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:participantRole) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:participantRole kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:awarenessCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1038"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10310-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10310 TargetAwareness (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole"
                 priority="1037"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ROL') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ROL') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ROL' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:playingDevice | hl7:playingEntity)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Auswahl (hl7:playingDevice  oder  hl7:playingEntity) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:scopingEntity) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:scopingEntity) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:scopingEntity kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:code[@codeSystem = '2.16.840.1.113883.5.111' or @nullFlavor]"
                 priority="1036"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice"
                 priority="1035"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DEV') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DEV') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von classCode MUSS 'DEV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:manufacturerModelName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:manufacturerModelName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:manufacturerModelName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:softwareName) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:softwareName) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Element hl7:softwareName kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingDevice/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1034"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.315-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDADevice): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity"
                 priority="1033"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:playingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1032"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.313-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPlayingEntity): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity"
                 priority="1031"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ENT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ENT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von classCode MUSS 'ENT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@determinerCode) = ('INSTANCE') or not(@determinerCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Wert von determinerCode MUSS 'INSTANCE' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@determinerCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:desc) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:desc) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Element hl7:desc kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:participant[@typeCode][hl7:participantRole]/hl7:participantRole/hl7:scopingEntity/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1030"
                 mode="M125">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16040-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.321-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAParticipantBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16040 EntityCode (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:entryRelationship[@typeCode]"
                 priority="1029"
                 mode="M125">
      <xsl:variable name="elmcount"
                    select="count(hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']] | hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']] | hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']] | hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']] | hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']] | hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']] | hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']] | hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']] | hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.300-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAClinicalStatement): Auswahl (hl7:act[hl7:templateId[@root = '2.16.840.1.113883.10.12.301']]  oder  hl7:encounter[hl7:templateId[@root = '2.16.840.1.113883.10.12.302']]  oder  hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]  oder  hl7:observationMedia[hl7:templateId[@root = '2.16.840.1.113883.10.12.304']]  oder  hl7:organizer[hl7:templateId[@root = '2.16.840.1.113883.10.12.305']]  oder  hl7:procedure[hl7:templateId[@root = '2.16.840.1.113883.10.12.306']]  oder  hl7:regionOfInterest[hl7:templateId[@root = '2.16.840.1.113883.10.12.307']]  oder  hl7:substanceAdministration[hl7:templateId[@root = '2.16.840.1.113883.10.12.308']]  oder  hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.10.12.309']]) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19447-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19447' x_ActRelationshipEntryRelationship (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@inversionInd) or string(@inversionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@inversionInd) or string(@inversionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Attribute @inversionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@inversionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@negationInd) or string(@negationInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@negationInd) or string(@negationInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Attribute @negationInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@negationInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:sequenceNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:sequenceNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]"
                 priority="1027"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@typeCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.19000-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Der Wert von typeCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.19000' x_ActRelationshipExternalReference (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:seperatableInd) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:seperatableInd) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Element hl7:seperatableInd kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:externalAct | hl7:externalObservation | hl7:externalProcedure | hl7:externalDocument)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält nicht genügend Elemente [min 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$elmcount &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$elmcount &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.324-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAReference): Auswahl (hl7:externalAct  oder  hl7:externalObservation  oder  hl7:externalProcedure  oder  hl7:externalDocument) enthält zu viele Elemente [max 1x]</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct"
                 priority="1026"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('ACT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('ACT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von classCode MUSS 'ACT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:id"
                 priority="1025"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1024"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalAct/hl7:text"
                 priority="1023"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.325-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalAct): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation"
                 priority="1022"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:id"
                 priority="1021"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1020"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalObservation/hl7:text"
                 priority="1019"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.326-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalObservation): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure"
                 priority="1018"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('PROC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('PROC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von classCode MUSS 'PROC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:id"
                 priority="1017"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1016"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalProcedure/hl7:text"
                 priority="1015"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.327-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalProcedure): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument"
                 priority="1014"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOC') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOC') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von classCode MUSS 'DOC' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Wert von moodCode MUSS 'EVN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:setId) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:setId) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:setId kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:versionNumber) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:versionNumber) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Element hl7:versionNumber kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:id"
                 priority="1013"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:code[@codeSystem = '2.16.840.1.113883.6.1' or @nullFlavor]"
                 priority="1012"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.6.1')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.6.1'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:text"
                 priority="1011"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:setId"
                 priority="1010"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:reference[@typeCode]/hl7:externalDocument/hl7:versionNumber"
                 priority="1009"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-INT: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:uncertainty)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_INT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-INT: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='INT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:INT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^-?[1-9]\d*$|^+?\d*$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.328-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAExternalDocument): @value ist keine gültige INT Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]"
                 priority="1008"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('PRCN') or not(@typeCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('PRCN') or not(@typeCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von typeCode MUSS 'PRCN' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:criterion) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:criterion) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:criterion kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion"
                 priority="1007"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:precondition[hl7:criterion]/hl7:criterion/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1006"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.10.12.329-2005-09-07T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAPrecondition): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6672-false-d13243519e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]"
                 priority="1005"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@typeCode) = ('REFV')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@typeCode) = ('REFV')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von typeCode MUSS 'REFV' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:observationRange) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:observationRange) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:observationRange ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:observationRange) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:observationRange) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:observationRange kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6676-false-d13243540e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange"
                 priority="1004"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@moodCode) = ('EVN.CRT') or not(@moodCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Wert von moodCode MUSS 'EVN.CRT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@moodCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Element hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6682-false-d13243588e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:code[@codeSystem = '2.16.840.1.113883.5.4' or @nullFlavor]"
                 priority="1003"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.4')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.4'' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6687-false-d13243605e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:text"
                 priority="1002"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6689-false-d13243616e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:value"
                 priority="1001"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

	  <!--RULE d19e6692-false-d13243627e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.6'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:referenceRange[@typeCode = 'REFV'][hl7:observationRange]/hl7:observationRange/hl7:interpretationCode[concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1000"
                 mode="M125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.78-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.6-2018-04-16T121351.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CDAObservationT): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.78 ObservationInterpretation (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M125"/>
   <xsl:template match="@*|node()" priority="-2" mode="M125">
      <xsl:apply-templates select="*" mode="M125"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139ASIC Horowitz Quotient-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC Horowitz Quotient</svrl:text>

	  <!--RULE d19e6722-false-d13243675e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6731-false-d13243779e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60']"
                 priority="1007"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.60')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.60')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.60' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6736-false-d13243795e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6741-false-d13243811e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6747-false-d13243826e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6749-false-d13243840e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16226 ObservationType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6754-false-d13243862e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6756-false-d13243876e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

	  <!--RULE d19e6761-false-d13243898e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.60'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.60-2018-05-08T170139.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICHorowitzQuotient): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M126"/>
   <xsl:template match="@*|node()" priority="-2" mode="M126">
      <xsl:apply-templates select="*" mode="M126"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233ASIC adjunktiv supportive Maßnahmen-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ASIC adjunktiv supportive Maßnahmen</svrl:text>

	  <!--RULE d19e6765-false-d13243925e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]"
                 priority="1010"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6787-false-d13243950e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']"
                 priority="1009"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.61')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.61')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.61' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6792-false-d13243968e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]"
                 priority="1008"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('DOCSECT') or not(@classCode)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('DOCSECT') or not(@classCode)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von classCode MUSS 'DOCSECT' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.201']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.201'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:id) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:id) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:id kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:title) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:title) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:title kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6796-false-d13244045e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55']"
                 priority="1007"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.55')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.55')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.55' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6801-false-d13244061e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10']"
                 priority="1006"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.10')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.10' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6806-false-d13244077e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.201']"
                 priority="1005"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.201')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.201')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Der Wert von root MUSS '2.16.840.1.113883.10.12.201' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6811-false-d13244092e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:id"
                 priority="1004"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6814-false-d13244103e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:code"
                 priority="1003"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CE: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6816-false-d13244114e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:title"
                 priority="1002"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:reference)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:reference)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ST: no reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:thumbnail)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ST: no thumbnail</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@representation) or @representation='TXT'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@representation) or @representation='TXT'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ST: @representation SHALL be 'TXT' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@mediaType) or @mediaType='text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@mediaType) or @mediaType='text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ST: @mediaType SHALL be 'text/plain' if present.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ST: @compression SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ST: @integrityCheck SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ST</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ST: @integrityCheckAlgorithm SHALL NOT be used on ST.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ST' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ST" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6818-false-d13244125e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:text"
                 priority="1001"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='SD.TEXT' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:SD.TEXT" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

	  <!--RULE d19e6820-false-d13244136e0-->
   <xsl:template match="*[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.61']]/hl7:section[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.55'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.10'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.201']]/hl7:entry[@typeCode]"
                 priority="1000"
                 mode="M127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@typeCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@typeCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Attribut @typeCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@typeCode) or (string-length(@typeCode) &gt; 0 and not(matches(@typeCode,'\s')))">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Attribute @typeCode MUSS vom Datentyp 'cs' sein  - '<xsl:text/>
                  <xsl:value-of select="@typeCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@contextConductionInd) or string(@contextConductionInd)=('true','false')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.61-2018-05-14T143233.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ASICadjunktivSupportiveMassnahmen): Attribute @contextConductionInd MUSS vom Datentyp 'bl' sein  - '<xsl:text/>
                  <xsl:value-of select="@contextConductionInd"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M127"/>
   <xsl:template match="@*|node()" priority="-2" mode="M127">
      <xsl:apply-templates select="*" mode="M127"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422Template Messwerte: Adipositas-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Template Messwerte: Adipositas</svrl:text>

	  <!--RULE d19e6847-false-d13244176e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1007"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

	  <!--RULE d19e6856-false-d13244269e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

	  <!--RULE d19e6861-false-d13244285e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

	  <!--RULE d19e6866-false-d13244300e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

	  <!--RULE d19e6869-false-d13244314e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code[@codeSystem = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/completeCodeSystem/@codeSystem or concat(@code, @codeSystem) = doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1]/conceptList/concept/concat(@code, @codeSystem) or @nullFlavor]"
                 priority="1003"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.16226-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem] | completeCodeSystem[@codeSystem=$theCodeSystem]])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.16226 ObservationType (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

	  <!--RULE d19e6874-false-d13244336e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

	  <!--RULE d19e6876-false-d13244350e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

	  <!--RULE d19e6881-false-d13244372e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.7-2018-04-18T105422.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswerteAdipositas): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M128"/>
   <xsl:template match="@*|node()" priority="-2" mode="M128">
      <xsl:apply-templates select="*" mode="M128"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721Messwert: Harnstoff-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: Harnstoff</svrl:text>

	  <!--RULE d19e6905-false-d13244415e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:statusCode kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6914-false-d13244513e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8']"
                 priority="1007"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.8')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.8')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.8' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6919-false-d13244529e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6924-false-d13244545e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6930-false-d13244560e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6932-false-d13244571e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1003"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6934-false-d13244582e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6936-false-d13244593e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode"
                 priority="1001"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

	  <!--RULE d19e6938-false-d13244604e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.8'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.8-2018-04-18T105721.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertHarnstoff): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M129"/>
   <xsl:template match="@*|node()" priority="-2" mode="M129">
      <xsl:apply-templates select="*" mode="M129"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812Messwert: Kreatinin-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Messwert: Kreatinin</svrl:text>

	  <!--RULE d19e6962-false-d13244647e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]"
                 priority="1008"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@classCode) = ('OBS')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@classCode) = ('OBS')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Der Wert von classCode MUSS 'OBS' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@classCode"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@moodCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@moodCode">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Attribut @moodCode MUSS vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theAttValue"
                    select="distinct-values(tokenize(normalize-space(@moodCode),'\s'))"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@moodCode) or empty($theAttValue[not(. = (doc('include/voc-2.16.840.1.113883.1.11.18943-DYNAMIC.xml')/*/valueSet/conceptList/concept/@code))])">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Der Wert von moodCode MUSS gewählt werden aus Value Set '2.16.840.1.113883.1.11.18943' x_ActMoodDocumentObservation (DYNAMIC).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] ist mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:templateId[@root = '2.16.840.1.113883.10.12.303']) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:templateId[@root = '2.16.840.1.113883.10.12.303'] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &gt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:code ist required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:code) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:code) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:code kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:text) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:text) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:text kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor] kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7:value) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7:value) &lt;= 1">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Element hl7:value kommt zu häufig vor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6971-false-d13244748e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9']"
                 priority="1007"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.9')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.9')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.9' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6976-false-d13244764e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7']"
                 priority="1006"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.3.1937.99.61.45.10.7')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Der Wert von root MUSS '2.16.840.1.113883.3.1937.99.61.45.10.7' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6981-false-d13244780e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:templateId[@root = '2.16.840.1.113883.10.12.303']"
                 priority="1005"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@root) = ('2.16.840.1.113883.10.12.303')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@root) = ('2.16.840.1.113883.10.12.303')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Der Wert von root MUSS '2.16.840.1.113883.10.12.303' sein. Gefunden: "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6987-false-d13244795e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:id"
                 priority="1004"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (not(@nullFlavor) and @root)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-II: @root is required if @nullFlavor is not present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (@nullFlavor and not(@root))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-II: @root may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @identifierName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @identifierName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-II: @identifierName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayable)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayable)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-II: @displayable may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @reliability)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @reliability)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-II: @reliability may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @assigningAuthorityName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @assigningAuthorityName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-II: @assigningAuthorityName may not be used if @nullFlavor is present</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@root) &lt;= 128)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@root) &lt;= 128)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-8-II: @root should not be longer than 128 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@root)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
      <xsl:if test="not(string-length(@extension) &lt;= 64)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string-length(@extension) &lt;= 64)">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-9-II: @extension should not be longer than 64 characters. Found <xsl:text/>
               <xsl:value-of select="string-length(@extension)"/>
               <xsl:text/> characters. Please write a note to the authors of this rule if this is found to be not sufficient</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="OIDpattern" select="'^[0-2](\.(0|[1-9]\d*))*$'"/>
      <xsl:variable name="RUIDpattern" select="'^[A-Za-z][A-Za-z\d\-]*$'"/>
      <xsl:variable name="UUIDpattern"
                    select="'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@root) or matches(@root, $OIDpattern) or matches(@root, $UUIDpattern)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-II: @root SHALL be a syntactically correct OID or UUID.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $RUIDpattern) and not(matches(@root, $UUIDpattern)))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10a-II: @root SHALL NOT be a RUID. Identifiers in this scheme are only defined by balloted HL7 specifications. Local communities or systems must never use such reserved identifiers based on bilateral negotiations.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="root" select="@root"/>
      <xsl:variable name="extension" select="@extension"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@root=$root][empty($extension)] or $set_other[@root=$root][@extension=$extension])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-II: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT info-->
      <xsl:choose>
         <xsl:when test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(matches(@root, $UUIDpattern) and matches(@root, '[a-z]'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_II</xsl:attribute>
               <xsl:attribute name="role">info</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-II: Lower case UUID "<xsl:text/>
                  <xsl:value-of select="@root"/>
                  <xsl:text/>" found in @root. UUIDs SHALL, under official HL7 V3 Datatypes Release 1 (and 2) rules, have upper case hexadecimal digits A-F. RFC 4122 and HL7 FHIR state lower case UUID display.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6989-false-d13244806e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:code"
                 priority="1003"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CD: null or code and/or originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CD: code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CD: codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@codeSystem or not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CD: codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@code or not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CD: displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @code)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CD: co-occurence violation. Cannot have code and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CD: co-occurence violation. Cannot have displayName and null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-CD: no null on translations (Exceptional values (NULL-values) can not be elements of a set.)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystem][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystem][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-CD: translation code requires codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemName][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-CD: translation codeSystemName only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@codeSystemVersion][not(@codeSystem)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-CD: translation codeSystemVersion only if codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:translation[@displayName][not(@code)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:translation[@displayName][not(@code)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-CD: translation displayName only if code</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="matches(@displayName,'[\r\n\t]')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="matches(@displayName,'[\r\n\t]')">
            <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to interoperability problems.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>
      <xsl:variable name="code" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@code=$code][@codeSystem=$codeSystem])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@code=$code][@codeSystem=$codeSystem])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-CD: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@code=<xsl:text/>
                  <xsl:value-of select="$code"/>
                  <xsl:text/> @codeSystem=<xsl:text/>
                  <xsl:value-of select="$codeSystem"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-19-CD: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(.//hl7:originalText[@language and not(matches(@language,$RFC3066,'i'))])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CD</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-20-CD: originalText/@language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CD" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6991-false-d13244817e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:text"
                 priority="1002"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor | * | text()[string-length(normalize-space()) gt 0]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_BIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-BIN: there must be a nullFlavor, or content must be non-empty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@integrityCheck) or @integrityCheckAlgorithm">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-ED: thumbnails not null and reference</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-ED: thumbnails do not have thumbnails</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-ED: compression only on binary</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-ED: value implies mediaType is text/plain</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-ED: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value or xml) or not(@charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-ED: no charset for value or xml</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-9-ED: no nested translations</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @mediaType) or @mediaType = 'text/plain'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-10-ED: no mediaType if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @charset)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @charset)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-11-ED: no charset if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @language)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @language)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-12-ED: no language if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @compression)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @compression)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-13-ED: no compression if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheck)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheck)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-14-ED: no integrityCheck if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and @integrityCheckAlgorithm) or @integrityCheckAlgorithm = 'SHA-1'">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-15-ED: no integrityCheckAlgorithm if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-16-ED: no thumbnail if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-17-ED: no translation if null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="RFC3066" select="'^[a-z]{2,3}(-[a-z]{2})?|[ix](-[a-z\d]{2,8})+$'"/>
      <xsl:variable name="RFC3066restricted" select="'^[a-z]{2,3}(-[a-z]{2})?$'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@language) or matches(@language,$RFC3066,'i')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@language) or matches(@language,$RFC3066,'i')">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ED</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-18-ED: @language SHALL conform to RFC 3066. This usually has format sss?-CC with sss? for language code (ISO-639-1 / ISO-639-2) and optional CC for country code (conform ISO-3166 alpha-2)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ED' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ED" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6993-false-d13244831e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:statusCode[@code = doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/*/@code or @nullFlavor]"
                 priority="1001"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystem)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-CS: cannot have codeSystem</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-CS: cannot have codeSystemName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@codeSystemVersion)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-CS: cannot have codeSystemVersion</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@displayName)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-5-CS: cannot have displayName</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-6-CS: cannot have originalText</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:qualifier)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-7-CS: cannot have qualifier</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(hl7:translation)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_CS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-8-CS: cannot have translation</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CS" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.15933-DYNAMIC.xml')//valueSet[1]/conceptList/concept[@code = $theCode] or completeCodeSystem)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.15933 ActStatus (DYNAMIC)' sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>

	  <!--RULE d19e6998-false-d13244853e0-->
   <xsl:template match="*[hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]]/hl7:observation[hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.9'] and hl7:templateId[@root = '2.16.840.1.113883.3.1937.99.61.45.10.7'] and hl7:templateId[@root = '2.16.840.1.113883.10.12.303']]/hl7:value"
                 priority="1000"
                 mode="M130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::*[             not(@nullFlavor) or             (@nullFlavor                        and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or             (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation))         ]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::*[ not(@nullFlavor) or (@nullFlavor and not(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true']) | * | text()[string-length(normalize-space()) gt 0])) or (@nullFlavor = ('OTH', 'NA', 'UNC') and not(@* except (@xsi:type|@xsi:nil|@*:valueSet|@*:valueSetVersion|@codeSystem|@extension|@nullFlavor|@partType|@integrityCheckAlgorithm[. = 'SHA-1']|@mediaType[. = 'text/plain']|@operator[. = 'I']|@representation[. = 'TXT']|@inclusive[. = 'true'])) and (@extension | @codeSystem | hl7:originalText | hl7:translation)) ]">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_ANY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-ANY: if there is a nullFlavor, there shall be no text or other attribute or element, unless it's nullFlavor='OTH' or 'NA' (@codeSystem, &lt;originalText&gt; or &lt;translation&gt; may have a value), or nullFlavor 'UNC' (@extension or &lt;originalText&gt; may have a value)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-QTY: no uncertainty</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-2-QTY: no history or updateMode</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="name" select="local-name()"/>
      <xsl:variable name="set_other"
                    select="preceding-sibling::*[local-name()=$name] | following-sibling::*[local-name()=$name]"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor and $set_other[not(@nullFlavor)])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor and $set_other[not(@nullFlavor)])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-QTY: [RIM-001] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> SHALL NOT have nullFlavor, if there are other <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> elements which are not null</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="value" select="@value"/>
      <xsl:variable name="unit" select="@unit"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not($set_other[@value=$value][@unit=$unit])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($set_other[@value=$value][@unit=$unit])">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_QTY</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-4-QTY: [RIM-002] <xsl:text/>
                  <xsl:value-of select="$name"/>
                  <xsl:text/> (@value=<xsl:text/>
                  <xsl:value-of select="$value"/>
                  <xsl:text/> @unit=<xsl:text/>
                  <xsl:value-of select="$unit"/>
                  <xsl:text/>) SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(@nullFlavor or @value or *) and not(@nullFlavor and @value)">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-1-PQ: null or value or child element in case of extension</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="translations"
                    select=".//hl7:translation/concat(@value,@code,@codeSystem)"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="count($translations)=count(distinct-values($translations))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count($translations)=count(distinct-values($translations))">
               <xsl:attribute name="see">https://art-decor.org/mediawiki/index.php?title=DTr1_PQ</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>dtr1-3-PQ: [RIM-002] translations SHALL be distinct</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PQ' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PQ" haben, gefunden "{<xsl:text/>
                  <xsl:value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>}:<xsl:text/>
                  <xsl:value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@value) or matches(@value, '^[-+]?\d*\.?[0-9]+([eE][-+]?\d+)?$')">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): @value ist keine gültige PQ Zahl <xsl:text/>
                  <xsl:value-of select="@value"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="doc('include/voc-UCUM.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$UCUMtest='OK' or string-length($UCUMtest)=0">
               <xsl:attribute name="see">http://pub.art-decor.org/smul/smul-html-20180821T095010/tmp-2.16.840.1.113883.3.1937.99.61.45.10.9-2018-04-18T105812.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MesswertKreatinin): value/@unit (PQ) MUSS eine gültige UCUM-Einheit sein (<xsl:text/>
                  <xsl:value-of select="$UCUMtest"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M130"/>
   <xsl:template match="@*|node()" priority="-2" mode="M130">
      <xsl:apply-templates select="*" mode="M130"/>
   </xsl:template>
</xsl:stylesheet>
